Interface CasedevClient
-
- All Implemented Interfaces:
public interface CasedevClientA client for interacting with the Casedev REST API synchronously. You can also switch to asynchronous execution via the async method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCasedevClient.WithRawResponseA view of CasedevClient that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CasedevClientAsyncasync()Returns a version of this client that uses asynchronous execution. abstract CasedevClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CasedevClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentServiceagent()abstract SystemServicesystem()Public system metadata and discovery endpoints abstract ApplicationServiceapplications()abstract ComputeServicecompute()abstract DatabaseServicedatabase()abstract FormatServiceformat()abstract LegalServicelegal()abstract LlmServicellm()Access 40+ language models through a unified API abstract MemoryServicememory()abstract OcrServiceocr()abstract PrivilegeServiceprivilege()abstract SkillServiceskills()Search and read legal AI skills for agents abstract SearchServicesearch()abstract SuperdocServicesuperdoc()abstract TranslateServicetranslate()abstract VaultServicevault()Secure document storage with semantic search and GraphRAG abstract VoiceServicevoice()abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
async
abstract CasedevClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract CasedevClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CasedevClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agent
abstract AgentService agent()
-
system
abstract SystemService system()
Public system metadata and discovery endpoints
-
applications
abstract ApplicationService applications()
-
compute
abstract ComputeService compute()
-
database
abstract DatabaseService database()
-
format
abstract FormatService format()
-
legal
abstract LegalService legal()
-
llm
abstract LlmService llm()
Access 40+ language models through a unified API
-
memory
abstract MemoryService memory()
-
ocr
abstract OcrService ocr()
-
privilege
abstract PrivilegeService privilege()
-
skills
abstract SkillService skills()
Search and read legal AI skills for agents
-
search
abstract SearchService search()
-
superdoc
abstract SuperdocService superdoc()
-
translate
abstract TranslateService translate()
-
vault
abstract VaultService vault()
Secure document storage with semantic search and GraphRAG
-
voice
abstract VoiceService voice()
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-