Interface CasedevClientAsync
-
- All Implemented Interfaces:
public interface CasedevClientAsyncA client for interacting with the Casedev REST API asynchronously. You can also switch to synchronous execution via the sync method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCasedevClientAsync.WithRawResponseA view of CasedevClientAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CasedevClientsync()Returns a version of this client that uses synchronous execution. abstract CasedevClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CasedevClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentServiceAsyncagent()abstract SystemServiceAsyncsystem()Public system metadata and discovery endpoints abstract ApplicationServiceAsyncapplications()abstract ComputeServiceAsynccompute()abstract DatabaseServiceAsyncdatabase()abstract FormatServiceAsyncformat()abstract LegalServiceAsynclegal()abstract LlmServiceAsyncllm()Access 40+ language models through a unified API abstract MemoryServiceAsyncmemory()abstract OcrServiceAsyncocr()abstract PrivilegeServiceAsyncprivilege()abstract SkillServiceAsyncskills()Search and read legal AI skills for agents abstract SearchServiceAsyncsearch()abstract SuperdocServiceAsyncsuperdoc()abstract TranslateServiceAsynctranslate()abstract VaultServiceAsyncvault()Secure document storage with semantic search and GraphRAG abstract VoiceServiceAsyncvoice()abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
sync
abstract CasedevClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract CasedevClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CasedevClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agent
abstract AgentServiceAsync agent()
-
system
abstract SystemServiceAsync system()
Public system metadata and discovery endpoints
-
applications
abstract ApplicationServiceAsync applications()
-
compute
abstract ComputeServiceAsync compute()
-
database
abstract DatabaseServiceAsync database()
-
format
abstract FormatServiceAsync format()
-
legal
abstract LegalServiceAsync legal()
-
llm
abstract LlmServiceAsync llm()
Access 40+ language models through a unified API
-
memory
abstract MemoryServiceAsync memory()
-
ocr
abstract OcrServiceAsync ocr()
-
privilege
abstract PrivilegeServiceAsync privilege()
-
skills
abstract SkillServiceAsync skills()
Search and read legal AI skills for agents
-
search
abstract SearchServiceAsync search()
-
superdoc
abstract SuperdocServiceAsync superdoc()
-
translate
abstract TranslateServiceAsync translate()
-
vault
abstract VaultServiceAsync vault()
Secure document storage with semantic search and GraphRAG
-
voice
abstract VoiceServiceAsync voice()
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-