Class CasedevClientAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.client.CasedevClientAsync
public final class CasedevClientAsyncImpl implements CasedevClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCasedevClientAsyncImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description CasedevClientAsyncImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description CasedevClientsync()Returns a version of this client that uses synchronous execution. CasedevClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CasedevClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentServiceAsyncagent()SystemServiceAsyncsystem()Public system metadata and discovery endpoints ComputeServiceAsynccompute()DatabaseServiceAsyncdatabase()FormatServiceAsyncformat()LegalServiceAsynclegal()MatterServiceAsyncmatters()LlmServiceAsyncllm()Access 40+ language models through a unified API MemoryServiceAsyncmemory()OcrServiceAsyncocr()PrivilegeServiceAsyncprivilege()MailServiceAsyncmail()SkillServiceAsyncskills()Search and read legal AI skills for agents SearchServiceAsyncsearch()SuperdocServiceAsyncsuperdoc()TranslateServiceAsynctranslate()UsageServiceAsyncusage()VaultServiceAsyncvault()Secure document storage with semantic search and GraphRAG VoiceServiceAsyncvoice()WebhookServiceAsyncwebhooks()Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
CasedevClientAsyncImpl
CasedevClientAsyncImpl(ClientOptions clientOptions)
-
-
Method Detail
-
sync
CasedevClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
CasedevClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CasedevClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agent
AgentServiceAsync agent()
-
system
SystemServiceAsync system()
Public system metadata and discovery endpoints
-
compute
ComputeServiceAsync compute()
-
database
DatabaseServiceAsync database()
-
format
FormatServiceAsync format()
-
legal
LegalServiceAsync legal()
-
matters
MatterServiceAsync matters()
-
llm
LlmServiceAsync llm()
Access 40+ language models through a unified API
-
memory
MemoryServiceAsync memory()
-
ocr
OcrServiceAsync ocr()
-
privilege
PrivilegeServiceAsync privilege()
-
mail
MailServiceAsync mail()
-
skills
SkillServiceAsync skills()
Search and read legal AI skills for agents
-
search
SearchServiceAsync search()
-
superdoc
SuperdocServiceAsync superdoc()
-
translate
TranslateServiceAsync translate()
-
usage
UsageServiceAsync usage()
-
vault
VaultServiceAsync vault()
Secure document storage with semantic search and GraphRAG
-
voice
VoiceServiceAsync voice()
-
webhooks
WebhookServiceAsync webhooks()
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-