Class CasedevClientImpl
-
- All Implemented Interfaces:
-
dev.case.api.client.CasedevClient
public final class CasedevClientImpl implements CasedevClient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCasedevClientImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description CasedevClientImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description CasedevClientAsyncasync()Returns a version of this client that uses asynchronous execution. CasedevClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CasedevClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentServiceagent()SystemServicesystem()Public system metadata and discovery endpoints ApplicationServiceapplications()ComputeServicecompute()DatabaseServicedatabase()FormatServiceformat()LegalServicelegal()LlmServicellm()Access 40+ language models through a unified API MemoryServicememory()OcrServiceocr()PrivilegeServiceprivilege()MailServicemail()SkillServiceskills()Search and read legal AI skills for agents SearchServicesearch()SuperdocServicesuperdoc()TranslateServicetranslate()VaultServicevault()Secure document storage with semantic search and GraphRAG VoiceServicevoice()Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
CasedevClientImpl
CasedevClientImpl(ClientOptions clientOptions)
-
-
Method Detail
-
async
CasedevClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
CasedevClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CasedevClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agent
AgentService agent()
-
system
SystemService system()
Public system metadata and discovery endpoints
-
applications
ApplicationService applications()
-
compute
ComputeService compute()
-
database
DatabaseService database()
-
format
FormatService format()
-
legal
LegalService legal()
-
llm
LlmService llm()
Access 40+ language models through a unified API
-
memory
MemoryService memory()
-
ocr
OcrService ocr()
-
privilege
PrivilegeService privilege()
-
mail
MailService mail()
-
skills
SkillService skills()
Search and read legal AI skills for agents
-
search
SearchService search()
-
superdoc
SuperdocService superdoc()
-
translate
TranslateService translate()
-
vault
VaultService vault()
Secure document storage with semantic search and GraphRAG
-
voice
VoiceService voice()
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-