Package dev.case.api.client.okhttp
Class CasedevOkHttpClient
-
- All Implemented Interfaces:
public final class CasedevOkHttpClientA class that allows building an instance of CasedevClient with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCasedevOkHttpClient.BuilderA builder for CasedevOkHttpClient.
-
Method Summary
Modifier and Type Method Description final static CasedevOkHttpClient.Builderbuilder()Returns a mutable builder for constructing an instance of CasedevClient. final static CasedevClientfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static CasedevOkHttpClient.Builder builder()
Returns a mutable builder for constructing an instance of CasedevClient.
-
fromEnv
final static CasedevClient fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-