Package dev.case.api.client.okhttp
Class CasedevOkHttpClientAsync
-
- All Implemented Interfaces:
public final class CasedevOkHttpClientAsyncA class that allows building an instance of CasedevClientAsync with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCasedevOkHttpClientAsync.BuilderA builder for CasedevOkHttpClientAsync.
-
Method Summary
Modifier and Type Method Description final static CasedevOkHttpClientAsync.Builderbuilder()Returns a mutable builder for constructing an instance of CasedevClientAsync. final static CasedevClientAsyncfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static CasedevOkHttpClientAsync.Builder builder()
Returns a mutable builder for constructing an instance of CasedevClientAsync.
-
fromEnv
final static CasedevClientAsync fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-