Package dev.case.api.client.okhttp
See: Description
-
Class Summary Class Description Builder A builder for CasedevOkHttpClient. CasedevOkHttpClient A class that allows building an instance of CasedevClient with OkHttpClient as the underlying HttpClient. Builder A builder for CasedevOkHttpClientAsync. CasedevOkHttpClientAsync A class that allows building an instance of CasedevClientAsync with OkHttpClient as the underlying HttpClient. Builder OkHttpClient