Package dev.case.api.client
See: Description
-
Interface Summary Interface Description WithRawResponse A view of CasedevClient that provides access to raw HTTP responses for each method. CasedevClient A client for interacting with the Casedev REST API synchronously. WithRawResponse A view of CasedevClientAsync that provides access to raw HTTP responses for each method. CasedevClientAsync A client for interacting with the Casedev REST API asynchronously. -
Class Summary Class Description WithRawResponseImpl CasedevClientAsyncImpl WithRawResponseImpl CasedevClientImpl