Class NamespaceCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class NamespaceCreateParams implements Params
Create a private skill namespace owned by the authenticated org and receive a one-time bearer token used by the case-skills publisher.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNamespaceCreateParams.BuilderA builder for NamespaceCreateParams.
public final classNamespaceCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringnamespaceId()URL-safe slug, e.g. final Optional<String>description()final Optional<String>label()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = namespaceCreateParams.metadata().convert(MyClass.class);final JsonField<String>_namespaceId()Returns the raw JSON value of namespaceId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_label()Returns the raw JSON value of label. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final NamespaceCreateParams.BuildertoBuilder()final NamespaceCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static NamespaceCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of NamespaceCreateParams. -
-
Method Detail
-
namespaceId
final String namespaceId()
URL-safe slug, e.g. "curi" or "client-firm-abc". Lowercase alphanumeric with single hyphens, 2-64 chars.
-
description
final Optional<String> description()
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = namespaceCreateParams.metadata().convert(MyClass.class);
-
_namespaceId
final JsonField<String> _namespaceId()
Returns the raw JSON value of namespaceId.
Unlike namespaceId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_label
final JsonField<String> _label()
Returns the raw JSON value of label.
Unlike label, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final NamespaceCreateParams.Builder toBuilder()
-
_body
final NamespaceCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static NamespaceCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of NamespaceCreateParams.
The following fields are required:
.namespaceId()
-
-
-
-