Class NamespaceCreateParams.Body
-
- All Implemented Interfaces:
public final class NamespaceCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNamespaceCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringnamespaceId()URL-safe slug, e.g. final Optional<String>description()final Optional<String>label()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);final JsonField<String>_namespaceId()Returns the raw JSON value of namespaceId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_label()Returns the raw JSON value of label. final Map<String, JsonValue>_additionalProperties()final NamespaceCreateParams.Body.BuildertoBuilder()final NamespaceCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NamespaceCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
namespaceId
final String namespaceId()
URL-safe slug, e.g. "curi" or "client-firm-abc". Lowercase alphanumeric with single hyphens, 2-64 chars.
-
description
final Optional<String> description()
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);
-
_namespaceId
final JsonField<String> _namespaceId()
Returns the raw JSON value of namespaceId.
Unlike namespaceId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_label
final JsonField<String> _label()
Returns the raw JSON value of label.
Unlike label, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final NamespaceCreateParams.Body.Builder toBuilder()
-
validate
final NamespaceCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static NamespaceCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.namespaceId()
-
-
-
-