Class NamespacePublishParams.File
-
- All Implemented Interfaces:
public final class NamespacePublishParams.File
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNamespacePublishParams.File.BuilderA builder for File.
public final classNamespacePublishParams.File.Encoding
-
Method Summary
Modifier and Type Method Description final Stringcontent()final NamespacePublishParams.File.Encodingencoding()final Stringpath()final Optional<String>contentType()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<NamespacePublishParams.File.Encoding>_encoding()Returns the raw JSON value of encoding. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<String>_contentType()Returns the raw JSON value of contentType. final Map<String, JsonValue>_additionalProperties()final NamespacePublishParams.File.BuildertoBuilder()final NamespacePublishParams.Filevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NamespacePublishParams.File.Builderbuilder()Returns a mutable builder for constructing an instance of File. -
-
Method Detail
-
encoding
final NamespacePublishParams.File.Encoding encoding()
-
contentType
final Optional<String> contentType()
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_encoding
final JsonField<NamespacePublishParams.File.Encoding> _encoding()
Returns the raw JSON value of encoding.
Unlike encoding, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final NamespacePublishParams.File.Builder toBuilder()
-
validate
final NamespacePublishParams.File validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static NamespacePublishParams.File.Builder builder()
Returns a mutable builder for constructing an instance of File.
The following fields are required:
.content() .encoding() .path()
-
-
-
-