Class AgentCreateParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class AgentCreateParams
     implements Params
                        

    Creates a new agent definition with a scoped API key. The agent can then be used to create and execute runs.