Class AgentCreateParams.Body
-
- All Implemented Interfaces:
public final class AgentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringinstructions()System instructions that define agent behavior final Stringname()Display name for the agent final Optional<String>description()Optional description of the agent final Optional<List<String>>disabledTools()Denylist of tools the agent cannot use. final Optional<List<String>>enabledTools()Allowlist of tools the agent can use. final Optional<String>model()LLM model identifier (e.g. final Optional<AgentCreateParams.Sandbox>sandbox()Custom sandbox configuration (cpu, memoryMiB) final Optional<List<String>>vaultGroups()Restrict agent to vaults within specific vault group IDs final Optional<List<String>>vaultIds()Restrict agent to specific vault IDs final JsonField<String>_instructions()Returns the raw JSON value of instructions. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<String>>_disabledTools()Returns the raw JSON value of disabledTools. final JsonField<List<String>>_enabledTools()Returns the raw JSON value of enabledTools. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<AgentCreateParams.Sandbox>_sandbox()Returns the raw JSON value of sandbox. final JsonField<List<String>>_vaultGroups()Returns the raw JSON value of vaultGroups. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final AgentCreateParams.Body.BuildertoBuilder()final AgentCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
instructions
final String instructions()
System instructions that define agent behavior
-
description
final Optional<String> description()
Optional description of the agent
-
disabledTools
final Optional<List<String>> disabledTools()
Denylist of tools the agent cannot use. Mutually exclusive with enabledTools — set one or the other, not both.
-
enabledTools
final Optional<List<String>> enabledTools()
Allowlist of tools the agent can use. Mutually exclusive with disabledTools — set one or the other, not both.
-
model
final Optional<String> model()
LLM model identifier (e.g. anthropic/claude-sonnet-4.6). Defaults to anthropic/claude-sonnet-4.6
-
sandbox
final Optional<AgentCreateParams.Sandbox> sandbox()
Custom sandbox configuration (cpu, memoryMiB)
-
vaultGroups
final Optional<List<String>> vaultGroups()
Restrict agent to vaults within specific vault group IDs
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_disabledTools
final JsonField<List<String>> _disabledTools()
Returns the raw JSON value of disabledTools.
Unlike disabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_enabledTools
final JsonField<List<String>> _enabledTools()
Returns the raw JSON value of enabledTools.
Unlike enabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_sandbox
final JsonField<AgentCreateParams.Sandbox> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultGroups
final JsonField<List<String>> _vaultGroups()
Returns the raw JSON value of vaultGroups.
Unlike vaultGroups, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentCreateParams.Body.Builder toBuilder()
-
validate
final AgentCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AgentCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.instructions() .name()
-
-
-
-