Class AgentCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AgentCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
instructions
final AgentCreateParams.Body.Builder instructions(String instructions)
System instructions that define agent behavior
-
instructions
final AgentCreateParams.Body.Builder instructions(JsonField<String> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AgentCreateParams.Body.Builder name(String name)
Display name for the agent
-
name
final AgentCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final AgentCreateParams.Body.Builder description(String description)
Optional description of the agent
-
description
final AgentCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disabledTools
final AgentCreateParams.Body.Builder disabledTools(List<String> disabledTools)
Denylist of tools the agent cannot use. Mutually exclusive with enabledTools — set one or the other, not both.
-
disabledTools
final AgentCreateParams.Body.Builder disabledTools(Optional<List<String>> disabledTools)
Alias for calling Builder.disabledTools with
disabledTools.orElse(null).
-
disabledTools
final AgentCreateParams.Body.Builder disabledTools(JsonField<List<String>> disabledTools)
Sets Builder.disabledTools to an arbitrary JSON value.
You should usually call Builder.disabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDisabledTool
final AgentCreateParams.Body.Builder addDisabledTool(String disabledTool)
Adds a single String to disabledTools.
-
enabledTools
final AgentCreateParams.Body.Builder enabledTools(List<String> enabledTools)
Allowlist of tools the agent can use. Mutually exclusive with disabledTools — set one or the other, not both.
-
enabledTools
final AgentCreateParams.Body.Builder enabledTools(Optional<List<String>> enabledTools)
Alias for calling Builder.enabledTools with
enabledTools.orElse(null).
-
enabledTools
final AgentCreateParams.Body.Builder enabledTools(JsonField<List<String>> enabledTools)
Sets Builder.enabledTools to an arbitrary JSON value.
You should usually call Builder.enabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEnabledTool
final AgentCreateParams.Body.Builder addEnabledTool(String enabledTool)
Adds a single String to enabledTools.
-
model
final AgentCreateParams.Body.Builder model(String model)
LLM model identifier (e.g. anthropic/claude-sonnet-4.6). Defaults to anthropic/claude-sonnet-4.6
-
model
final AgentCreateParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sandbox
final AgentCreateParams.Body.Builder sandbox(AgentCreateParams.Sandbox sandbox)
Custom sandbox configuration (cpu, memoryMiB)
-
sandbox
final AgentCreateParams.Body.Builder sandbox(Optional<AgentCreateParams.Sandbox> sandbox)
Alias for calling Builder.sandbox with
sandbox.orElse(null).
-
sandbox
final AgentCreateParams.Body.Builder sandbox(JsonField<AgentCreateParams.Sandbox> sandbox)
Sets Builder.sandbox to an arbitrary JSON value.
You should usually call Builder.sandbox with a well-typed Sandbox value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultGroups
final AgentCreateParams.Body.Builder vaultGroups(List<String> vaultGroups)
Restrict agent to vaults within specific vault group IDs
-
vaultGroups
final AgentCreateParams.Body.Builder vaultGroups(Optional<List<String>> vaultGroups)
Alias for calling Builder.vaultGroups with
vaultGroups.orElse(null).
-
vaultGroups
final AgentCreateParams.Body.Builder vaultGroups(JsonField<List<String>> vaultGroups)
Sets Builder.vaultGroups to an arbitrary JSON value.
You should usually call Builder.vaultGroups with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultGroup
final AgentCreateParams.Body.Builder addVaultGroup(String vaultGroup)
Adds a single String to vaultGroups.
-
vaultIds
final AgentCreateParams.Body.Builder vaultIds(List<String> vaultIds)
Restrict agent to specific vault IDs
-
vaultIds
final AgentCreateParams.Body.Builder vaultIds(Optional<List<String>> vaultIds)
Alias for calling Builder.vaultIds with
vaultIds.orElse(null).
-
vaultIds
final AgentCreateParams.Body.Builder vaultIds(JsonField<List<String>> vaultIds)
Sets Builder.vaultIds to an arbitrary JSON value.
You should usually call Builder.vaultIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultId
final AgentCreateParams.Body.Builder addVaultId(String vaultId)
-
additionalProperties
final AgentCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AgentCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AgentCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AgentCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AgentCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AgentCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.instructions() .name()
-
-
-
-