Class AgentCreateParams.Builder
-
- All Implemented Interfaces:
public final class AgentCreateParams.BuilderA builder for AgentCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final AgentCreateParams.Builder body(AgentCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
instructions
final AgentCreateParams.Builder instructions(String instructions)
System instructions that define agent behavior
-
instructions
final AgentCreateParams.Builder instructions(JsonField<String> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AgentCreateParams.Builder name(String name)
Display name for the agent
-
name
final AgentCreateParams.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final AgentCreateParams.Builder description(String description)
Optional description of the agent
-
description
final AgentCreateParams.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disabledTools
final AgentCreateParams.Builder disabledTools(List<String> disabledTools)
Denylist of tools the agent cannot use. Mutually exclusive with enabledTools — set one or the other, not both.
-
disabledTools
final AgentCreateParams.Builder disabledTools(Optional<List<String>> disabledTools)
Alias for calling Builder.disabledTools with
disabledTools.orElse(null).
-
disabledTools
final AgentCreateParams.Builder disabledTools(JsonField<List<String>> disabledTools)
Sets Builder.disabledTools to an arbitrary JSON value.
You should usually call Builder.disabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDisabledTool
final AgentCreateParams.Builder addDisabledTool(String disabledTool)
Adds a single String to disabledTools.
-
enabledTools
final AgentCreateParams.Builder enabledTools(List<String> enabledTools)
Allowlist of tools the agent can use. Mutually exclusive with disabledTools — set one or the other, not both.
-
enabledTools
final AgentCreateParams.Builder enabledTools(Optional<List<String>> enabledTools)
Alias for calling Builder.enabledTools with
enabledTools.orElse(null).
-
enabledTools
final AgentCreateParams.Builder enabledTools(JsonField<List<String>> enabledTools)
Sets Builder.enabledTools to an arbitrary JSON value.
You should usually call Builder.enabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEnabledTool
final AgentCreateParams.Builder addEnabledTool(String enabledTool)
Adds a single String to enabledTools.
-
model
final AgentCreateParams.Builder model(String model)
LLM model identifier (e.g. anthropic/claude-sonnet-4.6). Defaults to anthropic/claude-sonnet-4.6
-
model
final AgentCreateParams.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sandbox
final AgentCreateParams.Builder sandbox(AgentCreateParams.Sandbox sandbox)
Custom sandbox configuration (cpu, memoryMiB)
-
sandbox
final AgentCreateParams.Builder sandbox(Optional<AgentCreateParams.Sandbox> sandbox)
Alias for calling Builder.sandbox with
sandbox.orElse(null).
-
sandbox
final AgentCreateParams.Builder sandbox(JsonField<AgentCreateParams.Sandbox> sandbox)
Sets Builder.sandbox to an arbitrary JSON value.
You should usually call Builder.sandbox with a well-typed Sandbox value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultGroups
final AgentCreateParams.Builder vaultGroups(List<String> vaultGroups)
Restrict agent to vaults within specific vault group IDs
-
vaultGroups
final AgentCreateParams.Builder vaultGroups(Optional<List<String>> vaultGroups)
Alias for calling Builder.vaultGroups with
vaultGroups.orElse(null).
-
vaultGroups
final AgentCreateParams.Builder vaultGroups(JsonField<List<String>> vaultGroups)
Sets Builder.vaultGroups to an arbitrary JSON value.
You should usually call Builder.vaultGroups with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultGroup
final AgentCreateParams.Builder addVaultGroup(String vaultGroup)
Adds a single String to vaultGroups.
-
vaultIds
final AgentCreateParams.Builder vaultIds(List<String> vaultIds)
Restrict agent to specific vault IDs
-
vaultIds
final AgentCreateParams.Builder vaultIds(Optional<List<String>> vaultIds)
Alias for calling Builder.vaultIds with
vaultIds.orElse(null).
-
vaultIds
final AgentCreateParams.Builder vaultIds(JsonField<List<String>> vaultIds)
Sets Builder.vaultIds to an arbitrary JSON value.
You should usually call Builder.vaultIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultId
final AgentCreateParams.Builder addVaultId(String vaultId)
-
additionalBodyProperties
final AgentCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final AgentCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final AgentCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final AgentCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final AgentCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final AgentCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final AgentCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final AgentCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final AgentCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final AgentCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final AgentCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final AgentCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final AgentCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final AgentCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final AgentCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final AgentCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final AgentCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final AgentCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final AgentCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final AgentCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final AgentCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final AgentCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final AgentCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final AgentCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final AgentCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final AgentCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final AgentCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final AgentCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final AgentCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final AgentCreateParams build()
Returns an immutable instance of AgentCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.instructions() .name()
-
-
-
-