Class AgentCreateParams.Sandbox
-
- All Implemented Interfaces:
public final class AgentCreateParams.SandboxCustom sandbox configuration (cpu, memoryMiB)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentCreateParams.Sandbox.BuilderA builder for Sandbox.
-
Method Summary
Modifier and Type Method Description final Optional<Long>cpu()Number of CPUs final Optional<Long>memoryMiB()Memory in MiB final JsonField<Long>_cpu()Returns the raw JSON value of cpu. final JsonField<Long>_memoryMiB()Returns the raw JSON value of memoryMiB. final Map<String, JsonValue>_additionalProperties()final AgentCreateParams.Sandbox.BuildertoBuilder()final AgentCreateParams.Sandboxvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentCreateParams.Sandbox.Builderbuilder()Returns a mutable builder for constructing an instance of Sandbox. -
-
Method Detail
-
_cpu
final JsonField<Long> _cpu()
Returns the raw JSON value of cpu.
Unlike cpu, this method doesn't throw if the JSON field has an unexpected type.
-
_memoryMiB
final JsonField<Long> _memoryMiB()
Returns the raw JSON value of memoryMiB.
Unlike memoryMiB, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentCreateParams.Sandbox.Builder toBuilder()
-
validate
final AgentCreateParams.Sandbox validate()
-
builder
final static AgentCreateParams.Sandbox.Builder builder()
Returns a mutable builder for constructing an instance of Sandbox.
-
-
-
-