Class AgentDeleteResponse.Builder
-
- All Implemented Interfaces:
public final class AgentDeleteResponse.BuilderA builder for AgentDeleteResponse.
-
-
Method Summary
Modifier and Type Method Description final AgentDeleteResponse.Builderok(Boolean ok)final AgentDeleteResponse.Builderok(JsonField<Boolean> ok)Sets Builder.ok to an arbitrary JSON value. final AgentDeleteResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AgentDeleteResponse.BuilderputAdditionalProperty(String key, JsonValue value)final AgentDeleteResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AgentDeleteResponse.BuilderremoveAdditionalProperty(String key)final AgentDeleteResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final AgentDeleteResponsebuild()Returns an immutable instance of AgentDeleteResponse. -
-
Method Detail
-
ok
final AgentDeleteResponse.Builder ok(Boolean ok)
-
ok
final AgentDeleteResponse.Builder ok(JsonField<Boolean> ok)
Sets Builder.ok to an arbitrary JSON value.
You should usually call Builder.ok with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AgentDeleteResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AgentDeleteResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AgentDeleteResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AgentDeleteResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AgentDeleteResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AgentDeleteResponse build()
Returns an immutable instance of AgentDeleteResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-