Class AgentListParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class AgentListParams implements Params
Lists all active agents for the authenticated organization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentListParams.BuilderA builder for AgentListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>cursor()Pagination cursor (agent ID from previous page). final Optional<Long>limit()Maximum number of agents to return (default 50, max 250) final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AgentListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentListParamsnone()final static AgentListParams.Builderbuilder()Returns a mutable builder for constructing an instance of AgentListParams. -
-
Method Detail
-
cursor
final Optional<String> cursor()
Pagination cursor (agent ID from previous page). Returns agents created before this agent.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AgentListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AgentListParams none()
-
builder
final static AgentListParams.Builder builder()
Returns a mutable builder for constructing an instance of AgentListParams.
-
-
-
-