Class AgentListResponse
-
- All Implemented Interfaces:
public final class AgentListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentListResponse.BuilderA builder for AgentListResponse.
public final classAgentListResponse.Agent
-
Method Summary
Modifier and Type Method Description final Optional<List<AgentListResponse.Agent>>agents()final Optional<Boolean>hasMore()final Optional<String>nextCursor()Pass as cursor to fetch the next page final JsonField<List<AgentListResponse.Agent>>_agents()Returns the raw JSON value of agents. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final AgentListResponse.BuildertoBuilder()final AgentListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AgentListResponse. -
-
Method Detail
-
agents
final Optional<List<AgentListResponse.Agent>> agents()
-
nextCursor
final Optional<String> nextCursor()
Pass as cursor to fetch the next page
-
_agents
final JsonField<List<AgentListResponse.Agent>> _agents()
Returns the raw JSON value of agents.
Unlike agents, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentListResponse.Builder toBuilder()
-
validate
final AgentListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AgentListResponse.Builder builder()
Returns a mutable builder for constructing an instance of AgentListResponse.
-
-
-
-