Class AgentListResponse.Agent
-
- All Implemented Interfaces:
public final class AgentListResponse.Agent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentListResponse.Agent.BuilderA builder for Agent.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<OffsetDateTime>createdAt()final Optional<String>description()final Optional<Boolean>isActive()final Optional<String>model()final Optional<String>name()final Optional<OffsetDateTime>updatedAt()final Optional<List<String>>vaultIds()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_isActive()Returns the raw JSON value of isActive. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final AgentListResponse.Agent.BuildertoBuilder()final AgentListResponse.Agentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentListResponse.Agent.Builderbuilder()Returns a mutable builder for constructing an instance of Agent. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
description
final Optional<String> description()
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentListResponse.Agent.Builder toBuilder()
-
validate
final AgentListResponse.Agent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AgentListResponse.Agent.Builder builder()
Returns a mutable builder for constructing an instance of Agent.
-
-
-
-