Class AgentListResponse.Agent.Builder
-
- All Implemented Interfaces:
public final class AgentListResponse.Agent.BuilderA builder for Agent.
-
-
Method Summary
-
-
Method Detail
-
id
final AgentListResponse.Agent.Builder id(String id)
-
id
final AgentListResponse.Agent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final AgentListResponse.Agent.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final AgentListResponse.Agent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final AgentListResponse.Agent.Builder description(String description)
-
description
final AgentListResponse.Agent.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final AgentListResponse.Agent.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isActive
final AgentListResponse.Agent.Builder isActive(Boolean isActive)
-
isActive
final AgentListResponse.Agent.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final AgentListResponse.Agent.Builder model(String model)
-
model
final AgentListResponse.Agent.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AgentListResponse.Agent.Builder name(String name)
-
name
final AgentListResponse.Agent.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final AgentListResponse.Agent.Builder updatedAt(OffsetDateTime updatedAt)
-
updatedAt
final AgentListResponse.Agent.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultIds
final AgentListResponse.Agent.Builder vaultIds(List<String> vaultIds)
-
vaultIds
final AgentListResponse.Agent.Builder vaultIds(Optional<List<String>> vaultIds)
Alias for calling Builder.vaultIds with
vaultIds.orElse(null).
-
vaultIds
final AgentListResponse.Agent.Builder vaultIds(JsonField<List<String>> vaultIds)
Sets Builder.vaultIds to an arbitrary JSON value.
You should usually call Builder.vaultIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultId
final AgentListResponse.Agent.Builder addVaultId(String vaultId)
-
additionalProperties
final AgentListResponse.Agent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AgentListResponse.Agent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AgentListResponse.Agent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AgentListResponse.Agent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AgentListResponse.Agent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AgentListResponse.Agent build()
Returns an immutable instance of Agent.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-