Class AgentListResponse.Builder
-
- All Implemented Interfaces:
public final class AgentListResponse.BuilderA builder for AgentListResponse.
-
-
Method Summary
-
-
Method Detail
-
agents
final AgentListResponse.Builder agents(List<AgentListResponse.Agent> agents)
-
agents
final AgentListResponse.Builder agents(JsonField<List<AgentListResponse.Agent>> agents)
Sets Builder.agents to an arbitrary JSON value.
You should usually call Builder.agents with a well-typed
List<Agent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAgent
final AgentListResponse.Builder addAgent(AgentListResponse.Agent agent)
-
hasMore
final AgentListResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final AgentListResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nextCursor
final AgentListResponse.Builder nextCursor(String nextCursor)
Pass as cursor to fetch the next page
-
nextCursor
final AgentListResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final AgentListResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AgentListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AgentListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AgentListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AgentListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AgentListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AgentListResponse build()
Returns an immutable instance of AgentListResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-