Class AgentUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AgentUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
description
final AgentUpdateParams.Body.Builder description(String description)
Updated agent description. Pass null to clear if supported by the client.
-
description
final AgentUpdateParams.Body.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final AgentUpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disabledTools
final AgentUpdateParams.Body.Builder disabledTools(List<String> disabledTools)
Denylist of tools the agent cannot use. Mutually exclusive with enabledTools — set one or the other, not both. Pass null to clear.
-
disabledTools
final AgentUpdateParams.Body.Builder disabledTools(Optional<List<String>> disabledTools)
Alias for calling Builder.disabledTools with
disabledTools.orElse(null).
-
disabledTools
final AgentUpdateParams.Body.Builder disabledTools(JsonField<List<String>> disabledTools)
Sets Builder.disabledTools to an arbitrary JSON value.
You should usually call Builder.disabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDisabledTool
final AgentUpdateParams.Body.Builder addDisabledTool(String disabledTool)
Adds a single String to disabledTools.
-
enabledTools
final AgentUpdateParams.Body.Builder enabledTools(List<String> enabledTools)
Allowlist of tools the agent can use. Mutually exclusive with disabledTools — set one or the other, not both. Pass null to clear.
-
enabledTools
final AgentUpdateParams.Body.Builder enabledTools(Optional<List<String>> enabledTools)
Alias for calling Builder.enabledTools with
enabledTools.orElse(null).
-
enabledTools
final AgentUpdateParams.Body.Builder enabledTools(JsonField<List<String>> enabledTools)
Sets Builder.enabledTools to an arbitrary JSON value.
You should usually call Builder.enabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEnabledTool
final AgentUpdateParams.Body.Builder addEnabledTool(String enabledTool)
Adds a single String to enabledTools.
-
instructions
final AgentUpdateParams.Body.Builder instructions(String instructions)
Updated system instructions that guide agent behavior
-
instructions
final AgentUpdateParams.Body.Builder instructions(JsonField<String> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final AgentUpdateParams.Body.Builder model(String model)
Model identifier the agent should use for future runs
-
model
final AgentUpdateParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AgentUpdateParams.Body.Builder name(String name)
Updated agent display name
-
name
final AgentUpdateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sandbox
final AgentUpdateParams.Body.Builder sandbox(JsonValue sandbox)
Sandbox configuration override for future agent runs. Pass null to clear.
-
vaultGroups
final AgentUpdateParams.Body.Builder vaultGroups(List<String> vaultGroups)
Vault group IDs the agent can access. Pass null to clear.
-
vaultGroups
final AgentUpdateParams.Body.Builder vaultGroups(Optional<List<String>> vaultGroups)
Alias for calling Builder.vaultGroups with
vaultGroups.orElse(null).
-
vaultGroups
final AgentUpdateParams.Body.Builder vaultGroups(JsonField<List<String>> vaultGroups)
Sets Builder.vaultGroups to an arbitrary JSON value.
You should usually call Builder.vaultGroups with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultGroup
final AgentUpdateParams.Body.Builder addVaultGroup(String vaultGroup)
Adds a single String to vaultGroups.
-
vaultIds
final AgentUpdateParams.Body.Builder vaultIds(List<String> vaultIds)
Vault IDs the agent can access directly. Pass null to clear.
-
vaultIds
final AgentUpdateParams.Body.Builder vaultIds(Optional<List<String>> vaultIds)
Alias for calling Builder.vaultIds with
vaultIds.orElse(null).
-
vaultIds
final AgentUpdateParams.Body.Builder vaultIds(JsonField<List<String>> vaultIds)
Sets Builder.vaultIds to an arbitrary JSON value.
You should usually call Builder.vaultIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultId
final AgentUpdateParams.Body.Builder addVaultId(String vaultId)
-
additionalProperties
final AgentUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AgentUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AgentUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AgentUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AgentUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AgentUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-