Class AgentUpdateResponse
-
- All Implemented Interfaces:
public final class AgentUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentUpdateResponse.BuilderA builder for AgentUpdateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<OffsetDateTime>createdAt()final Optional<String>description()final Optional<List<String>>disabledTools()final Optional<List<String>>enabledTools()final Optional<String>instructions()final Optional<Boolean>isActive()final Optional<String>model()final Optional<String>name()final JsonValue_sandbox()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = agentUpdateResponse.sandbox().convert(MyClass.class);final Optional<OffsetDateTime>updatedAt()final Optional<List<String>>vaultGroups()final Optional<List<String>>vaultIds()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<String>>_disabledTools()Returns the raw JSON value of disabledTools. final JsonField<List<String>>_enabledTools()Returns the raw JSON value of enabledTools. final JsonField<String>_instructions()Returns the raw JSON value of instructions. final JsonField<Boolean>_isActive()Returns the raw JSON value of isActive. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<List<String>>_vaultGroups()Returns the raw JSON value of vaultGroups. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final AgentUpdateResponse.BuildertoBuilder()final AgentUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AgentUpdateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
description
final Optional<String> description()
-
disabledTools
final Optional<List<String>> disabledTools()
-
enabledTools
final Optional<List<String>> enabledTools()
-
instructions
final Optional<String> instructions()
-
_sandbox
final JsonValue _sandbox()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = agentUpdateResponse.sandbox().convert(MyClass.class);
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
-
vaultGroups
final Optional<List<String>> vaultGroups()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_disabledTools
final JsonField<List<String>> _disabledTools()
Returns the raw JSON value of disabledTools.
Unlike disabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_enabledTools
final JsonField<List<String>> _enabledTools()
Returns the raw JSON value of enabledTools.
Unlike enabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultGroups
final JsonField<List<String>> _vaultGroups()
Returns the raw JSON value of vaultGroups.
Unlike vaultGroups, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentUpdateResponse.Builder toBuilder()
-
validate
final AgentUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AgentUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of AgentUpdateResponse.
-
-
-
-