Class AgentUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class AgentUpdateResponse.BuilderA builder for AgentUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final AgentUpdateResponse.Builder id(String id)
-
id
final AgentUpdateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final AgentUpdateResponse.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final AgentUpdateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final AgentUpdateResponse.Builder description(String description)
-
description
final AgentUpdateResponse.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final AgentUpdateResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disabledTools
final AgentUpdateResponse.Builder disabledTools(List<String> disabledTools)
-
disabledTools
final AgentUpdateResponse.Builder disabledTools(Optional<List<String>> disabledTools)
Alias for calling Builder.disabledTools with
disabledTools.orElse(null).
-
disabledTools
final AgentUpdateResponse.Builder disabledTools(JsonField<List<String>> disabledTools)
Sets Builder.disabledTools to an arbitrary JSON value.
You should usually call Builder.disabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDisabledTool
final AgentUpdateResponse.Builder addDisabledTool(String disabledTool)
Adds a single String to disabledTools.
-
enabledTools
final AgentUpdateResponse.Builder enabledTools(List<String> enabledTools)
-
enabledTools
final AgentUpdateResponse.Builder enabledTools(Optional<List<String>> enabledTools)
Alias for calling Builder.enabledTools with
enabledTools.orElse(null).
-
enabledTools
final AgentUpdateResponse.Builder enabledTools(JsonField<List<String>> enabledTools)
Sets Builder.enabledTools to an arbitrary JSON value.
You should usually call Builder.enabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEnabledTool
final AgentUpdateResponse.Builder addEnabledTool(String enabledTool)
Adds a single String to enabledTools.
-
instructions
final AgentUpdateResponse.Builder instructions(String instructions)
-
instructions
final AgentUpdateResponse.Builder instructions(JsonField<String> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isActive
final AgentUpdateResponse.Builder isActive(Boolean isActive)
-
isActive
final AgentUpdateResponse.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final AgentUpdateResponse.Builder model(String model)
-
model
final AgentUpdateResponse.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AgentUpdateResponse.Builder name(String name)
-
name
final AgentUpdateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sandbox
final AgentUpdateResponse.Builder sandbox(JsonValue sandbox)
-
updatedAt
final AgentUpdateResponse.Builder updatedAt(OffsetDateTime updatedAt)
-
updatedAt
final AgentUpdateResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultGroups
final AgentUpdateResponse.Builder vaultGroups(List<String> vaultGroups)
-
vaultGroups
final AgentUpdateResponse.Builder vaultGroups(Optional<List<String>> vaultGroups)
Alias for calling Builder.vaultGroups with
vaultGroups.orElse(null).
-
vaultGroups
final AgentUpdateResponse.Builder vaultGroups(JsonField<List<String>> vaultGroups)
Sets Builder.vaultGroups to an arbitrary JSON value.
You should usually call Builder.vaultGroups with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultGroup
final AgentUpdateResponse.Builder addVaultGroup(String vaultGroup)
Adds a single String to vaultGroups.
-
vaultIds
final AgentUpdateResponse.Builder vaultIds(List<String> vaultIds)
-
vaultIds
final AgentUpdateResponse.Builder vaultIds(Optional<List<String>> vaultIds)
Alias for calling Builder.vaultIds with
vaultIds.orElse(null).
-
vaultIds
final AgentUpdateResponse.Builder vaultIds(JsonField<List<String>> vaultIds)
Sets Builder.vaultIds to an arbitrary JSON value.
You should usually call Builder.vaultIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultId
final AgentUpdateResponse.Builder addVaultId(String vaultId)
-
additionalProperties
final AgentUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AgentUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AgentUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AgentUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AgentUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AgentUpdateResponse build()
Returns an immutable instance of AgentUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-