Package dev.case.api.models.agent.v1.agents
See: Description
-
Class Summary Class Description Builder A builder for AgentCreateParams. Builder A builder for Body. Body Builder A builder for Sandbox. Sandbox Custom sandbox configuration (cpu, memoryMiB) AgentCreateParams Creates a new agent definition with a scoped API key. Builder A builder for AgentCreateResponse. AgentCreateResponse Builder A builder for AgentDeleteParams. AgentDeleteParams Soft-deletes an agent and revokes its scoped API key. Builder A builder for AgentDeleteResponse. AgentDeleteResponse Builder A builder for AgentListParams. AgentListParams Lists all active agents for the authenticated organization. Builder A builder for AgentListResponse. Builder A builder for Agent. Agent AgentListResponse Builder A builder for AgentRetrieveParams. AgentRetrieveParams Retrieves a single agent definition by ID. Builder A builder for AgentRetrieveResponse. AgentRetrieveResponse Builder A builder for AgentUpdateParams. Builder A builder for Body. Body AgentUpdateParams Updates an agent definition. Builder A builder for AgentUpdateResponse. AgentUpdateResponse