Class ChatCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ChatCreateParams implements Params
Creates a persistent OpenCode chat session in a Modal sandbox. Session state is retained and can be resumed across requests.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateParams.BuilderA builder for ChatCreateParams.
public final classChatCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<Long>idleTimeoutMs()Idle timeout before session is eligible for snapshot/termination. final Optional<String>model()Optional model override for the OpenCode session final Optional<String>title()Optional human-readable session title final Optional<List<String>>vaultIds()Restrict the chat session to specific vault IDs final JsonField<Long>_idleTimeoutMs()Returns the raw JSON value of idleTimeoutMs. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ChatCreateParams.BuildertoBuilder()final ChatCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateParamsnone()final static ChatCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ChatCreateParams. -
-
Method Detail
-
idleTimeoutMs
final Optional<Long> idleTimeoutMs()
Idle timeout before session is eligible for snapshot/termination. Defaults to 15 minutes.
-
_idleTimeoutMs
final JsonField<Long> _idleTimeoutMs()
Returns the raw JSON value of idleTimeoutMs.
Unlike idleTimeoutMs, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ChatCreateParams.Builder toBuilder()
-
_body
final ChatCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ChatCreateParams none()
-
builder
final static ChatCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ChatCreateParams.
-
-
-
-