Class ChatCreateParams.Body
-
- All Implemented Interfaces:
public final class ChatCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<Long>idleTimeoutMs()Idle timeout before session is eligible for snapshot/termination. final Optional<String>model()Optional model override for the chat runtime session final Optional<String>title()Optional human-readable session title final Optional<List<String>>vaultIds()Restrict the chat session to specific vault IDs final JsonField<Long>_idleTimeoutMs()Returns the raw JSON value of idleTimeoutMs. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final ChatCreateParams.Body.BuildertoBuilder()final ChatCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
idleTimeoutMs
final Optional<Long> idleTimeoutMs()
Idle timeout before session is eligible for snapshot/termination. Defaults to 15 minutes.
-
_idleTimeoutMs
final JsonField<Long> _idleTimeoutMs()
Returns the raw JSON value of idleTimeoutMs.
Unlike idleTimeoutMs, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateParams.Body.Builder toBuilder()
-
validate
final ChatCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-