Class ChatCreateResponse
-
- All Implemented Interfaces:
public final class ChatCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateResponse.BuilderA builder for ChatCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<OffsetDateTime>createdAt()final Optional<Long>idleTimeoutMs()final Optional<String>status()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Long>_idleTimeoutMs()Returns the raw JSON value of idleTimeoutMs. final JsonField<String>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final ChatCreateResponse.BuildertoBuilder()final ChatCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ChatCreateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
idleTimeoutMs
final Optional<Long> idleTimeoutMs()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_idleTimeoutMs
final JsonField<Long> _idleTimeoutMs()
Returns the raw JSON value of idleTimeoutMs.
Unlike idleTimeoutMs, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateResponse.Builder toBuilder()
-
validate
final ChatCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChatCreateResponse.
-
-
-
-