Class ChatDeleteResponse
-
- All Implemented Interfaces:
public final class ChatDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatDeleteResponse.BuilderA builder for ChatDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Double>cost()final Optional<Long>runtimeMs()final Optional<String>snapshotImageId()final Optional<String>status()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Double>_cost()Returns the raw JSON value of cost. final JsonField<Long>_runtimeMs()Returns the raw JSON value of runtimeMs. final JsonField<String>_snapshotImageId()Returns the raw JSON value of snapshotImageId. final JsonField<String>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final ChatDeleteResponse.BuildertoBuilder()final ChatDeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ChatDeleteResponse. -
-
Method Detail
-
snapshotImageId
final Optional<String> snapshotImageId()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cost
final JsonField<Double> _cost()
Returns the raw JSON value of cost.
Unlike cost, this method doesn't throw if the JSON field has an unexpected type.
-
_runtimeMs
final JsonField<Long> _runtimeMs()
Returns the raw JSON value of runtimeMs.
Unlike runtimeMs, this method doesn't throw if the JSON field has an unexpected type.
-
_snapshotImageId
final JsonField<String> _snapshotImageId()
Returns the raw JSON value of snapshotImageId.
Unlike snapshotImageId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatDeleteResponse.Builder toBuilder()
-
validate
final ChatDeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChatDeleteResponse.
-
-
-
-