Class ChatReplyToQuestionParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ChatReplyToQuestionParams implements Params
Answers a pending runtime question for the chat session bound to this agent chat.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatReplyToQuestionParams.BuilderA builder for ChatReplyToQuestionParams.
public final classChatReplyToQuestionParams.Body
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>requestId()final List<List<String>>answers()Answer selections for each prompt element in the pending question final JsonField<List<List<String>>>_answers()Returns the raw JSON value of answers. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ChatReplyToQuestionParams.BuildertoBuilder()final ChatReplyToQuestionParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatReplyToQuestionParams.Builderbuilder()Returns a mutable builder for constructing an instance of ChatReplyToQuestionParams. -
-
Method Detail
-
answers
final List<List<String>> answers()
Answer selections for each prompt element in the pending question
-
_answers
final JsonField<List<List<String>>> _answers()
Returns the raw JSON value of answers.
Unlike answers, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ChatReplyToQuestionParams.Builder toBuilder()
-
_body
final ChatReplyToQuestionParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ChatReplyToQuestionParams.Builder builder()
Returns a mutable builder for constructing an instance of ChatReplyToQuestionParams.
The following fields are required:
.id() .answers()
-
-
-
-