Class ChatReplyToQuestionParams.Body
-
- All Implemented Interfaces:
public final class ChatReplyToQuestionParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatReplyToQuestionParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<List<String>>answers()Answer selections for each prompt element in the pending question final JsonField<List<List<String>>>_answers()Returns the raw JSON value of answers. final Map<String, JsonValue>_additionalProperties()final ChatReplyToQuestionParams.Body.BuildertoBuilder()final ChatReplyToQuestionParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatReplyToQuestionParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
answers
final List<List<String>> answers()
Answer selections for each prompt element in the pending question
-
_answers
final JsonField<List<List<String>>> _answers()
Returns the raw JSON value of answers.
Unlike answers, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatReplyToQuestionParams.Body.Builder toBuilder()
-
validate
final ChatReplyToQuestionParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatReplyToQuestionParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.answers()
-
-
-
-