Class ChatRespondParams.Body
-
- All Implemented Interfaces:
public final class ChatRespondParams.BodyMessage payload following the AI SDK UIMessage format. The body is passed through 1:1 to the underlying chat runtime session. Currently only text parts are supported.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatRespondParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<List<ChatRespondParams.Part>>parts()Message content parts. final JsonField<List<ChatRespondParams.Part>>_parts()Returns the raw JSON value of parts. final Map<String, JsonValue>_additionalProperties()final ChatRespondParams.Body.BuildertoBuilder()final ChatRespondParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatRespondParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
parts
final Optional<List<ChatRespondParams.Part>> parts()
Message content parts. Currently only "text" type is supported. Additional types (e.g. file, image) may be added in future versions.
-
_parts
final JsonField<List<ChatRespondParams.Part>> _parts()
Returns the raw JSON value of parts.
Unlike parts, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatRespondParams.Body.Builder toBuilder()
-
validate
final ChatRespondParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatRespondParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-