Class ChatRespondParams.Part
-
- All Implemented Interfaces:
public final class ChatRespondParams.Part
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatRespondParams.Part.BuilderA builder for Part.
public final classChatRespondParams.Part.TypePart type. Currently only "text" is supported.
-
Method Summary
Modifier and Type Method Description final Stringtext()The message text content final ChatRespondParams.Part.Typetype()Part type. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<ChatRespondParams.Part.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final ChatRespondParams.Part.BuildertoBuilder()final ChatRespondParams.Partvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatRespondParams.Part.Builderbuilder()Returns a mutable builder for constructing an instance of Part. -
-
Method Detail
-
type
final ChatRespondParams.Part.Type type()
Part type. Currently only "text" is supported.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ChatRespondParams.Part.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatRespondParams.Part.Builder toBuilder()
-
validate
final ChatRespondParams.Part validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatRespondParams.Part.Builder builder()
Returns a mutable builder for constructing an instance of Part.
The following fields are required:
.text() .type()
-
-
-
-