Class ChatRespondParams.Part.Builder
-
- All Implemented Interfaces:
public final class ChatRespondParams.Part.BuilderA builder for Part.
-
-
Method Summary
Modifier and Type Method Description final ChatRespondParams.Part.Buildertext(String text)The message text content final ChatRespondParams.Part.Buildertext(JsonField<String> text)Sets Builder.text to an arbitrary JSON value. final ChatRespondParams.Part.Buildertype(ChatRespondParams.Part.Type type)Part type. final ChatRespondParams.Part.Buildertype(JsonField<ChatRespondParams.Part.Type> type)Sets Builder.type to an arbitrary JSON value. final ChatRespondParams.Part.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ChatRespondParams.Part.BuilderputAdditionalProperty(String key, JsonValue value)final ChatRespondParams.Part.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ChatRespondParams.Part.BuilderremoveAdditionalProperty(String key)final ChatRespondParams.Part.BuilderremoveAllAdditionalProperties(Set<String> keys)final ChatRespondParams.Partbuild()Returns an immutable instance of Part. -
-
Method Detail
-
text
final ChatRespondParams.Part.Builder text(String text)
The message text content
-
text
final ChatRespondParams.Part.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ChatRespondParams.Part.Builder type(ChatRespondParams.Part.Type type)
Part type. Currently only "text" is supported.
-
type
final ChatRespondParams.Part.Builder type(JsonField<ChatRespondParams.Part.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatRespondParams.Part.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatRespondParams.Part.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatRespondParams.Part.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatRespondParams.Part.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatRespondParams.Part.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatRespondParams.Part build()
Returns an immutable instance of Part.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.text() .type()
-
-
-
-