Class ChatSendMessageParams.Part.Builder
-
- All Implemented Interfaces:
public final class ChatSendMessageParams.Part.BuilderA builder for Part.
-
-
Method Summary
-
-
Method Detail
-
text
final ChatSendMessageParams.Part.Builder text(String text)
The message text content
-
text
final ChatSendMessageParams.Part.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ChatSendMessageParams.Part.Builder type(ChatSendMessageParams.Part.Type type)
Part type. Currently only "text" is supported.
-
type
final ChatSendMessageParams.Part.Builder type(JsonField<ChatSendMessageParams.Part.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatSendMessageParams.Part.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatSendMessageParams.Part.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatSendMessageParams.Part.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatSendMessageParams.Part.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatSendMessageParams.Part.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatSendMessageParams.Part build()
Returns an immutable instance of Part.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.text() .type()
-
-
-
-