Class ExecuteCreateParams.Body
-
- All Implemented Interfaces:
public final class ExecuteCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExecuteCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringprompt()Task prompt for the agent final Optional<List<String>>disabledTools()Denylist of tools the agent cannot use. final Optional<List<String>>enabledTools()Allowlist of tools the agent can use. final Optional<String>guidance()Additional context or constraints for this run final Optional<String>instructions()System instructions. final Optional<String>model()LLM model identifier. final Optional<List<String>>objectIds()Scope this run to specific vault object IDs. final Optional<ExecuteCreateParams.Sandbox>sandbox()Custom sandbox resources (cpu, memoryMiB) final Optional<List<String>>vaultIds()Restrict agent to specific vault IDs final JsonField<String>_prompt()Returns the raw JSON value of prompt. final JsonField<List<String>>_disabledTools()Returns the raw JSON value of disabledTools. final JsonField<List<String>>_enabledTools()Returns the raw JSON value of enabledTools. final JsonField<String>_guidance()Returns the raw JSON value of guidance. final JsonField<String>_instructions()Returns the raw JSON value of instructions. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<List<String>>_objectIds()Returns the raw JSON value of objectIds. final JsonField<ExecuteCreateParams.Sandbox>_sandbox()Returns the raw JSON value of sandbox. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final ExecuteCreateParams.Body.BuildertoBuilder()final ExecuteCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExecuteCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
disabledTools
final Optional<List<String>> disabledTools()
Denylist of tools the agent cannot use. Mutually exclusive with enabledTools — set one or the other, not both.
-
enabledTools
final Optional<List<String>> enabledTools()
Allowlist of tools the agent can use. Mutually exclusive with disabledTools — set one or the other, not both.
-
instructions
final Optional<String> instructions()
System instructions. Defaults to a general-purpose legal assistant prompt if not provided.
-
objectIds
final Optional<List<String>> objectIds()
Scope this run to specific vault object IDs. The agent will only access these objects.
-
sandbox
final Optional<ExecuteCreateParams.Sandbox> sandbox()
Custom sandbox resources (cpu, memoryMiB)
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_disabledTools
final JsonField<List<String>> _disabledTools()
Returns the raw JSON value of disabledTools.
Unlike disabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_enabledTools
final JsonField<List<String>> _enabledTools()
Returns the raw JSON value of enabledTools.
Unlike enabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_guidance
final JsonField<String> _guidance()
Returns the raw JSON value of guidance.
Unlike guidance, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_objectIds
final JsonField<List<String>> _objectIds()
Returns the raw JSON value of objectIds.
Unlike objectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_sandbox
final JsonField<ExecuteCreateParams.Sandbox> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExecuteCreateParams.Body.Builder toBuilder()
-
validate
final ExecuteCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExecuteCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.prompt()
-
-
-
-