Class ExecuteCreateParams.Sandbox
-
- All Implemented Interfaces:
public final class ExecuteCreateParams.SandboxCustom sandbox resources (cpu, memoryMiB)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExecuteCreateParams.Sandbox.BuilderA builder for Sandbox.
-
Method Summary
Modifier and Type Method Description final Optional<Long>cpu()Number of CPUs final Optional<Long>memoryMiB()Memory in MiB final JsonField<Long>_cpu()Returns the raw JSON value of cpu. final JsonField<Long>_memoryMiB()Returns the raw JSON value of memoryMiB. final Map<String, JsonValue>_additionalProperties()final ExecuteCreateParams.Sandbox.BuildertoBuilder()final ExecuteCreateParams.Sandboxvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExecuteCreateParams.Sandbox.Builderbuilder()Returns a mutable builder for constructing an instance of Sandbox. -
-
Method Detail
-
_cpu
final JsonField<Long> _cpu()
Returns the raw JSON value of cpu.
Unlike cpu, this method doesn't throw if the JSON field has an unexpected type.
-
_memoryMiB
final JsonField<Long> _memoryMiB()
Returns the raw JSON value of memoryMiB.
Unlike memoryMiB, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExecuteCreateParams.Sandbox.Builder toBuilder()
-
validate
final ExecuteCreateParams.Sandbox validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExecuteCreateParams.Sandbox.Builder builder()
Returns a mutable builder for constructing an instance of Sandbox.
-
-
-
-