Class ExecuteCreateResponse
-
- All Implemented Interfaces:
public final class ExecuteCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExecuteCreateResponse.BuilderA builder for ExecuteCreateResponse.
public final classExecuteCreateResponse.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>agentId()Ephemeral agent ID (auto-created). final Optional<String>message()final Optional<String>runId()Run ID — poll /agent/v1/run/:id/status final Optional<ExecuteCreateResponse.Status>status()final JsonField<String>_agentId()Returns the raw JSON value of agentId. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_runId()Returns the raw JSON value of runId. final JsonField<ExecuteCreateResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final ExecuteCreateResponse.BuildertoBuilder()final ExecuteCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExecuteCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExecuteCreateResponse. -
-
Method Detail
-
agentId
final Optional<String> agentId()
Ephemeral agent ID (auto-created). This agent is soft-deleted when the run completes and should not be stored for reuse.
-
status
final Optional<ExecuteCreateResponse.Status> status()
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_runId
final JsonField<String> _runId()
Returns the raw JSON value of runId.
Unlike runId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ExecuteCreateResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExecuteCreateResponse.Builder toBuilder()
-
validate
final ExecuteCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExecuteCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExecuteCreateResponse.
-
-
-
-