Package dev.case.api.models.agent.v1.run
Class RunCancelResponse
-
- All Implemented Interfaces:
public final class RunCancelResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunCancelResponse.BuilderA builder for RunCancelResponse.
public final classRunCancelResponse.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>message()Present if run was already finished final Optional<RunCancelResponse.Status>status()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<RunCancelResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final RunCancelResponse.BuildertoBuilder()final RunCancelResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunCancelResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RunCancelResponse. -
-
Method Detail
-
status
final Optional<RunCancelResponse.Status> status()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RunCancelResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunCancelResponse.Builder toBuilder()
-
validate
final RunCancelResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunCancelResponse.Builder builder()
Returns a mutable builder for constructing an instance of RunCancelResponse.
-
-
-
-