Class RunCreateParams.Body
-
- All Implemented Interfaces:
public final class RunCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringagentId()ID of the agent to run final Stringprompt()Task prompt for the agent final Optional<String>callbackUrl()HTTPS callback URL to receive a notification when the run completes. final Optional<String>guidance()Additional guidance for this run final Optional<String>model()Override the agent default model for this run final Optional<List<String>>objectIds()Scope this run to specific vault object IDs. final JsonField<String>_agentId()Returns the raw JSON value of agentId. final JsonField<String>_prompt()Returns the raw JSON value of prompt. final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final JsonField<String>_guidance()Returns the raw JSON value of guidance. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<List<String>>_objectIds()Returns the raw JSON value of objectIds. final Map<String, JsonValue>_additionalProperties()final RunCreateParams.Body.BuildertoBuilder()final RunCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
callbackUrl
final Optional<String> callbackUrl()
HTTPS callback URL to receive a notification when the run completes. Registered atomically with the run — eliminates the race condition of calling /watch after /exec. Additional watchers can still be added via POST /run/:id/watch.
-
objectIds
final Optional<List<String>> objectIds()
Scope this run to specific vault object IDs. The agent will only be able to access these objects during execution.
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_guidance
final JsonField<String> _guidance()
Returns the raw JSON value of guidance.
Unlike guidance, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_objectIds
final JsonField<List<String>> _objectIds()
Returns the raw JSON value of objectIds.
Unlike objectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunCreateParams.Body.Builder toBuilder()
-
validate
final RunCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.agentId() .prompt()
-
-
-
-