Class RunCreateResponse.Builder
-
- All Implemented Interfaces:
public final class RunCreateResponse.BuilderA builder for RunCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final RunCreateResponse.Builder id(String id)
-
id
final RunCreateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
agentId
final RunCreateResponse.Builder agentId(String agentId)
-
agentId
final RunCreateResponse.Builder agentId(JsonField<String> agentId)
Sets Builder.agentId to an arbitrary JSON value.
You should usually call Builder.agentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final RunCreateResponse.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final RunCreateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectIds
final RunCreateResponse.Builder objectIds(List<String> objectIds)
-
objectIds
final RunCreateResponse.Builder objectIds(Optional<List<String>> objectIds)
Alias for calling Builder.objectIds with
objectIds.orElse(null).
-
objectIds
final RunCreateResponse.Builder objectIds(JsonField<List<String>> objectIds)
Sets Builder.objectIds to an arbitrary JSON value.
You should usually call Builder.objectIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addObjectId
final RunCreateResponse.Builder addObjectId(String objectId)
-
status
final RunCreateResponse.Builder status(RunCreateResponse.Status status)
-
status
final RunCreateResponse.Builder status(JsonField<RunCreateResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunCreateResponse build()
Returns an immutable instance of RunCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-