Package dev.case.api.models.agent.v1.run
Class RunEventsParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class RunEventsParams implements Params
Streams real-time run events over SSE. Supports replay using Last-Event-ID.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunEventsParams.BuilderA builder for RunEventsParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Long>lastEventId()Replay events after this sequence number final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final RunEventsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunEventsParamsnone()final static RunEventsParams.Builderbuilder()Returns a mutable builder for constructing an instance of RunEventsParams. -
-
Method Detail
-
lastEventId
final Optional<Long> lastEventId()
Replay events after this sequence number
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final RunEventsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static RunEventsParams none()
-
builder
final static RunEventsParams.Builder builder()
Returns a mutable builder for constructing an instance of RunEventsParams.
-
-
-
-