Class RunExecResponse
-
- All Implemented Interfaces:
public final class RunExecResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunExecResponse.BuilderA builder for RunExecResponse.
public final classRunExecResponse.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>message()final Optional<RunExecResponse.Status>status()final Optional<String>workflowId()Durable workflow run ID final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<RunExecResponse.Status>_status()Returns the raw JSON value of status. final JsonField<String>_workflowId()Returns the raw JSON value of workflowId. final Map<String, JsonValue>_additionalProperties()final RunExecResponse.BuildertoBuilder()final RunExecResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunExecResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RunExecResponse. -
-
Method Detail
-
status
final Optional<RunExecResponse.Status> status()
-
workflowId
final Optional<String> workflowId()
Durable workflow run ID
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RunExecResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_workflowId
final JsonField<String> _workflowId()
Returns the raw JSON value of workflowId.
Unlike workflowId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunExecResponse.Builder toBuilder()
-
validate
final RunExecResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunExecResponse.Builder builder()
Returns a mutable builder for constructing an instance of RunExecResponse.
-
-
-
-