Class RunGetDetailsResponse
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.BuilderA builder for RunGetDetailsResponse.
public final classRunGetDetailsResponse.ProviderRuntime provider for this run
public final classRunGetDetailsResponse.ResultFinal output from the agent
public final classRunGetDetailsResponse.RuntimeStateCurrent runtime state, when available
public final classRunGetDetailsResponse.Statuspublic final classRunGetDetailsResponse.Steppublic final classRunGetDetailsResponse.UsageToken usage statistics
-
Method Summary
-
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
modalSandboxId
@Deprecated(message = "deprecated") final Optional<String> modalSandboxId()
Deprecated legacy Modal sandbox ID. Prefer
providerandruntimeId.
-
provider
final Optional<RunGetDetailsResponse.Provider> provider()
Runtime provider for this run
-
result
final Optional<RunGetDetailsResponse.Result> result()
Final output from the agent
-
runtimeState
final Optional<RunGetDetailsResponse.RuntimeState> runtimeState()
Current runtime state, when available
-
startedAt
final Optional<OffsetDateTime> startedAt()
-
status
final Optional<RunGetDetailsResponse.Status> status()
-
steps
final Optional<List<RunGetDetailsResponse.Step>> steps()
-
usage
final Optional<RunGetDetailsResponse.Usage> usage()
Token usage statistics
-
workflowId
final Optional<String> workflowId()
Durable workflow run ID
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_guidance
final JsonField<String> _guidance()
Returns the raw JSON value of guidance.
Unlike guidance, this method doesn't throw if the JSON field has an unexpected type.
-
_modalSandboxId
@Deprecated(message = "deprecated") final JsonField<String> _modalSandboxId()
Returns the raw JSON value of modalSandboxId.
Unlike modalSandboxId, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_provider
final JsonField<RunGetDetailsResponse.Provider> _provider()
Returns the raw JSON value of provider.
Unlike provider, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<RunGetDetailsResponse.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_runtimeId
final JsonField<String> _runtimeId()
Returns the raw JSON value of runtimeId.
Unlike runtimeId, this method doesn't throw if the JSON field has an unexpected type.
-
_runtimeState
final JsonField<RunGetDetailsResponse.RuntimeState> _runtimeState()
Returns the raw JSON value of runtimeState.
Unlike runtimeState, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RunGetDetailsResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_steps
final JsonField<List<RunGetDetailsResponse.Step>> _steps()
Returns the raw JSON value of steps.
Unlike steps, this method doesn't throw if the JSON field has an unexpected type.
-
_usage
final JsonField<RunGetDetailsResponse.Usage> _usage()
Returns the raw JSON value of usage.
Unlike usage, this method doesn't throw if the JSON field has an unexpected type.
-
_workflowId
final JsonField<String> _workflowId()
Returns the raw JSON value of workflowId.
Unlike workflowId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Builder toBuilder()
-
validate
final RunGetDetailsResponse validate()
-
builder
final static RunGetDetailsResponse.Builder builder()
Returns a mutable builder for constructing an instance of RunGetDetailsResponse.
-
-
-
-