Class RunGetDetailsResponse.Builder
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.BuilderA builder for RunGetDetailsResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final RunGetDetailsResponse.Builder id(String id)
-
id
final RunGetDetailsResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
agentId
final RunGetDetailsResponse.Builder agentId(String agentId)
-
agentId
final RunGetDetailsResponse.Builder agentId(JsonField<String> agentId)
Sets Builder.agentId to an arbitrary JSON value.
You should usually call Builder.agentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final RunGetDetailsResponse.Builder completedAt(OffsetDateTime completedAt)
-
completedAt
final RunGetDetailsResponse.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final RunGetDetailsResponse.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final RunGetDetailsResponse.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final RunGetDetailsResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
guidance
final RunGetDetailsResponse.Builder guidance(String guidance)
-
guidance
final RunGetDetailsResponse.Builder guidance(Optional<String> guidance)
Alias for calling Builder.guidance with
guidance.orElse(null).
-
guidance
final RunGetDetailsResponse.Builder guidance(JsonField<String> guidance)
Sets Builder.guidance to an arbitrary JSON value.
You should usually call Builder.guidance with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
modalSandboxId
@Deprecated(message = "deprecated") final RunGetDetailsResponse.Builder modalSandboxId(String modalSandboxId)
Deprecated legacy Modal sandbox ID. Prefer
providerandruntimeId.
-
modalSandboxId
@Deprecated(message = "deprecated") final RunGetDetailsResponse.Builder modalSandboxId(Optional<String> modalSandboxId)
Alias for calling Builder.modalSandboxId with
modalSandboxId.orElse(null).
-
modalSandboxId
@Deprecated(message = "deprecated") final RunGetDetailsResponse.Builder modalSandboxId(JsonField<String> modalSandboxId)
Sets Builder.modalSandboxId to an arbitrary JSON value.
You should usually call Builder.modalSandboxId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final RunGetDetailsResponse.Builder model(String model)
-
model
final RunGetDetailsResponse.Builder model(Optional<String> model)
Alias for calling Builder.model with
model.orElse(null).
-
model
final RunGetDetailsResponse.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
prompt
final RunGetDetailsResponse.Builder prompt(String prompt)
-
prompt
final RunGetDetailsResponse.Builder prompt(JsonField<String> prompt)
Sets Builder.prompt to an arbitrary JSON value.
You should usually call Builder.prompt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
provider
final RunGetDetailsResponse.Builder provider(RunGetDetailsResponse.Provider provider)
Runtime provider for this run
-
provider
final RunGetDetailsResponse.Builder provider(Optional<RunGetDetailsResponse.Provider> provider)
Alias for calling Builder.provider with
provider.orElse(null).
-
provider
final RunGetDetailsResponse.Builder provider(JsonField<RunGetDetailsResponse.Provider> provider)
Sets Builder.provider to an arbitrary JSON value.
You should usually call Builder.provider with a well-typed Provider value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final RunGetDetailsResponse.Builder result(RunGetDetailsResponse.Result result)
Final output from the agent
-
result
final RunGetDetailsResponse.Builder result(Optional<RunGetDetailsResponse.Result> result)
Alias for calling Builder.result with
result.orElse(null).
-
result
final RunGetDetailsResponse.Builder result(JsonField<RunGetDetailsResponse.Result> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Result value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeId
final RunGetDetailsResponse.Builder runtimeId(String runtimeId)
Provider-specific runtime identifier
-
runtimeId
final RunGetDetailsResponse.Builder runtimeId(Optional<String> runtimeId)
Alias for calling Builder.runtimeId with
runtimeId.orElse(null).
-
runtimeId
final RunGetDetailsResponse.Builder runtimeId(JsonField<String> runtimeId)
Sets Builder.runtimeId to an arbitrary JSON value.
You should usually call Builder.runtimeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeState
final RunGetDetailsResponse.Builder runtimeState(RunGetDetailsResponse.RuntimeState runtimeState)
Current runtime state, when available
-
runtimeState
final RunGetDetailsResponse.Builder runtimeState(Optional<RunGetDetailsResponse.RuntimeState> runtimeState)
Alias for calling Builder.runtimeState with
runtimeState.orElse(null).
-
runtimeState
final RunGetDetailsResponse.Builder runtimeState(JsonField<RunGetDetailsResponse.RuntimeState> runtimeState)
Sets Builder.runtimeState to an arbitrary JSON value.
You should usually call Builder.runtimeState with a well-typed RuntimeState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startedAt
final RunGetDetailsResponse.Builder startedAt(OffsetDateTime startedAt)
-
startedAt
final RunGetDetailsResponse.Builder startedAt(Optional<OffsetDateTime> startedAt)
Alias for calling Builder.startedAt with
startedAt.orElse(null).
-
startedAt
final RunGetDetailsResponse.Builder startedAt(JsonField<OffsetDateTime> startedAt)
Sets Builder.startedAt to an arbitrary JSON value.
You should usually call Builder.startedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final RunGetDetailsResponse.Builder status(RunGetDetailsResponse.Status status)
-
status
final RunGetDetailsResponse.Builder status(JsonField<RunGetDetailsResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
steps
final RunGetDetailsResponse.Builder steps(List<RunGetDetailsResponse.Step> steps)
-
steps
final RunGetDetailsResponse.Builder steps(JsonField<List<RunGetDetailsResponse.Step>> steps)
Sets Builder.steps to an arbitrary JSON value.
You should usually call Builder.steps with a well-typed
List<Step>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStep
final RunGetDetailsResponse.Builder addStep(RunGetDetailsResponse.Step step)
-
usage
final RunGetDetailsResponse.Builder usage(RunGetDetailsResponse.Usage usage)
Token usage statistics
-
usage
final RunGetDetailsResponse.Builder usage(Optional<RunGetDetailsResponse.Usage> usage)
Alias for calling Builder.usage with
usage.orElse(null).
-
usage
final RunGetDetailsResponse.Builder usage(JsonField<RunGetDetailsResponse.Usage> usage)
Sets Builder.usage to an arbitrary JSON value.
You should usually call Builder.usage with a well-typed Usage value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workflowId
final RunGetDetailsResponse.Builder workflowId(String workflowId)
Durable workflow run ID
-
workflowId
final RunGetDetailsResponse.Builder workflowId(Optional<String> workflowId)
Alias for calling Builder.workflowId with
workflowId.orElse(null).
-
workflowId
final RunGetDetailsResponse.Builder workflowId(JsonField<String> workflowId)
Sets Builder.workflowId to an arbitrary JSON value.
You should usually call Builder.workflowId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunGetDetailsResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunGetDetailsResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunGetDetailsResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunGetDetailsResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunGetDetailsResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunGetDetailsResponse build()
Returns an immutable instance of RunGetDetailsResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-