Class RunGetDetailsResponse.Result
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.ResultFinal output from the agent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.Result.BuilderA builder for Result.
public final classRunGetDetailsResponse.Result.FinalResponseCompact agent-facing result summary and execution issues
public final classRunGetDetailsResponse.Result.LogsSandbox execution logs (runtime server + runner script)
-
Method Summary
Modifier and Type Method Description final Optional<RunGetDetailsResponse.Result.FinalResponse>finalResponse()Compact agent-facing result summary and execution issues final Optional<RunGetDetailsResponse.Result.Logs>logs()Sandbox execution logs (runtime server + runner script) final Optional<String>output()final Optional<List<String>>outputObjectIds()final JsonField<RunGetDetailsResponse.Result.FinalResponse>_finalResponse()Returns the raw JSON value of finalResponse. final JsonField<RunGetDetailsResponse.Result.Logs>_logs()Returns the raw JSON value of logs. final JsonField<String>_output()Returns the raw JSON value of output. final JsonField<List<String>>_outputObjectIds()Returns the raw JSON value of outputObjectIds. final Map<String, JsonValue>_additionalProperties()final RunGetDetailsResponse.Result.BuildertoBuilder()final RunGetDetailsResponse.Resultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunGetDetailsResponse.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
finalResponse
final Optional<RunGetDetailsResponse.Result.FinalResponse> finalResponse()
Compact agent-facing result summary and execution issues
-
logs
final Optional<RunGetDetailsResponse.Result.Logs> logs()
Sandbox execution logs (runtime server + runner script)
-
outputObjectIds
final Optional<List<String>> outputObjectIds()
-
_finalResponse
final JsonField<RunGetDetailsResponse.Result.FinalResponse> _finalResponse()
Returns the raw JSON value of finalResponse.
Unlike finalResponse, this method doesn't throw if the JSON field has an unexpected type.
-
_logs
final JsonField<RunGetDetailsResponse.Result.Logs> _logs()
Returns the raw JSON value of logs.
Unlike logs, this method doesn't throw if the JSON field has an unexpected type.
-
_output
final JsonField<String> _output()
Returns the raw JSON value of output.
Unlike output, this method doesn't throw if the JSON field has an unexpected type.
-
_outputObjectIds
final JsonField<List<String>> _outputObjectIds()
Returns the raw JSON value of outputObjectIds.
Unlike outputObjectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Result.Builder toBuilder()
-
validate
final RunGetDetailsResponse.Result validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunGetDetailsResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-