Package dev.case.api.models.agent.v1.run
Class RunGetDetailsResponse.Result.FinalResponse
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.Result.FinalResponseCompact agent-facing result summary and execution issues
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.Result.FinalResponse.BuilderA builder for FinalResponse.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>createdObjectIds()final Optional<List<String>>issues()final Optional<String>summary()final JsonField<List<String>>_createdObjectIds()Returns the raw JSON value of createdObjectIds. final JsonField<List<String>>_issues()Returns the raw JSON value of issues. final JsonField<String>_summary()Returns the raw JSON value of summary. final Map<String, JsonValue>_additionalProperties()final RunGetDetailsResponse.Result.FinalResponse.BuildertoBuilder()final RunGetDetailsResponse.Result.FinalResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunGetDetailsResponse.Result.FinalResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FinalResponse. -
-
Method Detail
-
createdObjectIds
final Optional<List<String>> createdObjectIds()
-
_createdObjectIds
final JsonField<List<String>> _createdObjectIds()
Returns the raw JSON value of createdObjectIds.
Unlike createdObjectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_issues
final JsonField<List<String>> _issues()
Returns the raw JSON value of issues.
Unlike issues, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Result.FinalResponse.Builder toBuilder()
-
validate
final RunGetDetailsResponse.Result.FinalResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunGetDetailsResponse.Result.FinalResponse.Builder builder()
Returns a mutable builder for constructing an instance of FinalResponse.
-
-
-
-