Package dev.case.api.models.agent.v1.run
Class RunGetDetailsResponse.Result.Logs
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.Result.LogsSandbox execution logs (runtime server + runner script)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.Result.Logs.BuilderA builder for Logs.
-
Method Summary
Modifier and Type Method Description final Optional<String>opencode()Legacy runtime server stdout/stderr final Optional<String>runner()Runner script stdout/stderr final Optional<String>runtime()Runtime server stdout/stderr final JsonField<String>_opencode()Returns the raw JSON value of opencode. final JsonField<String>_runner()Returns the raw JSON value of runner. final JsonField<String>_runtime()Returns the raw JSON value of runtime. final Map<String, JsonValue>_additionalProperties()final RunGetDetailsResponse.Result.Logs.BuildertoBuilder()final RunGetDetailsResponse.Result.Logsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunGetDetailsResponse.Result.Logs.Builderbuilder()Returns a mutable builder for constructing an instance of Logs. -
-
Method Detail
-
_opencode
final JsonField<String> _opencode()
Returns the raw JSON value of opencode.
Unlike opencode, this method doesn't throw if the JSON field has an unexpected type.
-
_runner
final JsonField<String> _runner()
Returns the raw JSON value of runner.
Unlike runner, this method doesn't throw if the JSON field has an unexpected type.
-
_runtime
final JsonField<String> _runtime()
Returns the raw JSON value of runtime.
Unlike runtime, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Result.Logs.Builder toBuilder()
-
validate
final RunGetDetailsResponse.Result.Logs validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunGetDetailsResponse.Result.Logs.Builder builder()
Returns a mutable builder for constructing an instance of Logs.
-
-
-
-