Class RunGetDetailsResponse.Step.Builder
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.Step.BuilderA builder for Step.
-
-
Method Summary
-
-
Method Detail
-
id
final RunGetDetailsResponse.Step.Builder id(String id)
-
id
final RunGetDetailsResponse.Step.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
content
final RunGetDetailsResponse.Step.Builder content(String content)
-
content
final RunGetDetailsResponse.Step.Builder content(Optional<String> content)
Alias for calling Builder.content with
content.orElse(null).
-
content
final RunGetDetailsResponse.Step.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
durationMs
final RunGetDetailsResponse.Step.Builder durationMs(Long durationMs)
-
durationMs
final RunGetDetailsResponse.Step.Builder durationMs(Long durationMs)
Alias for Builder.durationMs.
This unboxed primitive overload exists for backwards compatibility.
-
durationMs
final RunGetDetailsResponse.Step.Builder durationMs(Optional<Long> durationMs)
Alias for calling Builder.durationMs with
durationMs.orElse(null).
-
durationMs
final RunGetDetailsResponse.Step.Builder durationMs(JsonField<Long> durationMs)
Sets Builder.durationMs to an arbitrary JSON value.
You should usually call Builder.durationMs with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timestamp
final RunGetDetailsResponse.Step.Builder timestamp(OffsetDateTime timestamp)
-
timestamp
final RunGetDetailsResponse.Step.Builder timestamp(JsonField<OffsetDateTime> timestamp)
Sets Builder.timestamp to an arbitrary JSON value.
You should usually call Builder.timestamp with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
toolInput
final RunGetDetailsResponse.Step.Builder toolInput(JsonValue toolInput)
-
toolName
final RunGetDetailsResponse.Step.Builder toolName(String toolName)
-
toolName
final RunGetDetailsResponse.Step.Builder toolName(Optional<String> toolName)
Alias for calling Builder.toolName with
toolName.orElse(null).
-
toolName
final RunGetDetailsResponse.Step.Builder toolName(JsonField<String> toolName)
Sets Builder.toolName to an arbitrary JSON value.
You should usually call Builder.toolName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
toolOutput
final RunGetDetailsResponse.Step.Builder toolOutput(JsonValue toolOutput)
-
type
final RunGetDetailsResponse.Step.Builder type(RunGetDetailsResponse.Step.Type type)
-
type
final RunGetDetailsResponse.Step.Builder type(JsonField<RunGetDetailsResponse.Step.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunGetDetailsResponse.Step.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunGetDetailsResponse.Step.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunGetDetailsResponse.Step.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunGetDetailsResponse.Step.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunGetDetailsResponse.Step.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunGetDetailsResponse.Step build()
Returns an immutable instance of Step.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-