Class RunGetDetailsResponse.Usage.Entry
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.Usage.Entry
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.Usage.Entry.BuilderA builder for Entry.
public final classRunGetDetailsResponse.Usage.Entry.Kind
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Long>completionTokens()final Optional<Long>costMicros()final Optional<String>endpoint()final Optional<RunGetDetailsResponse.Usage.Entry.Kind>kind()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = entry.metadata().convert(MyClass.class);final Optional<String>method()final Optional<String>model()final Optional<Long>promptTokens()final Optional<String>service()final Optional<Long>statusCode()final Optional<OffsetDateTime>timestamp()final Optional<Long>totalTokens()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_completionTokens()Returns the raw JSON value of completionTokens. final JsonField<Long>_costMicros()Returns the raw JSON value of costMicros. final JsonField<String>_endpoint()Returns the raw JSON value of endpoint. final JsonField<RunGetDetailsResponse.Usage.Entry.Kind>_kind()Returns the raw JSON value of kind. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<Long>_promptTokens()Returns the raw JSON value of promptTokens. final JsonField<String>_service()Returns the raw JSON value of service. final JsonField<Long>_statusCode()Returns the raw JSON value of statusCode. final JsonField<OffsetDateTime>_timestamp()Returns the raw JSON value of timestamp. final JsonField<Long>_totalTokens()Returns the raw JSON value of totalTokens. final Map<String, JsonValue>_additionalProperties()final RunGetDetailsResponse.Usage.Entry.BuildertoBuilder()final RunGetDetailsResponse.Usage.Entryvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunGetDetailsResponse.Usage.Entry.Builderbuilder()Returns a mutable builder for constructing an instance of Entry. -
-
Method Detail
-
completionTokens
final Optional<Long> completionTokens()
-
costMicros
final Optional<Long> costMicros()
-
kind
final Optional<RunGetDetailsResponse.Usage.Entry.Kind> kind()
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = entry.metadata().convert(MyClass.class);
-
promptTokens
final Optional<Long> promptTokens()
-
statusCode
final Optional<Long> statusCode()
-
timestamp
final Optional<OffsetDateTime> timestamp()
-
totalTokens
final Optional<Long> totalTokens()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_completionTokens
final JsonField<Long> _completionTokens()
Returns the raw JSON value of completionTokens.
Unlike completionTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_costMicros
final JsonField<Long> _costMicros()
Returns the raw JSON value of costMicros.
Unlike costMicros, this method doesn't throw if the JSON field has an unexpected type.
-
_endpoint
final JsonField<String> _endpoint()
Returns the raw JSON value of endpoint.
Unlike endpoint, this method doesn't throw if the JSON field has an unexpected type.
-
_kind
final JsonField<RunGetDetailsResponse.Usage.Entry.Kind> _kind()
Returns the raw JSON value of kind.
Unlike kind, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_promptTokens
final JsonField<Long> _promptTokens()
Returns the raw JSON value of promptTokens.
Unlike promptTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_service
final JsonField<String> _service()
Returns the raw JSON value of service.
Unlike service, this method doesn't throw if the JSON field has an unexpected type.
-
_statusCode
final JsonField<Long> _statusCode()
Returns the raw JSON value of statusCode.
Unlike statusCode, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_totalTokens
final JsonField<Long> _totalTokens()
Returns the raw JSON value of totalTokens.
Unlike totalTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Usage.Entry.Builder toBuilder()
-
validate
final RunGetDetailsResponse.Usage.Entry validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunGetDetailsResponse.Usage.Entry.Builder builder()
Returns a mutable builder for constructing an instance of Entry.
-
-
-
-