Class RunGetDetailsResponse.Usage.Summary
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.Usage.Summary
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.Usage.Summary.BuilderA builder for Summary.
-
Method Summary
-
-
Method Detail
-
costMicros
final Optional<Long> costMicros()
-
totalInputTokens
final Optional<Long> totalInputTokens()
-
totalOutputTokens
final Optional<Long> totalOutputTokens()
-
totalTokens
final Optional<Long> totalTokens()
-
_costMicros
final JsonField<Long> _costMicros()
Returns the raw JSON value of costMicros.
Unlike costMicros, this method doesn't throw if the JSON field has an unexpected type.
-
_totalInputTokens
final JsonField<Long> _totalInputTokens()
Returns the raw JSON value of totalInputTokens.
Unlike totalInputTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_totalOutputTokens
final JsonField<Long> _totalOutputTokens()
Returns the raw JSON value of totalOutputTokens.
Unlike totalOutputTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_totalTokens
final JsonField<Long> _totalTokens()
Returns the raw JSON value of totalTokens.
Unlike totalTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Usage.Summary.Builder toBuilder()
-
validate
final RunGetDetailsResponse.Usage.Summary validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunGetDetailsResponse.Usage.Summary.Builder builder()
Returns a mutable builder for constructing an instance of Summary.
-
-
-
-