Class RunGetDetailsResponse.Usage.Summary.Builder
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.Usage.Summary.BuilderA builder for Summary.
-
-
Method Summary
-
-
Method Detail
-
costMicros
final RunGetDetailsResponse.Usage.Summary.Builder costMicros(Long costMicros)
-
costMicros
final RunGetDetailsResponse.Usage.Summary.Builder costMicros(JsonField<Long> costMicros)
Sets Builder.costMicros to an arbitrary JSON value.
You should usually call Builder.costMicros with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalInputTokens
final RunGetDetailsResponse.Usage.Summary.Builder totalInputTokens(Long totalInputTokens)
-
totalInputTokens
final RunGetDetailsResponse.Usage.Summary.Builder totalInputTokens(JsonField<Long> totalInputTokens)
Sets Builder.totalInputTokens to an arbitrary JSON value.
You should usually call Builder.totalInputTokens with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalOutputTokens
final RunGetDetailsResponse.Usage.Summary.Builder totalOutputTokens(Long totalOutputTokens)
-
totalOutputTokens
final RunGetDetailsResponse.Usage.Summary.Builder totalOutputTokens(JsonField<Long> totalOutputTokens)
Sets Builder.totalOutputTokens to an arbitrary JSON value.
You should usually call Builder.totalOutputTokens with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalTokens
final RunGetDetailsResponse.Usage.Summary.Builder totalTokens(Long totalTokens)
-
totalTokens
final RunGetDetailsResponse.Usage.Summary.Builder totalTokens(JsonField<Long> totalTokens)
Sets Builder.totalTokens to an arbitrary JSON value.
You should usually call Builder.totalTokens with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunGetDetailsResponse.Usage.Summary.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunGetDetailsResponse.Usage.Summary.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunGetDetailsResponse.Usage.Summary.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunGetDetailsResponse.Usage.Summary.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunGetDetailsResponse.Usage.Summary.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunGetDetailsResponse.Usage.Summary build()
Returns an immutable instance of Summary.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-