Class RunGetStatusResponse
-
- All Implemented Interfaces:
public final class RunGetStatusResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetStatusResponse.BuilderA builder for RunGetStatusResponse.
public final classRunGetStatusResponse.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<OffsetDateTime>completedAt()final Optional<Long>durationMs()Elapsed time in milliseconds final Optional<OffsetDateTime>startedAt()final Optional<RunGetStatusResponse.Status>status()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final JsonField<Long>_durationMs()Returns the raw JSON value of durationMs. final JsonField<OffsetDateTime>_startedAt()Returns the raw JSON value of startedAt. final JsonField<RunGetStatusResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final RunGetStatusResponse.BuildertoBuilder()final RunGetStatusResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunGetStatusResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RunGetStatusResponse. -
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
-
durationMs
final Optional<Long> durationMs()
Elapsed time in milliseconds
-
startedAt
final Optional<OffsetDateTime> startedAt()
-
status
final Optional<RunGetStatusResponse.Status> status()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_durationMs
final JsonField<Long> _durationMs()
Returns the raw JSON value of durationMs.
Unlike durationMs, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RunGetStatusResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetStatusResponse.Builder toBuilder()
-
validate
final RunGetStatusResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunGetStatusResponse.Builder builder()
Returns a mutable builder for constructing an instance of RunGetStatusResponse.
-
-
-
-