Package dev.case.api.models.agent.v1.run
Class RunListResponse
-
- All Implemented Interfaces:
public final class RunListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunListResponse.BuilderA builder for RunListResponse.
public final classRunListResponse.Run
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>hasMore()final Optional<String>nextCursor()Pass as cursor to fetch the next page final Optional<List<RunListResponse.Run>>runs()final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final JsonField<List<RunListResponse.Run>>_runs()Returns the raw JSON value of runs. final Map<String, JsonValue>_additionalProperties()final RunListResponse.BuildertoBuilder()final RunListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RunListResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
Pass as cursor to fetch the next page
-
runs
final Optional<List<RunListResponse.Run>> runs()
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_runs
final JsonField<List<RunListResponse.Run>> _runs()
Returns the raw JSON value of runs.
Unlike runs, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunListResponse.Builder toBuilder()
-
validate
final RunListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunListResponse.Builder builder()
Returns a mutable builder for constructing an instance of RunListResponse.
-
-
-
-