Class RunListResponse.Builder
-
- All Implemented Interfaces:
public final class RunListResponse.BuilderA builder for RunListResponse.
-
-
Method Summary
-
-
Method Detail
-
hasMore
final RunListResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final RunListResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nextCursor
final RunListResponse.Builder nextCursor(String nextCursor)
Pass as cursor to fetch the next page
-
nextCursor
final RunListResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final RunListResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runs
final RunListResponse.Builder runs(List<RunListResponse.Run> runs)
-
runs
final RunListResponse.Builder runs(JsonField<List<RunListResponse.Run>> runs)
Sets Builder.runs to an arbitrary JSON value.
You should usually call Builder.runs with a well-typed
List<Run>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRun
final RunListResponse.Builder addRun(RunListResponse.Run run)
-
additionalProperties
final RunListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunListResponse build()
Returns an immutable instance of RunListResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-