Class RunListResponse.Run
-
- All Implemented Interfaces:
public final class RunListResponse.Run
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunListResponse.Run.BuilderA builder for Run.
public final classRunListResponse.Run.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>agentId()final Optional<OffsetDateTime>completedAt()final Optional<OffsetDateTime>createdAt()final Optional<String>model()final Optional<String>prompt()Truncated to first 200 characters final Optional<OffsetDateTime>startedAt()final Optional<RunListResponse.Run.Status>status()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_agentId()Returns the raw JSON value of agentId. final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_prompt()Returns the raw JSON value of prompt. final JsonField<OffsetDateTime>_startedAt()Returns the raw JSON value of startedAt. final JsonField<RunListResponse.Run.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final RunListResponse.Run.BuildertoBuilder()final RunListResponse.Runvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunListResponse.Run.Builderbuilder()Returns a mutable builder for constructing an instance of Run. -
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
startedAt
final Optional<OffsetDateTime> startedAt()
-
status
final Optional<RunListResponse.Run.Status> status()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RunListResponse.Run.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunListResponse.Run.Builder toBuilder()
-
validate
final RunListResponse.Run validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunListResponse.Run.Builder builder()
Returns a mutable builder for constructing an instance of Run.
-
-
-
-