Class RunListResponse.Run.Builder
-
- All Implemented Interfaces:
public final class RunListResponse.Run.BuilderA builder for Run.
-
-
Method Summary
-
-
Method Detail
-
id
final RunListResponse.Run.Builder id(String id)
-
id
final RunListResponse.Run.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
agentId
final RunListResponse.Run.Builder agentId(String agentId)
-
agentId
final RunListResponse.Run.Builder agentId(JsonField<String> agentId)
Sets Builder.agentId to an arbitrary JSON value.
You should usually call Builder.agentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final RunListResponse.Run.Builder completedAt(OffsetDateTime completedAt)
-
completedAt
final RunListResponse.Run.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final RunListResponse.Run.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final RunListResponse.Run.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final RunListResponse.Run.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final RunListResponse.Run.Builder model(String model)
-
model
final RunListResponse.Run.Builder model(Optional<String> model)
Alias for calling Builder.model with
model.orElse(null).
-
model
final RunListResponse.Run.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
prompt
final RunListResponse.Run.Builder prompt(String prompt)
Truncated to first 200 characters
-
prompt
final RunListResponse.Run.Builder prompt(JsonField<String> prompt)
Sets Builder.prompt to an arbitrary JSON value.
You should usually call Builder.prompt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startedAt
final RunListResponse.Run.Builder startedAt(OffsetDateTime startedAt)
-
startedAt
final RunListResponse.Run.Builder startedAt(Optional<OffsetDateTime> startedAt)
Alias for calling Builder.startedAt with
startedAt.orElse(null).
-
startedAt
final RunListResponse.Run.Builder startedAt(JsonField<OffsetDateTime> startedAt)
Sets Builder.startedAt to an arbitrary JSON value.
You should usually call Builder.startedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final RunListResponse.Run.Builder status(RunListResponse.Run.Status status)
-
status
final RunListResponse.Run.Builder status(JsonField<RunListResponse.Run.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunListResponse.Run.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunListResponse.Run.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunListResponse.Run.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunListResponse.Run.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunListResponse.Run.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunListResponse.Run build()
Returns an immutable instance of Run.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-