Package dev.case.api.models.agent.v1.run
Class RunWatchParams.Body
-
- All Implemented Interfaces:
public final class RunWatchParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunWatchParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcallbackUrl()HTTPS URL to receive completion callback final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final Map<String, JsonValue>_additionalProperties()final RunWatchParams.Body.BuildertoBuilder()final RunWatchParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunWatchParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
callbackUrl
final String callbackUrl()
HTTPS URL to receive completion callback
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunWatchParams.Body.Builder toBuilder()
-
validate
final RunWatchParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunWatchParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.callbackUrl()
-
-
-
-