Package dev.case.api.models.agent.v1.run
Class RunWatchResponse
-
- All Implemented Interfaces:
public final class RunWatchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunWatchResponse.BuilderA builder for RunWatchResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>callbackUrl()final Optional<Boolean>ok()final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final JsonField<Boolean>_ok()Returns the raw JSON value of ok. final Map<String, JsonValue>_additionalProperties()final RunWatchResponse.BuildertoBuilder()final RunWatchResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunWatchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RunWatchResponse. -
-
Method Detail
-
callbackUrl
final Optional<String> callbackUrl()
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_ok
final JsonField<Boolean> _ok()
Returns the raw JSON value of ok.
Unlike ok, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunWatchResponse.Builder toBuilder()
-
validate
final RunWatchResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RunWatchResponse.Builder builder()
Returns a mutable builder for constructing an instance of RunWatchResponse.
-
-
-
-