Package dev.case.api.models.agent.v1.run
Class RunWatchResponse.Builder
-
- All Implemented Interfaces:
public final class RunWatchResponse.BuilderA builder for RunWatchResponse.
-
-
Method Summary
Modifier and Type Method Description final RunWatchResponse.BuildercallbackUrl(String callbackUrl)final RunWatchResponse.BuildercallbackUrl(JsonField<String> callbackUrl)Sets Builder.callbackUrl to an arbitrary JSON value. final RunWatchResponse.Builderok(Boolean ok)final RunWatchResponse.Builderok(JsonField<Boolean> ok)Sets Builder.ok to an arbitrary JSON value. final RunWatchResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RunWatchResponse.BuilderputAdditionalProperty(String key, JsonValue value)final RunWatchResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RunWatchResponse.BuilderremoveAdditionalProperty(String key)final RunWatchResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final RunWatchResponsebuild()Returns an immutable instance of RunWatchResponse. -
-
Method Detail
-
callbackUrl
final RunWatchResponse.Builder callbackUrl(String callbackUrl)
-
callbackUrl
final RunWatchResponse.Builder callbackUrl(JsonField<String> callbackUrl)
Sets Builder.callbackUrl to an arbitrary JSON value.
You should usually call Builder.callbackUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ok
final RunWatchResponse.Builder ok(Boolean ok)
-
ok
final RunWatchResponse.Builder ok(JsonField<Boolean> ok)
Sets Builder.ok to an arbitrary JSON value.
You should usually call Builder.ok with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunWatchResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunWatchResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunWatchResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunWatchResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunWatchResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunWatchResponse build()
Returns an immutable instance of RunWatchResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-