Class ChatCreateResponse
-
- All Implemented Interfaces:
public final class ChatCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateResponse.BuilderA builder for ChatCreateResponse.
public final classChatCreateResponse.Provider
-
Method Summary
-
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
idleTimeoutMs
final Optional<Long> idleTimeoutMs()
-
provider
final Optional<ChatCreateResponse.Provider> provider()
-
runtimeState
final Optional<String> runtimeState()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_idleTimeoutMs
final JsonField<Long> _idleTimeoutMs()
Returns the raw JSON value of idleTimeoutMs.
Unlike idleTimeoutMs, this method doesn't throw if the JSON field has an unexpected type.
-
_provider
final JsonField<ChatCreateResponse.Provider> _provider()
Returns the raw JSON value of provider.
Unlike provider, this method doesn't throw if the JSON field has an unexpected type.
-
_runtimeState
final JsonField<String> _runtimeState()
Returns the raw JSON value of runtimeState.
Unlike runtimeState, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateResponse.Builder toBuilder()
-
validate
final ChatCreateResponse validate()
-
builder
final static ChatCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChatCreateResponse.
-
-
-
-