Class ChatCreateStreamTokenResponse
-
- All Implemented Interfaces:
public final class ChatCreateStreamTokenResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateStreamTokenResponse.BuilderA builder for ChatCreateStreamTokenResponse.
-
Method Summary
Modifier and Type Method Description final Stringtoken()final OffsetDateTimeexpiresAt()final StringstreamUrl()final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_expiresAt()Returns the raw JSON value of expiresAt. final JsonField<String>_streamUrl()Returns the raw JSON value of streamUrl. final Map<String, JsonValue>_additionalProperties()final ChatCreateStreamTokenResponse.BuildertoBuilder()final ChatCreateStreamTokenResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateStreamTokenResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ChatCreateStreamTokenResponse. -
-
Method Detail
-
expiresAt
final OffsetDateTime expiresAt()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_streamUrl
final JsonField<String> _streamUrl()
Returns the raw JSON value of streamUrl.
Unlike streamUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateStreamTokenResponse.Builder toBuilder()
-
validate
final ChatCreateStreamTokenResponse validate()
-
builder
final static ChatCreateStreamTokenResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChatCreateStreamTokenResponse.
The following fields are required:
.token() .expiresAt() .streamUrl()
-
-
-
-