Class ChatCreateStreamTokenResponse.Builder
-
- All Implemented Interfaces:
public final class ChatCreateStreamTokenResponse.BuilderA builder for ChatCreateStreamTokenResponse.
-
-
Method Summary
-
-
Method Detail
-
token
final ChatCreateStreamTokenResponse.Builder token(String token)
-
token
final ChatCreateStreamTokenResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiresAt
final ChatCreateStreamTokenResponse.Builder expiresAt(OffsetDateTime expiresAt)
-
expiresAt
final ChatCreateStreamTokenResponse.Builder expiresAt(JsonField<OffsetDateTime> expiresAt)
Sets Builder.expiresAt to an arbitrary JSON value.
You should usually call Builder.expiresAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
streamUrl
final ChatCreateStreamTokenResponse.Builder streamUrl(String streamUrl)
-
streamUrl
final ChatCreateStreamTokenResponse.Builder streamUrl(JsonField<String> streamUrl)
Sets Builder.streamUrl to an arbitrary JSON value.
You should usually call Builder.streamUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatCreateStreamTokenResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatCreateStreamTokenResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatCreateStreamTokenResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatCreateStreamTokenResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatCreateStreamTokenResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatCreateStreamTokenResponse build()
Returns an immutable instance of ChatCreateStreamTokenResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .expiresAt() .streamUrl()
-
-
-
-