Class ChatDeleteResponse.Builder
-
- All Implemented Interfaces:
public final class ChatDeleteResponse.BuilderA builder for ChatDeleteResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ChatDeleteResponse.Builder id(String id)
-
id
final ChatDeleteResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cost
final ChatDeleteResponse.Builder cost(Double cost)
-
cost
final ChatDeleteResponse.Builder cost(JsonField<Double> cost)
Sets Builder.cost to an arbitrary JSON value.
You should usually call Builder.cost with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
provider
final ChatDeleteResponse.Builder provider(String provider)
-
provider
final ChatDeleteResponse.Builder provider(Optional<String> provider)
Alias for calling Builder.provider with
provider.orElse(null).
-
provider
final ChatDeleteResponse.Builder provider(JsonField<String> provider)
Sets Builder.provider to an arbitrary JSON value.
You should usually call Builder.provider with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeId
final ChatDeleteResponse.Builder runtimeId(String runtimeId)
-
runtimeId
final ChatDeleteResponse.Builder runtimeId(Optional<String> runtimeId)
Alias for calling Builder.runtimeId with
runtimeId.orElse(null).
-
runtimeId
final ChatDeleteResponse.Builder runtimeId(JsonField<String> runtimeId)
Sets Builder.runtimeId to an arbitrary JSON value.
You should usually call Builder.runtimeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeMs
final ChatDeleteResponse.Builder runtimeMs(Long runtimeMs)
-
runtimeMs
final ChatDeleteResponse.Builder runtimeMs(JsonField<Long> runtimeMs)
Sets Builder.runtimeMs to an arbitrary JSON value.
You should usually call Builder.runtimeMs with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ChatDeleteResponse.Builder status(String status)
-
status
final ChatDeleteResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatDeleteResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatDeleteResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatDeleteResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatDeleteResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatDeleteResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatDeleteResponse build()
Returns an immutable instance of ChatDeleteResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-