Class ChatSendMessageParams.Body.Builder
-
- All Implemented Interfaces:
public final class ChatSendMessageParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
model
final ChatSendMessageParams.Body.Builder model(String model)
Optional model override. When provided, the runtime bootstrap config is updated so subsequent turns use this model. Conversation history is preserved.
-
model
final ChatSendMessageParams.Body.Builder model(Optional<String> model)
Alias for calling Builder.model with
model.orElse(null).
-
model
final ChatSendMessageParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
parts
final ChatSendMessageParams.Body.Builder parts(List<ChatSendMessageParams.Part> parts)
Message content parts. Currently only "text" type is supported. Additional types (e.g. file, image) may be added in future versions.
-
parts
final ChatSendMessageParams.Body.Builder parts(JsonField<List<ChatSendMessageParams.Part>> parts)
Sets Builder.parts to an arbitrary JSON value.
You should usually call Builder.parts with a well-typed
List<Part>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPart
final ChatSendMessageParams.Body.Builder addPart(ChatSendMessageParams.Part part)
-
additionalProperties
final ChatSendMessageParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatSendMessageParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatSendMessageParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatSendMessageParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatSendMessageParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatSendMessageParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-