Class ExecuteCreateParams.Body
-
- All Implemented Interfaces:
public final class ExecuteCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExecuteCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
disabledTools
final Optional<List<String>> disabledTools()
-
enabledTools
final Optional<List<String>> enabledTools()
-
instructions
final Optional<String> instructions()
-
sandbox
final Optional<ExecuteCreateParams.Sandbox> sandbox()
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_disabledTools
final JsonField<List<String>> _disabledTools()
Returns the raw JSON value of disabledTools.
Unlike disabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_enabledTools
final JsonField<List<String>> _enabledTools()
Returns the raw JSON value of enabledTools.
Unlike enabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_guidance
final JsonField<String> _guidance()
Returns the raw JSON value of guidance.
Unlike guidance, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_objectIds
final JsonField<List<String>> _objectIds()
Returns the raw JSON value of objectIds.
Unlike objectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_sandbox
final JsonField<ExecuteCreateParams.Sandbox> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExecuteCreateParams.Body.Builder toBuilder()
-
validate
final ExecuteCreateParams.Body validate()
-
builder
final static ExecuteCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.prompt()
-
-
-
-