Class ExecuteCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ExecuteCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
prompt
final ExecuteCreateParams.Body.Builder prompt(String prompt)
-
prompt
final ExecuteCreateParams.Body.Builder prompt(JsonField<String> prompt)
Sets Builder.prompt to an arbitrary JSON value.
You should usually call Builder.prompt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disabledTools
final ExecuteCreateParams.Body.Builder disabledTools(List<String> disabledTools)
-
disabledTools
final ExecuteCreateParams.Body.Builder disabledTools(Optional<List<String>> disabledTools)
Alias for calling Builder.disabledTools with
disabledTools.orElse(null).
-
disabledTools
final ExecuteCreateParams.Body.Builder disabledTools(JsonField<List<String>> disabledTools)
Sets Builder.disabledTools to an arbitrary JSON value.
You should usually call Builder.disabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDisabledTool
final ExecuteCreateParams.Body.Builder addDisabledTool(String disabledTool)
Adds a single String to disabledTools.
-
enabledTools
final ExecuteCreateParams.Body.Builder enabledTools(List<String> enabledTools)
-
enabledTools
final ExecuteCreateParams.Body.Builder enabledTools(Optional<List<String>> enabledTools)
Alias for calling Builder.enabledTools with
enabledTools.orElse(null).
-
enabledTools
final ExecuteCreateParams.Body.Builder enabledTools(JsonField<List<String>> enabledTools)
Sets Builder.enabledTools to an arbitrary JSON value.
You should usually call Builder.enabledTools with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEnabledTool
final ExecuteCreateParams.Body.Builder addEnabledTool(String enabledTool)
Adds a single String to enabledTools.
-
guidance
final ExecuteCreateParams.Body.Builder guidance(String guidance)
-
guidance
final ExecuteCreateParams.Body.Builder guidance(Optional<String> guidance)
Alias for calling Builder.guidance with
guidance.orElse(null).
-
guidance
final ExecuteCreateParams.Body.Builder guidance(JsonField<String> guidance)
Sets Builder.guidance to an arbitrary JSON value.
You should usually call Builder.guidance with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructions
final ExecuteCreateParams.Body.Builder instructions(String instructions)
-
instructions
final ExecuteCreateParams.Body.Builder instructions(JsonField<String> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final ExecuteCreateParams.Body.Builder model(String model)
-
model
final ExecuteCreateParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectIds
final ExecuteCreateParams.Body.Builder objectIds(List<String> objectIds)
-
objectIds
final ExecuteCreateParams.Body.Builder objectIds(Optional<List<String>> objectIds)
Alias for calling Builder.objectIds with
objectIds.orElse(null).
-
objectIds
final ExecuteCreateParams.Body.Builder objectIds(JsonField<List<String>> objectIds)
Sets Builder.objectIds to an arbitrary JSON value.
You should usually call Builder.objectIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addObjectId
final ExecuteCreateParams.Body.Builder addObjectId(String objectId)
-
sandbox
final ExecuteCreateParams.Body.Builder sandbox(ExecuteCreateParams.Sandbox sandbox)
-
sandbox
final ExecuteCreateParams.Body.Builder sandbox(Optional<ExecuteCreateParams.Sandbox> sandbox)
Alias for calling Builder.sandbox with
sandbox.orElse(null).
-
sandbox
final ExecuteCreateParams.Body.Builder sandbox(JsonField<ExecuteCreateParams.Sandbox> sandbox)
Sets Builder.sandbox to an arbitrary JSON value.
You should usually call Builder.sandbox with a well-typed Sandbox value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultIds
final ExecuteCreateParams.Body.Builder vaultIds(List<String> vaultIds)
-
vaultIds
final ExecuteCreateParams.Body.Builder vaultIds(Optional<List<String>> vaultIds)
Alias for calling Builder.vaultIds with
vaultIds.orElse(null).
-
vaultIds
final ExecuteCreateParams.Body.Builder vaultIds(JsonField<List<String>> vaultIds)
Sets Builder.vaultIds to an arbitrary JSON value.
You should usually call Builder.vaultIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultId
final ExecuteCreateParams.Body.Builder addVaultId(String vaultId)
-
additionalProperties
final ExecuteCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExecuteCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExecuteCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExecuteCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExecuteCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExecuteCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.prompt()
-
-
-
-