Class ExecuteCreateResponse
-
- All Implemented Interfaces:
public final class ExecuteCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExecuteCreateResponse.BuilderA builder for ExecuteCreateResponse.
public final classExecuteCreateResponse.Providerpublic final classExecuteCreateResponse.RuntimeStatepublic final classExecuteCreateResponse.Status
-
Method Summary
-
-
Method Detail
-
provider
final Optional<ExecuteCreateResponse.Provider> provider()
-
runtimeState
final Optional<ExecuteCreateResponse.RuntimeState> runtimeState()
-
status
final Optional<ExecuteCreateResponse.Status> status()
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_provider
final JsonField<ExecuteCreateResponse.Provider> _provider()
Returns the raw JSON value of provider.
Unlike provider, this method doesn't throw if the JSON field has an unexpected type.
-
_runId
final JsonField<String> _runId()
Returns the raw JSON value of runId.
Unlike runId, this method doesn't throw if the JSON field has an unexpected type.
-
_runtimeState
final JsonField<ExecuteCreateResponse.RuntimeState> _runtimeState()
Returns the raw JSON value of runtimeState.
Unlike runtimeState, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ExecuteCreateResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExecuteCreateResponse.Builder toBuilder()
-
validate
final ExecuteCreateResponse validate()
-
builder
final static ExecuteCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExecuteCreateResponse.
-
-
-
-