Class ExecuteCreateResponse.Builder
-
- All Implemented Interfaces:
public final class ExecuteCreateResponse.BuilderA builder for ExecuteCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
agentId
final ExecuteCreateResponse.Builder agentId(String agentId)
-
agentId
final ExecuteCreateResponse.Builder agentId(JsonField<String> agentId)
Sets Builder.agentId to an arbitrary JSON value.
You should usually call Builder.agentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
error
final ExecuteCreateResponse.Builder error(String error)
-
error
final ExecuteCreateResponse.Builder error(Optional<String> error)
Alias for calling Builder.error with
error.orElse(null).
-
error
final ExecuteCreateResponse.Builder error(JsonField<String> error)
Sets Builder.error to an arbitrary JSON value.
You should usually call Builder.error with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
logs
final ExecuteCreateResponse.Builder logs(ExecuteCreateResponse.Logs logs)
-
logs
final ExecuteCreateResponse.Builder logs(Optional<ExecuteCreateResponse.Logs> logs)
Alias for calling Builder.logs with
logs.orElse(null).
-
logs
final ExecuteCreateResponse.Builder logs(JsonField<ExecuteCreateResponse.Logs> logs)
Sets Builder.logs to an arbitrary JSON value.
You should usually call Builder.logs with a well-typed Logs value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final ExecuteCreateResponse.Builder message(String message)
-
message
final ExecuteCreateResponse.Builder message(Optional<String> message)
Alias for calling Builder.message with
message.orElse(null).
-
message
final ExecuteCreateResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
output
final ExecuteCreateResponse.Builder output(String output)
-
output
final ExecuteCreateResponse.Builder output(Optional<String> output)
Alias for calling Builder.output with
output.orElse(null).
-
output
final ExecuteCreateResponse.Builder output(JsonField<String> output)
Sets Builder.output to an arbitrary JSON value.
You should usually call Builder.output with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
provider
final ExecuteCreateResponse.Builder provider(ExecuteCreateResponse.Provider provider)
-
provider
final ExecuteCreateResponse.Builder provider(JsonField<ExecuteCreateResponse.Provider> provider)
Sets Builder.provider to an arbitrary JSON value.
You should usually call Builder.provider with a well-typed Provider value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runId
final ExecuteCreateResponse.Builder runId(String runId)
-
runId
final ExecuteCreateResponse.Builder runId(JsonField<String> runId)
Sets Builder.runId to an arbitrary JSON value.
You should usually call Builder.runId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeId
final ExecuteCreateResponse.Builder runtimeId(String runtimeId)
-
runtimeId
final ExecuteCreateResponse.Builder runtimeId(Optional<String> runtimeId)
Alias for calling Builder.runtimeId with
runtimeId.orElse(null).
-
runtimeId
final ExecuteCreateResponse.Builder runtimeId(JsonField<String> runtimeId)
Sets Builder.runtimeId to an arbitrary JSON value.
You should usually call Builder.runtimeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeState
final ExecuteCreateResponse.Builder runtimeState(ExecuteCreateResponse.RuntimeState runtimeState)
-
runtimeState
final ExecuteCreateResponse.Builder runtimeState(JsonField<ExecuteCreateResponse.RuntimeState> runtimeState)
Sets Builder.runtimeState to an arbitrary JSON value.
You should usually call Builder.runtimeState with a well-typed RuntimeState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ExecuteCreateResponse.Builder status(ExecuteCreateResponse.Status status)
-
status
final ExecuteCreateResponse.Builder status(JsonField<ExecuteCreateResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
usage
final ExecuteCreateResponse.Builder usage(JsonValue usage)
-
additionalProperties
final ExecuteCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExecuteCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExecuteCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExecuteCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExecuteCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExecuteCreateResponse build()
Returns an immutable instance of ExecuteCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-