Class RunCreateParams.Body
-
- All Implemented Interfaces:
public final class RunCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
callbackUrl
final Optional<String> callbackUrl()
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_guidance
final JsonField<String> _guidance()
Returns the raw JSON value of guidance.
Unlike guidance, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_objectIds
final JsonField<List<String>> _objectIds()
Returns the raw JSON value of objectIds.
Unlike objectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunCreateParams.Body.Builder toBuilder()
-
validate
final RunCreateParams.Body validate()
-
builder
final static RunCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.agentId() .prompt()
-
-
-
-