Class RunCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class RunCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
agentId
final RunCreateParams.Body.Builder agentId(String agentId)
-
agentId
final RunCreateParams.Body.Builder agentId(JsonField<String> agentId)
Sets Builder.agentId to an arbitrary JSON value.
You should usually call Builder.agentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
prompt
final RunCreateParams.Body.Builder prompt(String prompt)
-
prompt
final RunCreateParams.Body.Builder prompt(JsonField<String> prompt)
Sets Builder.prompt to an arbitrary JSON value.
You should usually call Builder.prompt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
callbackUrl
final RunCreateParams.Body.Builder callbackUrl(String callbackUrl)
-
callbackUrl
final RunCreateParams.Body.Builder callbackUrl(Optional<String> callbackUrl)
Alias for calling Builder.callbackUrl with
callbackUrl.orElse(null).
-
callbackUrl
final RunCreateParams.Body.Builder callbackUrl(JsonField<String> callbackUrl)
Sets Builder.callbackUrl to an arbitrary JSON value.
You should usually call Builder.callbackUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
guidance
final RunCreateParams.Body.Builder guidance(String guidance)
-
guidance
final RunCreateParams.Body.Builder guidance(Optional<String> guidance)
Alias for calling Builder.guidance with
guidance.orElse(null).
-
guidance
final RunCreateParams.Body.Builder guidance(JsonField<String> guidance)
Sets Builder.guidance to an arbitrary JSON value.
You should usually call Builder.guidance with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final RunCreateParams.Body.Builder model(String model)
-
model
final RunCreateParams.Body.Builder model(Optional<String> model)
Alias for calling Builder.model with
model.orElse(null).
-
model
final RunCreateParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectIds
final RunCreateParams.Body.Builder objectIds(List<String> objectIds)
-
objectIds
final RunCreateParams.Body.Builder objectIds(Optional<List<String>> objectIds)
Alias for calling Builder.objectIds with
objectIds.orElse(null).
-
objectIds
final RunCreateParams.Body.Builder objectIds(JsonField<List<String>> objectIds)
Sets Builder.objectIds to an arbitrary JSON value.
You should usually call Builder.objectIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addObjectId
final RunCreateParams.Body.Builder addObjectId(String objectId)
-
additionalProperties
final RunCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.agentId() .prompt()
-
-
-
-