Class RunExecResponse.Builder
-
- All Implemented Interfaces:
public final class RunExecResponse.BuilderA builder for RunExecResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final RunExecResponse.Builder id(String id)
-
id
final RunExecResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final RunExecResponse.Builder message(String message)
-
message
final RunExecResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
provider
final RunExecResponse.Builder provider(RunExecResponse.Provider provider)
-
provider
final RunExecResponse.Builder provider(JsonField<RunExecResponse.Provider> provider)
Sets Builder.provider to an arbitrary JSON value.
You should usually call Builder.provider with a well-typed Provider value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeState
final RunExecResponse.Builder runtimeState(RunExecResponse.RuntimeState runtimeState)
-
runtimeState
final RunExecResponse.Builder runtimeState(JsonField<RunExecResponse.RuntimeState> runtimeState)
Sets Builder.runtimeState to an arbitrary JSON value.
You should usually call Builder.runtimeState with a well-typed RuntimeState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final RunExecResponse.Builder status(RunExecResponse.Status status)
-
status
final RunExecResponse.Builder status(JsonField<RunExecResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workflowId
final RunExecResponse.Builder workflowId(String workflowId)
-
workflowId
final RunExecResponse.Builder workflowId(JsonField<String> workflowId)
Sets Builder.workflowId to an arbitrary JSON value.
You should usually call Builder.workflowId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunExecResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunExecResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunExecResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunExecResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunExecResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunExecResponse build()
Returns an immutable instance of RunExecResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-