Class RunGetStatusResponse.Builder
-
- All Implemented Interfaces:
public final class RunGetStatusResponse.BuilderA builder for RunGetStatusResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final RunGetStatusResponse.Builder id(String id)
-
id
final RunGetStatusResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final RunGetStatusResponse.Builder completedAt(OffsetDateTime completedAt)
-
completedAt
final RunGetStatusResponse.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final RunGetStatusResponse.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
durationMs
final RunGetStatusResponse.Builder durationMs(Long durationMs)
-
durationMs
final RunGetStatusResponse.Builder durationMs(Long durationMs)
Alias for Builder.durationMs.
This unboxed primitive overload exists for backwards compatibility.
-
durationMs
final RunGetStatusResponse.Builder durationMs(Optional<Long> durationMs)
Alias for calling Builder.durationMs with
durationMs.orElse(null).
-
durationMs
final RunGetStatusResponse.Builder durationMs(JsonField<Long> durationMs)
Sets Builder.durationMs to an arbitrary JSON value.
You should usually call Builder.durationMs with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
provider
final RunGetStatusResponse.Builder provider(String provider)
-
provider
final RunGetStatusResponse.Builder provider(Optional<String> provider)
Alias for calling Builder.provider with
provider.orElse(null).
-
provider
final RunGetStatusResponse.Builder provider(JsonField<String> provider)
Sets Builder.provider to an arbitrary JSON value.
You should usually call Builder.provider with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeId
final RunGetStatusResponse.Builder runtimeId(String runtimeId)
-
runtimeId
final RunGetStatusResponse.Builder runtimeId(Optional<String> runtimeId)
Alias for calling Builder.runtimeId with
runtimeId.orElse(null).
-
runtimeId
final RunGetStatusResponse.Builder runtimeId(JsonField<String> runtimeId)
Sets Builder.runtimeId to an arbitrary JSON value.
You should usually call Builder.runtimeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
runtimeState
final RunGetStatusResponse.Builder runtimeState(String runtimeState)
-
runtimeState
final RunGetStatusResponse.Builder runtimeState(Optional<String> runtimeState)
Alias for calling Builder.runtimeState with
runtimeState.orElse(null).
-
runtimeState
final RunGetStatusResponse.Builder runtimeState(JsonField<String> runtimeState)
Sets Builder.runtimeState to an arbitrary JSON value.
You should usually call Builder.runtimeState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startedAt
final RunGetStatusResponse.Builder startedAt(OffsetDateTime startedAt)
-
startedAt
final RunGetStatusResponse.Builder startedAt(Optional<OffsetDateTime> startedAt)
Alias for calling Builder.startedAt with
startedAt.orElse(null).
-
startedAt
final RunGetStatusResponse.Builder startedAt(JsonField<OffsetDateTime> startedAt)
Sets Builder.startedAt to an arbitrary JSON value.
You should usually call Builder.startedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final RunGetStatusResponse.Builder status(RunGetStatusResponse.Status status)
-
status
final RunGetStatusResponse.Builder status(JsonField<RunGetStatusResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RunGetStatusResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RunGetStatusResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RunGetStatusResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RunGetStatusResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RunGetStatusResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RunGetStatusResponse build()
Returns an immutable instance of RunGetStatusResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-