Class DeploymentCreateParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class DeploymentCreateParams
     implements Params
                        

    Creates a deployment for an existing project by fetching repository files from GitHub and uploading them to the hosting provider. Use ref to deploy a branch, tag, or commit other than the project default branch.