Class DeploymentCreateParams.Body
-
- All Implemented Interfaces:
public final class DeploymentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeploymentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringprojectId()Project ID to deploy final Optional<String>ref()Git branch, tag, or commit to deploy. final Optional<DeploymentCreateParams.Target>target()Deployment target environment final JsonField<String>_projectId()Returns the raw JSON value of projectId. final JsonField<String>_ref()Returns the raw JSON value of ref. final JsonField<DeploymentCreateParams.Target>_target()Returns the raw JSON value of target. final Map<String, JsonValue>_additionalProperties()final DeploymentCreateParams.Body.BuildertoBuilder()final DeploymentCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeploymentCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
ref
final Optional<String> ref()
Git branch, tag, or commit to deploy. Defaults to the project branch.
-
target
final Optional<DeploymentCreateParams.Target> target()
Deployment target environment
-
_projectId
final JsonField<String> _projectId()
Returns the raw JSON value of projectId.
Unlike projectId, this method doesn't throw if the JSON field has an unexpected type.
-
_ref
final JsonField<String> _ref()
Returns the raw JSON value of ref.
Unlike ref, this method doesn't throw if the JSON field has an unexpected type.
-
_target
final JsonField<DeploymentCreateParams.Target> _target()
Returns the raw JSON value of target.
Unlike target, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeploymentCreateParams.Body.Builder toBuilder()
-
validate
final DeploymentCreateParams.Body validate()
-
builder
final static DeploymentCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.projectId()
-
-
-
-