Class DeploymentCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class DeploymentCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
projectId
final DeploymentCreateParams.Body.Builder projectId(String projectId)
Project ID
-
projectId
final DeploymentCreateParams.Body.Builder projectId(JsonField<String> projectId)
Sets Builder.projectId to an arbitrary JSON value.
You should usually call Builder.projectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ref
final DeploymentCreateParams.Body.Builder ref(String ref)
Git ref (branch, tag, or commit) to deploy
-
ref
final DeploymentCreateParams.Body.Builder ref(JsonField<String> ref)
Sets Builder.ref to an arbitrary JSON value.
You should usually call Builder.ref with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
target
final DeploymentCreateParams.Body.Builder target(DeploymentCreateParams.Target target)
Deployment target
-
target
final DeploymentCreateParams.Body.Builder target(JsonField<DeploymentCreateParams.Target> target)
Sets Builder.target to an arbitrary JSON value.
You should usually call Builder.target with a well-typed Target value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DeploymentCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeploymentCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeploymentCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeploymentCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeploymentCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeploymentCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.projectId()
-
-
-
-