Class DeploymentGetLogsParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class DeploymentGetLogsParams
     implements Params
                        

    Returns build and runtime log events for a deployment after verifying access to the owning project. Use this when you need detailed output for a failed or in-progress build.