Class DeploymentGetStatusParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class DeploymentGetStatusParams
     implements Params
                        

    Returns the current status of a deployment without fetching full build logs. Use this endpoint for lightweight polling while a deployment is building or waiting to become ready.