Class DeploymentRetrieveParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class DeploymentRetrieveParams
     implements Params
                        

    Returns deployment details for one project in the authenticated organization. Set includeLogs=true to include recent build output in the response.