Class DeploymentStreamParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class DeploymentStreamParams implements Params
Stream real-time deployment progress events via Server-Sent Events
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeploymentStreamParams.BuilderA builder for DeploymentStreamParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final StringprojectId()Project ID (for authorization) final Optional<Double>startIndex()Resume stream from this index (for reconnection) final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DeploymentStreamParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeploymentStreamParams.Builderbuilder()Returns a mutable builder for constructing an instance of DeploymentStreamParams. -
-
Method Detail
-
startIndex
final Optional<Double> startIndex()
Resume stream from this index (for reconnection)
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DeploymentStreamParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static DeploymentStreamParams.Builder builder()
Returns a mutable builder for constructing an instance of DeploymentStreamParams.
The following fields are required:
.projectId()
-
-
-
-