Class ProjectCreateDeploymentParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectCreateDeploymentParams
     implements Params
                        

    Starts a new deployment for an existing project using its saved repository and hosting configuration. Any environment variables passed in the request are merged into the deployment workflow before the build starts.