Class ProjectCreateDeploymentParams.EnvironmentVariable.Builder
-
- All Implemented Interfaces:
public final class ProjectCreateDeploymentParams.EnvironmentVariable.BuilderA builder for EnvironmentVariable.
-
-
Method Summary
-
-
Method Detail
-
key
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder key(String key)
Environment variable name
-
key
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder key(JsonField<String> key)
Sets Builder.key to an arbitrary JSON value.
You should usually call Builder.key with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
target
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder target(List<ProjectCreateDeploymentParams.EnvironmentVariable.Target> target)
Deployment targets that should receive this variable
-
target
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder target(JsonField<List<ProjectCreateDeploymentParams.EnvironmentVariable.Target>> target)
Sets Builder.target to an arbitrary JSON value.
You should usually call Builder.target with a well-typed
List<Target>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTarget
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder addTarget(ProjectCreateDeploymentParams.EnvironmentVariable.Target target)
Adds a single Target to Builder.target.
-
value
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder value(String value)
Environment variable value
-
value
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder value(JsonField<String> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder type(ProjectCreateDeploymentParams.EnvironmentVariable.Type type)
Storage mode for the environment variable value
-
type
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder type(JsonField<ProjectCreateDeploymentParams.EnvironmentVariable.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectCreateDeploymentParams.EnvironmentVariable.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectCreateDeploymentParams.EnvironmentVariable build()
Returns an immutable instance of EnvironmentVariable.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.key() .target() .value()
-
-
-
-