Class ProjectCreateDomainParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectCreateDomainParams implements Params
Add a custom domain to a project
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateDomainParams.BuilderA builder for ProjectCreateDomainParams.
public final classProjectCreateDomainParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Stringdomain()Domain name to add final Optional<String>gitBranch()Git branch to associate with this domain final JsonField<String>_domain()Returns the raw JSON value of domain. final JsonField<String>_gitBranch()Returns the raw JSON value of gitBranch. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectCreateDomainParams.BuildertoBuilder()final ProjectCreateDomainParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateDomainParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateDomainParams. -
-
Method Detail
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_gitBranch
final JsonField<String> _gitBranch()
Returns the raw JSON value of gitBranch.
Unlike gitBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectCreateDomainParams.Builder toBuilder()
-
_body
final ProjectCreateDomainParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ProjectCreateDomainParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateDomainParams.
The following fields are required:
.domain()
-
-
-
-