Class ProjectCreateDomainParams.Body
-
- All Implemented Interfaces:
public final class ProjectCreateDomainParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateDomainParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringdomain()Domain name to add final Optional<String>gitBranch()Git branch to associate with this domain final JsonField<String>_domain()Returns the raw JSON value of domain. final JsonField<String>_gitBranch()Returns the raw JSON value of gitBranch. final Map<String, JsonValue>_additionalProperties()final ProjectCreateDomainParams.Body.BuildertoBuilder()final ProjectCreateDomainParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateDomainParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_gitBranch
final JsonField<String> _gitBranch()
Returns the raw JSON value of gitBranch.
Unlike gitBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateDomainParams.Body.Builder toBuilder()
-
validate
final ProjectCreateDomainParams.Body validate()
-
builder
final static ProjectCreateDomainParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.domain()
-
-
-
-