Class ProjectCreateEnvParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectCreateEnvParams implements Params
Create a new environment variable for a project
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateEnvParams.BuilderA builder for ProjectCreateEnvParams.
public final classProjectCreateEnvParams.Bodypublic final classProjectCreateEnvParams.Targetpublic final classProjectCreateEnvParams.TypeVariable type
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Stringkey()Environment variable name final List<ProjectCreateEnvParams.Target>target()Deployment targets for this variable final Stringvalue()Environment variable value final Optional<String>gitBranch()Specific git branch (for preview deployments) final Optional<ProjectCreateEnvParams.Type>type()Variable type final JsonField<String>_key()Returns the raw JSON value of key. final JsonField<List<ProjectCreateEnvParams.Target>>_target()Returns the raw JSON value of target. final JsonField<String>_value()Returns the raw JSON value of value. final JsonField<String>_gitBranch()Returns the raw JSON value of gitBranch. final JsonField<ProjectCreateEnvParams.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectCreateEnvParams.BuildertoBuilder()final ProjectCreateEnvParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateEnvParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateEnvParams. -
-
Method Detail
-
target
final List<ProjectCreateEnvParams.Target> target()
Deployment targets for this variable
-
type
final Optional<ProjectCreateEnvParams.Type> type()
Variable type
-
_key
final JsonField<String> _key()
Returns the raw JSON value of key.
Unlike key, this method doesn't throw if the JSON field has an unexpected type.
-
_target
final JsonField<List<ProjectCreateEnvParams.Target>> _target()
Returns the raw JSON value of target.
Unlike target, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_gitBranch
final JsonField<String> _gitBranch()
Returns the raw JSON value of gitBranch.
Unlike gitBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ProjectCreateEnvParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectCreateEnvParams.Builder toBuilder()
-
_body
final ProjectCreateEnvParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ProjectCreateEnvParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateEnvParams.
The following fields are required:
.key() .target() .value()
-
-
-
-