Class ProjectCreateEnvParams.Body
-
- All Implemented Interfaces:
public final class ProjectCreateEnvParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateEnvParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringkey()Environment variable name final List<ProjectCreateEnvParams.Target>target()Deployment targets for this variable final Stringvalue()Environment variable value final Optional<String>gitBranch()Specific git branch (for preview deployments) final Optional<ProjectCreateEnvParams.Type>type()Variable type final JsonField<String>_key()Returns the raw JSON value of key. final JsonField<List<ProjectCreateEnvParams.Target>>_target()Returns the raw JSON value of target. final JsonField<String>_value()Returns the raw JSON value of value. final JsonField<String>_gitBranch()Returns the raw JSON value of gitBranch. final JsonField<ProjectCreateEnvParams.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final ProjectCreateEnvParams.Body.BuildertoBuilder()final ProjectCreateEnvParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateEnvParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
target
final List<ProjectCreateEnvParams.Target> target()
Deployment targets for this variable
-
type
final Optional<ProjectCreateEnvParams.Type> type()
Variable type
-
_key
final JsonField<String> _key()
Returns the raw JSON value of key.
Unlike key, this method doesn't throw if the JSON field has an unexpected type.
-
_target
final JsonField<List<ProjectCreateEnvParams.Target>> _target()
Returns the raw JSON value of target.
Unlike target, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_gitBranch
final JsonField<String> _gitBranch()
Returns the raw JSON value of gitBranch.
Unlike gitBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ProjectCreateEnvParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateEnvParams.Body.Builder toBuilder()
-
validate
final ProjectCreateEnvParams.Body validate()
-
builder
final static ProjectCreateEnvParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.key() .target() .value()
-
-
-
-