Class ProjectCreateEnvParams.Body.Builder
-
- All Implemented Interfaces:
public final class ProjectCreateEnvParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
key
final ProjectCreateEnvParams.Body.Builder key(String key)
Environment variable name
-
key
final ProjectCreateEnvParams.Body.Builder key(JsonField<String> key)
Sets Builder.key to an arbitrary JSON value.
You should usually call Builder.key with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
target
final ProjectCreateEnvParams.Body.Builder target(List<ProjectCreateEnvParams.Target> target)
Deployment targets for this variable
-
target
final ProjectCreateEnvParams.Body.Builder target(JsonField<List<ProjectCreateEnvParams.Target>> target)
Sets Builder.target to an arbitrary JSON value.
You should usually call Builder.target with a well-typed
List<Target>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTarget
final ProjectCreateEnvParams.Body.Builder addTarget(ProjectCreateEnvParams.Target target)
Adds a single Target to Builder.target.
-
value
final ProjectCreateEnvParams.Body.Builder value(String value)
Environment variable value
-
value
final ProjectCreateEnvParams.Body.Builder value(JsonField<String> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gitBranch
final ProjectCreateEnvParams.Body.Builder gitBranch(String gitBranch)
Specific git branch (for preview deployments)
-
gitBranch
final ProjectCreateEnvParams.Body.Builder gitBranch(JsonField<String> gitBranch)
Sets Builder.gitBranch to an arbitrary JSON value.
You should usually call Builder.gitBranch with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ProjectCreateEnvParams.Body.Builder type(ProjectCreateEnvParams.Type type)
Variable type
-
type
final ProjectCreateEnvParams.Body.Builder type(JsonField<ProjectCreateEnvParams.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectCreateEnvParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectCreateEnvParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectCreateEnvParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectCreateEnvParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectCreateEnvParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectCreateEnvParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.key() .target() .value()
-
-
-
-