Class ProjectCreateParams.Body
-
- All Implemented Interfaces:
public final class ProjectCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringgitRepo()GitHub repository URL or owner/repo identifier final Stringname()Human-readable project name final Optional<String>buildCommand()Custom build command to override the framework default final Optional<List<ProjectCreateParams.EnvironmentVariable>>environmentVariables()Environment variables to create before the first deployment final Optional<String>framework()Framework preset for the hosting project, such as nextjs or remix final Optional<String>gitBranch()Git branch to deploy. final Optional<String>installCommand()Custom install command to override the framework default final Optional<String>outputDirectory()Build output directory relative to the project root final Optional<String>rootDirectory()Repository subdirectory that contains the app to deploy final JsonField<String>_gitRepo()Returns the raw JSON value of gitRepo. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_buildCommand()Returns the raw JSON value of buildCommand. final JsonField<List<ProjectCreateParams.EnvironmentVariable>>_environmentVariables()Returns the raw JSON value of environmentVariables. final JsonField<String>_framework()Returns the raw JSON value of framework. final JsonField<String>_gitBranch()Returns the raw JSON value of gitBranch. final JsonField<String>_installCommand()Returns the raw JSON value of installCommand. final JsonField<String>_outputDirectory()Returns the raw JSON value of outputDirectory. final JsonField<String>_rootDirectory()Returns the raw JSON value of rootDirectory. final Map<String, JsonValue>_additionalProperties()final ProjectCreateParams.Body.BuildertoBuilder()final ProjectCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
buildCommand
final Optional<String> buildCommand()
Custom build command to override the framework default
-
environmentVariables
final Optional<List<ProjectCreateParams.EnvironmentVariable>> environmentVariables()
Environment variables to create before the first deployment
-
framework
final Optional<String> framework()
Framework preset for the hosting project, such as nextjs or remix
-
installCommand
final Optional<String> installCommand()
Custom install command to override the framework default
-
outputDirectory
final Optional<String> outputDirectory()
Build output directory relative to the project root
-
rootDirectory
final Optional<String> rootDirectory()
Repository subdirectory that contains the app to deploy
-
_gitRepo
final JsonField<String> _gitRepo()
Returns the raw JSON value of gitRepo.
Unlike gitRepo, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_buildCommand
final JsonField<String> _buildCommand()
Returns the raw JSON value of buildCommand.
Unlike buildCommand, this method doesn't throw if the JSON field has an unexpected type.
-
_environmentVariables
final JsonField<List<ProjectCreateParams.EnvironmentVariable>> _environmentVariables()
Returns the raw JSON value of environmentVariables.
Unlike environmentVariables, this method doesn't throw if the JSON field has an unexpected type.
-
_framework
final JsonField<String> _framework()
Returns the raw JSON value of framework.
Unlike framework, this method doesn't throw if the JSON field has an unexpected type.
-
_gitBranch
final JsonField<String> _gitBranch()
Returns the raw JSON value of gitBranch.
Unlike gitBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_installCommand
final JsonField<String> _installCommand()
Returns the raw JSON value of installCommand.
Unlike installCommand, this method doesn't throw if the JSON field has an unexpected type.
-
_outputDirectory
final JsonField<String> _outputDirectory()
Returns the raw JSON value of outputDirectory.
Unlike outputDirectory, this method doesn't throw if the JSON field has an unexpected type.
-
_rootDirectory
final JsonField<String> _rootDirectory()
Returns the raw JSON value of rootDirectory.
Unlike rootDirectory, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateParams.Body.Builder toBuilder()
-
validate
final ProjectCreateParams.Body validate()
-
builder
final static ProjectCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.gitRepo() .name()
-
-
-
-