Class ProjectCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ProjectCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
gitRepo
final ProjectCreateParams.Body.Builder gitRepo(String gitRepo)
GitHub repository URL or owner/repo identifier
-
gitRepo
final ProjectCreateParams.Body.Builder gitRepo(JsonField<String> gitRepo)
Sets Builder.gitRepo to an arbitrary JSON value.
You should usually call Builder.gitRepo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectCreateParams.Body.Builder name(String name)
Human-readable project name
-
name
final ProjectCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
buildCommand
final ProjectCreateParams.Body.Builder buildCommand(String buildCommand)
Custom build command to override the framework default
-
buildCommand
final ProjectCreateParams.Body.Builder buildCommand(JsonField<String> buildCommand)
Sets Builder.buildCommand to an arbitrary JSON value.
You should usually call Builder.buildCommand with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
environmentVariables
final ProjectCreateParams.Body.Builder environmentVariables(List<ProjectCreateParams.EnvironmentVariable> environmentVariables)
Environment variables to create before the first deployment
-
environmentVariables
final ProjectCreateParams.Body.Builder environmentVariables(JsonField<List<ProjectCreateParams.EnvironmentVariable>> environmentVariables)
Sets Builder.environmentVariables to an arbitrary JSON value.
You should usually call Builder.environmentVariables with a well-typed
List<EnvironmentVariable>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEnvironmentVariable
final ProjectCreateParams.Body.Builder addEnvironmentVariable(ProjectCreateParams.EnvironmentVariable environmentVariable)
Adds a single EnvironmentVariable to environmentVariables.
-
framework
final ProjectCreateParams.Body.Builder framework(String framework)
Framework preset for the hosting project, such as nextjs or remix
-
framework
final ProjectCreateParams.Body.Builder framework(JsonField<String> framework)
Sets Builder.framework to an arbitrary JSON value.
You should usually call Builder.framework with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gitBranch
final ProjectCreateParams.Body.Builder gitBranch(String gitBranch)
Git branch to deploy. Defaults to main.
-
gitBranch
final ProjectCreateParams.Body.Builder gitBranch(JsonField<String> gitBranch)
Sets Builder.gitBranch to an arbitrary JSON value.
You should usually call Builder.gitBranch with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
installCommand
final ProjectCreateParams.Body.Builder installCommand(String installCommand)
Custom install command to override the framework default
-
installCommand
final ProjectCreateParams.Body.Builder installCommand(JsonField<String> installCommand)
Sets Builder.installCommand to an arbitrary JSON value.
You should usually call Builder.installCommand with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outputDirectory
final ProjectCreateParams.Body.Builder outputDirectory(String outputDirectory)
Build output directory relative to the project root
-
outputDirectory
final ProjectCreateParams.Body.Builder outputDirectory(JsonField<String> outputDirectory)
Sets Builder.outputDirectory to an arbitrary JSON value.
You should usually call Builder.outputDirectory with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rootDirectory
final ProjectCreateParams.Body.Builder rootDirectory(String rootDirectory)
Repository subdirectory that contains the app to deploy
-
rootDirectory
final ProjectCreateParams.Body.Builder rootDirectory(JsonField<String> rootDirectory)
Sets Builder.rootDirectory to an arbitrary JSON value.
You should usually call Builder.rootDirectory with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.gitRepo() .name()
-
-
-
-