Class ProjectCreateParams.Builder
-
- All Implemented Interfaces:
public final class ProjectCreateParams.BuilderA builder for ProjectCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final ProjectCreateParams.Builder body(ProjectCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
gitRepo
final ProjectCreateParams.Builder gitRepo(String gitRepo)
GitHub repository URL or owner/repo identifier
-
gitRepo
final ProjectCreateParams.Builder gitRepo(JsonField<String> gitRepo)
Sets Builder.gitRepo to an arbitrary JSON value.
You should usually call Builder.gitRepo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectCreateParams.Builder name(String name)
Human-readable project name
-
name
final ProjectCreateParams.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
buildCommand
final ProjectCreateParams.Builder buildCommand(String buildCommand)
Custom build command to override the framework default
-
buildCommand
final ProjectCreateParams.Builder buildCommand(JsonField<String> buildCommand)
Sets Builder.buildCommand to an arbitrary JSON value.
You should usually call Builder.buildCommand with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
environmentVariables
final ProjectCreateParams.Builder environmentVariables(List<ProjectCreateParams.EnvironmentVariable> environmentVariables)
Environment variables to create before the first deployment
-
environmentVariables
final ProjectCreateParams.Builder environmentVariables(JsonField<List<ProjectCreateParams.EnvironmentVariable>> environmentVariables)
Sets Builder.environmentVariables to an arbitrary JSON value.
You should usually call Builder.environmentVariables with a well-typed
List<EnvironmentVariable>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEnvironmentVariable
final ProjectCreateParams.Builder addEnvironmentVariable(ProjectCreateParams.EnvironmentVariable environmentVariable)
Adds a single EnvironmentVariable to environmentVariables.
-
framework
final ProjectCreateParams.Builder framework(String framework)
Framework preset for the hosting project, such as nextjs or remix
-
framework
final ProjectCreateParams.Builder framework(JsonField<String> framework)
Sets Builder.framework to an arbitrary JSON value.
You should usually call Builder.framework with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gitBranch
final ProjectCreateParams.Builder gitBranch(String gitBranch)
Git branch to deploy. Defaults to main.
-
gitBranch
final ProjectCreateParams.Builder gitBranch(JsonField<String> gitBranch)
Sets Builder.gitBranch to an arbitrary JSON value.
You should usually call Builder.gitBranch with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
installCommand
final ProjectCreateParams.Builder installCommand(String installCommand)
Custom install command to override the framework default
-
installCommand
final ProjectCreateParams.Builder installCommand(JsonField<String> installCommand)
Sets Builder.installCommand to an arbitrary JSON value.
You should usually call Builder.installCommand with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outputDirectory
final ProjectCreateParams.Builder outputDirectory(String outputDirectory)
Build output directory relative to the project root
-
outputDirectory
final ProjectCreateParams.Builder outputDirectory(JsonField<String> outputDirectory)
Sets Builder.outputDirectory to an arbitrary JSON value.
You should usually call Builder.outputDirectory with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rootDirectory
final ProjectCreateParams.Builder rootDirectory(String rootDirectory)
Repository subdirectory that contains the app to deploy
-
rootDirectory
final ProjectCreateParams.Builder rootDirectory(JsonField<String> rootDirectory)
Sets Builder.rootDirectory to an arbitrary JSON value.
You should usually call Builder.rootDirectory with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final ProjectCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final ProjectCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final ProjectCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final ProjectCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final ProjectCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final ProjectCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final ProjectCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final ProjectCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final ProjectCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final ProjectCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final ProjectCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final ProjectCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final ProjectCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final ProjectCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final ProjectCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final ProjectCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final ProjectCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final ProjectCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final ProjectCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final ProjectCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final ProjectCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final ProjectCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final ProjectCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final ProjectCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final ProjectCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final ProjectCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final ProjectCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final ProjectCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final ProjectCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final ProjectCreateParams build()
Returns an immutable instance of ProjectCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.gitRepo() .name()
-
-
-
-