Class ProjectCreateParams.EnvironmentVariable
-
- All Implemented Interfaces:
public final class ProjectCreateParams.EnvironmentVariable
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateParams.EnvironmentVariable.BuilderA builder for EnvironmentVariable.
public final classProjectCreateParams.EnvironmentVariable.Targetpublic final classProjectCreateParams.EnvironmentVariable.TypeStorage mode for the environment variable value
-
Method Summary
-
-
Method Detail
-
target
final List<ProjectCreateParams.EnvironmentVariable.Target> target()
Deployment targets that should receive this variable
-
type
final Optional<ProjectCreateParams.EnvironmentVariable.Type> type()
Storage mode for the environment variable value
-
_key
final JsonField<String> _key()
Returns the raw JSON value of key.
Unlike key, this method doesn't throw if the JSON field has an unexpected type.
-
_target
final JsonField<List<ProjectCreateParams.EnvironmentVariable.Target>> _target()
Returns the raw JSON value of target.
Unlike target, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ProjectCreateParams.EnvironmentVariable.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateParams.EnvironmentVariable.Builder toBuilder()
-
validate
final ProjectCreateParams.EnvironmentVariable validate()
-
builder
final static ProjectCreateParams.EnvironmentVariable.Builder builder()
Returns a mutable builder for constructing an instance of EnvironmentVariable.
The following fields are required:
.key() .target() .value()
-
-
-
-