Class ProjectDeleteParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectDeleteParams
     implements Params
                        

    Soft-deletes an application project or deployed Thurgood app from Case.dev. By default it also removes the linked hosting project; set deleteFromHosting=false to keep the external hosting resources intact.