Class ProjectListDeploymentsParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectListDeploymentsParams
     implements Params
                        

    Lists deployments for one project in the authenticated organization. If the hosting project has not been created yet, this endpoint returns an empty list with a progress message instead of failing.