Class ProjectListParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectListParams
     implements Params
                        

    Lists application projects and deployed Thurgood apps for the authenticated organization. Use enrich=true to include additional hosting metadata for projects linked to Vercel.