Class ProjectListResponse.Project
-
- All Implemented Interfaces:
public final class ProjectListResponse.Project
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListResponse.Project.BuilderA builder for Project.
public final classProjectListResponse.Project.Domain
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Project identifier final Optional<String>createdAt()When the project record was created final Optional<List<ProjectListResponse.Project.Domain>>domains()Custom or generated domains assigned to the project final Optional<String>framework()Detected or configured application framework final Optional<String>gitBranch()Default Git branch used for deployments final Optional<String>gitRepo()Connected Git repository in owner/repo format final Optional<String>name()Project display name final Optional<String>status()Current project deployment status final Optional<String>updatedAt()When the project record was last updated final Optional<String>vercelProjectId()Hosting provider project ID, when linked final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_createdAt()Returns the raw JSON value of createdAt. final JsonField<List<ProjectListResponse.Project.Domain>>_domains()Returns the raw JSON value of domains. final JsonField<String>_framework()Returns the raw JSON value of framework. final JsonField<String>_gitBranch()Returns the raw JSON value of gitBranch. final JsonField<String>_gitRepo()Returns the raw JSON value of gitRepo. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<String>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<String>_vercelProjectId()Returns the raw JSON value of vercelProjectId. final Map<String, JsonValue>_additionalProperties()final ProjectListResponse.Project.BuildertoBuilder()final ProjectListResponse.Projectvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListResponse.Project.Builderbuilder()Returns a mutable builder for constructing an instance of Project. -
-
Method Detail
-
domains
final Optional<List<ProjectListResponse.Project.Domain>> domains()
Custom or generated domains assigned to the project
-
vercelProjectId
final Optional<String> vercelProjectId()
Hosting provider project ID, when linked
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<String> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_domains
final JsonField<List<ProjectListResponse.Project.Domain>> _domains()
Returns the raw JSON value of domains.
Unlike domains, this method doesn't throw if the JSON field has an unexpected type.
-
_framework
final JsonField<String> _framework()
Returns the raw JSON value of framework.
Unlike framework, this method doesn't throw if the JSON field has an unexpected type.
-
_gitBranch
final JsonField<String> _gitBranch()
Returns the raw JSON value of gitBranch.
Unlike gitBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_gitRepo
final JsonField<String> _gitRepo()
Returns the raw JSON value of gitRepo.
Unlike gitRepo, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<String> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_vercelProjectId
final JsonField<String> _vercelProjectId()
Returns the raw JSON value of vercelProjectId.
Unlike vercelProjectId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListResponse.Project.Builder toBuilder()
-
validate
final ProjectListResponse.Project validate()
-
builder
final static ProjectListResponse.Project.Builder builder()
Returns a mutable builder for constructing an instance of Project.
-
-
-
-