Class ProjectListResponse.Project.Builder
-
- All Implemented Interfaces:
public final class ProjectListResponse.Project.BuilderA builder for Project.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectListResponse.Project.Builder id(String id)
Project identifier
-
id
final ProjectListResponse.Project.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ProjectListResponse.Project.Builder createdAt(String createdAt)
When the project record was created
-
createdAt
final ProjectListResponse.Project.Builder createdAt(JsonField<String> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
domains
final ProjectListResponse.Project.Builder domains(List<ProjectListResponse.Project.Domain> domains)
Custom or generated domains assigned to the project
-
domains
final ProjectListResponse.Project.Builder domains(JsonField<List<ProjectListResponse.Project.Domain>> domains)
Sets Builder.domains to an arbitrary JSON value.
You should usually call Builder.domains with a well-typed
List<Domain>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDomain
final ProjectListResponse.Project.Builder addDomain(ProjectListResponse.Project.Domain domain)
-
framework
final ProjectListResponse.Project.Builder framework(String framework)
Detected or configured application framework
-
framework
final ProjectListResponse.Project.Builder framework(JsonField<String> framework)
Sets Builder.framework to an arbitrary JSON value.
You should usually call Builder.framework with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gitBranch
final ProjectListResponse.Project.Builder gitBranch(String gitBranch)
Default Git branch used for deployments
-
gitBranch
final ProjectListResponse.Project.Builder gitBranch(JsonField<String> gitBranch)
Sets Builder.gitBranch to an arbitrary JSON value.
You should usually call Builder.gitBranch with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gitRepo
final ProjectListResponse.Project.Builder gitRepo(String gitRepo)
Connected Git repository in owner/repo format
-
gitRepo
final ProjectListResponse.Project.Builder gitRepo(JsonField<String> gitRepo)
Sets Builder.gitRepo to an arbitrary JSON value.
You should usually call Builder.gitRepo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectListResponse.Project.Builder name(String name)
Project display name
-
name
final ProjectListResponse.Project.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ProjectListResponse.Project.Builder status(String status)
Current project deployment status
-
status
final ProjectListResponse.Project.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final ProjectListResponse.Project.Builder updatedAt(String updatedAt)
When the project record was last updated
-
updatedAt
final ProjectListResponse.Project.Builder updatedAt(JsonField<String> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vercelProjectId
final ProjectListResponse.Project.Builder vercelProjectId(String vercelProjectId)
Hosting provider project ID, when linked
-
vercelProjectId
final ProjectListResponse.Project.Builder vercelProjectId(JsonField<String> vercelProjectId)
Sets Builder.vercelProjectId to an arbitrary JSON value.
You should usually call Builder.vercelProjectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectListResponse.Project.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectListResponse.Project.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectListResponse.Project.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectListResponse.Project.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectListResponse.Project.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectListResponse.Project build()
Returns an immutable instance of Project.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-