Class ProjectListResponse.Project.Domain
-
- All Implemented Interfaces:
public final class ProjectListResponse.Project.Domain
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListResponse.Project.Domain.BuilderA builder for Domain.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Domain record identifier final Optional<String>domain()Hostname assigned to the project final Optional<Boolean>isPrimary()Whether this is the primary project domain final Optional<Boolean>isVerified()Whether the domain has been verified by the hosting provider final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_domain()Returns the raw JSON value of domain. final JsonField<Boolean>_isPrimary()Returns the raw JSON value of isPrimary. final JsonField<Boolean>_isVerified()Returns the raw JSON value of isVerified. final Map<String, JsonValue>_additionalProperties()final ProjectListResponse.Project.Domain.BuildertoBuilder()final ProjectListResponse.Project.Domainvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListResponse.Project.Domain.Builderbuilder()Returns a mutable builder for constructing an instance of Domain. -
-
Method Detail
-
isVerified
final Optional<Boolean> isVerified()
Whether the domain has been verified by the hosting provider
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_isPrimary
final JsonField<Boolean> _isPrimary()
Returns the raw JSON value of isPrimary.
Unlike isPrimary, this method doesn't throw if the JSON field has an unexpected type.
-
_isVerified
final JsonField<Boolean> _isVerified()
Returns the raw JSON value of isVerified.
Unlike isVerified, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListResponse.Project.Domain.Builder toBuilder()
-
validate
final ProjectListResponse.Project.Domain validate()
-
builder
final static ProjectListResponse.Project.Domain.Builder builder()
Returns a mutable builder for constructing an instance of Domain.
-
-
-
-