Class ProjectRetrieveParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectRetrieveParams implements Params
Returns project details, domains, and recent deployment information for one application project or deployed Thurgood app. Use this endpoint when you need a single record with hosting metadata for a details view.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectRetrieveParams.BuilderA builder for ProjectRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectRetrieveParamsnone()final static ProjectRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectRetrieveParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ProjectRetrieveParams none()
-
builder
final static ProjectRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectRetrieveParams.
-
-
-
-