Package dev.case.api.models.applications.v1.projects
See: Description
-
Class Summary Class Description Builder A builder for ProjectCreateDeploymentParams. Builder A builder for Body. Body Builder A builder for EnvironmentVariable. Target Type Storage mode for the environment variable value EnvironmentVariable ProjectCreateDeploymentParams Starts a new deployment for an existing project using its saved repository and hosting configuration. Builder A builder for ProjectCreateDomainParams. Builder A builder for Body. Body ProjectCreateDomainParams Add a custom domain to a project Builder A builder for ProjectCreateEnvParams. Builder A builder for Body. Body Target Type Variable type ProjectCreateEnvParams Create a new environment variable for a project Builder A builder for ProjectCreateParams. Builder A builder for Body. Body Builder A builder for EnvironmentVariable. Target Type Storage mode for the environment variable value EnvironmentVariable ProjectCreateParams Creates a new application project, validates GitHub access, provisions a default case.dev domain, and starts the deployment workflow. Builder A builder for ProjectDeleteDomainParams. ProjectDeleteDomainParams Remove a domain from a project Builder A builder for ProjectDeleteEnvParams. ProjectDeleteEnvParams Delete an environment variable from a project Builder A builder for ProjectDeleteParams. ProjectDeleteParams Soft-deletes an application project or deployed Thurgood app from Case.dev. Builder A builder for ProjectGetRuntimeLogsParams. ProjectGetRuntimeLogsParams Get runtime/function logs for a project Builder A builder for ProjectListDeploymentsParams. Target Deployment target to filter by ProjectListDeploymentsParams Lists deployments for one project in the authenticated organization. Builder A builder for ProjectListDomainsParams. ProjectListDomainsParams List all domains configured for a project Builder A builder for ProjectListEnvParams. ProjectListEnvParams List all environment variables for a project (values are hidden unless decrypt=true) Builder A builder for ProjectListParams. ProjectListParams Lists application projects and deployed Thurgood apps for the authenticated organization. Builder A builder for ProjectListResponse. Builder A builder for Project. Builder A builder for Domain. Domain Project ProjectListResponse Builder A builder for ProjectRetrieveParams. ProjectRetrieveParams Returns project details, domains, and recent deployment information for one application project or deployed Thurgood app. -
Enum Summary Enum Description Known An enum containing Target's known values. Value An enum containing Target's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing Target's known values. Value An enum containing Target's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing Target's known values. Value An enum containing Target's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing Target's known values. Value An enum containing Target's known values, as well as an _UNKNOWN member.