Package dev.case.api.models.compute.v1
Class V1GetPricingParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1GetPricingParams implements Params
Returns current pricing for GPU instances. Prices are fetched in real-time and include a 20% platform fee. For detailed instance types and availability, use GET /compute/v1/instance-types.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetPricingParams.BuilderA builder for V1GetPricingParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1GetPricingParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetPricingParamsnone()final static V1GetPricingParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1GetPricingParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1GetPricingParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static V1GetPricingParams none()
-
builder
final static V1GetPricingParams.Builder builder()
Returns a mutable builder for constructing an instance of V1GetPricingParams.
-
-
-
-