Package dev.case.api.models.compute.v1
Class V1GetUsageResponse
-
- All Implemented Interfaces:
public final class V1GetUsageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.BuilderA builder for V1GetUsageResponse.
public final classV1GetUsageResponse.ByEnvironmentpublic final classV1GetUsageResponse.Periodpublic final classV1GetUsageResponse.Summary
-
Method Summary
Modifier and Type Method Description final Optional<List<V1GetUsageResponse.ByEnvironment>>byEnvironment()final Optional<V1GetUsageResponse.Period>period()final Optional<V1GetUsageResponse.Summary>summary()final JsonField<List<V1GetUsageResponse.ByEnvironment>>_byEnvironment()Returns the raw JSON value of byEnvironment. final JsonField<V1GetUsageResponse.Period>_period()Returns the raw JSON value of period. final JsonField<V1GetUsageResponse.Summary>_summary()Returns the raw JSON value of summary. final Map<String, JsonValue>_additionalProperties()final V1GetUsageResponse.BuildertoBuilder()final V1GetUsageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1GetUsageResponse. -
-
Method Detail
-
byEnvironment
final Optional<List<V1GetUsageResponse.ByEnvironment>> byEnvironment()
-
period
final Optional<V1GetUsageResponse.Period> period()
-
summary
final Optional<V1GetUsageResponse.Summary> summary()
-
_byEnvironment
final JsonField<List<V1GetUsageResponse.ByEnvironment>> _byEnvironment()
Returns the raw JSON value of byEnvironment.
Unlike byEnvironment, this method doesn't throw if the JSON field has an unexpected type.
-
_period
final JsonField<V1GetUsageResponse.Period> _period()
Returns the raw JSON value of period.
Unlike period, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<V1GetUsageResponse.Summary> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Builder toBuilder()
-
validate
final V1GetUsageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1GetUsageResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1GetUsageResponse.
-
-
-
-