Class V1GetUsageResponse.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.BuilderA builder for V1GetUsageResponse.
-
-
Method Summary
-
-
Method Detail
-
byEnvironment
final V1GetUsageResponse.Builder byEnvironment(List<V1GetUsageResponse.ByEnvironment> byEnvironment)
-
byEnvironment
final V1GetUsageResponse.Builder byEnvironment(JsonField<List<V1GetUsageResponse.ByEnvironment>> byEnvironment)
Sets Builder.byEnvironment to an arbitrary JSON value.
You should usually call Builder.byEnvironment with a well-typed
List<ByEnvironment>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addByEnvironment
final V1GetUsageResponse.Builder addByEnvironment(V1GetUsageResponse.ByEnvironment byEnvironment)
Adds a single ByEnvironment to Builder.byEnvironment.
-
period
final V1GetUsageResponse.Builder period(V1GetUsageResponse.Period period)
-
period
final V1GetUsageResponse.Builder period(JsonField<V1GetUsageResponse.Period> period)
Sets Builder.period to an arbitrary JSON value.
You should usually call Builder.period with a well-typed Period value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
summary
final V1GetUsageResponse.Builder summary(V1GetUsageResponse.Summary summary)
-
summary
final V1GetUsageResponse.Builder summary(JsonField<V1GetUsageResponse.Summary> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed Summary value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse build()
Returns an immutable instance of V1GetUsageResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-