Class V1GetUsageResponse.ByEnvironment
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.ByEnvironment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.ByEnvironment.BuilderA builder for ByEnvironment.
-
Method Summary
-
-
Method Detail
-
environment
final Optional<String> environment()
-
totalCostCents
final Optional<Long> totalCostCents()
-
totalCostFormatted
final Optional<String> totalCostFormatted()
-
totalCpuSeconds
final Optional<Long> totalCpuSeconds()
-
totalGpuSeconds
final Optional<Long> totalGpuSeconds()
-
_environment
final JsonField<String> _environment()
Returns the raw JSON value of environment.
Unlike environment, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCostCents
final JsonField<Long> _totalCostCents()
Returns the raw JSON value of totalCostCents.
Unlike totalCostCents, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCostFormatted
final JsonField<String> _totalCostFormatted()
Returns the raw JSON value of totalCostFormatted.
Unlike totalCostFormatted, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCpuSeconds
final JsonField<Long> _totalCpuSeconds()
Returns the raw JSON value of totalCpuSeconds.
Unlike totalCpuSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_totalGpuSeconds
final JsonField<Long> _totalGpuSeconds()
Returns the raw JSON value of totalGpuSeconds.
Unlike totalGpuSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_totalRuns
final JsonField<Long> _totalRuns()
Returns the raw JSON value of totalRuns.
Unlike totalRuns, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.ByEnvironment.Builder toBuilder()
-
validate
final V1GetUsageResponse.ByEnvironment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1GetUsageResponse.ByEnvironment.Builder builder()
Returns a mutable builder for constructing an instance of ByEnvironment.
-
-
-
-