Class V1GetUsageResponse.ByEnvironment.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.ByEnvironment.BuilderA builder for ByEnvironment.
-
-
Method Summary
-
-
Method Detail
-
environment
final V1GetUsageResponse.ByEnvironment.Builder environment(String environment)
-
environment
final V1GetUsageResponse.ByEnvironment.Builder environment(JsonField<String> environment)
Sets Builder.environment to an arbitrary JSON value.
You should usually call Builder.environment with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCostCents
final V1GetUsageResponse.ByEnvironment.Builder totalCostCents(Long totalCostCents)
-
totalCostCents
final V1GetUsageResponse.ByEnvironment.Builder totalCostCents(JsonField<Long> totalCostCents)
Sets Builder.totalCostCents to an arbitrary JSON value.
You should usually call Builder.totalCostCents with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCostFormatted
final V1GetUsageResponse.ByEnvironment.Builder totalCostFormatted(String totalCostFormatted)
-
totalCostFormatted
final V1GetUsageResponse.ByEnvironment.Builder totalCostFormatted(JsonField<String> totalCostFormatted)
Sets Builder.totalCostFormatted to an arbitrary JSON value.
You should usually call Builder.totalCostFormatted with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCpuSeconds
final V1GetUsageResponse.ByEnvironment.Builder totalCpuSeconds(Long totalCpuSeconds)
-
totalCpuSeconds
final V1GetUsageResponse.ByEnvironment.Builder totalCpuSeconds(JsonField<Long> totalCpuSeconds)
Sets Builder.totalCpuSeconds to an arbitrary JSON value.
You should usually call Builder.totalCpuSeconds with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalGpuSeconds
final V1GetUsageResponse.ByEnvironment.Builder totalGpuSeconds(Long totalGpuSeconds)
-
totalGpuSeconds
final V1GetUsageResponse.ByEnvironment.Builder totalGpuSeconds(JsonField<Long> totalGpuSeconds)
Sets Builder.totalGpuSeconds to an arbitrary JSON value.
You should usually call Builder.totalGpuSeconds with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalRuns
final V1GetUsageResponse.ByEnvironment.Builder totalRuns(Long totalRuns)
-
totalRuns
final V1GetUsageResponse.ByEnvironment.Builder totalRuns(JsonField<Long> totalRuns)
Sets Builder.totalRuns to an arbitrary JSON value.
You should usually call Builder.totalRuns with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.ByEnvironment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.ByEnvironment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.ByEnvironment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.ByEnvironment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.ByEnvironment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse.ByEnvironment build()
Returns an immutable instance of ByEnvironment.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-