Package dev.case.api.models.compute.v1
Class V1GetUsageResponse.Period
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Period
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.Period.BuilderA builder for Period.
-
Method Summary
Modifier and Type Method Description final Optional<Long>month()final Optional<String>monthName()final Optional<Long>year()final JsonField<Long>_month()Returns the raw JSON value of month. final JsonField<String>_monthName()Returns the raw JSON value of monthName. final JsonField<Long>_year()Returns the raw JSON value of year. final Map<String, JsonValue>_additionalProperties()final V1GetUsageResponse.Period.BuildertoBuilder()final V1GetUsageResponse.Periodvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageResponse.Period.Builderbuilder()Returns a mutable builder for constructing an instance of Period. -
-
Method Detail
-
_month
final JsonField<Long> _month()
Returns the raw JSON value of month.
Unlike month, this method doesn't throw if the JSON field has an unexpected type.
-
_monthName
final JsonField<String> _monthName()
Returns the raw JSON value of monthName.
Unlike monthName, this method doesn't throw if the JSON field has an unexpected type.
-
_year
final JsonField<Long> _year()
Returns the raw JSON value of year.
Unlike year, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Period.Builder toBuilder()
-
validate
final V1GetUsageResponse.Period validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1GetUsageResponse.Period.Builder builder()
Returns a mutable builder for constructing an instance of Period.
-
-
-
-