Class V1GetUsageResponse.Summary
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Summary
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.Summary.BuilderA builder for Summary.
-
Method Summary
-
-
Method Detail
-
totalCostCents
final Optional<Long> totalCostCents()
-
totalCostFormatted
final Optional<String> totalCostFormatted()
-
totalCpuHours
final Optional<Double> totalCpuHours()
-
totalGpuHours
final Optional<Double> totalGpuHours()
-
_totalCostCents
final JsonField<Long> _totalCostCents()
Returns the raw JSON value of totalCostCents.
Unlike totalCostCents, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCostFormatted
final JsonField<String> _totalCostFormatted()
Returns the raw JSON value of totalCostFormatted.
Unlike totalCostFormatted, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCpuHours
final JsonField<Double> _totalCpuHours()
Returns the raw JSON value of totalCpuHours.
Unlike totalCpuHours, this method doesn't throw if the JSON field has an unexpected type.
-
_totalGpuHours
final JsonField<Double> _totalGpuHours()
Returns the raw JSON value of totalGpuHours.
Unlike totalGpuHours, this method doesn't throw if the JSON field has an unexpected type.
-
_totalRuns
final JsonField<Long> _totalRuns()
Returns the raw JSON value of totalRuns.
Unlike totalRuns, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Summary.Builder toBuilder()
-
validate
final V1GetUsageResponse.Summary validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1GetUsageResponse.Summary.Builder builder()
Returns a mutable builder for constructing an instance of Summary.
-
-
-
-