Class V1GetUsageResponse.Summary.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Summary.BuilderA builder for Summary.
-
-
Method Summary
-
-
Method Detail
-
totalCostCents
final V1GetUsageResponse.Summary.Builder totalCostCents(Long totalCostCents)
-
totalCostCents
final V1GetUsageResponse.Summary.Builder totalCostCents(JsonField<Long> totalCostCents)
Sets Builder.totalCostCents to an arbitrary JSON value.
You should usually call Builder.totalCostCents with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCostFormatted
final V1GetUsageResponse.Summary.Builder totalCostFormatted(String totalCostFormatted)
-
totalCostFormatted
final V1GetUsageResponse.Summary.Builder totalCostFormatted(JsonField<String> totalCostFormatted)
Sets Builder.totalCostFormatted to an arbitrary JSON value.
You should usually call Builder.totalCostFormatted with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCpuHours
final V1GetUsageResponse.Summary.Builder totalCpuHours(Double totalCpuHours)
-
totalCpuHours
final V1GetUsageResponse.Summary.Builder totalCpuHours(JsonField<Double> totalCpuHours)
Sets Builder.totalCpuHours to an arbitrary JSON value.
You should usually call Builder.totalCpuHours with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalGpuHours
final V1GetUsageResponse.Summary.Builder totalGpuHours(Double totalGpuHours)
-
totalGpuHours
final V1GetUsageResponse.Summary.Builder totalGpuHours(JsonField<Double> totalGpuHours)
Sets Builder.totalGpuHours to an arbitrary JSON value.
You should usually call Builder.totalGpuHours with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalRuns
final V1GetUsageResponse.Summary.Builder totalRuns(Long totalRuns)
-
totalRuns
final V1GetUsageResponse.Summary.Builder totalRuns(JsonField<Long> totalRuns)
Sets Builder.totalRuns to an arbitrary JSON value.
You should usually call Builder.totalRuns with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.Summary.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.Summary.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.Summary.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.Summary.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.Summary.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse.Summary build()
Returns an immutable instance of Summary.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-