Class EnvironmentCreateParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class EnvironmentCreateParams
     implements Params
                        

    Creates a new compute environment for running serverless workloads. Each environment gets its own isolated namespace with a unique domain for hosting applications and APIs. The first environment created becomes the default environment for the organization.