Class EnvironmentCreateResponse
-
- All Implemented Interfaces:
public final class EnvironmentCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentCreateResponse.BuilderA builder for EnvironmentCreateResponse.
public final classEnvironmentCreateResponse.StatusEnvironment status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique environment identifier final Optional<OffsetDateTime>createdAt()Environment creation timestamp final Optional<String>domain()Unique domain for this environment final Optional<Boolean>isDefault()Whether this is the default environment final Optional<String>name()Environment name final Optional<String>slug()URL-friendly slug derived from name final Optional<EnvironmentCreateResponse.Status>status()Environment status final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_domain()Returns the raw JSON value of domain. final JsonField<Boolean>_isDefault()Returns the raw JSON value of isDefault. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<EnvironmentCreateResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final EnvironmentCreateResponse.BuildertoBuilder()final EnvironmentCreateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnvironmentCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EnvironmentCreateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Environment creation timestamp
-
status
final Optional<EnvironmentCreateResponse.Status> status()
Environment status
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_isDefault
final JsonField<Boolean> _isDefault()
Returns the raw JSON value of isDefault.
Unlike isDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EnvironmentCreateResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnvironmentCreateResponse.Builder toBuilder()
-
validate
final EnvironmentCreateResponse validate()
-
builder
final static EnvironmentCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of EnvironmentCreateResponse.
-
-
-
-