Class EnvironmentDeleteResponse
-
- All Implemented Interfaces:
public final class EnvironmentDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentDeleteResponse.BuilderA builder for EnvironmentDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Stringmessage()final Booleansuccess()final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final EnvironmentDeleteResponse.BuildertoBuilder()final EnvironmentDeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnvironmentDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EnvironmentDeleteResponse. -
-
Method Detail
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnvironmentDeleteResponse.Builder toBuilder()
-
validate
final EnvironmentDeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnvironmentDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of EnvironmentDeleteResponse.
The following fields are required:
.message() .success()
-
-
-
-