Class EnvironmentDeleteResponse.Builder
-
- All Implemented Interfaces:
public final class EnvironmentDeleteResponse.BuilderA builder for EnvironmentDeleteResponse.
-
-
Method Summary
Modifier and Type Method Description final EnvironmentDeleteResponse.Buildermessage(String message)final EnvironmentDeleteResponse.Buildermessage(JsonField<String> message)Sets Builder.message to an arbitrary JSON value. final EnvironmentDeleteResponse.Buildersuccess(Boolean success)final EnvironmentDeleteResponse.Buildersuccess(JsonField<Boolean> success)Sets Builder.success to an arbitrary JSON value. final EnvironmentDeleteResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final EnvironmentDeleteResponse.BuilderputAdditionalProperty(String key, JsonValue value)final EnvironmentDeleteResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final EnvironmentDeleteResponse.BuilderremoveAdditionalProperty(String key)final EnvironmentDeleteResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final EnvironmentDeleteResponsebuild()Returns an immutable instance of EnvironmentDeleteResponse. -
-
Method Detail
-
message
final EnvironmentDeleteResponse.Builder message(String message)
-
message
final EnvironmentDeleteResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
success
final EnvironmentDeleteResponse.Builder success(Boolean success)
-
success
final EnvironmentDeleteResponse.Builder success(JsonField<Boolean> success)
Sets Builder.success to an arbitrary JSON value.
You should usually call Builder.success with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EnvironmentDeleteResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EnvironmentDeleteResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EnvironmentDeleteResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EnvironmentDeleteResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EnvironmentDeleteResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EnvironmentDeleteResponse build()
Returns an immutable instance of EnvironmentDeleteResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.message() .success()
-
-
-
-