Class EnvironmentListParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class EnvironmentListParams implements Params
Retrieve all compute environments for your organization. Environments provide isolated execution contexts for running code and workflows.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentListParams.BuilderA builder for EnvironmentListParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EnvironmentListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnvironmentListParamsnone()final static EnvironmentListParams.Builderbuilder()Returns a mutable builder for constructing an instance of EnvironmentListParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EnvironmentListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EnvironmentListParams none()
-
builder
final static EnvironmentListParams.Builder builder()
Returns a mutable builder for constructing an instance of EnvironmentListParams.
-
-
-
-