Class EnvironmentListResponse
-
- All Implemented Interfaces:
public final class EnvironmentListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentListResponse.BuilderA builder for EnvironmentListResponse.
public final classEnvironmentListResponse.Environment
-
Method Summary
Modifier and Type Method Description final Optional<List<EnvironmentListResponse.Environment>>environments()final JsonField<List<EnvironmentListResponse.Environment>>_environments()Returns the raw JSON value of environments. final Map<String, JsonValue>_additionalProperties()final EnvironmentListResponse.BuildertoBuilder()final EnvironmentListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnvironmentListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EnvironmentListResponse. -
-
Method Detail
-
environments
final Optional<List<EnvironmentListResponse.Environment>> environments()
-
_environments
final JsonField<List<EnvironmentListResponse.Environment>> _environments()
Returns the raw JSON value of environments.
Unlike environments, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnvironmentListResponse.Builder toBuilder()
-
validate
final EnvironmentListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnvironmentListResponse.Builder builder()
Returns a mutable builder for constructing an instance of EnvironmentListResponse.
-
-
-
-