Class EnvironmentListResponse.Environment.Builder
-
- All Implemented Interfaces:
public final class EnvironmentListResponse.Environment.BuilderA builder for Environment.
-
-
Method Summary
-
-
Method Detail
-
id
final EnvironmentListResponse.Environment.Builder id(String id)
Unique environment identifier
-
id
final EnvironmentListResponse.Environment.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final EnvironmentListResponse.Environment.Builder createdAt(OffsetDateTime createdAt)
Environment creation timestamp
-
createdAt
final EnvironmentListResponse.Environment.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
domain
final EnvironmentListResponse.Environment.Builder domain(String domain)
Environment domain
-
domain
final EnvironmentListResponse.Environment.Builder domain(JsonField<String> domain)
Sets Builder.domain to an arbitrary JSON value.
You should usually call Builder.domain with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isDefault
final EnvironmentListResponse.Environment.Builder isDefault(Boolean isDefault)
Whether this is the default environment
-
isDefault
final EnvironmentListResponse.Environment.Builder isDefault(JsonField<Boolean> isDefault)
Sets Builder.isDefault to an arbitrary JSON value.
You should usually call Builder.isDefault with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EnvironmentListResponse.Environment.Builder name(String name)
Human-readable environment name
-
name
final EnvironmentListResponse.Environment.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
slug
final EnvironmentListResponse.Environment.Builder slug(String slug)
URL-safe environment identifier
-
slug
final EnvironmentListResponse.Environment.Builder slug(JsonField<String> slug)
Sets Builder.slug to an arbitrary JSON value.
You should usually call Builder.slug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final EnvironmentListResponse.Environment.Builder status(String status)
Environment status
-
status
final EnvironmentListResponse.Environment.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final EnvironmentListResponse.Environment.Builder updatedAt(OffsetDateTime updatedAt)
Last update timestamp
-
updatedAt
final EnvironmentListResponse.Environment.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EnvironmentListResponse.Environment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EnvironmentListResponse.Environment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EnvironmentListResponse.Environment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EnvironmentListResponse.Environment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EnvironmentListResponse.Environment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EnvironmentListResponse.Environment build()
Returns an immutable instance of Environment.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-