Class EnvironmentRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class EnvironmentRetrieveResponse.BuilderA builder for EnvironmentRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final EnvironmentRetrieveResponse.Builder id(String id)
Unique environment identifier
-
id
final EnvironmentRetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final EnvironmentRetrieveResponse.Builder createdAt(OffsetDateTime createdAt)
Environment creation timestamp
-
createdAt
final EnvironmentRetrieveResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
domain
final EnvironmentRetrieveResponse.Builder domain(String domain)
Environment domain URL
-
domain
final EnvironmentRetrieveResponse.Builder domain(JsonField<String> domain)
Sets Builder.domain to an arbitrary JSON value.
You should usually call Builder.domain with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isDefault
final EnvironmentRetrieveResponse.Builder isDefault(Boolean isDefault)
Whether this is the default environment
-
isDefault
final EnvironmentRetrieveResponse.Builder isDefault(JsonField<Boolean> isDefault)
Sets Builder.isDefault to an arbitrary JSON value.
You should usually call Builder.isDefault with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EnvironmentRetrieveResponse.Builder name(String name)
Environment name
-
name
final EnvironmentRetrieveResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
slug
final EnvironmentRetrieveResponse.Builder slug(String slug)
URL-safe environment slug
-
slug
final EnvironmentRetrieveResponse.Builder slug(JsonField<String> slug)
Sets Builder.slug to an arbitrary JSON value.
You should usually call Builder.slug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final EnvironmentRetrieveResponse.Builder status(String status)
Environment status (active, inactive, etc.)
-
status
final EnvironmentRetrieveResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final EnvironmentRetrieveResponse.Builder updatedAt(OffsetDateTime updatedAt)
Environment last update timestamp
-
updatedAt
final EnvironmentRetrieveResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EnvironmentRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EnvironmentRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EnvironmentRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EnvironmentRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EnvironmentRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EnvironmentRetrieveResponse build()
Returns an immutable instance of EnvironmentRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-