Class EnvironmentSetDefaultParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class EnvironmentSetDefaultParams
     implements Params
                        

    Sets a compute environment as the default for the organization. Only one environment can be default at a time - setting a new default will automatically unset the previous one.