Class EnvironmentSetDefaultResponse
-
- All Implemented Interfaces:
public final class EnvironmentSetDefaultResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentSetDefaultResponse.BuilderA builder for EnvironmentSetDefaultResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique environment identifier final Optional<OffsetDateTime>createdAt()Environment creation timestamp final Optional<String>domain()Environment domain final Optional<Boolean>isDefault()Whether this is the default environment final Optional<String>name()Environment name final Optional<String>slug()URL-friendly environment identifier final Optional<String>status()Current environment status final Optional<OffsetDateTime>updatedAt()Last update timestamp final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_domain()Returns the raw JSON value of domain. final JsonField<Boolean>_isDefault()Returns the raw JSON value of isDefault. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final EnvironmentSetDefaultResponse.BuildertoBuilder()final EnvironmentSetDefaultResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnvironmentSetDefaultResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EnvironmentSetDefaultResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Environment creation timestamp
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Last update timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_isDefault
final JsonField<Boolean> _isDefault()
Returns the raw JSON value of isDefault.
Unlike isDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnvironmentSetDefaultResponse.Builder toBuilder()
-
validate
final EnvironmentSetDefaultResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnvironmentSetDefaultResponse.Builder builder()
Returns a mutable builder for constructing an instance of EnvironmentSetDefaultResponse.
-
-
-
-