Class InstanceCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class InstanceCreateParams implements Params
Launches a new GPU compute instance with automatic SSH key generation. Supports mounting Case.dev Vaults as filesystems. Instance boots in ~2-5 minutes. Perfect for batch OCR processing, AI model training, and intensive document analysis workloads.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceCreateParams.BuilderA builder for InstanceCreateParams.
public final classInstanceCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringinstanceType()GPU type (e.g. final Stringname()Instance name final Stringregion()Region (e.g. final Optional<List<String>>vaultIds()Vault IDs to mount final JsonField<String>_instanceType()Returns the raw JSON value of instanceType. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InstanceCreateParams.BuildertoBuilder()final InstanceCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InstanceCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InstanceCreateParams. -
-
Method Detail
-
instanceType
final String instanceType()
GPU type (e.g., 'gpu_1x_h100_sxm5')
-
_instanceType
final JsonField<String> _instanceType()
Returns the raw JSON value of instanceType.
Unlike instanceType, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InstanceCreateParams.Builder toBuilder()
-
_body
final InstanceCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InstanceCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InstanceCreateParams.
The following fields are required:
.instanceType() .name() .region()
-
-
-
-