Class InstanceCreateParams.Body
-
- All Implemented Interfaces:
public final class InstanceCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringinstanceType()GPU type (e.g. final Stringname()Instance name final Stringregion()Region (e.g. final Optional<Long>autoShutdownMinutes()Auto-shutdown timer (null = never) final Optional<List<String>>vaultIds()Vault IDs to mount final JsonField<String>_instanceType()Returns the raw JSON value of instanceType. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<Long>_autoShutdownMinutes()Returns the raw JSON value of autoShutdownMinutes. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final InstanceCreateParams.Body.BuildertoBuilder()final InstanceCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InstanceCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
instanceType
final String instanceType()
GPU type (e.g., 'gpu_1x_h100_sxm5')
-
autoShutdownMinutes
final Optional<Long> autoShutdownMinutes()
Auto-shutdown timer (null = never)
-
_instanceType
final JsonField<String> _instanceType()
Returns the raw JSON value of instanceType.
Unlike instanceType, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_autoShutdownMinutes
final JsonField<Long> _autoShutdownMinutes()
Returns the raw JSON value of autoShutdownMinutes.
Unlike autoShutdownMinutes, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InstanceCreateParams.Body.Builder toBuilder()
-
validate
final InstanceCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InstanceCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.instanceType() .name() .region()
-
-
-
-