Class InstanceCreateResponse.Builder
-
- All Implemented Interfaces:
public final class InstanceCreateResponse.BuilderA builder for InstanceCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final InstanceCreateResponse.Builder id(String id)
-
id
final InstanceCreateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
autoShutdownMinutes
final InstanceCreateResponse.Builder autoShutdownMinutes(Long autoShutdownMinutes)
-
autoShutdownMinutes
final InstanceCreateResponse.Builder autoShutdownMinutes(Long autoShutdownMinutes)
Alias for Builder.autoShutdownMinutes.
This unboxed primitive overload exists for backwards compatibility.
-
autoShutdownMinutes
final InstanceCreateResponse.Builder autoShutdownMinutes(Optional<Long> autoShutdownMinutes)
Alias for calling Builder.autoShutdownMinutes with
autoShutdownMinutes.orElse(null).
-
autoShutdownMinutes
final InstanceCreateResponse.Builder autoShutdownMinutes(JsonField<Long> autoShutdownMinutes)
Sets Builder.autoShutdownMinutes to an arbitrary JSON value.
You should usually call Builder.autoShutdownMinutes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InstanceCreateResponse.Builder createdAt(String createdAt)
-
createdAt
final InstanceCreateResponse.Builder createdAt(JsonField<String> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gpu
final InstanceCreateResponse.Builder gpu(String gpu)
-
gpu
final InstanceCreateResponse.Builder gpu(JsonField<String> gpu)
Sets Builder.gpu to an arbitrary JSON value.
You should usually call Builder.gpu with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instanceType
final InstanceCreateResponse.Builder instanceType(String instanceType)
-
instanceType
final InstanceCreateResponse.Builder instanceType(JsonField<String> instanceType)
Sets Builder.instanceType to an arbitrary JSON value.
You should usually call Builder.instanceType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final InstanceCreateResponse.Builder message(String message)
-
message
final InstanceCreateResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final InstanceCreateResponse.Builder name(String name)
-
name
final InstanceCreateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pricePerHour
final InstanceCreateResponse.Builder pricePerHour(String pricePerHour)
-
pricePerHour
final InstanceCreateResponse.Builder pricePerHour(JsonField<String> pricePerHour)
Sets Builder.pricePerHour to an arbitrary JSON value.
You should usually call Builder.pricePerHour with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final InstanceCreateResponse.Builder region(String region)
-
region
final InstanceCreateResponse.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
specs
final InstanceCreateResponse.Builder specs(JsonValue specs)
-
status
final InstanceCreateResponse.Builder status(String status)
-
status
final InstanceCreateResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaults
final InstanceCreateResponse.Builder vaults(List<JsonValue> vaults)
-
vaults
final InstanceCreateResponse.Builder vaults(JsonField<List<JsonValue>> vaults)
Sets Builder.vaults to an arbitrary JSON value.
You should usually call Builder.vaults with a well-typed
List<JsonValue>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVault
final InstanceCreateResponse.Builder addVault(JsonValue vault)
-
additionalProperties
final InstanceCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InstanceCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InstanceCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InstanceCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InstanceCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InstanceCreateResponse build()
Returns an immutable instance of InstanceCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-