Class InstanceDeleteResponse.Builder
-
- All Implemented Interfaces:
public final class InstanceDeleteResponse.BuilderA builder for InstanceDeleteResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final InstanceDeleteResponse.Builder id(String id)
-
id
final InstanceDeleteResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final InstanceDeleteResponse.Builder message(String message)
-
message
final InstanceDeleteResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final InstanceDeleteResponse.Builder name(String name)
-
name
final InstanceDeleteResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InstanceDeleteResponse.Builder status(String status)
-
status
final InstanceDeleteResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCost
final InstanceDeleteResponse.Builder totalCost(String totalCost)
-
totalCost
final InstanceDeleteResponse.Builder totalCost(JsonField<String> totalCost)
Sets Builder.totalCost to an arbitrary JSON value.
You should usually call Builder.totalCost with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalRuntimeSeconds
final InstanceDeleteResponse.Builder totalRuntimeSeconds(Long totalRuntimeSeconds)
-
totalRuntimeSeconds
final InstanceDeleteResponse.Builder totalRuntimeSeconds(JsonField<Long> totalRuntimeSeconds)
Sets Builder.totalRuntimeSeconds to an arbitrary JSON value.
You should usually call Builder.totalRuntimeSeconds with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InstanceDeleteResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InstanceDeleteResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InstanceDeleteResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InstanceDeleteResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InstanceDeleteResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InstanceDeleteResponse build()
Returns an immutable instance of InstanceDeleteResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-