Class InstanceListResponse
-
- All Implemented Interfaces:
public final class InstanceListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceListResponse.BuilderA builder for InstanceListResponse.
public final classInstanceListResponse.Instance
-
Method Summary
Modifier and Type Method Description final Optional<Long>count()final Optional<List<InstanceListResponse.Instance>>instances()final JsonField<Long>_count()Returns the raw JSON value of count. final JsonField<List<InstanceListResponse.Instance>>_instances()Returns the raw JSON value of instances. final Map<String, JsonValue>_additionalProperties()final InstanceListResponse.BuildertoBuilder()final InstanceListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InstanceListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of InstanceListResponse. -
-
Method Detail
-
instances
final Optional<List<InstanceListResponse.Instance>> instances()
-
_count
final JsonField<Long> _count()
Returns the raw JSON value of count.
Unlike count, this method doesn't throw if the JSON field has an unexpected type.
-
_instances
final JsonField<List<InstanceListResponse.Instance>> _instances()
Returns the raw JSON value of instances.
Unlike instances, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InstanceListResponse.Builder toBuilder()
-
validate
final InstanceListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InstanceListResponse.Builder builder()
Returns a mutable builder for constructing an instance of InstanceListResponse.
-
-
-
-