Class InstanceListResponse.Instance.Builder
-
- All Implemented Interfaces:
public final class InstanceListResponse.Instance.BuilderA builder for Instance.
-
-
Method Summary
-
-
Method Detail
-
id
final InstanceListResponse.Instance.Builder id(String id)
-
id
final InstanceListResponse.Instance.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
autoShutdownMinutes
final InstanceListResponse.Instance.Builder autoShutdownMinutes(Long autoShutdownMinutes)
-
autoShutdownMinutes
final InstanceListResponse.Instance.Builder autoShutdownMinutes(Long autoShutdownMinutes)
Alias for Builder.autoShutdownMinutes.
This unboxed primitive overload exists for backwards compatibility.
-
autoShutdownMinutes
final InstanceListResponse.Instance.Builder autoShutdownMinutes(Optional<Long> autoShutdownMinutes)
Alias for calling Builder.autoShutdownMinutes with
autoShutdownMinutes.orElse(null).
-
autoShutdownMinutes
final InstanceListResponse.Instance.Builder autoShutdownMinutes(JsonField<Long> autoShutdownMinutes)
Sets Builder.autoShutdownMinutes to an arbitrary JSON value.
You should usually call Builder.autoShutdownMinutes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InstanceListResponse.Instance.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final InstanceListResponse.Instance.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gpu
final InstanceListResponse.Instance.Builder gpu(String gpu)
-
gpu
final InstanceListResponse.Instance.Builder gpu(JsonField<String> gpu)
Sets Builder.gpu to an arbitrary JSON value.
You should usually call Builder.gpu with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instanceType
final InstanceListResponse.Instance.Builder instanceType(String instanceType)
-
instanceType
final InstanceListResponse.Instance.Builder instanceType(JsonField<String> instanceType)
Sets Builder.instanceType to an arbitrary JSON value.
You should usually call Builder.instanceType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ip
final InstanceListResponse.Instance.Builder ip(String ip)
-
ip
final InstanceListResponse.Instance.Builder ip(Optional<String> ip)
Alias for calling Builder.ip with
ip.orElse(null).
-
ip
final InstanceListResponse.Instance.Builder ip(JsonField<String> ip)
Sets Builder.ip to an arbitrary JSON value.
You should usually call Builder.ip with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final InstanceListResponse.Instance.Builder name(String name)
-
name
final InstanceListResponse.Instance.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pricePerHour
final InstanceListResponse.Instance.Builder pricePerHour(String pricePerHour)
-
pricePerHour
final InstanceListResponse.Instance.Builder pricePerHour(JsonField<String> pricePerHour)
Sets Builder.pricePerHour to an arbitrary JSON value.
You should usually call Builder.pricePerHour with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final InstanceListResponse.Instance.Builder region(String region)
-
region
final InstanceListResponse.Instance.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startedAt
final InstanceListResponse.Instance.Builder startedAt(OffsetDateTime startedAt)
-
startedAt
final InstanceListResponse.Instance.Builder startedAt(Optional<OffsetDateTime> startedAt)
Alias for calling Builder.startedAt with
startedAt.orElse(null).
-
startedAt
final InstanceListResponse.Instance.Builder startedAt(JsonField<OffsetDateTime> startedAt)
Sets Builder.startedAt to an arbitrary JSON value.
You should usually call Builder.startedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InstanceListResponse.Instance.Builder status(InstanceListResponse.Instance.Status status)
-
status
final InstanceListResponse.Instance.Builder status(JsonField<InstanceListResponse.Instance.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCost
final InstanceListResponse.Instance.Builder totalCost(String totalCost)
-
totalCost
final InstanceListResponse.Instance.Builder totalCost(JsonField<String> totalCost)
Sets Builder.totalCost to an arbitrary JSON value.
You should usually call Builder.totalCost with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalRuntimeSeconds
final InstanceListResponse.Instance.Builder totalRuntimeSeconds(Long totalRuntimeSeconds)
-
totalRuntimeSeconds
final InstanceListResponse.Instance.Builder totalRuntimeSeconds(JsonField<Long> totalRuntimeSeconds)
Sets Builder.totalRuntimeSeconds to an arbitrary JSON value.
You should usually call Builder.totalRuntimeSeconds with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InstanceListResponse.Instance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InstanceListResponse.Instance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InstanceListResponse.Instance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InstanceListResponse.Instance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InstanceListResponse.Instance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InstanceListResponse.Instance build()
Returns an immutable instance of Instance.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-