Class InstanceRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class InstanceRetrieveResponse.BuilderA builder for InstanceRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final InstanceRetrieveResponse.Builder id(String id)
-
id
final InstanceRetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InstanceRetrieveResponse.Builder createdAt(String createdAt)
-
createdAt
final InstanceRetrieveResponse.Builder createdAt(JsonField<String> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currentCost
final InstanceRetrieveResponse.Builder currentCost(String currentCost)
-
currentCost
final InstanceRetrieveResponse.Builder currentCost(JsonField<String> currentCost)
Sets Builder.currentCost to an arbitrary JSON value.
You should usually call Builder.currentCost with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currentRuntimeSeconds
final InstanceRetrieveResponse.Builder currentRuntimeSeconds(Long currentRuntimeSeconds)
-
currentRuntimeSeconds
final InstanceRetrieveResponse.Builder currentRuntimeSeconds(JsonField<Long> currentRuntimeSeconds)
Sets Builder.currentRuntimeSeconds to an arbitrary JSON value.
You should usually call Builder.currentRuntimeSeconds with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gpu
final InstanceRetrieveResponse.Builder gpu(String gpu)
-
gpu
final InstanceRetrieveResponse.Builder gpu(JsonField<String> gpu)
Sets Builder.gpu to an arbitrary JSON value.
You should usually call Builder.gpu with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instanceType
final InstanceRetrieveResponse.Builder instanceType(String instanceType)
-
instanceType
final InstanceRetrieveResponse.Builder instanceType(JsonField<String> instanceType)
Sets Builder.instanceType to an arbitrary JSON value.
You should usually call Builder.instanceType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ip
final InstanceRetrieveResponse.Builder ip(String ip)
-
ip
final InstanceRetrieveResponse.Builder ip(Optional<String> ip)
Alias for calling Builder.ip with
ip.orElse(null).
-
ip
final InstanceRetrieveResponse.Builder ip(JsonField<String> ip)
Sets Builder.ip to an arbitrary JSON value.
You should usually call Builder.ip with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final InstanceRetrieveResponse.Builder name(String name)
-
name
final InstanceRetrieveResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pricePerHour
final InstanceRetrieveResponse.Builder pricePerHour(String pricePerHour)
-
pricePerHour
final InstanceRetrieveResponse.Builder pricePerHour(JsonField<String> pricePerHour)
Sets Builder.pricePerHour to an arbitrary JSON value.
You should usually call Builder.pricePerHour with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final InstanceRetrieveResponse.Builder region(String region)
-
region
final InstanceRetrieveResponse.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
specs
final InstanceRetrieveResponse.Builder specs(JsonValue specs)
-
ssh
final InstanceRetrieveResponse.Builder ssh(InstanceRetrieveResponse.Ssh ssh)
-
ssh
final InstanceRetrieveResponse.Builder ssh(Optional<InstanceRetrieveResponse.Ssh> ssh)
Alias for calling Builder.ssh with
ssh.orElse(null).
-
ssh
final InstanceRetrieveResponse.Builder ssh(JsonField<InstanceRetrieveResponse.Ssh> ssh)
Sets Builder.ssh to an arbitrary JSON value.
You should usually call Builder.ssh with a well-typed Ssh value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startedAt
final InstanceRetrieveResponse.Builder startedAt(String startedAt)
-
startedAt
final InstanceRetrieveResponse.Builder startedAt(Optional<String> startedAt)
Alias for calling Builder.startedAt with
startedAt.orElse(null).
-
startedAt
final InstanceRetrieveResponse.Builder startedAt(JsonField<String> startedAt)
Sets Builder.startedAt to an arbitrary JSON value.
You should usually call Builder.startedAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InstanceRetrieveResponse.Builder status(String status)
-
status
final InstanceRetrieveResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultMounts
final InstanceRetrieveResponse.Builder vaultMounts(JsonValue vaultMounts)
-
additionalProperties
final InstanceRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InstanceRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InstanceRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InstanceRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InstanceRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InstanceRetrieveResponse build()
Returns an immutable instance of InstanceRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-