Class InstanceRetrieveResponse.Ssh
-
- All Implemented Interfaces:
public final class InstanceRetrieveResponse.Ssh
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceRetrieveResponse.Ssh.BuilderA builder for Ssh.
-
Method Summary
Modifier and Type Method Description final Optional<String>command()final Optional<String>host()final Optional<List<JsonValue>>instructions()final Optional<String>privateKey()final Optional<String>user()final JsonField<String>_command()Returns the raw JSON value of command. final JsonField<String>_host()Returns the raw JSON value of host. final JsonField<List<JsonValue>>_instructions()Returns the raw JSON value of instructions. final JsonField<String>_privateKey()Returns the raw JSON value of privateKey. final JsonField<String>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalProperties()final InstanceRetrieveResponse.Ssh.BuildertoBuilder()final InstanceRetrieveResponse.Sshvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InstanceRetrieveResponse.Ssh.Builderbuilder()Returns a mutable builder for constructing an instance of Ssh. -
-
Method Detail
-
instructions
final Optional<List<JsonValue>> instructions()
-
privateKey
final Optional<String> privateKey()
-
_command
final JsonField<String> _command()
Returns the raw JSON value of command.
Unlike command, this method doesn't throw if the JSON field has an unexpected type.
-
_host
final JsonField<String> _host()
Returns the raw JSON value of host.
Unlike host, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<List<JsonValue>> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_privateKey
final JsonField<String> _privateKey()
Returns the raw JSON value of privateKey.
Unlike privateKey, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<String> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InstanceRetrieveResponse.Ssh.Builder toBuilder()
-
validate
final InstanceRetrieveResponse.Ssh validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InstanceRetrieveResponse.Ssh.Builder builder()
Returns a mutable builder for constructing an instance of Ssh.
-
-
-
-