Class InstanceRetrieveResponse.Ssh.Builder
-
- All Implemented Interfaces:
public final class InstanceRetrieveResponse.Ssh.BuilderA builder for Ssh.
-
-
Method Summary
-
-
Method Detail
-
command
final InstanceRetrieveResponse.Ssh.Builder command(String command)
-
command
final InstanceRetrieveResponse.Ssh.Builder command(JsonField<String> command)
Sets Builder.command to an arbitrary JSON value.
You should usually call Builder.command with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
host
final InstanceRetrieveResponse.Ssh.Builder host(String host)
-
host
final InstanceRetrieveResponse.Ssh.Builder host(JsonField<String> host)
Sets Builder.host to an arbitrary JSON value.
You should usually call Builder.host with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructions
final InstanceRetrieveResponse.Ssh.Builder instructions(List<JsonValue> instructions)
-
instructions
final InstanceRetrieveResponse.Ssh.Builder instructions(JsonField<List<JsonValue>> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed
List<JsonValue>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addInstruction
final InstanceRetrieveResponse.Ssh.Builder addInstruction(JsonValue instruction)
Adds a single JsonValue to instructions.
-
privateKey
final InstanceRetrieveResponse.Ssh.Builder privateKey(String privateKey)
-
privateKey
final InstanceRetrieveResponse.Ssh.Builder privateKey(JsonField<String> privateKey)
Sets Builder.privateKey to an arbitrary JSON value.
You should usually call Builder.privateKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
user
final InstanceRetrieveResponse.Ssh.Builder user(String user)
-
user
final InstanceRetrieveResponse.Ssh.Builder user(JsonField<String> user)
Sets Builder.user to an arbitrary JSON value.
You should usually call Builder.user with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InstanceRetrieveResponse.Ssh.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InstanceRetrieveResponse.Ssh.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InstanceRetrieveResponse.Ssh.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InstanceRetrieveResponse.Ssh.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InstanceRetrieveResponse.Ssh.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InstanceRetrieveResponse.Ssh build()
Returns an immutable instance of Ssh.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-