Class SecretCreateParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class SecretCreateParams
     implements Params
                        

    Creates a new secret group in a compute environment. Secret groups organize related secrets for use in serverless functions and workflows. If no environment is specified, the group is created in the default environment.

    Features:

    • Organize secrets by logical groups (e.g., database, APIs, third-party services)

    • Environment-based isolation

    • Validation of group names

    • Conflict detection for existing groups