Class SecretCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SecretCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
name
final SecretCreateParams.Body.Builder name(String name)
Unique name for the secret group. Must contain only letters, numbers, hyphens, and underscores.
-
name
final SecretCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final SecretCreateParams.Body.Builder description(String description)
Optional description of the secret group's purpose
-
description
final SecretCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
env
final SecretCreateParams.Body.Builder env(String env)
Environment name where the secret group will be created. Uses default environment if not specified.
-
env
final SecretCreateParams.Body.Builder env(JsonField<String> env)
Sets Builder.env to an arbitrary JSON value.
You should usually call Builder.env with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SecretCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SecretCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SecretCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SecretCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SecretCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SecretCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-