Class SecretCreateResponse
-
- All Implemented Interfaces:
public final class SecretCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretCreateResponse.BuilderA builder for SecretCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique identifier for the secret group final Optional<OffsetDateTime>createdAt()Creation timestamp final Optional<String>description()Description of the secret group final Optional<String>name()Name of the secret group final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final SecretCreateResponse.BuildertoBuilder()final SecretCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SecretCreateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Creation timestamp
-
description
final Optional<String> description()
Description of the secret group
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretCreateResponse.Builder toBuilder()
-
validate
final SecretCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SecretCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of SecretCreateResponse.
-
-
-
-