Class SecretCreateResponse.Builder
-
- All Implemented Interfaces:
public final class SecretCreateResponse.BuilderA builder for SecretCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final SecretCreateResponse.Builder id(String id)
Unique identifier for the secret group
-
id
final SecretCreateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final SecretCreateResponse.Builder createdAt(OffsetDateTime createdAt)
Creation timestamp
-
createdAt
final SecretCreateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final SecretCreateResponse.Builder description(String description)
Description of the secret group
-
description
final SecretCreateResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final SecretCreateResponse.Builder name(String name)
Name of the secret group
-
name
final SecretCreateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SecretCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SecretCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SecretCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SecretCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SecretCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SecretCreateResponse build()
Returns an immutable instance of SecretCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-