Class SecretDeleteGroupParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class SecretDeleteGroupParams
     implements Params
                        

    Delete an entire secret group or a specific key within a secret group. When deleting a specific key, the remaining secrets in the group are preserved. When deleting the entire group, all secrets and the group itself are removed.