Class SecretDeleteGroupResponse
-
- All Implemented Interfaces:
public final class SecretDeleteGroupResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretDeleteGroupResponse.BuilderA builder for SecretDeleteGroupResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>message()final Optional<Boolean>success()final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final SecretDeleteGroupResponse.BuildertoBuilder()final SecretDeleteGroupResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretDeleteGroupResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SecretDeleteGroupResponse. -
-
Method Detail
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretDeleteGroupResponse.Builder toBuilder()
-
validate
final SecretDeleteGroupResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SecretDeleteGroupResponse.Builder builder()
Returns a mutable builder for constructing an instance of SecretDeleteGroupResponse.
-
-
-
-