Class SecretDeleteGroupResponse.Builder
-
- All Implemented Interfaces:
public final class SecretDeleteGroupResponse.BuilderA builder for SecretDeleteGroupResponse.
-
-
Method Summary
Modifier and Type Method Description final SecretDeleteGroupResponse.Buildermessage(String message)final SecretDeleteGroupResponse.Buildermessage(JsonField<String> message)Sets Builder.message to an arbitrary JSON value. final SecretDeleteGroupResponse.Buildersuccess(Boolean success)final SecretDeleteGroupResponse.Buildersuccess(JsonField<Boolean> success)Sets Builder.success to an arbitrary JSON value. final SecretDeleteGroupResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final SecretDeleteGroupResponse.BuilderputAdditionalProperty(String key, JsonValue value)final SecretDeleteGroupResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final SecretDeleteGroupResponse.BuilderremoveAdditionalProperty(String key)final SecretDeleteGroupResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final SecretDeleteGroupResponsebuild()Returns an immutable instance of SecretDeleteGroupResponse. -
-
Method Detail
-
message
final SecretDeleteGroupResponse.Builder message(String message)
-
message
final SecretDeleteGroupResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
success
final SecretDeleteGroupResponse.Builder success(Boolean success)
-
success
final SecretDeleteGroupResponse.Builder success(JsonField<Boolean> success)
Sets Builder.success to an arbitrary JSON value.
You should usually call Builder.success with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SecretDeleteGroupResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SecretDeleteGroupResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SecretDeleteGroupResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SecretDeleteGroupResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SecretDeleteGroupResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SecretDeleteGroupResponse build()
Returns an immutable instance of SecretDeleteGroupResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-