Class SecretListResponse
-
- All Implemented Interfaces:
public final class SecretListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretListResponse.BuilderA builder for SecretListResponse.
public final classSecretListResponse.Group
-
Method Summary
Modifier and Type Method Description final Optional<List<SecretListResponse.Group>>groups()final JsonField<List<SecretListResponse.Group>>_groups()Returns the raw JSON value of groups. final Map<String, JsonValue>_additionalProperties()final SecretListResponse.BuildertoBuilder()final SecretListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SecretListResponse. -
-
Method Detail
-
groups
final Optional<List<SecretListResponse.Group>> groups()
-
_groups
final JsonField<List<SecretListResponse.Group>> _groups()
Returns the raw JSON value of groups.
Unlike groups, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretListResponse.Builder toBuilder()
-
validate
final SecretListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SecretListResponse.Builder builder()
Returns a mutable builder for constructing an instance of SecretListResponse.
-
-
-
-