Class SecretListResponse.Group.Builder
-
- All Implemented Interfaces:
public final class SecretListResponse.Group.BuilderA builder for Group.
-
-
Method Summary
-
-
Method Detail
-
id
final SecretListResponse.Group.Builder id(String id)
Unique identifier for the secret group
-
id
final SecretListResponse.Group.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final SecretListResponse.Group.Builder createdAt(OffsetDateTime createdAt)
When the secret group was created
-
createdAt
final SecretListResponse.Group.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final SecretListResponse.Group.Builder description(String description)
Description of the secret group
-
description
final SecretListResponse.Group.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final SecretListResponse.Group.Builder name(String name)
Name of the secret group
-
name
final SecretListResponse.Group.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final SecretListResponse.Group.Builder updatedAt(OffsetDateTime updatedAt)
When the secret group was last updated
-
updatedAt
final SecretListResponse.Group.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SecretListResponse.Group.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SecretListResponse.Group.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SecretListResponse.Group.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SecretListResponse.Group.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SecretListResponse.Group.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SecretListResponse.Group build()
Returns an immutable instance of Group.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-