Class SecretRetrieveGroupParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SecretRetrieveGroupParams implements Params
Retrieve the keys (names) of secrets in a specified group within a compute environment. For security reasons, actual secret values are not returned - only the keys and metadata.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretRetrieveGroupParams.BuilderA builder for SecretRetrieveGroupParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>group()final Optional<String>env()Environment name. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SecretRetrieveGroupParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretRetrieveGroupParamsnone()final static SecretRetrieveGroupParams.Builderbuilder()Returns a mutable builder for constructing an instance of SecretRetrieveGroupParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SecretRetrieveGroupParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SecretRetrieveGroupParams none()
-
builder
final static SecretRetrieveGroupParams.Builder builder()
Returns a mutable builder for constructing an instance of SecretRetrieveGroupParams.
-
-
-
-