Class SecretRetrieveGroupResponse
-
- All Implemented Interfaces:
public final class SecretRetrieveGroupResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretRetrieveGroupResponse.BuilderA builder for SecretRetrieveGroupResponse.
public final classSecretRetrieveGroupResponse.Grouppublic final classSecretRetrieveGroupResponse.Key
-
Method Summary
Modifier and Type Method Description final Optional<SecretRetrieveGroupResponse.Group>group()final Optional<List<SecretRetrieveGroupResponse.Key>>keys()final JsonField<SecretRetrieveGroupResponse.Group>_group()Returns the raw JSON value of group. final JsonField<List<SecretRetrieveGroupResponse.Key>>_keys()Returns the raw JSON value of keys. final Map<String, JsonValue>_additionalProperties()final SecretRetrieveGroupResponse.BuildertoBuilder()final SecretRetrieveGroupResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretRetrieveGroupResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SecretRetrieveGroupResponse. -
-
Method Detail
-
group
final Optional<SecretRetrieveGroupResponse.Group> group()
-
keys
final Optional<List<SecretRetrieveGroupResponse.Key>> keys()
-
_group
final JsonField<SecretRetrieveGroupResponse.Group> _group()
Returns the raw JSON value of group.
Unlike group, this method doesn't throw if the JSON field has an unexpected type.
-
_keys
final JsonField<List<SecretRetrieveGroupResponse.Key>> _keys()
Returns the raw JSON value of keys.
Unlike keys, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretRetrieveGroupResponse.Builder toBuilder()
-
validate
final SecretRetrieveGroupResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SecretRetrieveGroupResponse.Builder builder()
Returns a mutable builder for constructing an instance of SecretRetrieveGroupResponse.
-
-
-
-