Class SecretRetrieveGroupResponse.Builder
-
- All Implemented Interfaces:
public final class SecretRetrieveGroupResponse.BuilderA builder for SecretRetrieveGroupResponse.
-
-
Method Summary
-
-
Method Detail
-
group
final SecretRetrieveGroupResponse.Builder group(SecretRetrieveGroupResponse.Group group)
-
group
final SecretRetrieveGroupResponse.Builder group(JsonField<SecretRetrieveGroupResponse.Group> group)
Sets Builder.group to an arbitrary JSON value.
You should usually call Builder.group with a well-typed Group value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
keys
final SecretRetrieveGroupResponse.Builder keys(List<SecretRetrieveGroupResponse.Key> keys)
-
keys
final SecretRetrieveGroupResponse.Builder keys(JsonField<List<SecretRetrieveGroupResponse.Key>> keys)
Sets Builder.keys to an arbitrary JSON value.
You should usually call Builder.keys with a well-typed
List<Key>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addKey
final SecretRetrieveGroupResponse.Builder addKey(SecretRetrieveGroupResponse.Key key)
-
additionalProperties
final SecretRetrieveGroupResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SecretRetrieveGroupResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SecretRetrieveGroupResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SecretRetrieveGroupResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SecretRetrieveGroupResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SecretRetrieveGroupResponse build()
Returns an immutable instance of SecretRetrieveGroupResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-