Class SecretRetrieveGroupResponse.Group
-
- All Implemented Interfaces:
public final class SecretRetrieveGroupResponse.Group
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretRetrieveGroupResponse.Group.BuilderA builder for Group.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique identifier of the secret group final Optional<String>description()Description of the secret group final Optional<String>name()Name of the secret group final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final SecretRetrieveGroupResponse.Group.BuildertoBuilder()final SecretRetrieveGroupResponse.Groupvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretRetrieveGroupResponse.Group.Builderbuilder()Returns a mutable builder for constructing an instance of Group. -
-
Method Detail
-
description
final Optional<String> description()
Description of the secret group
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretRetrieveGroupResponse.Group.Builder toBuilder()
-
validate
final SecretRetrieveGroupResponse.Group validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SecretRetrieveGroupResponse.Group.Builder builder()
Returns a mutable builder for constructing an instance of Group.
-
-
-
-