Class SecretRetrieveGroupResponse.Group.Builder
-
- All Implemented Interfaces:
public final class SecretRetrieveGroupResponse.Group.BuilderA builder for Group.
-
-
Method Summary
-
-
Method Detail
-
id
final SecretRetrieveGroupResponse.Group.Builder id(String id)
Unique identifier of the secret group
-
id
final SecretRetrieveGroupResponse.Group.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final SecretRetrieveGroupResponse.Group.Builder description(String description)
Description of the secret group
-
description
final SecretRetrieveGroupResponse.Group.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final SecretRetrieveGroupResponse.Group.Builder name(String name)
Name of the secret group
-
name
final SecretRetrieveGroupResponse.Group.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SecretRetrieveGroupResponse.Group.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SecretRetrieveGroupResponse.Group.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SecretRetrieveGroupResponse.Group.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SecretRetrieveGroupResponse.Group.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SecretRetrieveGroupResponse.Group.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SecretRetrieveGroupResponse.Group build()
Returns an immutable instance of Group.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-