Class SecretRetrieveGroupResponse.Key.Builder
-
- All Implemented Interfaces:
public final class SecretRetrieveGroupResponse.Key.BuilderA builder for Key.
-
-
Method Summary
-
-
Method Detail
-
createdAt
final SecretRetrieveGroupResponse.Key.Builder createdAt(OffsetDateTime createdAt)
When the secret was created
-
createdAt
final SecretRetrieveGroupResponse.Key.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
key
final SecretRetrieveGroupResponse.Key.Builder key(String key)
Name of the secret key
-
key
final SecretRetrieveGroupResponse.Key.Builder key(JsonField<String> key)
Sets Builder.key to an arbitrary JSON value.
You should usually call Builder.key with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final SecretRetrieveGroupResponse.Key.Builder updatedAt(OffsetDateTime updatedAt)
When the secret was last updated
-
updatedAt
final SecretRetrieveGroupResponse.Key.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SecretRetrieveGroupResponse.Key.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SecretRetrieveGroupResponse.Key.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SecretRetrieveGroupResponse.Key.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SecretRetrieveGroupResponse.Key.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SecretRetrieveGroupResponse.Key.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SecretRetrieveGroupResponse.Key build()
Returns an immutable instance of Key.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-