Class SecretUpdateGroupParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SecretUpdateGroupParams implements Params
Set or update secrets in a compute secret group. Secrets are encrypted with AES-256-GCM. Use this to manage environment variables and API keys for your compute workloads.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretUpdateGroupParams.BuilderA builder for SecretUpdateGroupParams.
public final classSecretUpdateGroupParams.Bodypublic final classSecretUpdateGroupParams.SecretsKey-value pairs of secrets to set
-
Method Summary
Modifier and Type Method Description final Optional<String>group()final SecretUpdateGroupParams.Secretssecrets()Key-value pairs of secrets to set final Optional<String>env()Environment name (optional, uses default if not specified) final JsonField<SecretUpdateGroupParams.Secrets>_secrets()Returns the raw JSON value of secrets. final JsonField<String>_env()Returns the raw JSON value of env. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SecretUpdateGroupParams.BuildertoBuilder()final SecretUpdateGroupParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretUpdateGroupParams.Builderbuilder()Returns a mutable builder for constructing an instance of SecretUpdateGroupParams. -
-
Method Detail
-
secrets
final SecretUpdateGroupParams.Secrets secrets()
Key-value pairs of secrets to set
-
_secrets
final JsonField<SecretUpdateGroupParams.Secrets> _secrets()
Returns the raw JSON value of secrets.
Unlike secrets, this method doesn't throw if the JSON field has an unexpected type.
-
_env
final JsonField<String> _env()
Returns the raw JSON value of env.
Unlike env, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SecretUpdateGroupParams.Builder toBuilder()
-
_body
final SecretUpdateGroupParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SecretUpdateGroupParams.Builder builder()
Returns a mutable builder for constructing an instance of SecretUpdateGroupParams.
The following fields are required:
.secrets()
-
-
-
-