Class SecretUpdateGroupParams.Secrets
-
- All Implemented Interfaces:
public final class SecretUpdateGroupParams.SecretsKey-value pairs of secrets to set
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretUpdateGroupParams.Secrets.BuilderA builder for Secrets.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final SecretUpdateGroupParams.Secrets.BuildertoBuilder()final SecretUpdateGroupParams.Secretsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretUpdateGroupParams.Secrets.Builderbuilder()Returns a mutable builder for constructing an instance of Secrets. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretUpdateGroupParams.Secrets.Builder toBuilder()
-
validate
final SecretUpdateGroupParams.Secrets validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SecretUpdateGroupParams.Secrets.Builder builder()
Returns a mutable builder for constructing an instance of Secrets.
-
-
-
-