Class SecretUpdateGroupResponse
-
- All Implemented Interfaces:
public final class SecretUpdateGroupResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretUpdateGroupResponse.BuilderA builder for SecretUpdateGroupResponse.
-
Method Summary
Modifier and Type Method Description final Optional<Double>created()Number of new secrets created final Optional<String>group()Name of the secret group final Optional<String>message()final Optional<Boolean>success()final Optional<Double>updated()Number of existing secrets updated final JsonField<Double>_created()Returns the raw JSON value of created. final JsonField<String>_group()Returns the raw JSON value of group. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<Boolean>_success()Returns the raw JSON value of success. final JsonField<Double>_updated()Returns the raw JSON value of updated. final Map<String, JsonValue>_additionalProperties()final SecretUpdateGroupResponse.BuildertoBuilder()final SecretUpdateGroupResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretUpdateGroupResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SecretUpdateGroupResponse. -
-
Method Detail
-
_created
final JsonField<Double> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_group
final JsonField<String> _group()
Returns the raw JSON value of group.
Unlike group, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<Double> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretUpdateGroupResponse.Builder toBuilder()
-
validate
final SecretUpdateGroupResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SecretUpdateGroupResponse.Builder builder()
Returns a mutable builder for constructing an instance of SecretUpdateGroupResponse.
-
-
-
-