Class V1GetUsageResponse
-
- All Implemented Interfaces:
public final class V1GetUsageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.BuilderA builder for V1GetUsageResponse.
public final classV1GetUsageResponse.Periodpublic final classV1GetUsageResponse.PricingCurrent pricing rates
public final classV1GetUsageResponse.Projectpublic final classV1GetUsageResponse.TotalsAggregated totals across all projects
-
Method Summary
Modifier and Type Method Description final Optional<V1GetUsageResponse.Period>period()final Optional<V1GetUsageResponse.Pricing>pricing()Current pricing rates final Optional<Long>projectCount()Total number of projects with usage final Optional<List<V1GetUsageResponse.Project>>projects()Usage breakdown by project final Optional<V1GetUsageResponse.Totals>totals()Aggregated totals across all projects final JsonField<V1GetUsageResponse.Period>_period()Returns the raw JSON value of period. final JsonField<V1GetUsageResponse.Pricing>_pricing()Returns the raw JSON value of pricing. final JsonField<Long>_projectCount()Returns the raw JSON value of projectCount. final JsonField<List<V1GetUsageResponse.Project>>_projects()Returns the raw JSON value of projects. final JsonField<V1GetUsageResponse.Totals>_totals()Returns the raw JSON value of totals. final Map<String, JsonValue>_additionalProperties()final V1GetUsageResponse.BuildertoBuilder()final V1GetUsageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1GetUsageResponse. -
-
Method Detail
-
period
final Optional<V1GetUsageResponse.Period> period()
-
pricing
final Optional<V1GetUsageResponse.Pricing> pricing()
Current pricing rates
-
projectCount
final Optional<Long> projectCount()
Total number of projects with usage
-
projects
final Optional<List<V1GetUsageResponse.Project>> projects()
Usage breakdown by project
-
totals
final Optional<V1GetUsageResponse.Totals> totals()
Aggregated totals across all projects
-
_period
final JsonField<V1GetUsageResponse.Period> _period()
Returns the raw JSON value of period.
Unlike period, this method doesn't throw if the JSON field has an unexpected type.
-
_pricing
final JsonField<V1GetUsageResponse.Pricing> _pricing()
Returns the raw JSON value of pricing.
Unlike pricing, this method doesn't throw if the JSON field has an unexpected type.
-
_projectCount
final JsonField<Long> _projectCount()
Returns the raw JSON value of projectCount.
Unlike projectCount, this method doesn't throw if the JSON field has an unexpected type.
-
_projects
final JsonField<List<V1GetUsageResponse.Project>> _projects()
Returns the raw JSON value of projects.
Unlike projects, this method doesn't throw if the JSON field has an unexpected type.
-
_totals
final JsonField<V1GetUsageResponse.Totals> _totals()
Returns the raw JSON value of totals.
Unlike totals, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Builder toBuilder()
-
validate
final V1GetUsageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1GetUsageResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1GetUsageResponse.
-
-
-
-