Class V1GetUsageResponse.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.BuilderA builder for V1GetUsageResponse.
-
-
Method Summary
-
-
Method Detail
-
period
final V1GetUsageResponse.Builder period(V1GetUsageResponse.Period period)
-
period
final V1GetUsageResponse.Builder period(JsonField<V1GetUsageResponse.Period> period)
Sets Builder.period to an arbitrary JSON value.
You should usually call Builder.period with a well-typed Period value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pricing
final V1GetUsageResponse.Builder pricing(V1GetUsageResponse.Pricing pricing)
Current pricing rates
-
pricing
final V1GetUsageResponse.Builder pricing(JsonField<V1GetUsageResponse.Pricing> pricing)
Sets Builder.pricing to an arbitrary JSON value.
You should usually call Builder.pricing with a well-typed Pricing value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
projectCount
final V1GetUsageResponse.Builder projectCount(Long projectCount)
Total number of projects with usage
-
projectCount
final V1GetUsageResponse.Builder projectCount(JsonField<Long> projectCount)
Sets Builder.projectCount to an arbitrary JSON value.
You should usually call Builder.projectCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
projects
final V1GetUsageResponse.Builder projects(List<V1GetUsageResponse.Project> projects)
Usage breakdown by project
-
projects
final V1GetUsageResponse.Builder projects(JsonField<List<V1GetUsageResponse.Project>> projects)
Sets Builder.projects to an arbitrary JSON value.
You should usually call Builder.projects with a well-typed
List<Project>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addProject
final V1GetUsageResponse.Builder addProject(V1GetUsageResponse.Project project)
-
totals
final V1GetUsageResponse.Builder totals(V1GetUsageResponse.Totals totals)
Aggregated totals across all projects
-
totals
final V1GetUsageResponse.Builder totals(JsonField<V1GetUsageResponse.Totals> totals)
Sets Builder.totals to an arbitrary JSON value.
You should usually call Builder.totals with a well-typed Totals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse build()
Returns an immutable instance of V1GetUsageResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-