Class V1GetUsageResponse.Pricing
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.PricingCurrent pricing rates
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.Pricing.BuilderA builder for Pricing.
-
Method Summary
Modifier and Type Method Description final Optional<Double>branchPerMonth()Cost per branch per month in dollars final Optional<Double>computePerCuHour()Cost per compute unit hour in dollars final Optional<Long>freeBranches()Number of free branches included final Optional<Double>storagePerGbMonth()Cost per GB of storage per month in dollars final Optional<Double>transferPerGb()Cost per GB of data transfer in dollars final JsonField<Double>_branchPerMonth()Returns the raw JSON value of branchPerMonth. final JsonField<Double>_computePerCuHour()Returns the raw JSON value of computePerCuHour. final JsonField<Long>_freeBranches()Returns the raw JSON value of freeBranches. final JsonField<Double>_storagePerGbMonth()Returns the raw JSON value of storagePerGbMonth. final JsonField<Double>_transferPerGb()Returns the raw JSON value of transferPerGb. final Map<String, JsonValue>_additionalProperties()final V1GetUsageResponse.Pricing.BuildertoBuilder()final V1GetUsageResponse.Pricingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageResponse.Pricing.Builderbuilder()Returns a mutable builder for constructing an instance of Pricing. -
-
Method Detail
-
branchPerMonth
final Optional<Double> branchPerMonth()
Cost per branch per month in dollars
-
computePerCuHour
final Optional<Double> computePerCuHour()
Cost per compute unit hour in dollars
-
freeBranches
final Optional<Long> freeBranches()
Number of free branches included
-
storagePerGbMonth
final Optional<Double> storagePerGbMonth()
Cost per GB of storage per month in dollars
-
transferPerGb
final Optional<Double> transferPerGb()
Cost per GB of data transfer in dollars
-
_branchPerMonth
final JsonField<Double> _branchPerMonth()
Returns the raw JSON value of branchPerMonth.
Unlike branchPerMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_computePerCuHour
final JsonField<Double> _computePerCuHour()
Returns the raw JSON value of computePerCuHour.
Unlike computePerCuHour, this method doesn't throw if the JSON field has an unexpected type.
-
_freeBranches
final JsonField<Long> _freeBranches()
Returns the raw JSON value of freeBranches.
Unlike freeBranches, this method doesn't throw if the JSON field has an unexpected type.
-
_storagePerGbMonth
final JsonField<Double> _storagePerGbMonth()
Returns the raw JSON value of storagePerGbMonth.
Unlike storagePerGbMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_transferPerGb
final JsonField<Double> _transferPerGb()
Returns the raw JSON value of transferPerGb.
Unlike transferPerGb, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Pricing.Builder toBuilder()
-
validate
final V1GetUsageResponse.Pricing validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1GetUsageResponse.Pricing.Builder builder()
Returns a mutable builder for constructing an instance of Pricing.
-
-
-
-