Class V1GetUsageResponse.Pricing.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Pricing.BuilderA builder for Pricing.
-
-
Method Summary
-
-
Method Detail
-
branchPerMonth
final V1GetUsageResponse.Pricing.Builder branchPerMonth(Double branchPerMonth)
Cost per branch per month in dollars
-
branchPerMonth
final V1GetUsageResponse.Pricing.Builder branchPerMonth(JsonField<Double> branchPerMonth)
Sets Builder.branchPerMonth to an arbitrary JSON value.
You should usually call Builder.branchPerMonth with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
computePerCuHour
final V1GetUsageResponse.Pricing.Builder computePerCuHour(Double computePerCuHour)
Cost per compute unit hour in dollars
-
computePerCuHour
final V1GetUsageResponse.Pricing.Builder computePerCuHour(JsonField<Double> computePerCuHour)
Sets Builder.computePerCuHour to an arbitrary JSON value.
You should usually call Builder.computePerCuHour with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
freeBranches
final V1GetUsageResponse.Pricing.Builder freeBranches(Long freeBranches)
Number of free branches included
-
freeBranches
final V1GetUsageResponse.Pricing.Builder freeBranches(JsonField<Long> freeBranches)
Sets Builder.freeBranches to an arbitrary JSON value.
You should usually call Builder.freeBranches with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
storagePerGbMonth
final V1GetUsageResponse.Pricing.Builder storagePerGbMonth(Double storagePerGbMonth)
Cost per GB of storage per month in dollars
-
storagePerGbMonth
final V1GetUsageResponse.Pricing.Builder storagePerGbMonth(JsonField<Double> storagePerGbMonth)
Sets Builder.storagePerGbMonth to an arbitrary JSON value.
You should usually call Builder.storagePerGbMonth with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferPerGb
final V1GetUsageResponse.Pricing.Builder transferPerGb(Double transferPerGb)
Cost per GB of data transfer in dollars
-
transferPerGb
final V1GetUsageResponse.Pricing.Builder transferPerGb(JsonField<Double> transferPerGb)
Sets Builder.transferPerGb to an arbitrary JSON value.
You should usually call Builder.transferPerGb with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.Pricing.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.Pricing.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.Pricing.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.Pricing.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.Pricing.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse.Pricing build()
Returns an immutable instance of Pricing.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-