Class V1GetUsageResponse.Project.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Project.BuilderA builder for Project.
-
-
Method Summary
-
-
Method Detail
-
id
final V1GetUsageResponse.Project.Builder id(String id)
-
id
final V1GetUsageResponse.Project.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
branchCount
final V1GetUsageResponse.Project.Builder branchCount(Long branchCount)
-
branchCount
final V1GetUsageResponse.Project.Builder branchCount(JsonField<Long> branchCount)
Sets Builder.branchCount to an arbitrary JSON value.
You should usually call Builder.branchCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
computeCuHours
final V1GetUsageResponse.Project.Builder computeCuHours(Double computeCuHours)
-
computeCuHours
final V1GetUsageResponse.Project.Builder computeCuHours(JsonField<Double> computeCuHours)
Sets Builder.computeCuHours to an arbitrary JSON value.
You should usually call Builder.computeCuHours with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
costs
final V1GetUsageResponse.Project.Builder costs(V1GetUsageResponse.Project.Costs costs)
-
costs
final V1GetUsageResponse.Project.Builder costs(JsonField<V1GetUsageResponse.Project.Costs> costs)
Sets Builder.costs to an arbitrary JSON value.
You should usually call Builder.costs with a well-typed Costs value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastUpdated
final V1GetUsageResponse.Project.Builder lastUpdated(OffsetDateTime lastUpdated)
-
lastUpdated
final V1GetUsageResponse.Project.Builder lastUpdated(JsonField<OffsetDateTime> lastUpdated)
Sets Builder.lastUpdated to an arbitrary JSON value.
You should usually call Builder.lastUpdated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
projectId
final V1GetUsageResponse.Project.Builder projectId(String projectId)
-
projectId
final V1GetUsageResponse.Project.Builder projectId(JsonField<String> projectId)
Sets Builder.projectId to an arbitrary JSON value.
You should usually call Builder.projectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
projectName
final V1GetUsageResponse.Project.Builder projectName(String projectName)
-
projectName
final V1GetUsageResponse.Project.Builder projectName(Optional<String> projectName)
Alias for calling Builder.projectName with
projectName.orElse(null).
-
projectName
final V1GetUsageResponse.Project.Builder projectName(JsonField<String> projectName)
Sets Builder.projectName to an arbitrary JSON value.
You should usually call Builder.projectName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
storageGbMonths
final V1GetUsageResponse.Project.Builder storageGbMonths(Double storageGbMonths)
-
storageGbMonths
final V1GetUsageResponse.Project.Builder storageGbMonths(JsonField<Double> storageGbMonths)
Sets Builder.storageGbMonths to an arbitrary JSON value.
You should usually call Builder.storageGbMonths with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferGb
final V1GetUsageResponse.Project.Builder transferGb(Double transferGb)
-
transferGb
final V1GetUsageResponse.Project.Builder transferGb(JsonField<Double> transferGb)
Sets Builder.transferGb to an arbitrary JSON value.
You should usually call Builder.transferGb with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.Project.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.Project.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.Project.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.Project.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.Project.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse.Project build()
Returns an immutable instance of Project.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-