Class V1GetUsageResponse.Project.Costs.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Project.Costs.BuilderA builder for Costs.
-
-
Method Summary
-
-
Method Detail
-
branches
final V1GetUsageResponse.Project.Costs.Builder branches(String branches)
-
branches
final V1GetUsageResponse.Project.Costs.Builder branches(JsonField<String> branches)
Sets Builder.branches to an arbitrary JSON value.
You should usually call Builder.branches with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
compute
final V1GetUsageResponse.Project.Costs.Builder compute(String compute)
-
compute
final V1GetUsageResponse.Project.Costs.Builder compute(JsonField<String> compute)
Sets Builder.compute to an arbitrary JSON value.
You should usually call Builder.compute with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
storage
final V1GetUsageResponse.Project.Costs.Builder storage(String storage)
-
storage
final V1GetUsageResponse.Project.Costs.Builder storage(JsonField<String> storage)
Sets Builder.storage to an arbitrary JSON value.
You should usually call Builder.storage with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
total
final V1GetUsageResponse.Project.Costs.Builder total(String total)
-
total
final V1GetUsageResponse.Project.Costs.Builder total(JsonField<String> total)
Sets Builder.total to an arbitrary JSON value.
You should usually call Builder.total with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transfer
final V1GetUsageResponse.Project.Costs.Builder transfer(String transfer)
-
transfer
final V1GetUsageResponse.Project.Costs.Builder transfer(JsonField<String> transfer)
Sets Builder.transfer to an arbitrary JSON value.
You should usually call Builder.transfer with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.Project.Costs.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.Project.Costs.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.Project.Costs.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.Project.Costs.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.Project.Costs.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse.Project.Costs build()
Returns an immutable instance of Costs.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-