Class V1GetUsageResponse.Totals
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.TotalsAggregated totals across all projects
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.Totals.BuilderA builder for Totals.
-
Method Summary
Modifier and Type Method Description final Optional<String>branchCostDollars()Total branch cost formatted as dollars final Optional<String>computeCostDollars()Total compute cost formatted as dollars final Optional<Double>computeCuHours()Total compute unit hours final Optional<String>storageCostDollars()Total storage cost formatted as dollars final Optional<Double>storageGbMonths()Total storage in GB-months final Optional<Long>totalBranches()Total number of branches final Optional<String>totalCostDollars()Total cost formatted as dollars final Optional<String>transferCostDollars()Total transfer cost formatted as dollars final Optional<Double>transferGb()Total data transfer in GB final JsonField<String>_branchCostDollars()Returns the raw JSON value of branchCostDollars. final JsonField<String>_computeCostDollars()Returns the raw JSON value of computeCostDollars. final JsonField<Double>_computeCuHours()Returns the raw JSON value of computeCuHours. final JsonField<String>_storageCostDollars()Returns the raw JSON value of storageCostDollars. final JsonField<Double>_storageGbMonths()Returns the raw JSON value of storageGbMonths. final JsonField<Long>_totalBranches()Returns the raw JSON value of totalBranches. final JsonField<String>_totalCostDollars()Returns the raw JSON value of totalCostDollars. final JsonField<String>_transferCostDollars()Returns the raw JSON value of transferCostDollars. final JsonField<Double>_transferGb()Returns the raw JSON value of transferGb. final Map<String, JsonValue>_additionalProperties()final V1GetUsageResponse.Totals.BuildertoBuilder()final V1GetUsageResponse.Totalsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageResponse.Totals.Builderbuilder()Returns a mutable builder for constructing an instance of Totals. -
-
Method Detail
-
branchCostDollars
final Optional<String> branchCostDollars()
Total branch cost formatted as dollars
-
computeCostDollars
final Optional<String> computeCostDollars()
Total compute cost formatted as dollars
-
computeCuHours
final Optional<Double> computeCuHours()
Total compute unit hours
-
storageCostDollars
final Optional<String> storageCostDollars()
Total storage cost formatted as dollars
-
storageGbMonths
final Optional<Double> storageGbMonths()
Total storage in GB-months
-
totalBranches
final Optional<Long> totalBranches()
Total number of branches
-
totalCostDollars
final Optional<String> totalCostDollars()
Total cost formatted as dollars
-
transferCostDollars
final Optional<String> transferCostDollars()
Total transfer cost formatted as dollars
-
transferGb
final Optional<Double> transferGb()
Total data transfer in GB
-
_branchCostDollars
final JsonField<String> _branchCostDollars()
Returns the raw JSON value of branchCostDollars.
Unlike branchCostDollars, this method doesn't throw if the JSON field has an unexpected type.
-
_computeCostDollars
final JsonField<String> _computeCostDollars()
Returns the raw JSON value of computeCostDollars.
Unlike computeCostDollars, this method doesn't throw if the JSON field has an unexpected type.
-
_computeCuHours
final JsonField<Double> _computeCuHours()
Returns the raw JSON value of computeCuHours.
Unlike computeCuHours, this method doesn't throw if the JSON field has an unexpected type.
-
_storageCostDollars
final JsonField<String> _storageCostDollars()
Returns the raw JSON value of storageCostDollars.
Unlike storageCostDollars, this method doesn't throw if the JSON field has an unexpected type.
-
_storageGbMonths
final JsonField<Double> _storageGbMonths()
Returns the raw JSON value of storageGbMonths.
Unlike storageGbMonths, this method doesn't throw if the JSON field has an unexpected type.
-
_totalBranches
final JsonField<Long> _totalBranches()
Returns the raw JSON value of totalBranches.
Unlike totalBranches, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCostDollars
final JsonField<String> _totalCostDollars()
Returns the raw JSON value of totalCostDollars.
Unlike totalCostDollars, this method doesn't throw if the JSON field has an unexpected type.
-
_transferCostDollars
final JsonField<String> _transferCostDollars()
Returns the raw JSON value of transferCostDollars.
Unlike transferCostDollars, this method doesn't throw if the JSON field has an unexpected type.
-
_transferGb
final JsonField<Double> _transferGb()
Returns the raw JSON value of transferGb.
Unlike transferGb, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Totals.Builder toBuilder()
-
validate
final V1GetUsageResponse.Totals validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1GetUsageResponse.Totals.Builder builder()
Returns a mutable builder for constructing an instance of Totals.
-
-
-
-