Class V1GetUsageResponse.Totals.Builder
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Totals.BuilderA builder for Totals.
-
-
Method Summary
-
-
Method Detail
-
branchCostDollars
final V1GetUsageResponse.Totals.Builder branchCostDollars(String branchCostDollars)
Total branch cost formatted as dollars
-
branchCostDollars
final V1GetUsageResponse.Totals.Builder branchCostDollars(JsonField<String> branchCostDollars)
Sets Builder.branchCostDollars to an arbitrary JSON value.
You should usually call Builder.branchCostDollars with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
computeCostDollars
final V1GetUsageResponse.Totals.Builder computeCostDollars(String computeCostDollars)
Total compute cost formatted as dollars
-
computeCostDollars
final V1GetUsageResponse.Totals.Builder computeCostDollars(JsonField<String> computeCostDollars)
Sets Builder.computeCostDollars to an arbitrary JSON value.
You should usually call Builder.computeCostDollars with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
computeCuHours
final V1GetUsageResponse.Totals.Builder computeCuHours(Double computeCuHours)
Total compute unit hours
-
computeCuHours
final V1GetUsageResponse.Totals.Builder computeCuHours(JsonField<Double> computeCuHours)
Sets Builder.computeCuHours to an arbitrary JSON value.
You should usually call Builder.computeCuHours with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
storageCostDollars
final V1GetUsageResponse.Totals.Builder storageCostDollars(String storageCostDollars)
Total storage cost formatted as dollars
-
storageCostDollars
final V1GetUsageResponse.Totals.Builder storageCostDollars(JsonField<String> storageCostDollars)
Sets Builder.storageCostDollars to an arbitrary JSON value.
You should usually call Builder.storageCostDollars with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
storageGbMonths
final V1GetUsageResponse.Totals.Builder storageGbMonths(Double storageGbMonths)
Total storage in GB-months
-
storageGbMonths
final V1GetUsageResponse.Totals.Builder storageGbMonths(JsonField<Double> storageGbMonths)
Sets Builder.storageGbMonths to an arbitrary JSON value.
You should usually call Builder.storageGbMonths with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalBranches
final V1GetUsageResponse.Totals.Builder totalBranches(Long totalBranches)
Total number of branches
-
totalBranches
final V1GetUsageResponse.Totals.Builder totalBranches(JsonField<Long> totalBranches)
Sets Builder.totalBranches to an arbitrary JSON value.
You should usually call Builder.totalBranches with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalCostDollars
final V1GetUsageResponse.Totals.Builder totalCostDollars(String totalCostDollars)
Total cost formatted as dollars
-
totalCostDollars
final V1GetUsageResponse.Totals.Builder totalCostDollars(JsonField<String> totalCostDollars)
Sets Builder.totalCostDollars to an arbitrary JSON value.
You should usually call Builder.totalCostDollars with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferCostDollars
final V1GetUsageResponse.Totals.Builder transferCostDollars(String transferCostDollars)
Total transfer cost formatted as dollars
-
transferCostDollars
final V1GetUsageResponse.Totals.Builder transferCostDollars(JsonField<String> transferCostDollars)
Sets Builder.transferCostDollars to an arbitrary JSON value.
You should usually call Builder.transferCostDollars with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferGb
final V1GetUsageResponse.Totals.Builder transferGb(Double transferGb)
Total data transfer in GB
-
transferGb
final V1GetUsageResponse.Totals.Builder transferGb(JsonField<Double> transferGb)
Sets Builder.transferGb to an arbitrary JSON value.
You should usually call Builder.transferGb with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1GetUsageResponse.Totals.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1GetUsageResponse.Totals.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1GetUsageResponse.Totals.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1GetUsageResponse.Totals.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1GetUsageResponse.Totals.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1GetUsageResponse.Totals build()
Returns an immutable instance of Totals.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-