Class ProjectCreateBranchParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectCreateBranchParams implements Params
Creates a new branch from the specified parent branch (or default 'main' branch). Branches provide instant point-in-time clones of your database for isolated development, staging, testing, or feature work. Perfect for testing schema changes, running migrations safely, or creating ephemeral preview environments.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateBranchParams.BuilderA builder for ProjectCreateBranchParams.
public final classProjectCreateBranchParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Stringname()Branch name (letters, numbers, hyphens, underscores only) final Optional<String>parentBranchId()Parent branch ID to clone from (defaults to main branch) final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_parentBranchId()Returns the raw JSON value of parentBranchId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectCreateBranchParams.BuildertoBuilder()final ProjectCreateBranchParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateBranchParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateBranchParams. -
-
Method Detail
-
parentBranchId
final Optional<String> parentBranchId()
Parent branch ID to clone from (defaults to main branch)
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_parentBranchId
final JsonField<String> _parentBranchId()
Returns the raw JSON value of parentBranchId.
Unlike parentBranchId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectCreateBranchParams.Builder toBuilder()
-
_body
final ProjectCreateBranchParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ProjectCreateBranchParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateBranchParams.
The following fields are required:
.name()
-
-
-
-