Class ProjectCreateBranchParams.Body
-
- All Implemented Interfaces:
public final class ProjectCreateBranchParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateBranchParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()Branch name (letters, numbers, hyphens, underscores only) final Optional<String>parentBranchId()Parent branch ID to clone from (defaults to main branch) final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_parentBranchId()Returns the raw JSON value of parentBranchId. final Map<String, JsonValue>_additionalProperties()final ProjectCreateBranchParams.Body.BuildertoBuilder()final ProjectCreateBranchParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateBranchParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
parentBranchId
final Optional<String> parentBranchId()
Parent branch ID to clone from (defaults to main branch)
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_parentBranchId
final JsonField<String> _parentBranchId()
Returns the raw JSON value of parentBranchId.
Unlike parentBranchId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateBranchParams.Body.Builder toBuilder()
-
validate
final ProjectCreateBranchParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectCreateBranchParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-