Class ProjectCreateBranchResponse
-
- All Implemented Interfaces:
public final class ProjectCreateBranchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateBranchResponse.BuilderA builder for ProjectCreateBranchResponse.
-
Method Summary
Modifier and Type Method Description final Stringid()Branch ID final OffsetDateTimecreatedAt()Branch creation timestamp final BooleanisDefault()Whether this is the default branch (always false for new branches) final Stringname()Branch name final Optional<String>parentBranchId()Parent branch ID final Stringstatus()Branch status final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Boolean>_isDefault()Returns the raw JSON value of isDefault. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_parentBranchId()Returns the raw JSON value of parentBranchId. final JsonField<String>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final ProjectCreateBranchResponse.BuildertoBuilder()final ProjectCreateBranchResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateBranchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateBranchResponse. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
Branch creation timestamp
-
isDefault
final Boolean isDefault()
Whether this is the default branch (always false for new branches)
-
parentBranchId
final Optional<String> parentBranchId()
Parent branch ID
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_isDefault
final JsonField<Boolean> _isDefault()
Returns the raw JSON value of isDefault.
Unlike isDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_parentBranchId
final JsonField<String> _parentBranchId()
Returns the raw JSON value of parentBranchId.
Unlike parentBranchId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateBranchResponse.Builder toBuilder()
-
validate
final ProjectCreateBranchResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectCreateBranchResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateBranchResponse.
The following fields are required:
.id() .createdAt() .isDefault() .name() .parentBranchId() .status()
-
-
-
-