Class ProjectCreateBranchResponse.Builder
-
- All Implemented Interfaces:
public final class ProjectCreateBranchResponse.BuilderA builder for ProjectCreateBranchResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectCreateBranchResponse.Builder id(String id)
Branch ID
-
id
final ProjectCreateBranchResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ProjectCreateBranchResponse.Builder createdAt(OffsetDateTime createdAt)
Branch creation timestamp
-
createdAt
final ProjectCreateBranchResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isDefault
final ProjectCreateBranchResponse.Builder isDefault(Boolean isDefault)
Whether this is the default branch (always false for new branches)
-
isDefault
final ProjectCreateBranchResponse.Builder isDefault(JsonField<Boolean> isDefault)
Sets Builder.isDefault to an arbitrary JSON value.
You should usually call Builder.isDefault with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectCreateBranchResponse.Builder name(String name)
Branch name
-
name
final ProjectCreateBranchResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
parentBranchId
final ProjectCreateBranchResponse.Builder parentBranchId(String parentBranchId)
Parent branch ID
-
parentBranchId
final ProjectCreateBranchResponse.Builder parentBranchId(Optional<String> parentBranchId)
Alias for calling Builder.parentBranchId with
parentBranchId.orElse(null).
-
parentBranchId
final ProjectCreateBranchResponse.Builder parentBranchId(JsonField<String> parentBranchId)
Sets Builder.parentBranchId to an arbitrary JSON value.
You should usually call Builder.parentBranchId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ProjectCreateBranchResponse.Builder status(String status)
Branch status
-
status
final ProjectCreateBranchResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectCreateBranchResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectCreateBranchResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectCreateBranchResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectCreateBranchResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectCreateBranchResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectCreateBranchResponse build()
Returns an immutable instance of ProjectCreateBranchResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .isDefault() .name() .parentBranchId() .status()
-
-
-
-