Class ProjectCreateParams.Body
-
- All Implemented Interfaces:
public final class ProjectCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()Project name (letters, numbers, hyphens, underscores only) final Optional<String>description()Optional project description final Optional<ProjectCreateParams.Region>region()AWS region for database deployment final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<ProjectCreateParams.Region>_region()Returns the raw JSON value of region. final Map<String, JsonValue>_additionalProperties()final ProjectCreateParams.Body.BuildertoBuilder()final ProjectCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
Optional project description
-
region
final Optional<ProjectCreateParams.Region> region()
AWS region for database deployment
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<ProjectCreateParams.Region> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateParams.Body.Builder toBuilder()
-
validate
final ProjectCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-