Class ProjectCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ProjectCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
name
final ProjectCreateParams.Body.Builder name(String name)
Project name (letters, numbers, hyphens, underscores only)
-
name
final ProjectCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final ProjectCreateParams.Body.Builder description(String description)
Optional project description
-
description
final ProjectCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final ProjectCreateParams.Body.Builder region(ProjectCreateParams.Region region)
AWS region for database deployment
-
region
final ProjectCreateParams.Body.Builder region(JsonField<ProjectCreateParams.Region> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed Region value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-