Class ProjectCreateParams.Region
-
- All Implemented Interfaces:
-
dev.case.api.core.Enum
public final class ProjectCreateParams.Region implements EnumAWS region for database deployment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumProjectCreateParams.Region.KnownAn enum containing Region's known values.
public enumProjectCreateParams.Region.ValueAn enum containing Region's known values, as well as an _UNKNOWN member.
An instance of Region can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static ProjectCreateParams.RegionAWS_US_EAST_1public final static ProjectCreateParams.RegionAWS_US_EAST_2public final static ProjectCreateParams.RegionAWS_US_WEST_2public final static ProjectCreateParams.RegionAWS_EU_CENTRAL_1public final static ProjectCreateParams.RegionAWS_EU_WEST_1public final static ProjectCreateParams.RegionAWS_EU_WEST_2public final static ProjectCreateParams.RegionAWS_AP_SOUTHEAST_1public final static ProjectCreateParams.RegionAWS_AP_SOUTHEAST_2
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final ProjectCreateParams.Region.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final ProjectCreateParams.Region.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final ProjectCreateParams.Regionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateParams.Regionof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final ProjectCreateParams.Region.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final ProjectCreateParams.Region.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final ProjectCreateParams.Region validate()
-
of
final static ProjectCreateParams.Region of(String value)
-
-
-
-