Enum ProjectCreateParams.Region.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ProjectCreateParams.Region.Known extends Enum<ProjectCreateParams.Region.Known>
An enum containing Region's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ProjectCreateParams.Region.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description AWS_US_EAST_1AWS_US_EAST_2AWS_US_WEST_2AWS_EU_CENTRAL_1AWS_EU_WEST_1AWS_EU_WEST_2AWS_AP_SOUTHEAST_1AWS_AP_SOUTHEAST_2
-
Method Summary
Modifier and Type Method Description final ProjectCreateParams.Region.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ProjectCreateParams.Region.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ProjectCreateParams.Region.Known>getEntries()An enum containing Region's known values. -
-
Method Detail
-
valueOf
final ProjectCreateParams.Region.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ProjectCreateParams.Region.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ProjectCreateParams.Region.Known> getEntries()
An enum containing Region's known values.
-
-
-
-