Class ProjectCreateResponse
-
- All Implemented Interfaces:
public final class ProjectCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateResponse.BuilderA builder for ProjectCreateResponse.
public final classProjectCreateResponse.DefaultBranchDefault 'main' branch details
public final classProjectCreateResponse.StatusProject status
-
Method Summary
Modifier and Type Method Description final Stringid()Project ID final OffsetDateTimecreatedAt()Project creation timestamp final ProjectCreateResponse.DefaultBranchdefaultBranch()Default 'main' branch details final Stringname()Project name final LongpgVersion()PostgreSQL major version final Stringregion()AWS region final ProjectCreateResponse.Statusstatus()Project status final Optional<String>description()Project description final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<ProjectCreateResponse.DefaultBranch>_defaultBranch()Returns the raw JSON value of defaultBranch. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_pgVersion()Returns the raw JSON value of pgVersion. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<ProjectCreateResponse.Status>_status()Returns the raw JSON value of status. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final ProjectCreateResponse.BuildertoBuilder()final ProjectCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateResponse. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
Project creation timestamp
-
defaultBranch
final ProjectCreateResponse.DefaultBranch defaultBranch()
Default 'main' branch details
-
status
final ProjectCreateResponse.Status status()
Project status
-
description
final Optional<String> description()
Project description
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_defaultBranch
final JsonField<ProjectCreateResponse.DefaultBranch> _defaultBranch()
Returns the raw JSON value of defaultBranch.
Unlike defaultBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_pgVersion
final JsonField<Long> _pgVersion()
Returns the raw JSON value of pgVersion.
Unlike pgVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ProjectCreateResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateResponse.Builder toBuilder()
-
validate
final ProjectCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateResponse.
The following fields are required:
.id() .createdAt() .defaultBranch() .name() .pgVersion() .region() .status()
-
-
-
-