Class ProjectCreateResponse.Builder
-
- All Implemented Interfaces:
public final class ProjectCreateResponse.BuilderA builder for ProjectCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectCreateResponse.Builder id(String id)
Project ID
-
id
final ProjectCreateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ProjectCreateResponse.Builder createdAt(OffsetDateTime createdAt)
Project creation timestamp
-
createdAt
final ProjectCreateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
defaultBranch
final ProjectCreateResponse.Builder defaultBranch(ProjectCreateResponse.DefaultBranch defaultBranch)
Default 'main' branch details
-
defaultBranch
final ProjectCreateResponse.Builder defaultBranch(JsonField<ProjectCreateResponse.DefaultBranch> defaultBranch)
Sets Builder.defaultBranch to an arbitrary JSON value.
You should usually call Builder.defaultBranch with a well-typed DefaultBranch value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectCreateResponse.Builder name(String name)
Project name
-
name
final ProjectCreateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pgVersion
final ProjectCreateResponse.Builder pgVersion(Long pgVersion)
PostgreSQL major version
-
pgVersion
final ProjectCreateResponse.Builder pgVersion(JsonField<Long> pgVersion)
Sets Builder.pgVersion to an arbitrary JSON value.
You should usually call Builder.pgVersion with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final ProjectCreateResponse.Builder region(String region)
AWS region
-
region
final ProjectCreateResponse.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ProjectCreateResponse.Builder status(ProjectCreateResponse.Status status)
Project status
-
status
final ProjectCreateResponse.Builder status(JsonField<ProjectCreateResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final ProjectCreateResponse.Builder description(String description)
Project description
-
description
final ProjectCreateResponse.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final ProjectCreateResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectCreateResponse build()
Returns an immutable instance of ProjectCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .defaultBranch() .name() .pgVersion() .region() .status()
-
-
-
-