Class ProjectCreateResponse.DefaultBranch
-
- All Implemented Interfaces:
public final class ProjectCreateResponse.DefaultBranchDefault 'main' branch details
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateResponse.DefaultBranch.BuilderA builder for DefaultBranch.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Branch ID final Optional<String>name()Branch name final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final ProjectCreateResponse.DefaultBranch.BuildertoBuilder()final ProjectCreateResponse.DefaultBranchvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateResponse.DefaultBranch.Builderbuilder()Returns a mutable builder for constructing an instance of DefaultBranch. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateResponse.DefaultBranch.Builder toBuilder()
-
validate
final ProjectCreateResponse.DefaultBranch validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectCreateResponse.DefaultBranch.Builder builder()
Returns a mutable builder for constructing an instance of DefaultBranch.
-
-
-
-