Class ProjectDeleteParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectDeleteParams
     implements Params
                        

    Permanently deletes a database project from Neon and marks it as deleted in Case.dev. This action cannot be undone and will destroy all data including branches and databases. Use with caution.