Class ProjectDeleteResponse
-
- All Implemented Interfaces:
public final class ProjectDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectDeleteResponse.BuilderA builder for ProjectDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Stringmessage()Confirmation message final Booleansuccess()Deletion success indicator final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final ProjectDeleteResponse.BuildertoBuilder()final ProjectDeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectDeleteResponse. -
-
Method Detail
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectDeleteResponse.Builder toBuilder()
-
validate
final ProjectDeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProjectDeleteResponse.
The following fields are required:
.message() .success()
-
-
-
-