Class ProjectGetConnectionResponse
-
- All Implemented Interfaces:
public final class ProjectGetConnectionResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectGetConnectionResponse.BuilderA builder for ProjectGetConnectionResponse.
-
Method Summary
Modifier and Type Method Description final Stringbranch()Branch name for this connection final StringconnectionUri()PostgreSQL connection string (includes credentials) final Booleanpooled()Whether this is a pooled connection final JsonField<String>_branch()Returns the raw JSON value of branch. final JsonField<String>_connectionUri()Returns the raw JSON value of connectionUri. final JsonField<Boolean>_pooled()Returns the raw JSON value of pooled. final Map<String, JsonValue>_additionalProperties()final ProjectGetConnectionResponse.BuildertoBuilder()final ProjectGetConnectionResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectGetConnectionResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectGetConnectionResponse. -
-
Method Detail
-
connectionUri
final String connectionUri()
PostgreSQL connection string (includes credentials)
-
_branch
final JsonField<String> _branch()
Returns the raw JSON value of branch.
Unlike branch, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionUri
final JsonField<String> _connectionUri()
Returns the raw JSON value of connectionUri.
Unlike connectionUri, this method doesn't throw if the JSON field has an unexpected type.
-
_pooled
final JsonField<Boolean> _pooled()
Returns the raw JSON value of pooled.
Unlike pooled, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectGetConnectionResponse.Builder toBuilder()
-
validate
final ProjectGetConnectionResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectGetConnectionResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProjectGetConnectionResponse.
The following fields are required:
.branch() .connectionUri() .pooled()
-
-
-
-