Class ProjectGetConnectionResponse.Builder
-
- All Implemented Interfaces:
public final class ProjectGetConnectionResponse.BuilderA builder for ProjectGetConnectionResponse.
-
-
Method Summary
-
-
Method Detail
-
branch
final ProjectGetConnectionResponse.Builder branch(String branch)
Branch name for this connection
-
branch
final ProjectGetConnectionResponse.Builder branch(JsonField<String> branch)
Sets Builder.branch to an arbitrary JSON value.
You should usually call Builder.branch with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionUri
final ProjectGetConnectionResponse.Builder connectionUri(String connectionUri)
PostgreSQL connection string (includes credentials)
-
connectionUri
final ProjectGetConnectionResponse.Builder connectionUri(JsonField<String> connectionUri)
Sets Builder.connectionUri to an arbitrary JSON value.
You should usually call Builder.connectionUri with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pooled
final ProjectGetConnectionResponse.Builder pooled(Boolean pooled)
Whether this is a pooled connection
-
pooled
final ProjectGetConnectionResponse.Builder pooled(JsonField<Boolean> pooled)
Sets Builder.pooled to an arbitrary JSON value.
You should usually call Builder.pooled with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectGetConnectionResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectGetConnectionResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectGetConnectionResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectGetConnectionResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectGetConnectionResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectGetConnectionResponse build()
Returns an immutable instance of ProjectGetConnectionResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.branch() .connectionUri() .pooled()
-
-
-
-