Class ProjectListBranchesParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectListBranchesParams
     implements Params
                        

    Retrieves all branches for a database project. Branches enable isolated development and testing environments with instant point-in-time cloning. Each branch includes the default branch and any custom branches created for staging, testing, or feature development.