Class ProjectListBranchesResponse.Builder
-
- All Implemented Interfaces:
public final class ProjectListBranchesResponse.BuilderA builder for ProjectListBranchesResponse.
-
-
Method Summary
-
-
Method Detail
-
branches
final ProjectListBranchesResponse.Builder branches(List<ProjectListBranchesResponse.Branch> branches)
-
branches
final ProjectListBranchesResponse.Builder branches(JsonField<List<ProjectListBranchesResponse.Branch>> branches)
Sets Builder.branches to an arbitrary JSON value.
You should usually call Builder.branches with a well-typed
List<Branch>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBranch
final ProjectListBranchesResponse.Builder addBranch(ProjectListBranchesResponse.Branch branch)
-
additionalProperties
final ProjectListBranchesResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectListBranchesResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectListBranchesResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectListBranchesResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectListBranchesResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectListBranchesResponse build()
Returns an immutable instance of ProjectListBranchesResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.branches()
-
-
-
-