Class ProjectListParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectListParams
     implements Params
                        

    Retrieves all serverless Postgres database projects for the authenticated organization. Includes storage and compute metrics, plus linked application deployments and Compute instances.