Class ProjectListResponse.Project.Builder
-
- All Implemented Interfaces:
public final class ProjectListResponse.Project.BuilderA builder for Project.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectListResponse.Project.Builder id(String id)
Project ID
-
id
final ProjectListResponse.Project.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
computeTimeSeconds
final ProjectListResponse.Project.Builder computeTimeSeconds(Double computeTimeSeconds)
Total compute time consumed in seconds
-
computeTimeSeconds
final ProjectListResponse.Project.Builder computeTimeSeconds(JsonField<Double> computeTimeSeconds)
Sets Builder.computeTimeSeconds to an arbitrary JSON value.
You should usually call Builder.computeTimeSeconds with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ProjectListResponse.Project.Builder createdAt(OffsetDateTime createdAt)
Project creation timestamp
-
createdAt
final ProjectListResponse.Project.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final ProjectListResponse.Project.Builder description(String description)
Project description
-
description
final ProjectListResponse.Project.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final ProjectListResponse.Project.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
linkedDeployments
final ProjectListResponse.Project.Builder linkedDeployments(List<ProjectListResponse.Project.LinkedDeployment> linkedDeployments)
Linked application deployments using this database
-
linkedDeployments
final ProjectListResponse.Project.Builder linkedDeployments(JsonField<List<ProjectListResponse.Project.LinkedDeployment>> linkedDeployments)
Sets Builder.linkedDeployments to an arbitrary JSON value.
You should usually call Builder.linkedDeployments with a well-typed
List<LinkedDeployment>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addLinkedDeployment
final ProjectListResponse.Project.Builder addLinkedDeployment(ProjectListResponse.Project.LinkedDeployment linkedDeployment)
Adds a single LinkedDeployment to linkedDeployments.
-
name
final ProjectListResponse.Project.Builder name(String name)
Project name
-
name
final ProjectListResponse.Project.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pgVersion
final ProjectListResponse.Project.Builder pgVersion(Long pgVersion)
PostgreSQL major version
-
pgVersion
final ProjectListResponse.Project.Builder pgVersion(JsonField<Long> pgVersion)
Sets Builder.pgVersion to an arbitrary JSON value.
You should usually call Builder.pgVersion with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final ProjectListResponse.Project.Builder region(String region)
AWS region where database is deployed
-
region
final ProjectListResponse.Project.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ProjectListResponse.Project.Builder status(ProjectListResponse.Project.Status status)
Current project status
-
status
final ProjectListResponse.Project.Builder status(JsonField<ProjectListResponse.Project.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
storageSizeBytes
final ProjectListResponse.Project.Builder storageSizeBytes(Double storageSizeBytes)
Current storage usage in bytes
-
storageSizeBytes
final ProjectListResponse.Project.Builder storageSizeBytes(JsonField<Double> storageSizeBytes)
Sets Builder.storageSizeBytes to an arbitrary JSON value.
You should usually call Builder.storageSizeBytes with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final ProjectListResponse.Project.Builder updatedAt(OffsetDateTime updatedAt)
Project last update timestamp
-
updatedAt
final ProjectListResponse.Project.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectListResponse.Project.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectListResponse.Project.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectListResponse.Project.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectListResponse.Project.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectListResponse.Project.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectListResponse.Project build()
Returns an immutable instance of Project.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-