Class ProjectListResponse.Project.LinkedDeployment
-
- All Implemented Interfaces:
public final class ProjectListResponse.Project.LinkedDeployment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListResponse.Project.LinkedDeployment.BuilderA builder for LinkedDeployment.
public final classProjectListResponse.Project.LinkedDeployment.TypeType of deployment
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Deployment ID final Optional<String>name()Deployment name final Optional<ProjectListResponse.Project.LinkedDeployment.Type>type()Type of deployment final Optional<String>url()Deployment URL final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<ProjectListResponse.Project.LinkedDeployment.Type>_type()Returns the raw JSON value of type. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final ProjectListResponse.Project.LinkedDeployment.BuildertoBuilder()final ProjectListResponse.Project.LinkedDeploymentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListResponse.Project.LinkedDeployment.Builderbuilder()Returns a mutable builder for constructing an instance of LinkedDeployment. -
-
Method Detail
-
type
final Optional<ProjectListResponse.Project.LinkedDeployment.Type> type()
Type of deployment
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ProjectListResponse.Project.LinkedDeployment.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListResponse.Project.LinkedDeployment.Builder toBuilder()
-
validate
final ProjectListResponse.Project.LinkedDeployment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectListResponse.Project.LinkedDeployment.Builder builder()
Returns a mutable builder for constructing an instance of LinkedDeployment.
-
-
-
-