Class ProjectListResponse.Project.LinkedDeployment.Builder
-
- All Implemented Interfaces:
public final class ProjectListResponse.Project.LinkedDeployment.BuilderA builder for LinkedDeployment.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectListResponse.Project.LinkedDeployment.Builder id(String id)
Deployment ID
-
id
final ProjectListResponse.Project.LinkedDeployment.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectListResponse.Project.LinkedDeployment.Builder name(String name)
Deployment name
-
name
final ProjectListResponse.Project.LinkedDeployment.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ProjectListResponse.Project.LinkedDeployment.Builder type(ProjectListResponse.Project.LinkedDeployment.Type type)
Type of deployment
-
type
final ProjectListResponse.Project.LinkedDeployment.Builder type(JsonField<ProjectListResponse.Project.LinkedDeployment.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final ProjectListResponse.Project.LinkedDeployment.Builder url(String url)
Deployment URL
-
url
final ProjectListResponse.Project.LinkedDeployment.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectListResponse.Project.LinkedDeployment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectListResponse.Project.LinkedDeployment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectListResponse.Project.LinkedDeployment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectListResponse.Project.LinkedDeployment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectListResponse.Project.LinkedDeployment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectListResponse.Project.LinkedDeployment build()
Returns an immutable instance of LinkedDeployment.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-