Class ProjectListResponse.Project.Status
-
- All Implemented Interfaces:
-
dev.case.api.core.Enum
public final class ProjectListResponse.Project.Status implements EnumCurrent project status
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumProjectListResponse.Project.Status.KnownAn enum containing Status's known values.
public enumProjectListResponse.Project.Status.ValueAn enum containing Status's known values, as well as an _UNKNOWN member.
An instance of Status can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static ProjectListResponse.Project.StatusACTIVEpublic final static ProjectListResponse.Project.StatusSUSPENDEDpublic final static ProjectListResponse.Project.StatusDELETED
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final ProjectListResponse.Project.Status.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final ProjectListResponse.Project.Status.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final ProjectListResponse.Project.Statusvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListResponse.Project.Statusof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final ProjectListResponse.Project.Status.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final ProjectListResponse.Project.Status.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final ProjectListResponse.Project.Status validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
of
final static ProjectListResponse.Project.Status of(String value)
-
-
-
-