Class ProjectRetrieveResponse
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectRetrieveResponse.BuilderA builder for ProjectRetrieveResponse.
public final classProjectRetrieveResponse.Branchpublic final classProjectRetrieveResponse.Databasepublic final classProjectRetrieveResponse.LinkedDeploymentpublic final classProjectRetrieveResponse.StatusProject status
-
Method Summary
Modifier and Type Method Description final Stringid()Project ID final List<ProjectRetrieveResponse.Branch>branches()All branches in this project final DoublecomputeTimeSeconds()Total compute time consumed in seconds final StringconnectionHost()Database connection hostname (masked for security) final OffsetDateTimecreatedAt()Project creation timestamp final List<ProjectRetrieveResponse.Database>databases()Databases in the default branch final List<ProjectRetrieveResponse.LinkedDeployment>linkedDeployments()Linked deployments using this database final Stringname()Project name final LongpgVersion()PostgreSQL major version final Stringregion()AWS region final ProjectRetrieveResponse.Statusstatus()Project status final DoublestorageSizeBytes()Current storage usage in bytes final OffsetDateTimeupdatedAt()Project last update timestamp final Optional<String>description()Project description final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<List<ProjectRetrieveResponse.Branch>>_branches()Returns the raw JSON value of branches. final JsonField<Double>_computeTimeSeconds()Returns the raw JSON value of computeTimeSeconds. final JsonField<String>_connectionHost()Returns the raw JSON value of connectionHost. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<List<ProjectRetrieveResponse.Database>>_databases()Returns the raw JSON value of databases. final JsonField<List<ProjectRetrieveResponse.LinkedDeployment>>_linkedDeployments()Returns the raw JSON value of linkedDeployments. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_pgVersion()Returns the raw JSON value of pgVersion. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<ProjectRetrieveResponse.Status>_status()Returns the raw JSON value of status. final JsonField<Double>_storageSizeBytes()Returns the raw JSON value of storageSizeBytes. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final ProjectRetrieveResponse.BuildertoBuilder()final ProjectRetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectRetrieveResponse. -
-
Method Detail
-
branches
final List<ProjectRetrieveResponse.Branch> branches()
All branches in this project
-
computeTimeSeconds
final Double computeTimeSeconds()
Total compute time consumed in seconds
-
connectionHost
final String connectionHost()
Database connection hostname (masked for security)
-
createdAt
final OffsetDateTime createdAt()
Project creation timestamp
-
databases
final List<ProjectRetrieveResponse.Database> databases()
Databases in the default branch
-
linkedDeployments
final List<ProjectRetrieveResponse.LinkedDeployment> linkedDeployments()
Linked deployments using this database
-
status
final ProjectRetrieveResponse.Status status()
Project status
-
storageSizeBytes
final Double storageSizeBytes()
Current storage usage in bytes
-
updatedAt
final OffsetDateTime updatedAt()
Project last update timestamp
-
description
final Optional<String> description()
Project description
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_branches
final JsonField<List<ProjectRetrieveResponse.Branch>> _branches()
Returns the raw JSON value of branches.
Unlike branches, this method doesn't throw if the JSON field has an unexpected type.
-
_computeTimeSeconds
final JsonField<Double> _computeTimeSeconds()
Returns the raw JSON value of computeTimeSeconds.
Unlike computeTimeSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_connectionHost
final JsonField<String> _connectionHost()
Returns the raw JSON value of connectionHost.
Unlike connectionHost, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_databases
final JsonField<List<ProjectRetrieveResponse.Database>> _databases()
Returns the raw JSON value of databases.
Unlike databases, this method doesn't throw if the JSON field has an unexpected type.
-
_linkedDeployments
final JsonField<List<ProjectRetrieveResponse.LinkedDeployment>> _linkedDeployments()
Returns the raw JSON value of linkedDeployments.
Unlike linkedDeployments, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_pgVersion
final JsonField<Long> _pgVersion()
Returns the raw JSON value of pgVersion.
Unlike pgVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ProjectRetrieveResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_storageSizeBytes
final JsonField<Double> _storageSizeBytes()
Returns the raw JSON value of storageSizeBytes.
Unlike storageSizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectRetrieveResponse.Builder toBuilder()
-
validate
final ProjectRetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProjectRetrieveResponse.
The following fields are required:
.id() .branches() .computeTimeSeconds() .connectionHost() .createdAt() .databases() .linkedDeployments() .name() .pgVersion() .region() .status() .storageSizeBytes() .updatedAt()
-
-
-
-