Class ProjectRetrieveResponse.Branch
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse.Branch
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectRetrieveResponse.Branch.BuilderA builder for Branch.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Branch ID final Optional<OffsetDateTime>createdAt()Branch creation timestamp final Optional<Boolean>isDefault()Whether this is the default branch final Optional<String>name()Branch name final Optional<String>status()Branch status final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Boolean>_isDefault()Returns the raw JSON value of isDefault. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final ProjectRetrieveResponse.Branch.BuildertoBuilder()final ProjectRetrieveResponse.Branchvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectRetrieveResponse.Branch.Builderbuilder()Returns a mutable builder for constructing an instance of Branch. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Branch creation timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_isDefault
final JsonField<Boolean> _isDefault()
Returns the raw JSON value of isDefault.
Unlike isDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectRetrieveResponse.Branch.Builder toBuilder()
-
validate
final ProjectRetrieveResponse.Branch validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectRetrieveResponse.Branch.Builder builder()
Returns a mutable builder for constructing an instance of Branch.
-
-
-
-