Class ProjectRetrieveResponse.Branch.Builder
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse.Branch.BuilderA builder for Branch.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectRetrieveResponse.Branch.Builder id(String id)
Branch ID
-
id
final ProjectRetrieveResponse.Branch.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ProjectRetrieveResponse.Branch.Builder createdAt(OffsetDateTime createdAt)
Branch creation timestamp
-
createdAt
final ProjectRetrieveResponse.Branch.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isDefault
final ProjectRetrieveResponse.Branch.Builder isDefault(Boolean isDefault)
Whether this is the default branch
-
isDefault
final ProjectRetrieveResponse.Branch.Builder isDefault(JsonField<Boolean> isDefault)
Sets Builder.isDefault to an arbitrary JSON value.
You should usually call Builder.isDefault with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectRetrieveResponse.Branch.Builder name(String name)
Branch name
-
name
final ProjectRetrieveResponse.Branch.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ProjectRetrieveResponse.Branch.Builder status(String status)
Branch status
-
status
final ProjectRetrieveResponse.Branch.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectRetrieveResponse.Branch.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectRetrieveResponse.Branch.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectRetrieveResponse.Branch.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectRetrieveResponse.Branch.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectRetrieveResponse.Branch.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectRetrieveResponse.Branch build()
Returns an immutable instance of Branch.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-