Class ProjectRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse.BuilderA builder for ProjectRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectRetrieveResponse.Builder id(String id)
Project ID
-
id
final ProjectRetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
branches
final ProjectRetrieveResponse.Builder branches(List<ProjectRetrieveResponse.Branch> branches)
All branches in this project
-
branches
final ProjectRetrieveResponse.Builder branches(JsonField<List<ProjectRetrieveResponse.Branch>> branches)
Sets Builder.branches to an arbitrary JSON value.
You should usually call Builder.branches with a well-typed
List<Branch>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBranch
final ProjectRetrieveResponse.Builder addBranch(ProjectRetrieveResponse.Branch branch)
-
computeTimeSeconds
final ProjectRetrieveResponse.Builder computeTimeSeconds(Double computeTimeSeconds)
Total compute time consumed in seconds
-
computeTimeSeconds
final ProjectRetrieveResponse.Builder computeTimeSeconds(JsonField<Double> computeTimeSeconds)
Sets Builder.computeTimeSeconds to an arbitrary JSON value.
You should usually call Builder.computeTimeSeconds with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectionHost
final ProjectRetrieveResponse.Builder connectionHost(String connectionHost)
Database connection hostname (masked for security)
-
connectionHost
final ProjectRetrieveResponse.Builder connectionHost(JsonField<String> connectionHost)
Sets Builder.connectionHost to an arbitrary JSON value.
You should usually call Builder.connectionHost with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ProjectRetrieveResponse.Builder createdAt(OffsetDateTime createdAt)
Project creation timestamp
-
createdAt
final ProjectRetrieveResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
databases
final ProjectRetrieveResponse.Builder databases(List<ProjectRetrieveResponse.Database> databases)
Databases in the default branch
-
databases
final ProjectRetrieveResponse.Builder databases(JsonField<List<ProjectRetrieveResponse.Database>> databases)
Sets Builder.databases to an arbitrary JSON value.
You should usually call Builder.databases with a well-typed
List<Database>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDatabase
final ProjectRetrieveResponse.Builder addDatabase(ProjectRetrieveResponse.Database database)
-
linkedDeployments
final ProjectRetrieveResponse.Builder linkedDeployments(List<ProjectRetrieveResponse.LinkedDeployment> linkedDeployments)
Linked deployments using this database
-
linkedDeployments
final ProjectRetrieveResponse.Builder linkedDeployments(JsonField<List<ProjectRetrieveResponse.LinkedDeployment>> linkedDeployments)
Sets Builder.linkedDeployments to an arbitrary JSON value.
You should usually call Builder.linkedDeployments with a well-typed
List<LinkedDeployment>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addLinkedDeployment
final ProjectRetrieveResponse.Builder addLinkedDeployment(ProjectRetrieveResponse.LinkedDeployment linkedDeployment)
Adds a single LinkedDeployment to linkedDeployments.
-
name
final ProjectRetrieveResponse.Builder name(String name)
Project name
-
name
final ProjectRetrieveResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pgVersion
final ProjectRetrieveResponse.Builder pgVersion(Long pgVersion)
PostgreSQL major version
-
pgVersion
final ProjectRetrieveResponse.Builder pgVersion(JsonField<Long> pgVersion)
Sets Builder.pgVersion to an arbitrary JSON value.
You should usually call Builder.pgVersion with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final ProjectRetrieveResponse.Builder region(String region)
AWS region
-
region
final ProjectRetrieveResponse.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ProjectRetrieveResponse.Builder status(ProjectRetrieveResponse.Status status)
Project status
-
status
final ProjectRetrieveResponse.Builder status(JsonField<ProjectRetrieveResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
storageSizeBytes
final ProjectRetrieveResponse.Builder storageSizeBytes(Double storageSizeBytes)
Current storage usage in bytes
-
storageSizeBytes
final ProjectRetrieveResponse.Builder storageSizeBytes(JsonField<Double> storageSizeBytes)
Sets Builder.storageSizeBytes to an arbitrary JSON value.
You should usually call Builder.storageSizeBytes with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final ProjectRetrieveResponse.Builder updatedAt(OffsetDateTime updatedAt)
Project last update timestamp
-
updatedAt
final ProjectRetrieveResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final ProjectRetrieveResponse.Builder description(String description)
Project description
-
description
final ProjectRetrieveResponse.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final ProjectRetrieveResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectRetrieveResponse build()
Returns an immutable instance of ProjectRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .branches() .computeTimeSeconds() .connectionHost() .createdAt() .databases() .linkedDeployments() .name() .pgVersion() .region() .status() .storageSizeBytes() .updatedAt()
-
-
-
-