Class ProjectRetrieveResponse.Database
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse.Database
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectRetrieveResponse.Database.BuilderA builder for Database.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Database ID final Optional<String>name()Database name final Optional<String>ownerName()Database owner role name final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_ownerName()Returns the raw JSON value of ownerName. final Map<String, JsonValue>_additionalProperties()final ProjectRetrieveResponse.Database.BuildertoBuilder()final ProjectRetrieveResponse.Databasevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectRetrieveResponse.Database.Builderbuilder()Returns a mutable builder for constructing an instance of Database. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_ownerName
final JsonField<String> _ownerName()
Returns the raw JSON value of ownerName.
Unlike ownerName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectRetrieveResponse.Database.Builder toBuilder()
-
validate
final ProjectRetrieveResponse.Database validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectRetrieveResponse.Database.Builder builder()
Returns a mutable builder for constructing an instance of Database.
-
-
-
-