Class ProjectRetrieveResponse.Database.Builder
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse.Database.BuilderA builder for Database.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectRetrieveResponse.Database.Builder id(String id)
Database ID
-
id
final ProjectRetrieveResponse.Database.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectRetrieveResponse.Database.Builder name(String name)
Database name
-
name
final ProjectRetrieveResponse.Database.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ownerName
final ProjectRetrieveResponse.Database.Builder ownerName(String ownerName)
Database owner role name
-
ownerName
final ProjectRetrieveResponse.Database.Builder ownerName(JsonField<String> ownerName)
Sets Builder.ownerName to an arbitrary JSON value.
You should usually call Builder.ownerName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectRetrieveResponse.Database.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectRetrieveResponse.Database.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectRetrieveResponse.Database.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectRetrieveResponse.Database.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectRetrieveResponse.Database.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectRetrieveResponse.Database build()
Returns an immutable instance of Database.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-