Class ProjectRetrieveResponse.LinkedDeployment.Builder
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse.LinkedDeployment.BuilderA builder for LinkedDeployment.
-
-
Method Summary
-
-
Method Detail
-
id
final ProjectRetrieveResponse.LinkedDeployment.Builder id(String id)
Deployment ID
-
id
final ProjectRetrieveResponse.LinkedDeployment.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
envVarName
final ProjectRetrieveResponse.LinkedDeployment.Builder envVarName(String envVarName)
Environment variable name for connection string
-
envVarName
final ProjectRetrieveResponse.LinkedDeployment.Builder envVarName(JsonField<String> envVarName)
Sets Builder.envVarName to an arbitrary JSON value.
You should usually call Builder.envVarName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ProjectRetrieveResponse.LinkedDeployment.Builder name(String name)
Deployment name
-
name
final ProjectRetrieveResponse.LinkedDeployment.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ProjectRetrieveResponse.LinkedDeployment.Builder type(ProjectRetrieveResponse.LinkedDeployment.Type type)
Deployment type
-
type
final ProjectRetrieveResponse.LinkedDeployment.Builder type(JsonField<ProjectRetrieveResponse.LinkedDeployment.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final ProjectRetrieveResponse.LinkedDeployment.Builder url(String url)
Deployment URL
-
url
final ProjectRetrieveResponse.LinkedDeployment.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProjectRetrieveResponse.LinkedDeployment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProjectRetrieveResponse.LinkedDeployment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProjectRetrieveResponse.LinkedDeployment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProjectRetrieveResponse.LinkedDeployment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProjectRetrieveResponse.LinkedDeployment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProjectRetrieveResponse.LinkedDeployment build()
Returns an immutable instance of LinkedDeployment.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-