Package dev.case.api.models.database.v1.projects
See: Description
-
Class Summary Class Description Builder A builder for ProjectCreateBranchParams. Builder A builder for Body. Body ProjectCreateBranchParams Creates a new branch from the specified parent branch (or default 'main' branch). Builder A builder for ProjectCreateBranchResponse. ProjectCreateBranchResponse Builder A builder for ProjectCreateParams. Builder A builder for Body. Body Region AWS region for database deployment ProjectCreateParams Creates a new serverless Postgres database project powered by Neon. Builder A builder for ProjectCreateResponse. Builder A builder for DefaultBranch. DefaultBranch Default 'main' branch details Status Project status ProjectCreateResponse Builder A builder for ProjectDeleteParams. ProjectDeleteParams Permanently deletes a database project from Neon and marks it as deleted in Case.dev. Builder A builder for ProjectDeleteResponse. ProjectDeleteResponse Builder A builder for ProjectGetConnectionParams. ProjectGetConnectionParams Retrieves the PostgreSQL connection URI for a database project. Builder A builder for ProjectGetConnectionResponse. ProjectGetConnectionResponse Builder A builder for ProjectListBranchesParams. ProjectListBranchesParams Retrieves all branches for a database project. Builder A builder for ProjectListBranchesResponse. Builder A builder for Branch. Branch ProjectListBranchesResponse Builder A builder for ProjectListParams. ProjectListParams Retrieves all serverless Postgres database projects for the authenticated organization. Builder A builder for ProjectListResponse. Builder A builder for Project. Builder A builder for LinkedDeployment. Type Type of deployment LinkedDeployment Status Current project status Project ProjectListResponse Builder A builder for ProjectRetrieveParams. ProjectRetrieveParams Retrieves detailed information about a specific database project including branches, databases, storage/compute metrics, connection host, and linked deployments. Builder A builder for ProjectRetrieveResponse. Builder A builder for Branch. Branch Builder A builder for Database. Database Builder A builder for LinkedDeployment. Type Deployment type LinkedDeployment Status Project status ProjectRetrieveResponse -
Enum Summary Enum Description Known An enum containing Region's known values. Value An enum containing Region's known values, as well as an _UNKNOWN member. Known An enum containing Status's known values. Value An enum containing Status's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing Status's known values. Value An enum containing Status's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing Status's known values. Value An enum containing Status's known values, as well as an _UNKNOWN member.