Class V1CreateDocumentParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1CreateDocumentParams implements Params
Convert Markdown, JSON, or text content to professionally formatted PDF, DOCX, or HTML documents. Supports template components with variable interpolation for creating consistent legal documents like contracts, briefs, and reports.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateDocumentParams.BuilderA builder for V1CreateDocumentParams.
public final classV1CreateDocumentParams.Bodypublic final classV1CreateDocumentParams.OutputFormatDesired output format
public final classV1CreateDocumentParams.InputFormatFormat of the input content
public final classV1CreateDocumentParams.Options
-
Method Summary
Modifier and Type Method Description final Stringcontent()The source content to format final V1CreateDocumentParams.OutputFormatoutputFormat()Desired output format final Optional<V1CreateDocumentParams.InputFormat>inputFormat()Format of the input content final Optional<V1CreateDocumentParams.Options>options()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<V1CreateDocumentParams.OutputFormat>_outputFormat()Returns the raw JSON value of outputFormat. final JsonField<V1CreateDocumentParams.InputFormat>_inputFormat()Returns the raw JSON value of inputFormat. final JsonField<V1CreateDocumentParams.Options>_options()Returns the raw JSON value of options. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1CreateDocumentParams.BuildertoBuilder()final V1CreateDocumentParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateDocumentParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1CreateDocumentParams. -
-
Method Detail
-
outputFormat
final V1CreateDocumentParams.OutputFormat outputFormat()
Desired output format
-
inputFormat
final Optional<V1CreateDocumentParams.InputFormat> inputFormat()
Format of the input content
-
options
final Optional<V1CreateDocumentParams.Options> options()
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_outputFormat
final JsonField<V1CreateDocumentParams.OutputFormat> _outputFormat()
Returns the raw JSON value of outputFormat.
Unlike outputFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_inputFormat
final JsonField<V1CreateDocumentParams.InputFormat> _inputFormat()
Returns the raw JSON value of inputFormat.
Unlike inputFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_options
final JsonField<V1CreateDocumentParams.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1CreateDocumentParams.Builder toBuilder()
-
_body
final V1CreateDocumentParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1CreateDocumentParams.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateDocumentParams.
The following fields are required:
.content() .outputFormat()
-
-
-
-