Class V1CreateDocumentParams.Body
-
- All Implemented Interfaces:
public final class V1CreateDocumentParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateDocumentParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringcontent()The source content to format final V1CreateDocumentParams.OutputFormatoutputFormat()Desired output format final Optional<V1CreateDocumentParams.InputFormat>inputFormat()Format of the input content final Optional<V1CreateDocumentParams.Options>options()Optional template composition and styling settings used during document generation final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<V1CreateDocumentParams.OutputFormat>_outputFormat()Returns the raw JSON value of outputFormat. final JsonField<V1CreateDocumentParams.InputFormat>_inputFormat()Returns the raw JSON value of inputFormat. final JsonField<V1CreateDocumentParams.Options>_options()Returns the raw JSON value of options. final Map<String, JsonValue>_additionalProperties()final V1CreateDocumentParams.Body.BuildertoBuilder()final V1CreateDocumentParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateDocumentParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
outputFormat
final V1CreateDocumentParams.OutputFormat outputFormat()
Desired output format
-
inputFormat
final Optional<V1CreateDocumentParams.InputFormat> inputFormat()
Format of the input content
-
options
final Optional<V1CreateDocumentParams.Options> options()
Optional template composition and styling settings used during document generation
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_outputFormat
final JsonField<V1CreateDocumentParams.OutputFormat> _outputFormat()
Returns the raw JSON value of outputFormat.
Unlike outputFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_inputFormat
final JsonField<V1CreateDocumentParams.InputFormat> _inputFormat()
Returns the raw JSON value of inputFormat.
Unlike inputFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_options
final JsonField<V1CreateDocumentParams.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateDocumentParams.Body.Builder toBuilder()
-
validate
final V1CreateDocumentParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1CreateDocumentParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.content() .outputFormat()
-
-
-
-