Class V1CreateDocumentParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1CreateDocumentParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
content
final V1CreateDocumentParams.Body.Builder content(String content)
The source content to format
-
content
final V1CreateDocumentParams.Body.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outputFormat
final V1CreateDocumentParams.Body.Builder outputFormat(V1CreateDocumentParams.OutputFormat outputFormat)
Desired output format
-
outputFormat
final V1CreateDocumentParams.Body.Builder outputFormat(JsonField<V1CreateDocumentParams.OutputFormat> outputFormat)
Sets Builder.outputFormat to an arbitrary JSON value.
You should usually call Builder.outputFormat with a well-typed OutputFormat value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputFormat
final V1CreateDocumentParams.Body.Builder inputFormat(V1CreateDocumentParams.InputFormat inputFormat)
Format of the input content
-
inputFormat
final V1CreateDocumentParams.Body.Builder inputFormat(JsonField<V1CreateDocumentParams.InputFormat> inputFormat)
Sets Builder.inputFormat to an arbitrary JSON value.
You should usually call Builder.inputFormat with a well-typed InputFormat value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
options
final V1CreateDocumentParams.Body.Builder options(V1CreateDocumentParams.Options options)
Optional template composition and styling settings used during document generation
-
options
final V1CreateDocumentParams.Body.Builder options(JsonField<V1CreateDocumentParams.Options> options)
Sets Builder.options to an arbitrary JSON value.
You should usually call Builder.options with a well-typed Options value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateDocumentParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateDocumentParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateDocumentParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateDocumentParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateDocumentParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateDocumentParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.content() .outputFormat()
-
-
-
-