Enum V1CreateDocumentParams.InputFormat.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum V1CreateDocumentParams.InputFormat.Value
    extends Enum<V1CreateDocumentParams.InputFormat.Value>
                        

    An enum containing InputFormat's known values, as well as an _UNKNOWN member.

    An instance of InputFormat can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Constructor Detail

    • Method Detail

      • valueOf

         final V1CreateDocumentParams.InputFormat.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • getEntries

         final EnumEntries<V1CreateDocumentParams.InputFormat.Value> getEntries()

        An enum containing InputFormat's known values, as well as an _UNKNOWN member.

        An instance of InputFormat can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.