Package dev.case.api.models.format.v1
Class V1CreateDocumentParams.Options.Component.Builder
-
- All Implemented Interfaces:
public final class V1CreateDocumentParams.Options.Component.BuilderA builder for Component.
-
-
Method Summary
-
-
Method Detail
-
content
final V1CreateDocumentParams.Options.Component.Builder content(String content)
Inline template content
-
content
final V1CreateDocumentParams.Options.Component.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
styles
final V1CreateDocumentParams.Options.Component.Builder styles(JsonValue styles)
Custom styling options
-
templateId
final V1CreateDocumentParams.Options.Component.Builder templateId(String templateId)
ID of saved template component
-
templateId
final V1CreateDocumentParams.Options.Component.Builder templateId(JsonField<String> templateId)
Sets Builder.templateId to an arbitrary JSON value.
You should usually call Builder.templateId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
variables
final V1CreateDocumentParams.Options.Component.Builder variables(JsonValue variables)
Variables for template interpolation
-
additionalProperties
final V1CreateDocumentParams.Options.Component.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateDocumentParams.Options.Component.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateDocumentParams.Options.Component.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateDocumentParams.Options.Component.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateDocumentParams.Options.Component.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateDocumentParams.Options.Component build()
Returns an immutable instance of Component.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-