Package dev.case.api.models.format.v1
Enum V1CreateDocumentParams.OutputFormat.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum V1CreateDocumentParams.OutputFormat.Known extends Enum<V1CreateDocumentParams.OutputFormat.Known>
An enum containing OutputFormat's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<V1CreateDocumentParams.OutputFormat.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PDFDOCXHTML_PREVIEW
-
Method Summary
Modifier and Type Method Description final V1CreateDocumentParams.OutputFormat.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<V1CreateDocumentParams.OutputFormat.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<V1CreateDocumentParams.OutputFormat.Known>getEntries()An enum containing OutputFormat's known values. -
-
Method Detail
-
valueOf
final V1CreateDocumentParams.OutputFormat.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<V1CreateDocumentParams.OutputFormat.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<V1CreateDocumentParams.OutputFormat.Known> getEntries()
An enum containing OutputFormat's known values.
-
-
-
-