Class TemplateCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class TemplateCreateParams implements Params
Create a new format template for document formatting. Templates support variables using
{{variable}}syntax and can be used for captions, signatures, letterheads, certificates, footers, or custom formatting needs.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTemplateCreateParams.BuilderA builder for TemplateCreateParams.
public final classTemplateCreateParams.Bodypublic final classTemplateCreateParams.TypeTemplate type
-
Method Summary
Modifier and Type Method Description final Stringcontent()Template content with {{variable}} placeholders final Stringname()Template name final TemplateCreateParams.Typetype()Template type final Optional<String>description()Template description final JsonValue_styles()CSS styles for the templateThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = templateCreateParams.styles().convert(MyClass.class);final Optional<List<String>>tags()Template tags for organization final Optional<List<String>>variables()Template variables (auto-detected if not provided) final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<TemplateCreateParams.Type>_type()Returns the raw JSON value of type. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<List<String>>_variables()Returns the raw JSON value of variables. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final TemplateCreateParams.BuildertoBuilder()final TemplateCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static TemplateCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of TemplateCreateParams. -
-
Method Detail
-
type
final TemplateCreateParams.Type type()
Template type
-
description
final Optional<String> description()
Template description
-
_styles
final JsonValue _styles()
CSS styles for the template
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = templateCreateParams.styles().convert(MyClass.class);
-
variables
final Optional<List<String>> variables()
Template variables (auto-detected if not provided)
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<TemplateCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_variables
final JsonField<List<String>> _variables()
Returns the raw JSON value of variables.
Unlike variables, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final TemplateCreateParams.Builder toBuilder()
-
_body
final TemplateCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static TemplateCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of TemplateCreateParams.
The following fields are required:
.content() .name() .type()
-
-
-
-