Class TemplateCreateParams.Body
-
- All Implemented Interfaces:
public final class TemplateCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTemplateCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringcontent()Template content with {{variable}} placeholders final Stringname()Template name final TemplateCreateParams.Typetype()Template type final Optional<String>description()Template description final JsonValue_styles()CSS styles for the templateThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.styles().convert(MyClass.class);final Optional<List<String>>tags()Template tags for organization final Optional<List<String>>variables()Template variables (auto-detected if not provided) final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<TemplateCreateParams.Type>_type()Returns the raw JSON value of type. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<List<String>>_variables()Returns the raw JSON value of variables. final Map<String, JsonValue>_additionalProperties()final TemplateCreateParams.Body.BuildertoBuilder()final TemplateCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TemplateCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
type
final TemplateCreateParams.Type type()
Template type
-
description
final Optional<String> description()
Template description
-
_styles
final JsonValue _styles()
CSS styles for the template
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.styles().convert(MyClass.class);
-
variables
final Optional<List<String>> variables()
Template variables (auto-detected if not provided)
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<TemplateCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_variables
final JsonField<List<String>> _variables()
Returns the raw JSON value of variables.
Unlike variables, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TemplateCreateParams.Body.Builder toBuilder()
-
validate
final TemplateCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TemplateCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.content() .name() .type()
-
-
-
-