Class TemplateCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class TemplateCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
content
final TemplateCreateParams.Body.Builder content(String content)
Template content with {{variable}} placeholders
-
content
final TemplateCreateParams.Body.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final TemplateCreateParams.Body.Builder name(String name)
Template name
-
name
final TemplateCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final TemplateCreateParams.Body.Builder type(TemplateCreateParams.Type type)
Template type
-
type
final TemplateCreateParams.Body.Builder type(JsonField<TemplateCreateParams.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final TemplateCreateParams.Body.Builder description(String description)
Template description
-
description
final TemplateCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
styles
final TemplateCreateParams.Body.Builder styles(JsonValue styles)
CSS styles for the template
-
tags
final TemplateCreateParams.Body.Builder tags(List<String> tags)
Template tags for organization
-
tags
final TemplateCreateParams.Body.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final TemplateCreateParams.Body.Builder addTag(String tag)
-
variables
final TemplateCreateParams.Body.Builder variables(List<String> variables)
Template variables (auto-detected if not provided)
-
variables
final TemplateCreateParams.Body.Builder variables(JsonField<List<String>> variables)
Sets Builder.variables to an arbitrary JSON value.
You should usually call Builder.variables with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVariable
final TemplateCreateParams.Body.Builder addVariable(String variable)
-
additionalProperties
final TemplateCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TemplateCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TemplateCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TemplateCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TemplateCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TemplateCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.content() .name() .type()
-
-
-
-