Class TemplateCreateResponse
-
- All Implemented Interfaces:
public final class TemplateCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTemplateCreateResponse.BuilderA builder for TemplateCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Template ID final Optional<OffsetDateTime>createdAt()Creation timestamp final Optional<String>name()Template name final Optional<String>type()Template type final Optional<List<String>>variables()Detected template variables final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<List<String>>_variables()Returns the raw JSON value of variables. final Map<String, JsonValue>_additionalProperties()final TemplateCreateResponse.BuildertoBuilder()final TemplateCreateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TemplateCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TemplateCreateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Creation timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_variables
final JsonField<List<String>> _variables()
Returns the raw JSON value of variables.
Unlike variables, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TemplateCreateResponse.Builder toBuilder()
-
validate
final TemplateCreateResponse validate()
-
builder
final static TemplateCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of TemplateCreateResponse.
-
-
-
-