Class TemplateCreateResponse.Builder
-
- All Implemented Interfaces:
public final class TemplateCreateResponse.BuilderA builder for TemplateCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final TemplateCreateResponse.Builder id(String id)
Template ID
-
id
final TemplateCreateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final TemplateCreateResponse.Builder createdAt(OffsetDateTime createdAt)
Creation timestamp
-
createdAt
final TemplateCreateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final TemplateCreateResponse.Builder name(String name)
Template name
-
name
final TemplateCreateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final TemplateCreateResponse.Builder type(String type)
Template type
-
type
final TemplateCreateResponse.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
variables
final TemplateCreateResponse.Builder variables(List<String> variables)
Detected template variables
-
variables
final TemplateCreateResponse.Builder variables(JsonField<List<String>> variables)
Sets Builder.variables to an arbitrary JSON value.
You should usually call Builder.variables with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVariable
final TemplateCreateResponse.Builder addVariable(String variable)
-
additionalProperties
final TemplateCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TemplateCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TemplateCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TemplateCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TemplateCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TemplateCreateResponse build()
Returns an immutable instance of TemplateCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-