Class TemplateRetrieveParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class TemplateRetrieveParams
     implements Params
                        

    Retrieve a specific document format template by ID. Format templates define how documents should be structured and formatted for specific legal use cases such as contracts, briefs, or pleadings.