Class TemplateRetrieveResponse
-
- All Implemented Interfaces:
public final class TemplateRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTemplateRetrieveResponse.BuilderA builder for TemplateRetrieveResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique template identifier final JsonValue_content()Template formatting rules and structureThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = templateRetrieveResponse.content().convert(MyClass.class);final Optional<OffsetDateTime>createdAt()Template creation timestamp final Optional<String>description()Template description final Optional<String>name()Template name final Optional<String>organizationId()Organization ID that owns the template final Optional<OffsetDateTime>updatedAt()Template last modification timestamp final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_organizationId()Returns the raw JSON value of organizationId. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final TemplateRetrieveResponse.BuildertoBuilder()final TemplateRetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TemplateRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TemplateRetrieveResponse. -
-
Method Detail
-
_content
final JsonValue _content()
Template formatting rules and structure
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = templateRetrieveResponse.content().convert(MyClass.class);
-
createdAt
final Optional<OffsetDateTime> createdAt()
Template creation timestamp
-
description
final Optional<String> description()
Template description
-
organizationId
final Optional<String> organizationId()
Organization ID that owns the template
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Template last modification timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_organizationId
final JsonField<String> _organizationId()
Returns the raw JSON value of organizationId.
Unlike organizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TemplateRetrieveResponse.Builder toBuilder()
-
validate
final TemplateRetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TemplateRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of TemplateRetrieveResponse.
-
-
-
-