Class TemplateRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class TemplateRetrieveResponse.BuilderA builder for TemplateRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final TemplateRetrieveResponse.Builder id(String id)
Unique template identifier
-
id
final TemplateRetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
content
final TemplateRetrieveResponse.Builder content(JsonValue content)
Template formatting rules and structure
-
createdAt
final TemplateRetrieveResponse.Builder createdAt(OffsetDateTime createdAt)
Template creation timestamp
-
createdAt
final TemplateRetrieveResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final TemplateRetrieveResponse.Builder description(String description)
Template description
-
description
final TemplateRetrieveResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final TemplateRetrieveResponse.Builder name(String name)
Template name
-
name
final TemplateRetrieveResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
organizationId
final TemplateRetrieveResponse.Builder organizationId(String organizationId)
Organization ID that owns the template
-
organizationId
final TemplateRetrieveResponse.Builder organizationId(JsonField<String> organizationId)
Sets Builder.organizationId to an arbitrary JSON value.
You should usually call Builder.organizationId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final TemplateRetrieveResponse.Builder updatedAt(OffsetDateTime updatedAt)
Template last modification timestamp
-
updatedAt
final TemplateRetrieveResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TemplateRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TemplateRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TemplateRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TemplateRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TemplateRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TemplateRetrieveResponse build()
Returns an immutable instance of TemplateRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-