Class DocketSearchResult
-
- All Implemented Interfaces:
public final class DocketSearchResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocketSearchResult.BuilderA builder for DocketSearchResult.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>assignedTo()final Optional<String>caseName()final Optional<String>cause()final Optional<String>court()final Optional<String>courtId()final Optional<LocalDate>dateFiled()final Optional<LocalDate>dateTerminated()final Optional<String>docketNumber()final Optional<String>natureOfSuit()final Optional<String>pacerCaseId()final Optional<List<String>>parties()final Optional<String>url()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_assignedTo()Returns the raw JSON value of assignedTo. final JsonField<String>_caseName()Returns the raw JSON value of caseName. final JsonField<String>_cause()Returns the raw JSON value of cause. final JsonField<String>_court()Returns the raw JSON value of court. final JsonField<String>_courtId()Returns the raw JSON value of courtId. final JsonField<LocalDate>_dateFiled()Returns the raw JSON value of dateFiled. final JsonField<LocalDate>_dateTerminated()Returns the raw JSON value of dateTerminated. final JsonField<String>_docketNumber()Returns the raw JSON value of docketNumber. final JsonField<String>_natureOfSuit()Returns the raw JSON value of natureOfSuit. final JsonField<String>_pacerCaseId()Returns the raw JSON value of pacerCaseId. final JsonField<List<String>>_parties()Returns the raw JSON value of parties. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final DocketSearchResult.BuildertoBuilder()final DocketSearchResultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocketSearchResult.Builderbuilder()Returns a mutable builder for constructing an instance of DocketSearchResult. -
-
Method Detail
-
assignedTo
final Optional<String> assignedTo()
-
dateTerminated
final Optional<LocalDate> dateTerminated()
-
docketNumber
final Optional<String> docketNumber()
-
natureOfSuit
final Optional<String> natureOfSuit()
-
pacerCaseId
final Optional<String> pacerCaseId()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_assignedTo
final JsonField<String> _assignedTo()
Returns the raw JSON value of assignedTo.
Unlike assignedTo, this method doesn't throw if the JSON field has an unexpected type.
-
_caseName
final JsonField<String> _caseName()
Returns the raw JSON value of caseName.
Unlike caseName, this method doesn't throw if the JSON field has an unexpected type.
-
_cause
final JsonField<String> _cause()
Returns the raw JSON value of cause.
Unlike cause, this method doesn't throw if the JSON field has an unexpected type.
-
_court
final JsonField<String> _court()
Returns the raw JSON value of court.
Unlike court, this method doesn't throw if the JSON field has an unexpected type.
-
_courtId
final JsonField<String> _courtId()
Returns the raw JSON value of courtId.
Unlike courtId, this method doesn't throw if the JSON field has an unexpected type.
-
_dateFiled
final JsonField<LocalDate> _dateFiled()
Returns the raw JSON value of dateFiled.
Unlike dateFiled, this method doesn't throw if the JSON field has an unexpected type.
-
_dateTerminated
final JsonField<LocalDate> _dateTerminated()
Returns the raw JSON value of dateTerminated.
Unlike dateTerminated, this method doesn't throw if the JSON field has an unexpected type.
-
_docketNumber
final JsonField<String> _docketNumber()
Returns the raw JSON value of docketNumber.
Unlike docketNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_natureOfSuit
final JsonField<String> _natureOfSuit()
Returns the raw JSON value of natureOfSuit.
Unlike natureOfSuit, this method doesn't throw if the JSON field has an unexpected type.
-
_pacerCaseId
final JsonField<String> _pacerCaseId()
Returns the raw JSON value of pacerCaseId.
Unlike pacerCaseId, this method doesn't throw if the JSON field has an unexpected type.
-
_parties
final JsonField<List<String>> _parties()
Returns the raw JSON value of parties.
Unlike parties, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DocketSearchResult.Builder toBuilder()
-
validate
final DocketSearchResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DocketSearchResult.Builder builder()
Returns a mutable builder for constructing an instance of DocketSearchResult.
-
-
-
-