Class V1GetFullTextResponse
-
- All Implemented Interfaces:
public final class V1GetFullTextResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetFullTextResponse.BuilderA builder for V1GetFullTextResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>author()Author or court final Optional<Long>characterCount()Total characters in text final Optional<List<String>>highlights()Highlighted relevant passages final Optional<String>publishedDate()Publication date final Optional<String>summary()AI-generated summary final Optional<String>text()Full document text final Optional<String>title()Document title final Optional<String>url()Document URL final JsonField<String>_author()Returns the raw JSON value of author. final JsonField<Long>_characterCount()Returns the raw JSON value of characterCount. final JsonField<List<String>>_highlights()Returns the raw JSON value of highlights. final JsonField<String>_publishedDate()Returns the raw JSON value of publishedDate. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final V1GetFullTextResponse.BuildertoBuilder()final V1GetFullTextResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetFullTextResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1GetFullTextResponse. -
-
Method Detail
-
characterCount
final Optional<Long> characterCount()
Total characters in text
-
highlights
final Optional<List<String>> highlights()
Highlighted relevant passages
-
publishedDate
final Optional<String> publishedDate()
Publication date
-
_author
final JsonField<String> _author()
Returns the raw JSON value of author.
Unlike author, this method doesn't throw if the JSON field has an unexpected type.
-
_characterCount
final JsonField<Long> _characterCount()
Returns the raw JSON value of characterCount.
Unlike characterCount, this method doesn't throw if the JSON field has an unexpected type.
-
_highlights
final JsonField<List<String>> _highlights()
Returns the raw JSON value of highlights.
Unlike highlights, this method doesn't throw if the JSON field has an unexpected type.
-
_publishedDate
final JsonField<String> _publishedDate()
Returns the raw JSON value of publishedDate.
Unlike publishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetFullTextResponse.Builder toBuilder()
-
validate
final V1GetFullTextResponse validate()
-
builder
final static V1GetFullTextResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1GetFullTextResponse.
-
-
-
-