Class V1SecFilingResponse
-
- All Implemented Interfaces:
public final class V1SecFilingResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SecFilingResponse.BuilderA builder for V1SecFilingResponse.
public final classV1SecFilingResponse.Filingpublic final classV1SecFilingResponse.Type
-
Method Summary
-
-
Method Detail
-
dateBefore
final Optional<LocalDate> dateBefore()
-
filings
final Optional<List<V1SecFilingResponse.Filing>> filings()
-
type
final Optional<V1SecFilingResponse.Type> type()
-
_cik
final JsonField<String> _cik()
Returns the raw JSON value of cik.
Unlike cik, this method doesn't throw if the JSON field has an unexpected type.
-
_dateAfter
final JsonField<LocalDate> _dateAfter()
Returns the raw JSON value of dateAfter.
Unlike dateAfter, this method doesn't throw if the JSON field has an unexpected type.
-
_dateBefore
final JsonField<LocalDate> _dateBefore()
Returns the raw JSON value of dateBefore.
Unlike dateBefore, this method doesn't throw if the JSON field has an unexpected type.
-
_entity
final JsonField<String> _entity()
Returns the raw JSON value of entity.
Unlike entity, this method doesn't throw if the JSON field has an unexpected type.
-
_filings
final JsonField<List<V1SecFilingResponse.Filing>> _filings()
Returns the raw JSON value of filings.
Unlike filings, this method doesn't throw if the JSON field has an unexpected type.
-
_formTypes
final JsonField<List<String>> _formTypes()
Returns the raw JSON value of formTypes.
Unlike formTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_limit
final JsonField<Long> _limit()
Returns the raw JSON value of limit.
Unlike limit, this method doesn't throw if the JSON field has an unexpected type.
-
_offset
final JsonField<Long> _offset()
Returns the raw JSON value of offset.
Unlike offset, this method doesn't throw if the JSON field has an unexpected type.
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_ticker
final JsonField<String> _ticker()
Returns the raw JSON value of ticker.
Unlike ticker, this method doesn't throw if the JSON field has an unexpected type.
-
_total
final JsonField<Long> _total()
Returns the raw JSON value of total.
Unlike total, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<V1SecFilingResponse.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SecFilingResponse.Builder toBuilder()
-
validate
final V1SecFilingResponse validate()
-
builder
final static V1SecFilingResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1SecFilingResponse.
-
-
-
-