Class V1SecFilingResponse.Filing
-
- All Implemented Interfaces:
public final class V1SecFilingResponse.Filing
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SecFilingResponse.Filing.BuilderA builder for Filing.
public final classV1SecFilingResponse.Filing.Documentpublic final classV1SecFilingResponse.Filing.Entity
-
Method Summary
-
-
Method Detail
-
accessionNumber
final Optional<String> accessionNumber()
-
description
final Optional<String> description()
-
documents
final Optional<List<V1SecFilingResponse.Filing.Document>> documents()
-
entity
final Optional<V1SecFilingResponse.Filing.Entity> entity()
-
periodOfReport
final Optional<LocalDate> periodOfReport()
-
_accessionNumber
final JsonField<String> _accessionNumber()
Returns the raw JSON value of accessionNumber.
Unlike accessionNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_documents
final JsonField<List<V1SecFilingResponse.Filing.Document>> _documents()
Returns the raw JSON value of documents.
Unlike documents, this method doesn't throw if the JSON field has an unexpected type.
-
_entity
final JsonField<V1SecFilingResponse.Filing.Entity> _entity()
Returns the raw JSON value of entity.
Unlike entity, this method doesn't throw if the JSON field has an unexpected type.
-
_filedAt
final JsonField<LocalDate> _filedAt()
Returns the raw JSON value of filedAt.
Unlike filedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_formType
final JsonField<String> _formType()
Returns the raw JSON value of formType.
Unlike formType, this method doesn't throw if the JSON field has an unexpected type.
-
_periodOfReport
final JsonField<LocalDate> _periodOfReport()
Returns the raw JSON value of periodOfReport.
Unlike periodOfReport, this method doesn't throw if the JSON field has an unexpected type.
-
_secUrl
final JsonField<String> _secUrl()
Returns the raw JSON value of secUrl.
Unlike secUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_snippet
final JsonField<String> _snippet()
Returns the raw JSON value of snippet.
Unlike snippet, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SecFilingResponse.Filing.Builder toBuilder()
-
validate
final V1SecFilingResponse.Filing validate()
-
builder
final static V1SecFilingResponse.Filing.Builder builder()
Returns a mutable builder for constructing an instance of Filing.
-
-
-
-