Class V1SecFilingResponse.Filing.Entity
-
- All Implemented Interfaces:
public final class V1SecFilingResponse.Filing.Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SecFilingResponse.Filing.Entity.BuilderA builder for Entity.
-
Method Summary
-
-
Method Detail
-
entityType
final Optional<String> entityType()
-
sicDescription
final Optional<String> sicDescription()
-
stateOfIncorporation
final Optional<String> stateOfIncorporation()
-
_cik
final JsonField<String> _cik()
Returns the raw JSON value of cik.
Unlike cik, this method doesn't throw if the JSON field has an unexpected type.
-
_entityType
final JsonField<String> _entityType()
Returns the raw JSON value of entityType.
Unlike entityType, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_sic
final JsonField<String> _sic()
Returns the raw JSON value of sic.
Unlike sic, this method doesn't throw if the JSON field has an unexpected type.
-
_sicDescription
final JsonField<String> _sicDescription()
Returns the raw JSON value of sicDescription.
Unlike sicDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_stateOfIncorporation
final JsonField<String> _stateOfIncorporation()
Returns the raw JSON value of stateOfIncorporation.
Unlike stateOfIncorporation, this method doesn't throw if the JSON field has an unexpected type.
-
_ticker
final JsonField<String> _ticker()
Returns the raw JSON value of ticker.
Unlike ticker, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SecFilingResponse.Filing.Entity.Builder toBuilder()
-
validate
final V1SecFilingResponse.Filing.Entity validate()
-
builder
final static V1SecFilingResponse.Filing.Entity.Builder builder()
Returns a mutable builder for constructing an instance of Entity.
-
-
-
-