Package dev.case.api.models.llm
Class LlmGetConfigResponse
-
- All Implemented Interfaces:
public final class LlmGetConfigResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLlmGetConfigResponse.BuilderA builder for LlmGetConfigResponse.
public final classLlmGetConfigResponse.Model
-
Method Summary
Modifier and Type Method Description final List<LlmGetConfigResponse.Model>models()final JsonField<List<LlmGetConfigResponse.Model>>_models()Returns the raw JSON value of models. final Map<String, JsonValue>_additionalProperties()final LlmGetConfigResponse.BuildertoBuilder()final LlmGetConfigResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LlmGetConfigResponse.Builderbuilder()Returns a mutable builder for constructing an instance of LlmGetConfigResponse. -
-
Method Detail
-
models
final List<LlmGetConfigResponse.Model> models()
-
_models
final JsonField<List<LlmGetConfigResponse.Model>> _models()
Returns the raw JSON value of models.
Unlike models, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LlmGetConfigResponse.Builder toBuilder()
-
validate
final LlmGetConfigResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LlmGetConfigResponse.Builder builder()
Returns a mutable builder for constructing an instance of LlmGetConfigResponse.
The following fields are required:
.models()
-
-
-
-