Class LlmGetConfigResponse.Model
-
- All Implemented Interfaces:
public final class LlmGetConfigResponse.Model
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLlmGetConfigResponse.Model.BuilderA builder for Model.
-
Method Summary
Modifier and Type Method Description final Stringid()Unique model identifier final StringmodelType()Type of model (e.g. final Stringname()Human-readable model name final Optional<String>description()Model description and capabilities final JsonValue_pricing()Pricing information for the modelThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = model.pricing().convert(MyClass.class);final JsonValue_specification()Technical specifications and limitsThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = model.specification().convert(MyClass.class);final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_modelType()Returns the raw JSON value of modelType. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final LlmGetConfigResponse.Model.BuildertoBuilder()final LlmGetConfigResponse.Modelvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LlmGetConfigResponse.Model.Builderbuilder()Returns a mutable builder for constructing an instance of Model. -
-
Method Detail
-
description
final Optional<String> description()
Model description and capabilities
-
_pricing
final JsonValue _pricing()
Pricing information for the model
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = model.pricing().convert(MyClass.class);
-
_specification
final JsonValue _specification()
Technical specifications and limits
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = model.specification().convert(MyClass.class);
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_modelType
final JsonField<String> _modelType()
Returns the raw JSON value of modelType.
Unlike modelType, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LlmGetConfigResponse.Model.Builder toBuilder()
-
validate
final LlmGetConfigResponse.Model validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LlmGetConfigResponse.Model.Builder builder()
Returns a mutable builder for constructing an instance of Model.
The following fields are required:
.id() .modelType() .name()
-
-
-
-