Class LlmGetConfigResponse.Model.Builder
-
- All Implemented Interfaces:
public final class LlmGetConfigResponse.Model.BuilderA builder for Model.
-
-
Method Summary
-
-
Method Detail
-
id
final LlmGetConfigResponse.Model.Builder id(String id)
Unique model identifier
-
id
final LlmGetConfigResponse.Model.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
modelType
final LlmGetConfigResponse.Model.Builder modelType(String modelType)
Type of model (e.g., language, embedding)
-
modelType
final LlmGetConfigResponse.Model.Builder modelType(JsonField<String> modelType)
Sets Builder.modelType to an arbitrary JSON value.
You should usually call Builder.modelType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final LlmGetConfigResponse.Model.Builder name(String name)
Human-readable model name
-
name
final LlmGetConfigResponse.Model.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final LlmGetConfigResponse.Model.Builder description(String description)
Model description and capabilities
-
description
final LlmGetConfigResponse.Model.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pricing
final LlmGetConfigResponse.Model.Builder pricing(JsonValue pricing)
Pricing information for the model
-
specification
final LlmGetConfigResponse.Model.Builder specification(JsonValue specification)
Technical specifications and limits
-
additionalProperties
final LlmGetConfigResponse.Model.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LlmGetConfigResponse.Model.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LlmGetConfigResponse.Model.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LlmGetConfigResponse.Model.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LlmGetConfigResponse.Model.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LlmGetConfigResponse.Model build()
Returns an immutable instance of Model.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .modelType() .name()
-
-
-
-