Class V1CreateEmbeddingParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1CreateEmbeddingParams implements Params
Create vector embeddings from text using OpenAI-compatible models. Perfect for semantic search, document similarity, and building RAG systems for legal documents.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateEmbeddingParams.BuilderA builder for V1CreateEmbeddingParams.
public final classV1CreateEmbeddingParams.Bodypublic final classV1CreateEmbeddingParams.InputText or array of texts to create embeddings for
public final classV1CreateEmbeddingParams.EncodingFormatFormat for returned embeddings
-
Method Summary
Modifier and Type Method Description final V1CreateEmbeddingParams.Inputinput()Text or array of texts to create embeddings for final Stringmodel()Embedding model to use (e.g. final Optional<Long>dimensions()Number of dimensions for the embeddings (model-specific) final Optional<V1CreateEmbeddingParams.EncodingFormat>encodingFormat()Format for returned embeddings final Optional<String>user()Unique identifier for the end-user final JsonField<V1CreateEmbeddingParams.Input>_input()Returns the raw JSON value of input. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<Long>_dimensions()Returns the raw JSON value of dimensions. final JsonField<V1CreateEmbeddingParams.EncodingFormat>_encodingFormat()Returns the raw JSON value of encodingFormat. final JsonField<String>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1CreateEmbeddingParams.BuildertoBuilder()final V1CreateEmbeddingParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateEmbeddingParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1CreateEmbeddingParams. -
-
Method Detail
-
input
final V1CreateEmbeddingParams.Input input()
Text or array of texts to create embeddings for
-
model
final String model()
Embedding model to use (e.g., text-embedding-ada-002, text-embedding-3-small)
-
dimensions
final Optional<Long> dimensions()
Number of dimensions for the embeddings (model-specific)
-
encodingFormat
final Optional<V1CreateEmbeddingParams.EncodingFormat> encodingFormat()
Format for returned embeddings
-
_input
final JsonField<V1CreateEmbeddingParams.Input> _input()
Returns the raw JSON value of input.
Unlike input, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_dimensions
final JsonField<Long> _dimensions()
Returns the raw JSON value of dimensions.
Unlike dimensions, this method doesn't throw if the JSON field has an unexpected type.
-
_encodingFormat
final JsonField<V1CreateEmbeddingParams.EncodingFormat> _encodingFormat()
Returns the raw JSON value of encodingFormat.
Unlike encodingFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<String> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1CreateEmbeddingParams.Builder toBuilder()
-
_body
final V1CreateEmbeddingParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1CreateEmbeddingParams.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateEmbeddingParams.
The following fields are required:
.input() .model()
-
-
-
-