Class V1CreateEmbeddingParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
input
final V1CreateEmbeddingParams.Body.Builder input(V1CreateEmbeddingParams.Input input)
Text or array of texts to create embeddings for
-
input
final V1CreateEmbeddingParams.Body.Builder input(JsonField<V1CreateEmbeddingParams.Input> input)
Sets Builder.input to an arbitrary JSON value.
You should usually call Builder.input with a well-typed Input value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
input
final V1CreateEmbeddingParams.Body.Builder input(String string)
Alias for calling input with
Input.ofString(string).
-
inputOfStrings
final V1CreateEmbeddingParams.Body.Builder inputOfStrings(List<String> strings)
Alias for calling input with
Input.ofStrings(strings).
-
model
final V1CreateEmbeddingParams.Body.Builder model(String model)
Embedding model to use (e.g., text-embedding-ada-002, text-embedding-3-small)
-
model
final V1CreateEmbeddingParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dimensions
final V1CreateEmbeddingParams.Body.Builder dimensions(Long dimensions)
Number of dimensions for the embeddings (model-specific)
-
dimensions
final V1CreateEmbeddingParams.Body.Builder dimensions(JsonField<Long> dimensions)
Sets Builder.dimensions to an arbitrary JSON value.
You should usually call Builder.dimensions with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
encodingFormat
final V1CreateEmbeddingParams.Body.Builder encodingFormat(V1CreateEmbeddingParams.EncodingFormat encodingFormat)
Format for returned embeddings
-
encodingFormat
final V1CreateEmbeddingParams.Body.Builder encodingFormat(JsonField<V1CreateEmbeddingParams.EncodingFormat> encodingFormat)
Sets Builder.encodingFormat to an arbitrary JSON value.
You should usually call Builder.encodingFormat with a well-typed EncodingFormat value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
user
final V1CreateEmbeddingParams.Body.Builder user(String user)
Unique identifier for the end-user
-
user
final V1CreateEmbeddingParams.Body.Builder user(JsonField<String> user)
Sets Builder.user to an arbitrary JSON value.
You should usually call Builder.user with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateEmbeddingParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateEmbeddingParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateEmbeddingParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateEmbeddingParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateEmbeddingParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateEmbeddingParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.input() .model()
-
-
-
-