Class V1CreateEmbeddingResponse
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateEmbeddingResponse.BuilderA builder for V1CreateEmbeddingResponse.
public final classV1CreateEmbeddingResponse.Datapublic final classV1CreateEmbeddingResponse.Usage
-
Method Summary
-
-
Method Detail
-
data
final Optional<List<V1CreateEmbeddingResponse.Data>> data()
-
usage
final Optional<V1CreateEmbeddingResponse.Usage> usage()
-
_data
final JsonField<List<V1CreateEmbeddingResponse.Data>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_object_
final JsonField<String> _object_()
Returns the raw JSON value of object_.
Unlike object_, this method doesn't throw if the JSON field has an unexpected type.
-
_usage
final JsonField<V1CreateEmbeddingResponse.Usage> _usage()
Returns the raw JSON value of usage.
Unlike usage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateEmbeddingResponse.Builder toBuilder()
-
validate
final V1CreateEmbeddingResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1CreateEmbeddingResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateEmbeddingResponse.
-
-
-
-