Class V1CreateEmbeddingResponse.Builder
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingResponse.BuilderA builder for V1CreateEmbeddingResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final V1CreateEmbeddingResponse.Builder data(List<V1CreateEmbeddingResponse.Data> data)
-
data
final V1CreateEmbeddingResponse.Builder data(JsonField<List<V1CreateEmbeddingResponse.Data>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Data>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final V1CreateEmbeddingResponse.Builder addData(V1CreateEmbeddingResponse.Data data)
Adds a single Data to Builder.data.
-
model
final V1CreateEmbeddingResponse.Builder model(String model)
-
model
final V1CreateEmbeddingResponse.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
object_
final V1CreateEmbeddingResponse.Builder object_(String object_)
-
object_
final V1CreateEmbeddingResponse.Builder object_(JsonField<String> object_)
Sets Builder.object_ to an arbitrary JSON value.
You should usually call Builder.object_ with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
usage
final V1CreateEmbeddingResponse.Builder usage(V1CreateEmbeddingResponse.Usage usage)
-
usage
final V1CreateEmbeddingResponse.Builder usage(JsonField<V1CreateEmbeddingResponse.Usage> usage)
Sets Builder.usage to an arbitrary JSON value.
You should usually call Builder.usage with a well-typed Usage value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateEmbeddingResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateEmbeddingResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateEmbeddingResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateEmbeddingResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateEmbeddingResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateEmbeddingResponse build()
Returns an immutable instance of V1CreateEmbeddingResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-