Class V1CreateEmbeddingResponse.Data.Builder
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingResponse.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
embedding
final V1CreateEmbeddingResponse.Data.Builder embedding(List<Double> embedding)
-
embedding
final V1CreateEmbeddingResponse.Data.Builder embedding(JsonField<List<Double>> embedding)
Sets Builder.embedding to an arbitrary JSON value.
You should usually call Builder.embedding with a well-typed
List<Double>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEmbedding
final V1CreateEmbeddingResponse.Data.Builder addEmbedding(Double embedding)
Adds a single Double to Builder.embedding.
-
index
final V1CreateEmbeddingResponse.Data.Builder index(Long index)
-
index
final V1CreateEmbeddingResponse.Data.Builder index(JsonField<Long> index)
Sets Builder.index to an arbitrary JSON value.
You should usually call Builder.index with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
object_
final V1CreateEmbeddingResponse.Data.Builder object_(String object_)
-
object_
final V1CreateEmbeddingResponse.Data.Builder object_(JsonField<String> object_)
Sets Builder.object_ to an arbitrary JSON value.
You should usually call Builder.object_ with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateEmbeddingResponse.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateEmbeddingResponse.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateEmbeddingResponse.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateEmbeddingResponse.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateEmbeddingResponse.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateEmbeddingResponse.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-