Package dev.case.api.models.llm.v1
Class V1CreateEmbeddingResponse.Usage
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingResponse.Usage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateEmbeddingResponse.Usage.BuilderA builder for Usage.
-
Method Summary
Modifier and Type Method Description final Optional<Long>promptTokens()final Optional<Long>totalTokens()final JsonField<Long>_promptTokens()Returns the raw JSON value of promptTokens. final JsonField<Long>_totalTokens()Returns the raw JSON value of totalTokens. final Map<String, JsonValue>_additionalProperties()final V1CreateEmbeddingResponse.Usage.BuildertoBuilder()final V1CreateEmbeddingResponse.Usagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateEmbeddingResponse.Usage.Builderbuilder()Returns a mutable builder for constructing an instance of Usage. -
-
Method Detail
-
promptTokens
final Optional<Long> promptTokens()
-
totalTokens
final Optional<Long> totalTokens()
-
_promptTokens
final JsonField<Long> _promptTokens()
Returns the raw JSON value of promptTokens.
Unlike promptTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_totalTokens
final JsonField<Long> _totalTokens()
Returns the raw JSON value of totalTokens.
Unlike totalTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateEmbeddingResponse.Usage.Builder toBuilder()
-
validate
final V1CreateEmbeddingResponse.Usage validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1CreateEmbeddingResponse.Usage.Builder builder()
Returns a mutable builder for constructing an instance of Usage.
-
-
-
-