Package dev.case.api.models.llm.v1
Class V1ListModelsResponse
-
- All Implemented Interfaces:
public final class V1ListModelsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListModelsResponse.BuilderA builder for V1ListModelsResponse.
public final classV1ListModelsResponse.Data
-
Method Summary
Modifier and Type Method Description final Optional<List<V1ListModelsResponse.Data>>data()final Optional<String>object_()Response object type, always 'list' final JsonField<List<V1ListModelsResponse.Data>>_data()Returns the raw JSON value of data. final JsonField<String>_object_()Returns the raw JSON value of object_. final Map<String, JsonValue>_additionalProperties()final V1ListModelsResponse.BuildertoBuilder()final V1ListModelsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListModelsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1ListModelsResponse. -
-
Method Detail
-
data
final Optional<List<V1ListModelsResponse.Data>> data()
-
_data
final JsonField<List<V1ListModelsResponse.Data>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_object_
final JsonField<String> _object_()
Returns the raw JSON value of object_.
Unlike object_, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ListModelsResponse.Builder toBuilder()
-
validate
final V1ListModelsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ListModelsResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1ListModelsResponse.
-
-
-
-