Class V1ListModelsResponse.Data.Builder
-
- All Implemented Interfaces:
public final class V1ListModelsResponse.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
id
final V1ListModelsResponse.Data.Builder id(String id)
Unique model identifier
-
id
final V1ListModelsResponse.Data.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final V1ListModelsResponse.Data.Builder created(Long created)
Unix timestamp of model creation
-
created
final V1ListModelsResponse.Data.Builder created(JsonField<Long> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
object_
final V1ListModelsResponse.Data.Builder object_(String object_)
Object type, always 'model'
-
object_
final V1ListModelsResponse.Data.Builder object_(JsonField<String> object_)
Sets Builder.object_ to an arbitrary JSON value.
You should usually call Builder.object_ with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ownedBy
final V1ListModelsResponse.Data.Builder ownedBy(String ownedBy)
Model provider (openai, anthropic, google, casemark, etc.)
-
ownedBy
final V1ListModelsResponse.Data.Builder ownedBy(JsonField<String> ownedBy)
Sets Builder.ownedBy to an arbitrary JSON value.
You should usually call Builder.ownedBy with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pricing
final V1ListModelsResponse.Data.Builder pricing(V1ListModelsResponse.Data.Pricing pricing)
-
pricing
final V1ListModelsResponse.Data.Builder pricing(JsonField<V1ListModelsResponse.Data.Pricing> pricing)
Sets Builder.pricing to an arbitrary JSON value.
You should usually call Builder.pricing with a well-typed Pricing value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1ListModelsResponse.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1ListModelsResponse.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1ListModelsResponse.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1ListModelsResponse.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1ListModelsResponse.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1ListModelsResponse.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-