Class ChatCreateCompletionParams.Body
-
- All Implemented Interfaces:
public final class ChatCreateCompletionParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateCompletionParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<ChatCreateCompletionParams.Message>messages()List of messages comprising the conversation final Optional<Boolean>casemarkShowReasoning()CaseMark-only: when true, allows reasoning fields in responses. final Optional<Double>frequencyPenalty()Frequency penalty parameter final Optional<Long>maxTokens()Maximum number of tokens to generate final Optional<String>model()Model to use for completion. final Optional<Double>presencePenalty()Presence penalty parameter final Optional<Boolean>stream()Whether to stream back partial progress final Optional<Double>temperature()Sampling temperature between 0 and 2 final Optional<Double>topP()Nucleus sampling parameter final JsonField<List<ChatCreateCompletionParams.Message>>_messages()Returns the raw JSON value of messages. final JsonField<Boolean>_casemarkShowReasoning()Returns the raw JSON value of casemarkShowReasoning. final JsonField<Double>_frequencyPenalty()Returns the raw JSON value of frequencyPenalty. final JsonField<Long>_maxTokens()Returns the raw JSON value of maxTokens. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<Double>_presencePenalty()Returns the raw JSON value of presencePenalty. final JsonField<Boolean>_stream()Returns the raw JSON value of stream. final JsonField<Double>_temperature()Returns the raw JSON value of temperature. final JsonField<Double>_topP()Returns the raw JSON value of topP. final Map<String, JsonValue>_additionalProperties()final ChatCreateCompletionParams.Body.BuildertoBuilder()final ChatCreateCompletionParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateCompletionParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
messages
final List<ChatCreateCompletionParams.Message> messages()
List of messages comprising the conversation
-
casemarkShowReasoning
final Optional<Boolean> casemarkShowReasoning()
CaseMark-only: when true, allows reasoning fields in responses. Defaults to false (reasoning is suppressed).
-
frequencyPenalty
final Optional<Double> frequencyPenalty()
Frequency penalty parameter
-
model
final Optional<String> model()
Model to use for completion. Defaults to casemark/core-large if not specified
-
presencePenalty
final Optional<Double> presencePenalty()
Presence penalty parameter
-
temperature
final Optional<Double> temperature()
Sampling temperature between 0 and 2
-
_messages
final JsonField<List<ChatCreateCompletionParams.Message>> _messages()
Returns the raw JSON value of messages.
Unlike messages, this method doesn't throw if the JSON field has an unexpected type.
-
_casemarkShowReasoning
final JsonField<Boolean> _casemarkShowReasoning()
Returns the raw JSON value of casemarkShowReasoning.
Unlike casemarkShowReasoning, this method doesn't throw if the JSON field has an unexpected type.
-
_frequencyPenalty
final JsonField<Double> _frequencyPenalty()
Returns the raw JSON value of frequencyPenalty.
Unlike frequencyPenalty, this method doesn't throw if the JSON field has an unexpected type.
-
_maxTokens
final JsonField<Long> _maxTokens()
Returns the raw JSON value of maxTokens.
Unlike maxTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_presencePenalty
final JsonField<Double> _presencePenalty()
Returns the raw JSON value of presencePenalty.
Unlike presencePenalty, this method doesn't throw if the JSON field has an unexpected type.
-
_stream
final JsonField<Boolean> _stream()
Returns the raw JSON value of stream.
Unlike stream, this method doesn't throw if the JSON field has an unexpected type.
-
_temperature
final JsonField<Double> _temperature()
Returns the raw JSON value of temperature.
Unlike temperature, this method doesn't throw if the JSON field has an unexpected type.
-
_topP
final JsonField<Double> _topP()
Returns the raw JSON value of topP.
Unlike topP, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateCompletionParams.Body.Builder toBuilder()
-
validate
final ChatCreateCompletionParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatCreateCompletionParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.messages()
-
-
-
-