Class ChatCreateCompletionParams.Body.Builder
-
- All Implemented Interfaces:
public final class ChatCreateCompletionParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
messages
final ChatCreateCompletionParams.Body.Builder messages(List<ChatCreateCompletionParams.Message> messages)
List of messages comprising the conversation
-
messages
final ChatCreateCompletionParams.Body.Builder messages(JsonField<List<ChatCreateCompletionParams.Message>> messages)
Sets Builder.messages to an arbitrary JSON value.
You should usually call Builder.messages with a well-typed
List<Message>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addMessage
final ChatCreateCompletionParams.Body.Builder addMessage(ChatCreateCompletionParams.Message message)
-
casemarkShowReasoning
final ChatCreateCompletionParams.Body.Builder casemarkShowReasoning(Boolean casemarkShowReasoning)
CaseMark-only: when true, allows reasoning fields in responses. Defaults to false (reasoning is suppressed).
-
casemarkShowReasoning
final ChatCreateCompletionParams.Body.Builder casemarkShowReasoning(JsonField<Boolean> casemarkShowReasoning)
Sets Builder.casemarkShowReasoning to an arbitrary JSON value.
You should usually call Builder.casemarkShowReasoning with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frequencyPenalty
final ChatCreateCompletionParams.Body.Builder frequencyPenalty(Double frequencyPenalty)
Frequency penalty parameter
-
frequencyPenalty
final ChatCreateCompletionParams.Body.Builder frequencyPenalty(JsonField<Double> frequencyPenalty)
Sets Builder.frequencyPenalty to an arbitrary JSON value.
You should usually call Builder.frequencyPenalty with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxTokens
final ChatCreateCompletionParams.Body.Builder maxTokens(Long maxTokens)
Maximum number of tokens to generate
-
maxTokens
final ChatCreateCompletionParams.Body.Builder maxTokens(JsonField<Long> maxTokens)
Sets Builder.maxTokens to an arbitrary JSON value.
You should usually call Builder.maxTokens with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final ChatCreateCompletionParams.Body.Builder model(String model)
Model to use for completion. Defaults to casemark/casemark-core-3 if not specified
-
model
final ChatCreateCompletionParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presencePenalty
final ChatCreateCompletionParams.Body.Builder presencePenalty(Double presencePenalty)
Presence penalty parameter
-
presencePenalty
final ChatCreateCompletionParams.Body.Builder presencePenalty(JsonField<Double> presencePenalty)
Sets Builder.presencePenalty to an arbitrary JSON value.
You should usually call Builder.presencePenalty with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stream
final ChatCreateCompletionParams.Body.Builder stream(Boolean stream)
Whether to stream back partial progress
-
stream
final ChatCreateCompletionParams.Body.Builder stream(JsonField<Boolean> stream)
Sets Builder.stream to an arbitrary JSON value.
You should usually call Builder.stream with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
temperature
final ChatCreateCompletionParams.Body.Builder temperature(Double temperature)
Sampling temperature between 0 and 2
-
temperature
final ChatCreateCompletionParams.Body.Builder temperature(JsonField<Double> temperature)
Sets Builder.temperature to an arbitrary JSON value.
You should usually call Builder.temperature with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topP
final ChatCreateCompletionParams.Body.Builder topP(Double topP)
Nucleus sampling parameter
-
topP
final ChatCreateCompletionParams.Body.Builder topP(JsonField<Double> topP)
Sets Builder.topP to an arbitrary JSON value.
You should usually call Builder.topP with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatCreateCompletionParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatCreateCompletionParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatCreateCompletionParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatCreateCompletionParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatCreateCompletionParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatCreateCompletionParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.messages()
-
-
-
-