Package dev.case.api.models.llm.v1.chat
Class ChatCreateCompletionParams.Message
-
- All Implemented Interfaces:
public final class ChatCreateCompletionParams.Message
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateCompletionParams.Message.BuilderA builder for Message.
public final classChatCreateCompletionParams.Message.RoleThe role of the message author
-
Method Summary
Modifier and Type Method Description final Optional<String>content()The contents of the message final Optional<ChatCreateCompletionParams.Message.Role>role()The role of the message author final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<ChatCreateCompletionParams.Message.Role>_role()Returns the raw JSON value of role. final Map<String, JsonValue>_additionalProperties()final ChatCreateCompletionParams.Message.BuildertoBuilder()final ChatCreateCompletionParams.Messagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateCompletionParams.Message.Builderbuilder()Returns a mutable builder for constructing an instance of Message. -
-
Method Detail
-
role
final Optional<ChatCreateCompletionParams.Message.Role> role()
The role of the message author
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<ChatCreateCompletionParams.Message.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateCompletionParams.Message.Builder toBuilder()
-
validate
final ChatCreateCompletionParams.Message validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatCreateCompletionParams.Message.Builder builder()
Returns a mutable builder for constructing an instance of Message.
-
-
-
-