Package dev.case.api.models.llm.v1.chat
Class ChatCreateCompletionParams.Message.Builder
-
- All Implemented Interfaces:
public final class ChatCreateCompletionParams.Message.BuilderA builder for Message.
-
-
Method Summary
-
-
Method Detail
-
content
final ChatCreateCompletionParams.Message.Builder content(String content)
The contents of the message
-
content
final ChatCreateCompletionParams.Message.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
role
final ChatCreateCompletionParams.Message.Builder role(ChatCreateCompletionParams.Message.Role role)
The role of the message author
-
role
final ChatCreateCompletionParams.Message.Builder role(JsonField<ChatCreateCompletionParams.Message.Role> role)
Sets Builder.role to an arbitrary JSON value.
You should usually call Builder.role with a well-typed Role value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatCreateCompletionParams.Message.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatCreateCompletionParams.Message.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatCreateCompletionParams.Message.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatCreateCompletionParams.Message.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatCreateCompletionParams.Message.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatCreateCompletionParams.Message build()
Returns an immutable instance of Message.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-