Class ChatCreateCompletionResponse
-
- All Implemented Interfaces:
public final class ChatCreateCompletionResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateCompletionResponse.BuilderA builder for ChatCreateCompletionResponse.
public final classChatCreateCompletionResponse.Choicepublic final classChatCreateCompletionResponse.Usage
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique identifier for the completion final Optional<List<ChatCreateCompletionResponse.Choice>>choices()final Optional<Long>created()Unix timestamp of completion creation final Optional<String>model()Model used for completion final Optional<String>object_()final Optional<ChatCreateCompletionResponse.Usage>usage()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<List<ChatCreateCompletionResponse.Choice>>_choices()Returns the raw JSON value of choices. final JsonField<Long>_created()Returns the raw JSON value of created. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_object_()Returns the raw JSON value of object_. final JsonField<ChatCreateCompletionResponse.Usage>_usage()Returns the raw JSON value of usage. final Map<String, JsonValue>_additionalProperties()final ChatCreateCompletionResponse.BuildertoBuilder()final ChatCreateCompletionResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateCompletionResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ChatCreateCompletionResponse. -
-
Method Detail
-
choices
final Optional<List<ChatCreateCompletionResponse.Choice>> choices()
-
usage
final Optional<ChatCreateCompletionResponse.Usage> usage()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_choices
final JsonField<List<ChatCreateCompletionResponse.Choice>> _choices()
Returns the raw JSON value of choices.
Unlike choices, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<Long> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_object_
final JsonField<String> _object_()
Returns the raw JSON value of object_.
Unlike object_, this method doesn't throw if the JSON field has an unexpected type.
-
_usage
final JsonField<ChatCreateCompletionResponse.Usage> _usage()
Returns the raw JSON value of usage.
Unlike usage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateCompletionResponse.Builder toBuilder()
-
validate
final ChatCreateCompletionResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatCreateCompletionResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChatCreateCompletionResponse.
-
-
-
-