Class ChatCreateCompletionResponse.Builder
-
- All Implemented Interfaces:
public final class ChatCreateCompletionResponse.BuilderA builder for ChatCreateCompletionResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ChatCreateCompletionResponse.Builder id(String id)
Unique identifier for the completion
-
id
final ChatCreateCompletionResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
choices
final ChatCreateCompletionResponse.Builder choices(List<ChatCreateCompletionResponse.Choice> choices)
-
choices
final ChatCreateCompletionResponse.Builder choices(JsonField<List<ChatCreateCompletionResponse.Choice>> choices)
Sets Builder.choices to an arbitrary JSON value.
You should usually call Builder.choices with a well-typed
List<Choice>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addChoice
final ChatCreateCompletionResponse.Builder addChoice(ChatCreateCompletionResponse.Choice choice)
-
created
final ChatCreateCompletionResponse.Builder created(Long created)
Unix timestamp of completion creation
-
created
final ChatCreateCompletionResponse.Builder created(JsonField<Long> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final ChatCreateCompletionResponse.Builder model(String model)
Model used for completion
-
model
final ChatCreateCompletionResponse.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
object_
final ChatCreateCompletionResponse.Builder object_(String object_)
-
object_
final ChatCreateCompletionResponse.Builder object_(JsonField<String> object_)
Sets Builder.object_ to an arbitrary JSON value.
You should usually call Builder.object_ with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
usage
final ChatCreateCompletionResponse.Builder usage(ChatCreateCompletionResponse.Usage usage)
-
usage
final ChatCreateCompletionResponse.Builder usage(JsonField<ChatCreateCompletionResponse.Usage> usage)
Sets Builder.usage to an arbitrary JSON value.
You should usually call Builder.usage with a well-typed Usage value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatCreateCompletionResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatCreateCompletionResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatCreateCompletionResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatCreateCompletionResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatCreateCompletionResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatCreateCompletionResponse build()
Returns an immutable instance of ChatCreateCompletionResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-