Class ChatCreateCompletionResponse.Choice.Builder
-
- All Implemented Interfaces:
public final class ChatCreateCompletionResponse.Choice.BuilderA builder for Choice.
-
-
Method Summary
-
-
Method Detail
-
finishReason
final ChatCreateCompletionResponse.Choice.Builder finishReason(String finishReason)
-
finishReason
final ChatCreateCompletionResponse.Choice.Builder finishReason(JsonField<String> finishReason)
Sets Builder.finishReason to an arbitrary JSON value.
You should usually call Builder.finishReason with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
index
final ChatCreateCompletionResponse.Choice.Builder index(Long index)
-
index
final ChatCreateCompletionResponse.Choice.Builder index(JsonField<Long> index)
Sets Builder.index to an arbitrary JSON value.
You should usually call Builder.index with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final ChatCreateCompletionResponse.Choice.Builder message(ChatCreateCompletionResponse.Choice.Message message)
-
message
final ChatCreateCompletionResponse.Choice.Builder message(JsonField<ChatCreateCompletionResponse.Choice.Message> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed Message value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChatCreateCompletionResponse.Choice.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChatCreateCompletionResponse.Choice.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChatCreateCompletionResponse.Choice.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChatCreateCompletionResponse.Choice.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChatCreateCompletionResponse.Choice.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChatCreateCompletionResponse.Choice build()
Returns an immutable instance of Choice.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-