Package dev.case.api.models.llm.v1.chat
Class ChatCreateCompletionResponse.Choice.Message
-
- All Implemented Interfaces:
public final class ChatCreateCompletionResponse.Choice.Message
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateCompletionResponse.Choice.Message.BuilderA builder for Message.
-
Method Summary
Modifier and Type Method Description final Optional<String>content()final Optional<String>role()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_role()Returns the raw JSON value of role. final Map<String, JsonValue>_additionalProperties()final ChatCreateCompletionResponse.Choice.Message.BuildertoBuilder()final ChatCreateCompletionResponse.Choice.Messagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateCompletionResponse.Choice.Message.Builderbuilder()Returns a mutable builder for constructing an instance of Message. -
-
Method Detail
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<String> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateCompletionResponse.Choice.Message.Builder toBuilder()
-
validate
final ChatCreateCompletionResponse.Choice.Message validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatCreateCompletionResponse.Choice.Message.Builder builder()
Returns a mutable builder for constructing an instance of Message.
-
-
-
-