Class InboxCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class InboxCreateParams implements Params
Create an inbox owned by the authenticated organization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxCreateParams.BuilderA builder for InboxCreateParams.
public final classInboxCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>address()final Optional<String>displayName()final JsonField<String>_address()Returns the raw JSON value of address. final JsonField<String>_displayName()Returns the raw JSON value of displayName. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboxCreateParams.BuildertoBuilder()final InboxCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboxCreateParamsnone()final static InboxCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboxCreateParams. -
-
Method Detail
-
displayName
final Optional<String> displayName()
-
_address
final JsonField<String> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboxCreateParams.Builder toBuilder()
-
_body
final InboxCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboxCreateParams none()
-
builder
final static InboxCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboxCreateParams.
-
-
-
-