Class InboxGetMessageParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class InboxGetMessageParams implements Params
Get a message for an inbox owned by the authenticated organization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxGetMessageParams.BuilderA builder for InboxGetMessageParams.
-
Method Summary
Modifier and Type Method Description final StringinboxId()final Optional<String>messageId()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboxGetMessageParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboxGetMessageParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboxGetMessageParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboxGetMessageParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboxGetMessageParams.Builder builder()
Returns a mutable builder for constructing an instance of InboxGetMessageParams.
The following fields are required:
.inboxId()
-
-
-
-