Class InboxListMessagesParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class InboxListMessagesParams implements Params
List messages for an inbox owned by the authenticated organization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxListMessagesParams.BuilderA builder for InboxListMessagesParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>inboxId()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboxListMessagesParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboxListMessagesParamsnone()final static InboxListMessagesParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboxListMessagesParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboxListMessagesParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboxListMessagesParams none()
-
builder
final static InboxListMessagesParams.Builder builder()
Returns a mutable builder for constructing an instance of InboxListMessagesParams.
-
-
-
-