Class InboxSetPolicyParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class InboxSetPolicyParams implements Params
Set the sender allowlist and send/reply/read access rules for an inbox owned by the authenticated organization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxSetPolicyParams.BuilderA builder for InboxSetPolicyParams.
public final classInboxSetPolicyParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>inboxId()final Optional<List<String>>allowedSenderPatterns()Exact emails, @domain rules, or * final Optional<Boolean>enforceSenderAllowlist()final Optional<List<String>>readAccessRules()Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or * final Optional<List<String>>replyAccessRules()Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or * final Optional<List<String>>sendAccessRules()Rules like organization, user:<id>, api_key, api_key:<id>, clerk_session, or * final JsonField<List<String>>_allowedSenderPatterns()Returns the raw JSON value of allowedSenderPatterns. final JsonField<Boolean>_enforceSenderAllowlist()Returns the raw JSON value of enforceSenderAllowlist. final JsonField<List<String>>_readAccessRules()Returns the raw JSON value of readAccessRules. final JsonField<List<String>>_replyAccessRules()Returns the raw JSON value of replyAccessRules. final JsonField<List<String>>_sendAccessRules()Returns the raw JSON value of sendAccessRules. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboxSetPolicyParams.BuildertoBuilder()final InboxSetPolicyParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboxSetPolicyParamsnone()final static InboxSetPolicyParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboxSetPolicyParams. -
-
Method Detail
-
allowedSenderPatterns
final Optional<List<String>> allowedSenderPatterns()
Exact emails, @domain rules, or *
-
enforceSenderAllowlist
final Optional<Boolean> enforceSenderAllowlist()
-
readAccessRules
final Optional<List<String>> readAccessRules()
Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
replyAccessRules
final Optional<List<String>> replyAccessRules()
Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
sendAccessRules
final Optional<List<String>> sendAccessRules()
Rules like organization, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
_allowedSenderPatterns
final JsonField<List<String>> _allowedSenderPatterns()
Returns the raw JSON value of allowedSenderPatterns.
Unlike allowedSenderPatterns, this method doesn't throw if the JSON field has an unexpected type.
-
_enforceSenderAllowlist
final JsonField<Boolean> _enforceSenderAllowlist()
Returns the raw JSON value of enforceSenderAllowlist.
Unlike enforceSenderAllowlist, this method doesn't throw if the JSON field has an unexpected type.
-
_readAccessRules
final JsonField<List<String>> _readAccessRules()
Returns the raw JSON value of readAccessRules.
Unlike readAccessRules, this method doesn't throw if the JSON field has an unexpected type.
-
_replyAccessRules
final JsonField<List<String>> _replyAccessRules()
Returns the raw JSON value of replyAccessRules.
Unlike replyAccessRules, this method doesn't throw if the JSON field has an unexpected type.
-
_sendAccessRules
final JsonField<List<String>> _sendAccessRules()
Returns the raw JSON value of sendAccessRules.
Unlike sendAccessRules, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboxSetPolicyParams.Builder toBuilder()
-
_body
final InboxSetPolicyParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboxSetPolicyParams none()
-
builder
final static InboxSetPolicyParams.Builder builder()
Returns a mutable builder for constructing an instance of InboxSetPolicyParams.
-
-
-
-