Class InboxSetPolicyParams.Body.Builder
-
- All Implemented Interfaces:
public final class InboxSetPolicyParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
allowedSenderPatterns
final InboxSetPolicyParams.Body.Builder allowedSenderPatterns(List<String> allowedSenderPatterns)
Exact emails, @domain rules, or *
-
allowedSenderPatterns
final InboxSetPolicyParams.Body.Builder allowedSenderPatterns(JsonField<List<String>> allowedSenderPatterns)
Sets Builder.allowedSenderPatterns to an arbitrary JSON value.
You should usually call Builder.allowedSenderPatterns with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAllowedSenderPattern
final InboxSetPolicyParams.Body.Builder addAllowedSenderPattern(String allowedSenderPattern)
Adds a single String to allowedSenderPatterns.
-
enforceSenderAllowlist
final InboxSetPolicyParams.Body.Builder enforceSenderAllowlist(Boolean enforceSenderAllowlist)
-
enforceSenderAllowlist
final InboxSetPolicyParams.Body.Builder enforceSenderAllowlist(JsonField<Boolean> enforceSenderAllowlist)
Sets Builder.enforceSenderAllowlist to an arbitrary JSON value.
You should usually call Builder.enforceSenderAllowlist with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
readAccessRules
final InboxSetPolicyParams.Body.Builder readAccessRules(List<String> readAccessRules)
Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
readAccessRules
final InboxSetPolicyParams.Body.Builder readAccessRules(JsonField<List<String>> readAccessRules)
Sets Builder.readAccessRules to an arbitrary JSON value.
You should usually call Builder.readAccessRules with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addReadAccessRule
final InboxSetPolicyParams.Body.Builder addReadAccessRule(String readAccessRule)
Adds a single String to readAccessRules.
-
replyAccessRules
final InboxSetPolicyParams.Body.Builder replyAccessRules(List<String> replyAccessRules)
Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
replyAccessRules
final InboxSetPolicyParams.Body.Builder replyAccessRules(JsonField<List<String>> replyAccessRules)
Sets Builder.replyAccessRules to an arbitrary JSON value.
You should usually call Builder.replyAccessRules with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addReplyAccessRule
final InboxSetPolicyParams.Body.Builder addReplyAccessRule(String replyAccessRule)
Adds a single String to replyAccessRules.
-
sendAccessRules
final InboxSetPolicyParams.Body.Builder sendAccessRules(List<String> sendAccessRules)
Rules like organization, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
sendAccessRules
final InboxSetPolicyParams.Body.Builder sendAccessRules(JsonField<List<String>> sendAccessRules)
Sets Builder.sendAccessRules to an arbitrary JSON value.
You should usually call Builder.sendAccessRules with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSendAccessRule
final InboxSetPolicyParams.Body.Builder addSendAccessRule(String sendAccessRule)
Adds a single String to sendAccessRules.
-
additionalProperties
final InboxSetPolicyParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboxSetPolicyParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboxSetPolicyParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboxSetPolicyParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboxSetPolicyParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboxSetPolicyParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-