Package dev.case.api.models.mail.v1.inboxes
See: Description
-
Class Summary Class Description Builder A builder for InboxCreateParams. Builder A builder for Body. Body InboxCreateParams Create an inbox owned by the authenticated organization. Builder A builder for InboxDeleteParams. InboxDeleteParams Delete an inbox owned by the authenticated organization. Builder A builder for InboxGetAttachmentParams. InboxGetAttachmentParams Get attachment metadata for a message in an inbox owned by the authenticated organization. Builder A builder for InboxGetMessageParams. InboxGetMessageParams Get a message for an inbox owned by the authenticated organization. Builder A builder for InboxListMessagesParams. InboxListMessagesParams List messages for an inbox owned by the authenticated organization. Builder A builder for InboxListParams. InboxListParams List inboxes owned by the authenticated organization. Builder A builder for InboxReplyParams. InboxReplyParams Reply to a message in an inbox owned by the authenticated organization. Builder A builder for InboxRetrieveParams. InboxRetrieveParams Get an inbox owned by the authenticated organization. Builder A builder for InboxSendParams. InboxSendParams Send a message from an inbox owned by the authenticated organization.