Class V1CreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1CreateParams implements Params
Create a new legal matter and optionally link an existing primary vault.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateParams.BuilderA builder for V1CreateParams.
public final classV1CreateParams.Bodypublic final classV1CreateParams.Billingpublic final classV1CreateParams.CustomFieldspublic final classV1CreateParams.ImportantDatespublic final classV1CreateParams.Jurisdictionpublic final classV1CreateParams.Metadatapublic final classV1CreateParams.Statuspublic final classV1CreateParams.Vault
-
Method Summary
-
-
Method Detail
-
billing
final Optional<V1CreateParams.Billing> billing()
-
clientName
final Optional<String> clientName()
-
clientPartyId
final Optional<String> clientPartyId()
-
customFields
final Optional<V1CreateParams.CustomFields> customFields()
-
description
final Optional<String> description()
-
importantDates
final Optional<V1CreateParams.ImportantDates> importantDates()
-
jurisdiction
final Optional<V1CreateParams.Jurisdiction> jurisdiction()
-
matterType
final Optional<String> matterType()
-
metadata
final Optional<V1CreateParams.Metadata> metadata()
-
practiceArea
final Optional<String> practiceArea()
-
responsibleAttorneyId
final Optional<String> responsibleAttorneyId()
-
status
final Optional<V1CreateParams.Status> status()
-
vault
final Optional<V1CreateParams.Vault> vault()
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_billing
final JsonField<V1CreateParams.Billing> _billing()
Returns the raw JSON value of billing.
Unlike billing, this method doesn't throw if the JSON field has an unexpected type.
-
_clientName
final JsonField<String> _clientName()
Returns the raw JSON value of clientName.
Unlike clientName, this method doesn't throw if the JSON field has an unexpected type.
-
_clientPartyId
final JsonField<String> _clientPartyId()
Returns the raw JSON value of clientPartyId.
Unlike clientPartyId, this method doesn't throw if the JSON field has an unexpected type.
-
_customFields
final JsonField<V1CreateParams.CustomFields> _customFields()
Returns the raw JSON value of customFields.
Unlike customFields, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_displayId
final JsonField<String> _displayId()
Returns the raw JSON value of displayId.
Unlike displayId, this method doesn't throw if the JSON field has an unexpected type.
-
_importantDates
final JsonField<V1CreateParams.ImportantDates> _importantDates()
Returns the raw JSON value of importantDates.
Unlike importantDates, this method doesn't throw if the JSON field has an unexpected type.
-
_jurisdiction
final JsonField<V1CreateParams.Jurisdiction> _jurisdiction()
Returns the raw JSON value of jurisdiction.
Unlike jurisdiction, this method doesn't throw if the JSON field has an unexpected type.
-
_matterType
final JsonField<String> _matterType()
Returns the raw JSON value of matterType.
Unlike matterType, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<V1CreateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_practiceArea
final JsonField<String> _practiceArea()
Returns the raw JSON value of practiceArea.
Unlike practiceArea, this method doesn't throw if the JSON field has an unexpected type.
-
_responsibleAttorneyId
final JsonField<String> _responsibleAttorneyId()
Returns the raw JSON value of responsibleAttorneyId.
Unlike responsibleAttorneyId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<V1CreateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_subtype
final JsonField<String> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_vault
final JsonField<V1CreateParams.Vault> _vault()
Returns the raw JSON value of vault.
Unlike vault, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1CreateParams.Builder toBuilder()
-
_body
final V1CreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1CreateParams.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateParams.
The following fields are required:
.title()
-
-
-
-