Class V1CreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1CreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
title
final V1CreateParams.Body.Builder title(String title)
-
title
final V1CreateParams.Body.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billing
final V1CreateParams.Body.Builder billing(V1CreateParams.Billing billing)
-
billing
final V1CreateParams.Body.Builder billing(JsonField<V1CreateParams.Billing> billing)
Sets Builder.billing to an arbitrary JSON value.
You should usually call Builder.billing with a well-typed Billing value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientName
final V1CreateParams.Body.Builder clientName(String clientName)
-
clientName
final V1CreateParams.Body.Builder clientName(JsonField<String> clientName)
Sets Builder.clientName to an arbitrary JSON value.
You should usually call Builder.clientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientPartyId
final V1CreateParams.Body.Builder clientPartyId(String clientPartyId)
-
clientPartyId
final V1CreateParams.Body.Builder clientPartyId(Optional<String> clientPartyId)
Alias for calling Builder.clientPartyId with
clientPartyId.orElse(null).
-
clientPartyId
final V1CreateParams.Body.Builder clientPartyId(JsonField<String> clientPartyId)
Sets Builder.clientPartyId to an arbitrary JSON value.
You should usually call Builder.clientPartyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customFields
final V1CreateParams.Body.Builder customFields(V1CreateParams.CustomFields customFields)
-
customFields
final V1CreateParams.Body.Builder customFields(JsonField<V1CreateParams.CustomFields> customFields)
Sets Builder.customFields to an arbitrary JSON value.
You should usually call Builder.customFields with a well-typed CustomFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final V1CreateParams.Body.Builder description(String description)
-
description
final V1CreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
displayId
final V1CreateParams.Body.Builder displayId(String displayId)
-
displayId
final V1CreateParams.Body.Builder displayId(JsonField<String> displayId)
Sets Builder.displayId to an arbitrary JSON value.
You should usually call Builder.displayId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
importantDates
final V1CreateParams.Body.Builder importantDates(V1CreateParams.ImportantDates importantDates)
-
importantDates
final V1CreateParams.Body.Builder importantDates(JsonField<V1CreateParams.ImportantDates> importantDates)
Sets Builder.importantDates to an arbitrary JSON value.
You should usually call Builder.importantDates with a well-typed ImportantDates value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jurisdiction
final V1CreateParams.Body.Builder jurisdiction(V1CreateParams.Jurisdiction jurisdiction)
-
jurisdiction
final V1CreateParams.Body.Builder jurisdiction(JsonField<V1CreateParams.Jurisdiction> jurisdiction)
Sets Builder.jurisdiction to an arbitrary JSON value.
You should usually call Builder.jurisdiction with a well-typed Jurisdiction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
matterType
final V1CreateParams.Body.Builder matterType(String matterType)
-
matterType
final V1CreateParams.Body.Builder matterType(JsonField<String> matterType)
Sets Builder.matterType to an arbitrary JSON value.
You should usually call Builder.matterType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1CreateParams.Body.Builder metadata(V1CreateParams.Metadata metadata)
-
metadata
final V1CreateParams.Body.Builder metadata(JsonField<V1CreateParams.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
practiceArea
final V1CreateParams.Body.Builder practiceArea(String practiceArea)
-
practiceArea
final V1CreateParams.Body.Builder practiceArea(JsonField<String> practiceArea)
Sets Builder.practiceArea to an arbitrary JSON value.
You should usually call Builder.practiceArea with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
responsibleAttorneyId
final V1CreateParams.Body.Builder responsibleAttorneyId(String responsibleAttorneyId)
-
responsibleAttorneyId
final V1CreateParams.Body.Builder responsibleAttorneyId(JsonField<String> responsibleAttorneyId)
Sets Builder.responsibleAttorneyId to an arbitrary JSON value.
You should usually call Builder.responsibleAttorneyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final V1CreateParams.Body.Builder status(V1CreateParams.Status status)
-
status
final V1CreateParams.Body.Builder status(JsonField<V1CreateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
subtype
final V1CreateParams.Body.Builder subtype(String subtype)
-
subtype
final V1CreateParams.Body.Builder subtype(JsonField<String> subtype)
Sets Builder.subtype to an arbitrary JSON value.
You should usually call Builder.subtype with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vault
final V1CreateParams.Body.Builder vault(V1CreateParams.Vault vault)
-
vault
final V1CreateParams.Body.Builder vault(JsonField<V1CreateParams.Vault> vault)
Sets Builder.vault to an arbitrary JSON value.
You should usually call Builder.vault with a well-typed Vault value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final V1CreateParams.Body.Builder vaultId(String vaultId)
-
vaultId
final V1CreateParams.Body.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.title()
-
-
-
-