Class V1CreateParams.Builder
-
- All Implemented Interfaces:
public final class V1CreateParams.BuilderA builder for V1CreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final V1CreateParams.Builder body(V1CreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
title
final V1CreateParams.Builder title(String title)
-
title
final V1CreateParams.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billing
final V1CreateParams.Builder billing(V1CreateParams.Billing billing)
-
billing
final V1CreateParams.Builder billing(JsonField<V1CreateParams.Billing> billing)
Sets Builder.billing to an arbitrary JSON value.
You should usually call Builder.billing with a well-typed Billing value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientName
final V1CreateParams.Builder clientName(String clientName)
-
clientName
final V1CreateParams.Builder clientName(JsonField<String> clientName)
Sets Builder.clientName to an arbitrary JSON value.
You should usually call Builder.clientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientPartyId
final V1CreateParams.Builder clientPartyId(String clientPartyId)
-
clientPartyId
final V1CreateParams.Builder clientPartyId(Optional<String> clientPartyId)
Alias for calling Builder.clientPartyId with
clientPartyId.orElse(null).
-
clientPartyId
final V1CreateParams.Builder clientPartyId(JsonField<String> clientPartyId)
Sets Builder.clientPartyId to an arbitrary JSON value.
You should usually call Builder.clientPartyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customFields
final V1CreateParams.Builder customFields(V1CreateParams.CustomFields customFields)
-
customFields
final V1CreateParams.Builder customFields(JsonField<V1CreateParams.CustomFields> customFields)
Sets Builder.customFields to an arbitrary JSON value.
You should usually call Builder.customFields with a well-typed CustomFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final V1CreateParams.Builder description(String description)
-
description
final V1CreateParams.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
displayId
final V1CreateParams.Builder displayId(String displayId)
-
displayId
final V1CreateParams.Builder displayId(JsonField<String> displayId)
Sets Builder.displayId to an arbitrary JSON value.
You should usually call Builder.displayId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
importantDates
final V1CreateParams.Builder importantDates(V1CreateParams.ImportantDates importantDates)
-
importantDates
final V1CreateParams.Builder importantDates(JsonField<V1CreateParams.ImportantDates> importantDates)
Sets Builder.importantDates to an arbitrary JSON value.
You should usually call Builder.importantDates with a well-typed ImportantDates value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jurisdiction
final V1CreateParams.Builder jurisdiction(V1CreateParams.Jurisdiction jurisdiction)
-
jurisdiction
final V1CreateParams.Builder jurisdiction(JsonField<V1CreateParams.Jurisdiction> jurisdiction)
Sets Builder.jurisdiction to an arbitrary JSON value.
You should usually call Builder.jurisdiction with a well-typed Jurisdiction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
matterType
final V1CreateParams.Builder matterType(String matterType)
-
matterType
final V1CreateParams.Builder matterType(JsonField<String> matterType)
Sets Builder.matterType to an arbitrary JSON value.
You should usually call Builder.matterType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1CreateParams.Builder metadata(V1CreateParams.Metadata metadata)
-
metadata
final V1CreateParams.Builder metadata(JsonField<V1CreateParams.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
practiceArea
final V1CreateParams.Builder practiceArea(String practiceArea)
-
practiceArea
final V1CreateParams.Builder practiceArea(JsonField<String> practiceArea)
Sets Builder.practiceArea to an arbitrary JSON value.
You should usually call Builder.practiceArea with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
responsibleAttorneyId
final V1CreateParams.Builder responsibleAttorneyId(String responsibleAttorneyId)
-
responsibleAttorneyId
final V1CreateParams.Builder responsibleAttorneyId(JsonField<String> responsibleAttorneyId)
Sets Builder.responsibleAttorneyId to an arbitrary JSON value.
You should usually call Builder.responsibleAttorneyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final V1CreateParams.Builder status(V1CreateParams.Status status)
-
status
final V1CreateParams.Builder status(JsonField<V1CreateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
subtype
final V1CreateParams.Builder subtype(String subtype)
-
subtype
final V1CreateParams.Builder subtype(JsonField<String> subtype)
Sets Builder.subtype to an arbitrary JSON value.
You should usually call Builder.subtype with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vault
final V1CreateParams.Builder vault(V1CreateParams.Vault vault)
-
vault
final V1CreateParams.Builder vault(JsonField<V1CreateParams.Vault> vault)
Sets Builder.vault to an arbitrary JSON value.
You should usually call Builder.vault with a well-typed Vault value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final V1CreateParams.Builder vaultId(String vaultId)
-
vaultId
final V1CreateParams.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final V1CreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final V1CreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final V1CreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final V1CreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final V1CreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final V1CreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final V1CreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final V1CreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final V1CreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final V1CreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final V1CreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final V1CreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final V1CreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final V1CreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final V1CreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final V1CreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final V1CreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final V1CreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final V1CreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final V1CreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final V1CreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final V1CreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final V1CreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final V1CreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final V1CreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final V1CreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final V1CreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final V1CreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final V1CreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final V1CreateParams build()
Returns an immutable instance of V1CreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.title()
-
-
-
-