Class V1CreateParams.Vault.Builder
-
- All Implemented Interfaces:
public final class V1CreateParams.Vault.BuilderA builder for Vault.
-
-
Method Summary
-
-
Method Detail
-
description
final V1CreateParams.Vault.Builder description(String description)
-
description
final V1CreateParams.Vault.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableGraph
final V1CreateParams.Vault.Builder enableGraph(Boolean enableGraph)
-
enableGraph
final V1CreateParams.Vault.Builder enableGraph(JsonField<Boolean> enableGraph)
Sets Builder.enableGraph to an arbitrary JSON value.
You should usually call Builder.enableGraph with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableIndexing
final V1CreateParams.Vault.Builder enableIndexing(Boolean enableIndexing)
-
enableIndexing
final V1CreateParams.Vault.Builder enableIndexing(JsonField<Boolean> enableIndexing)
Sets Builder.enableIndexing to an arbitrary JSON value.
You should usually call Builder.enableIndexing with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1CreateParams.Vault.Builder metadata(V1CreateParams.Vault.Metadata metadata)
-
metadata
final V1CreateParams.Vault.Builder metadata(JsonField<V1CreateParams.Vault.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateParams.Vault.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateParams.Vault.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateParams.Vault.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateParams.Vault.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateParams.Vault.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateParams.Vault build()
Returns an immutable instance of Vault.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-