Class V1UpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1UpdateParams implements Params
Update mutable matter fields.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1UpdateParams.BuilderA builder for V1UpdateParams.
public final classV1UpdateParams.Bodypublic final classV1UpdateParams.Billingpublic final classV1UpdateParams.CustomFieldspublic final classV1UpdateParams.ImportantDatespublic final classV1UpdateParams.Jurisdictionpublic final classV1UpdateParams.Metadatapublic final classV1UpdateParams.Status
-
Method Summary
-
-
Method Detail
-
archivedAt
final Optional<OffsetDateTime> archivedAt()
-
billing
final Optional<V1UpdateParams.Billing> billing()
-
clientName
final Optional<String> clientName()
-
clientPartyId
final Optional<String> clientPartyId()
-
customFields
final Optional<V1UpdateParams.CustomFields> customFields()
-
description
final Optional<String> description()
-
importantDates
final Optional<V1UpdateParams.ImportantDates> importantDates()
-
jurisdiction
final Optional<V1UpdateParams.Jurisdiction> jurisdiction()
-
matterType
final Optional<String> matterType()
-
metadata
final Optional<V1UpdateParams.Metadata> metadata()
-
practiceArea
final Optional<String> practiceArea()
-
responsibleAttorneyId
final Optional<String> responsibleAttorneyId()
-
status
final Optional<V1UpdateParams.Status> status()
-
_archivedAt
final JsonField<OffsetDateTime> _archivedAt()
Returns the raw JSON value of archivedAt.
Unlike archivedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_billing
final JsonField<V1UpdateParams.Billing> _billing()
Returns the raw JSON value of billing.
Unlike billing, this method doesn't throw if the JSON field has an unexpected type.
-
_clientName
final JsonField<String> _clientName()
Returns the raw JSON value of clientName.
Unlike clientName, this method doesn't throw if the JSON field has an unexpected type.
-
_clientPartyId
final JsonField<String> _clientPartyId()
Returns the raw JSON value of clientPartyId.
Unlike clientPartyId, this method doesn't throw if the JSON field has an unexpected type.
-
_customFields
final JsonField<V1UpdateParams.CustomFields> _customFields()
Returns the raw JSON value of customFields.
Unlike customFields, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_displayId
final JsonField<String> _displayId()
Returns the raw JSON value of displayId.
Unlike displayId, this method doesn't throw if the JSON field has an unexpected type.
-
_importantDates
final JsonField<V1UpdateParams.ImportantDates> _importantDates()
Returns the raw JSON value of importantDates.
Unlike importantDates, this method doesn't throw if the JSON field has an unexpected type.
-
_jurisdiction
final JsonField<V1UpdateParams.Jurisdiction> _jurisdiction()
Returns the raw JSON value of jurisdiction.
Unlike jurisdiction, this method doesn't throw if the JSON field has an unexpected type.
-
_matterType
final JsonField<String> _matterType()
Returns the raw JSON value of matterType.
Unlike matterType, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<V1UpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_practiceArea
final JsonField<String> _practiceArea()
Returns the raw JSON value of practiceArea.
Unlike practiceArea, this method doesn't throw if the JSON field has an unexpected type.
-
_responsibleAttorneyId
final JsonField<String> _responsibleAttorneyId()
Returns the raw JSON value of responsibleAttorneyId.
Unlike responsibleAttorneyId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<V1UpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_subtype
final JsonField<String> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1UpdateParams.Builder toBuilder()
-
_body
final V1UpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static V1UpdateParams none()
-
builder
final static V1UpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of V1UpdateParams.
-
-
-
-