Class V1UpdateParams.Body
-
- All Implemented Interfaces:
public final class V1UpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1UpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
archivedAt
final Optional<OffsetDateTime> archivedAt()
-
billing
final Optional<V1UpdateParams.Billing> billing()
-
clientName
final Optional<String> clientName()
-
clientPartyId
final Optional<String> clientPartyId()
-
customFields
final Optional<V1UpdateParams.CustomFields> customFields()
-
description
final Optional<String> description()
-
importantDates
final Optional<V1UpdateParams.ImportantDates> importantDates()
-
jurisdiction
final Optional<V1UpdateParams.Jurisdiction> jurisdiction()
-
matterType
final Optional<String> matterType()
-
metadata
final Optional<V1UpdateParams.Metadata> metadata()
-
practiceArea
final Optional<String> practiceArea()
-
responsibleAttorneyId
final Optional<String> responsibleAttorneyId()
-
status
final Optional<V1UpdateParams.Status> status()
-
_archivedAt
final JsonField<OffsetDateTime> _archivedAt()
Returns the raw JSON value of archivedAt.
Unlike archivedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_billing
final JsonField<V1UpdateParams.Billing> _billing()
Returns the raw JSON value of billing.
Unlike billing, this method doesn't throw if the JSON field has an unexpected type.
-
_clientName
final JsonField<String> _clientName()
Returns the raw JSON value of clientName.
Unlike clientName, this method doesn't throw if the JSON field has an unexpected type.
-
_clientPartyId
final JsonField<String> _clientPartyId()
Returns the raw JSON value of clientPartyId.
Unlike clientPartyId, this method doesn't throw if the JSON field has an unexpected type.
-
_customFields
final JsonField<V1UpdateParams.CustomFields> _customFields()
Returns the raw JSON value of customFields.
Unlike customFields, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_displayId
final JsonField<String> _displayId()
Returns the raw JSON value of displayId.
Unlike displayId, this method doesn't throw if the JSON field has an unexpected type.
-
_importantDates
final JsonField<V1UpdateParams.ImportantDates> _importantDates()
Returns the raw JSON value of importantDates.
Unlike importantDates, this method doesn't throw if the JSON field has an unexpected type.
-
_jurisdiction
final JsonField<V1UpdateParams.Jurisdiction> _jurisdiction()
Returns the raw JSON value of jurisdiction.
Unlike jurisdiction, this method doesn't throw if the JSON field has an unexpected type.
-
_matterType
final JsonField<String> _matterType()
Returns the raw JSON value of matterType.
Unlike matterType, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<V1UpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_practiceArea
final JsonField<String> _practiceArea()
Returns the raw JSON value of practiceArea.
Unlike practiceArea, this method doesn't throw if the JSON field has an unexpected type.
-
_responsibleAttorneyId
final JsonField<String> _responsibleAttorneyId()
Returns the raw JSON value of responsibleAttorneyId.
Unlike responsibleAttorneyId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<V1UpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_subtype
final JsonField<String> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1UpdateParams.Body.Builder toBuilder()
-
validate
final V1UpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1UpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-