Class V1UpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1UpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
archivedAt
final V1UpdateParams.Body.Builder archivedAt(OffsetDateTime archivedAt)
-
archivedAt
final V1UpdateParams.Body.Builder archivedAt(Optional<OffsetDateTime> archivedAt)
Alias for calling Builder.archivedAt with
archivedAt.orElse(null).
-
archivedAt
final V1UpdateParams.Body.Builder archivedAt(JsonField<OffsetDateTime> archivedAt)
Sets Builder.archivedAt to an arbitrary JSON value.
You should usually call Builder.archivedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billing
final V1UpdateParams.Body.Builder billing(V1UpdateParams.Billing billing)
-
billing
final V1UpdateParams.Body.Builder billing(JsonField<V1UpdateParams.Billing> billing)
Sets Builder.billing to an arbitrary JSON value.
You should usually call Builder.billing with a well-typed Billing value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientName
final V1UpdateParams.Body.Builder clientName(String clientName)
-
clientName
final V1UpdateParams.Body.Builder clientName(JsonField<String> clientName)
Sets Builder.clientName to an arbitrary JSON value.
You should usually call Builder.clientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientPartyId
final V1UpdateParams.Body.Builder clientPartyId(String clientPartyId)
-
clientPartyId
final V1UpdateParams.Body.Builder clientPartyId(Optional<String> clientPartyId)
Alias for calling Builder.clientPartyId with
clientPartyId.orElse(null).
-
clientPartyId
final V1UpdateParams.Body.Builder clientPartyId(JsonField<String> clientPartyId)
Sets Builder.clientPartyId to an arbitrary JSON value.
You should usually call Builder.clientPartyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customFields
final V1UpdateParams.Body.Builder customFields(V1UpdateParams.CustomFields customFields)
-
customFields
final V1UpdateParams.Body.Builder customFields(JsonField<V1UpdateParams.CustomFields> customFields)
Sets Builder.customFields to an arbitrary JSON value.
You should usually call Builder.customFields with a well-typed CustomFields value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final V1UpdateParams.Body.Builder description(String description)
-
description
final V1UpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
displayId
final V1UpdateParams.Body.Builder displayId(String displayId)
-
displayId
final V1UpdateParams.Body.Builder displayId(JsonField<String> displayId)
Sets Builder.displayId to an arbitrary JSON value.
You should usually call Builder.displayId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
importantDates
final V1UpdateParams.Body.Builder importantDates(V1UpdateParams.ImportantDates importantDates)
-
importantDates
final V1UpdateParams.Body.Builder importantDates(JsonField<V1UpdateParams.ImportantDates> importantDates)
Sets Builder.importantDates to an arbitrary JSON value.
You should usually call Builder.importantDates with a well-typed ImportantDates value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jurisdiction
final V1UpdateParams.Body.Builder jurisdiction(V1UpdateParams.Jurisdiction jurisdiction)
-
jurisdiction
final V1UpdateParams.Body.Builder jurisdiction(JsonField<V1UpdateParams.Jurisdiction> jurisdiction)
Sets Builder.jurisdiction to an arbitrary JSON value.
You should usually call Builder.jurisdiction with a well-typed Jurisdiction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
matterType
final V1UpdateParams.Body.Builder matterType(String matterType)
-
matterType
final V1UpdateParams.Body.Builder matterType(JsonField<String> matterType)
Sets Builder.matterType to an arbitrary JSON value.
You should usually call Builder.matterType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1UpdateParams.Body.Builder metadata(V1UpdateParams.Metadata metadata)
-
metadata
final V1UpdateParams.Body.Builder metadata(JsonField<V1UpdateParams.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
practiceArea
final V1UpdateParams.Body.Builder practiceArea(String practiceArea)
-
practiceArea
final V1UpdateParams.Body.Builder practiceArea(JsonField<String> practiceArea)
Sets Builder.practiceArea to an arbitrary JSON value.
You should usually call Builder.practiceArea with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
responsibleAttorneyId
final V1UpdateParams.Body.Builder responsibleAttorneyId(String responsibleAttorneyId)
-
responsibleAttorneyId
final V1UpdateParams.Body.Builder responsibleAttorneyId(JsonField<String> responsibleAttorneyId)
Sets Builder.responsibleAttorneyId to an arbitrary JSON value.
You should usually call Builder.responsibleAttorneyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final V1UpdateParams.Body.Builder status(V1UpdateParams.Status status)
-
status
final V1UpdateParams.Body.Builder status(JsonField<V1UpdateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
subtype
final V1UpdateParams.Body.Builder subtype(String subtype)
-
subtype
final V1UpdateParams.Body.Builder subtype(JsonField<String> subtype)
Sets Builder.subtype to an arbitrary JSON value.
You should usually call Builder.subtype with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
title
final V1UpdateParams.Body.Builder title(String title)
-
title
final V1UpdateParams.Body.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1UpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1UpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1UpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1UpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1UpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1UpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-