Class LogCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class LogCreateParams implements Params
Append a manual operational note or event to a matter log.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogCreateParams.BuilderA builder for LogCreateParams.
public final classLogCreateParams.Bodypublic final classLogCreateParams.Details
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Stringsummary()final Optional<LogCreateParams.Details>details()final Optional<String>eventType()final Optional<String>workItemId()final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<LogCreateParams.Details>_details()Returns the raw JSON value of details. final JsonField<String>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_workItemId()Returns the raw JSON value of workItemId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LogCreateParams.BuildertoBuilder()final LogCreateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of LogCreateParams. -
-
Method Detail
-
details
final Optional<LogCreateParams.Details> details()
-
workItemId
final Optional<String> workItemId()
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_details
final JsonField<LogCreateParams.Details> _details()
Returns the raw JSON value of details.
Unlike details, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_workItemId
final JsonField<String> _workItemId()
Returns the raw JSON value of workItemId.
Unlike workItemId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LogCreateParams.Builder toBuilder()
-
_body
final LogCreateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static LogCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of LogCreateParams.
The following fields are required:
.summary()
-
-
-
-