Class LogCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class LogCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
summary
final LogCreateParams.Body.Builder summary(String summary)
-
summary
final LogCreateParams.Body.Builder summary(JsonField<String> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
details
final LogCreateParams.Body.Builder details(LogCreateParams.Details details)
-
details
final LogCreateParams.Body.Builder details(JsonField<LogCreateParams.Details> details)
Sets Builder.details to an arbitrary JSON value.
You should usually call Builder.details with a well-typed Details value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final LogCreateParams.Body.Builder eventType(String eventType)
-
eventType
final LogCreateParams.Body.Builder eventType(JsonField<String> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workItemId
final LogCreateParams.Body.Builder workItemId(String workItemId)
-
workItemId
final LogCreateParams.Body.Builder workItemId(JsonField<String> workItemId)
Sets Builder.workItemId to an arbitrary JSON value.
You should usually call Builder.workItemId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LogCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LogCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LogCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LogCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LogCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LogCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.summary()
-
-
-
-