Class LogExportParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class LogExportParams implements Params
Bulk export matter log entries for audits, visibility, and eval pipelines. Supports json, csv, tsv, and jsonl. Limited to 10,000 entries per request.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogExportParams.BuilderA builder for LogExportParams.
public final classLogExportParams.Bodypublic final classLogExportParams.FormatExport format. Defaults to jsonl.
public final classLogExportParams.ScopeFilter by scope: matter, work_item, execution, sharing, all
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>actorId()Filter by actor ID final Optional<String>actorType()Filter by actor type final Optional<OffsetDateTime>endTime()End of time range (ISO 8601) final Optional<String>eventType()Filter by exact event type final Optional<LogExportParams.Format>format()Export format. final Optional<LogExportParams.Scope>scope()Filter by scope: matter, work_item, execution, sharing, all final Optional<OffsetDateTime>startTime()Start of time range (ISO 8601) final Optional<String>workItemId()Filter by work item ID final JsonField<String>_actorId()Returns the raw JSON value of actorId. final JsonField<String>_actorType()Returns the raw JSON value of actorType. final JsonField<OffsetDateTime>_endTime()Returns the raw JSON value of endTime. final JsonField<String>_eventType()Returns the raw JSON value of eventType. final JsonField<LogExportParams.Format>_format()Returns the raw JSON value of format. final JsonField<LogExportParams.Scope>_scope()Returns the raw JSON value of scope. final JsonField<OffsetDateTime>_startTime()Returns the raw JSON value of startTime. final JsonField<String>_workItemId()Returns the raw JSON value of workItemId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LogExportParams.BuildertoBuilder()final LogExportParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogExportParamsnone()final static LogExportParams.Builderbuilder()Returns a mutable builder for constructing an instance of LogExportParams. -
-
Method Detail
-
endTime
final Optional<OffsetDateTime> endTime()
End of time range (ISO 8601)
-
format
final Optional<LogExportParams.Format> format()
Export format. Defaults to jsonl.
-
scope
final Optional<LogExportParams.Scope> scope()
Filter by scope: matter, work_item, execution, sharing, all
-
startTime
final Optional<OffsetDateTime> startTime()
Start of time range (ISO 8601)
-
workItemId
final Optional<String> workItemId()
Filter by work item ID
-
_actorId
final JsonField<String> _actorId()
Returns the raw JSON value of actorId.
Unlike actorId, this method doesn't throw if the JSON field has an unexpected type.
-
_actorType
final JsonField<String> _actorType()
Returns the raw JSON value of actorType.
Unlike actorType, this method doesn't throw if the JSON field has an unexpected type.
-
_endTime
final JsonField<OffsetDateTime> _endTime()
Returns the raw JSON value of endTime.
Unlike endTime, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_format
final JsonField<LogExportParams.Format> _format()
Returns the raw JSON value of format.
Unlike format, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<LogExportParams.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_startTime
final JsonField<OffsetDateTime> _startTime()
Returns the raw JSON value of startTime.
Unlike startTime, this method doesn't throw if the JSON field has an unexpected type.
-
_workItemId
final JsonField<String> _workItemId()
Returns the raw JSON value of workItemId.
Unlike workItemId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LogExportParams.Builder toBuilder()
-
_body
final LogExportParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LogExportParams none()
-
builder
final static LogExportParams.Builder builder()
Returns a mutable builder for constructing an instance of LogExportParams.
-
-
-
-