Class LogExportParams.Body
-
- All Implemented Interfaces:
public final class LogExportParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogExportParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>actorId()Filter by actor ID final Optional<String>actorType()Filter by actor type final Optional<OffsetDateTime>endTime()End of time range (ISO 8601) final Optional<String>eventType()Filter by exact event type final Optional<LogExportParams.Format>format()Export format. final Optional<LogExportParams.Scope>scope()Filter by scope: matter, work_item, execution, sharing, all final Optional<OffsetDateTime>startTime()Start of time range (ISO 8601) final Optional<String>workItemId()Filter by work item ID final JsonField<String>_actorId()Returns the raw JSON value of actorId. final JsonField<String>_actorType()Returns the raw JSON value of actorType. final JsonField<OffsetDateTime>_endTime()Returns the raw JSON value of endTime. final JsonField<String>_eventType()Returns the raw JSON value of eventType. final JsonField<LogExportParams.Format>_format()Returns the raw JSON value of format. final JsonField<LogExportParams.Scope>_scope()Returns the raw JSON value of scope. final JsonField<OffsetDateTime>_startTime()Returns the raw JSON value of startTime. final JsonField<String>_workItemId()Returns the raw JSON value of workItemId. final Map<String, JsonValue>_additionalProperties()final LogExportParams.Body.BuildertoBuilder()final LogExportParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogExportParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
endTime
final Optional<OffsetDateTime> endTime()
End of time range (ISO 8601)
-
format
final Optional<LogExportParams.Format> format()
Export format. Defaults to jsonl.
-
scope
final Optional<LogExportParams.Scope> scope()
Filter by scope: matter, work_item, execution, sharing, all
-
startTime
final Optional<OffsetDateTime> startTime()
Start of time range (ISO 8601)
-
workItemId
final Optional<String> workItemId()
Filter by work item ID
-
_actorId
final JsonField<String> _actorId()
Returns the raw JSON value of actorId.
Unlike actorId, this method doesn't throw if the JSON field has an unexpected type.
-
_actorType
final JsonField<String> _actorType()
Returns the raw JSON value of actorType.
Unlike actorType, this method doesn't throw if the JSON field has an unexpected type.
-
_endTime
final JsonField<OffsetDateTime> _endTime()
Returns the raw JSON value of endTime.
Unlike endTime, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_format
final JsonField<LogExportParams.Format> _format()
Returns the raw JSON value of format.
Unlike format, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<LogExportParams.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_startTime
final JsonField<OffsetDateTime> _startTime()
Returns the raw JSON value of startTime.
Unlike startTime, this method doesn't throw if the JSON field has an unexpected type.
-
_workItemId
final JsonField<String> _workItemId()
Returns the raw JSON value of workItemId.
Unlike workItemId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LogExportParams.Body.Builder toBuilder()
-
validate
final LogExportParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LogExportParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-