Class LogExportParams.Scope
-
- All Implemented Interfaces:
public final class LogExportParams.ScopeFilter by scope: matter, work_item, execution, sharing, all
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLogExportParams.Scope.VisitorAn interface that defines how to map each variant of Scope to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<List<String>>strings()final BooleanisString()final BooleanisStrings()final StringasString()final List<String>asStrings()final Optional<JsonValue>_json()final <T extends Any> Taccept(LogExportParams.Scope.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final LogExportParams.Scopevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogExportParams.ScopeofString(String string)final static LogExportParams.ScopeofStrings(List<String> strings)-
-
Method Detail
-
accept
final <T extends Any> T accept(LogExportParams.Scope.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import dev.case.api.core.JsonValue; import java.util.Optional; Optional<String> result = scope.accept(new Scope.Visitor<Optional<String>>() { @Override public Optional<String> visitString(String string) { return Optional.of(string.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final LogExportParams.Scope validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofString
final static LogExportParams.Scope ofString(String string)
-
ofStrings
final static LogExportParams.Scope ofStrings(List<String> strings)
-
-
-
-