Class LogExportResponse
-
- All Implemented Interfaces:
public final class LogExportResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogExportResponse.BuilderA builder for LogExportResponse.
public final classLogExportResponse.Data
-
Method Summary
Modifier and Type Method Description final Optional<List<LogExportResponse.Data>>data()final JsonField<List<LogExportResponse.Data>>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final LogExportResponse.BuildertoBuilder()final LogExportResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogExportResponse.Builderbuilder()Returns a mutable builder for constructing an instance of LogExportResponse. -
-
Method Detail
-
data
final Optional<List<LogExportResponse.Data>> data()
-
_data
final JsonField<List<LogExportResponse.Data>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LogExportResponse.Builder toBuilder()
-
validate
final LogExportResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LogExportResponse.Builder builder()
Returns a mutable builder for constructing an instance of LogExportResponse.
-
-
-
-