Class LogExportResponse.Data
-
- All Implemented Interfaces:
public final class LogExportResponse.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogExportResponse.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final LogExportResponse.Data.BuildertoBuilder()final LogExportResponse.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogExportResponse.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LogExportResponse.Data.Builder toBuilder()
-
validate
final LogExportResponse.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LogExportResponse.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-