Class LogListParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class LogListParams implements Params
List the operational history for a matter.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogListParams.BuilderA builder for LogListParams.
public final classLogListParams.ScopeFilter by scope: matter, work_item, execution, sharing, all
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>actorId()Filter by actor ID final Optional<String>actorType()Filter by actor type final Optional<OffsetDateTime>endTime()End of time range (ISO 8601) final Optional<String>eventType()Filter by exact event type final Optional<Long>limit()Maximum number of log entries to return (max 200) final Optional<Long>offset()Number of log entries to skip for pagination final Optional<LogListParams.Scope>scope()Filter by scope: matter, work_item, execution, sharing, all final Optional<OffsetDateTime>startTime()Start of time range (ISO 8601) final Optional<String>workItemId()Filter by work item ID final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LogListParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogListParamsnone()final static LogListParams.Builderbuilder()Returns a mutable builder for constructing an instance of LogListParams. -
-
Method Detail
-
endTime
final Optional<OffsetDateTime> endTime()
End of time range (ISO 8601)
-
scope
final Optional<LogListParams.Scope> scope()
Filter by scope: matter, work_item, execution, sharing, all
-
startTime
final Optional<OffsetDateTime> startTime()
Start of time range (ISO 8601)
-
workItemId
final Optional<String> workItemId()
Filter by work item ID
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LogListParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LogListParams none()
-
builder
final static LogListParams.Builder builder()
Returns a mutable builder for constructing an instance of LogListParams.
-
-
-
-