Class WorkItemCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class WorkItemCreateParams implements Params
Create an active work item on a matter.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemCreateParams.BuilderA builder for WorkItemCreateParams.
public final classWorkItemCreateParams.Bodypublic final classWorkItemCreateParams.Metadatapublic final classWorkItemCreateParams.Prioritypublic final classWorkItemCreateParams.Type
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Stringtitle()final Optional<String>assigneeId()final Optional<String>description()final Optional<OffsetDateTime>dueAt()final Optional<List<String>>exitCriteria()final Optional<String>instructions()final Optional<WorkItemCreateParams.Metadata>metadata()final Optional<WorkItemCreateParams.Priority>priority()final Optional<WorkItemCreateParams.Type>type()final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<String>_assigneeId()Returns the raw JSON value of assigneeId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<OffsetDateTime>_dueAt()Returns the raw JSON value of dueAt. final JsonField<List<String>>_exitCriteria()Returns the raw JSON value of exitCriteria. final JsonField<String>_instructions()Returns the raw JSON value of instructions. final JsonField<WorkItemCreateParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<WorkItemCreateParams.Priority>_priority()Returns the raw JSON value of priority. final JsonField<WorkItemCreateParams.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final WorkItemCreateParams.BuildertoBuilder()final WorkItemCreateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkItemCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of WorkItemCreateParams. -
-
Method Detail
-
assigneeId
final Optional<String> assigneeId()
-
description
final Optional<String> description()
-
dueAt
final Optional<OffsetDateTime> dueAt()
-
exitCriteria
final Optional<List<String>> exitCriteria()
-
instructions
final Optional<String> instructions()
-
metadata
final Optional<WorkItemCreateParams.Metadata> metadata()
-
priority
final Optional<WorkItemCreateParams.Priority> priority()
-
type
final Optional<WorkItemCreateParams.Type> type()
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_assigneeId
final JsonField<String> _assigneeId()
Returns the raw JSON value of assigneeId.
Unlike assigneeId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_dueAt
final JsonField<OffsetDateTime> _dueAt()
Returns the raw JSON value of dueAt.
Unlike dueAt, this method doesn't throw if the JSON field has an unexpected type.
-
_exitCriteria
final JsonField<List<String>> _exitCriteria()
Returns the raw JSON value of exitCriteria.
Unlike exitCriteria, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<WorkItemCreateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_priority
final JsonField<WorkItemCreateParams.Priority> _priority()
Returns the raw JSON value of priority.
Unlike priority, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<WorkItemCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WorkItemCreateParams.Builder toBuilder()
-
_body
final WorkItemCreateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static WorkItemCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of WorkItemCreateParams.
The following fields are required:
.title()
-
-
-
-