Class WorkItemCreateParams.Body
-
- All Implemented Interfaces:
public final class WorkItemCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
assigneeId
final Optional<String> assigneeId()
-
description
final Optional<String> description()
-
dueAt
final Optional<OffsetDateTime> dueAt()
-
exitCriteria
final Optional<List<String>> exitCriteria()
-
instructions
final Optional<String> instructions()
-
metadata
final Optional<WorkItemCreateParams.Metadata> metadata()
-
priority
final Optional<WorkItemCreateParams.Priority> priority()
-
type
final Optional<WorkItemCreateParams.Type> type()
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_assigneeId
final JsonField<String> _assigneeId()
Returns the raw JSON value of assigneeId.
Unlike assigneeId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_dueAt
final JsonField<OffsetDateTime> _dueAt()
Returns the raw JSON value of dueAt.
Unlike dueAt, this method doesn't throw if the JSON field has an unexpected type.
-
_exitCriteria
final JsonField<List<String>> _exitCriteria()
Returns the raw JSON value of exitCriteria.
Unlike exitCriteria, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<WorkItemCreateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_priority
final JsonField<WorkItemCreateParams.Priority> _priority()
Returns the raw JSON value of priority.
Unlike priority, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<WorkItemCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkItemCreateParams.Body.Builder toBuilder()
-
validate
final WorkItemCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WorkItemCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.title()
-
-
-
-