Class WorkItemCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class WorkItemCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
title
final WorkItemCreateParams.Body.Builder title(String title)
-
title
final WorkItemCreateParams.Body.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
assigneeId
final WorkItemCreateParams.Body.Builder assigneeId(String assigneeId)
-
assigneeId
final WorkItemCreateParams.Body.Builder assigneeId(JsonField<String> assigneeId)
Sets Builder.assigneeId to an arbitrary JSON value.
You should usually call Builder.assigneeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final WorkItemCreateParams.Body.Builder description(String description)
-
description
final WorkItemCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dueAt
final WorkItemCreateParams.Body.Builder dueAt(OffsetDateTime dueAt)
-
dueAt
final WorkItemCreateParams.Body.Builder dueAt(JsonField<OffsetDateTime> dueAt)
Sets Builder.dueAt to an arbitrary JSON value.
You should usually call Builder.dueAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
exitCriteria
final WorkItemCreateParams.Body.Builder exitCriteria(List<String> exitCriteria)
-
exitCriteria
final WorkItemCreateParams.Body.Builder exitCriteria(JsonField<List<String>> exitCriteria)
Sets Builder.exitCriteria to an arbitrary JSON value.
You should usually call Builder.exitCriteria with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExitCriterion
final WorkItemCreateParams.Body.Builder addExitCriterion(String exitCriterion)
Adds a single String to exitCriteria.
-
instructions
final WorkItemCreateParams.Body.Builder instructions(String instructions)
-
instructions
final WorkItemCreateParams.Body.Builder instructions(JsonField<String> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final WorkItemCreateParams.Body.Builder metadata(WorkItemCreateParams.Metadata metadata)
-
metadata
final WorkItemCreateParams.Body.Builder metadata(JsonField<WorkItemCreateParams.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
priority
final WorkItemCreateParams.Body.Builder priority(WorkItemCreateParams.Priority priority)
-
priority
final WorkItemCreateParams.Body.Builder priority(JsonField<WorkItemCreateParams.Priority> priority)
Sets Builder.priority to an arbitrary JSON value.
You should usually call Builder.priority with a well-typed Priority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final WorkItemCreateParams.Body.Builder type(WorkItemCreateParams.Type type)
-
type
final WorkItemCreateParams.Body.Builder type(JsonField<WorkItemCreateParams.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WorkItemCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WorkItemCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WorkItemCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WorkItemCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WorkItemCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WorkItemCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.title()
-
-
-
-