Class WorkItemDecideParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class WorkItemDecideParams implements Params
Approve, revise, block, or reassign a work item. Used by humans or agents to move work items through their lifecycle.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemDecideParams.BuilderA builder for WorkItemDecideParams.
public final classWorkItemDecideParams.Bodypublic final classWorkItemDecideParams.Decisionpublic final classWorkItemDecideParams.Metadata
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>workItemId()final WorkItemDecideParams.Decisiondecision()final Optional<String>agentTypeId()final Optional<WorkItemDecideParams.Metadata>metadata()final Optional<String>reason()final JsonField<WorkItemDecideParams.Decision>_decision()Returns the raw JSON value of decision. final JsonField<String>_agentTypeId()Returns the raw JSON value of agentTypeId. final JsonField<WorkItemDecideParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final WorkItemDecideParams.BuildertoBuilder()final WorkItemDecideParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkItemDecideParams.Builderbuilder()Returns a mutable builder for constructing an instance of WorkItemDecideParams. -
-
Method Detail
-
workItemId
final Optional<String> workItemId()
-
decision
final WorkItemDecideParams.Decision decision()
-
agentTypeId
final Optional<String> agentTypeId()
-
metadata
final Optional<WorkItemDecideParams.Metadata> metadata()
-
_decision
final JsonField<WorkItemDecideParams.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_agentTypeId
final JsonField<String> _agentTypeId()
Returns the raw JSON value of agentTypeId.
Unlike agentTypeId, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<WorkItemDecideParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WorkItemDecideParams.Builder toBuilder()
-
_body
final WorkItemDecideParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static WorkItemDecideParams.Builder builder()
Returns a mutable builder for constructing an instance of WorkItemDecideParams.
The following fields are required:
.id() .decision()
-
-
-
-