Class WorkItemDecideParams.Body
-
- All Implemented Interfaces:
public final class WorkItemDecideParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemDecideParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
decision
final WorkItemDecideParams.Decision decision()
-
agentTypeId
final Optional<String> agentTypeId()
-
metadata
final Optional<WorkItemDecideParams.Metadata> metadata()
-
_decision
final JsonField<WorkItemDecideParams.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_agentTypeId
final JsonField<String> _agentTypeId()
Returns the raw JSON value of agentTypeId.
Unlike agentTypeId, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<WorkItemDecideParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkItemDecideParams.Body.Builder toBuilder()
-
validate
final WorkItemDecideParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WorkItemDecideParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.decision()
-
-
-
-