Class WorkItemUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class WorkItemUpdateParams implements Params
Update a matter work item.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemUpdateParams.BuilderA builder for WorkItemUpdateParams.
public final classWorkItemUpdateParams.Bodypublic final classWorkItemUpdateParams.Metadatapublic final classWorkItemUpdateParams.Prioritypublic final classWorkItemUpdateParams.Statuspublic final classWorkItemUpdateParams.Type
-
Method Summary
-
-
Method Detail
-
workItemId
final Optional<String> workItemId()
-
assigneeId
final Optional<String> assigneeId()
-
completedAt
final Optional<OffsetDateTime> completedAt()
-
description
final Optional<String> description()
-
dueAt
final Optional<OffsetDateTime> dueAt()
-
exitCriteria
final Optional<List<String>> exitCriteria()
-
instructions
final Optional<String> instructions()
-
metadata
final Optional<WorkItemUpdateParams.Metadata> metadata()
-
priority
final Optional<WorkItemUpdateParams.Priority> priority()
-
startedAt
final Optional<OffsetDateTime> startedAt()
-
status
final Optional<WorkItemUpdateParams.Status> status()
-
type
final Optional<WorkItemUpdateParams.Type> type()
-
_assigneeId
final JsonField<String> _assigneeId()
Returns the raw JSON value of assigneeId.
Unlike assigneeId, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_dueAt
final JsonField<OffsetDateTime> _dueAt()
Returns the raw JSON value of dueAt.
Unlike dueAt, this method doesn't throw if the JSON field has an unexpected type.
-
_exitCriteria
final JsonField<List<String>> _exitCriteria()
Returns the raw JSON value of exitCriteria.
Unlike exitCriteria, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<WorkItemUpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_priority
final JsonField<WorkItemUpdateParams.Priority> _priority()
Returns the raw JSON value of priority.
Unlike priority, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<WorkItemUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<WorkItemUpdateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WorkItemUpdateParams.Builder toBuilder()
-
_body
final WorkItemUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static WorkItemUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of WorkItemUpdateParams.
The following fields are required:
.id()
-
-
-
-