Class WorkItemUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class WorkItemUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
assigneeId
final WorkItemUpdateParams.Body.Builder assigneeId(String assigneeId)
-
assigneeId
final WorkItemUpdateParams.Body.Builder assigneeId(Optional<String> assigneeId)
Alias for calling Builder.assigneeId with
assigneeId.orElse(null).
-
assigneeId
final WorkItemUpdateParams.Body.Builder assigneeId(JsonField<String> assigneeId)
Sets Builder.assigneeId to an arbitrary JSON value.
You should usually call Builder.assigneeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final WorkItemUpdateParams.Body.Builder completedAt(OffsetDateTime completedAt)
-
completedAt
final WorkItemUpdateParams.Body.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final WorkItemUpdateParams.Body.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final WorkItemUpdateParams.Body.Builder description(String description)
-
description
final WorkItemUpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dueAt
final WorkItemUpdateParams.Body.Builder dueAt(OffsetDateTime dueAt)
-
dueAt
final WorkItemUpdateParams.Body.Builder dueAt(Optional<OffsetDateTime> dueAt)
Alias for calling Builder.dueAt with
dueAt.orElse(null).
-
dueAt
final WorkItemUpdateParams.Body.Builder dueAt(JsonField<OffsetDateTime> dueAt)
Sets Builder.dueAt to an arbitrary JSON value.
You should usually call Builder.dueAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
exitCriteria
final WorkItemUpdateParams.Body.Builder exitCriteria(List<String> exitCriteria)
-
exitCriteria
final WorkItemUpdateParams.Body.Builder exitCriteria(JsonField<List<String>> exitCriteria)
Sets Builder.exitCriteria to an arbitrary JSON value.
You should usually call Builder.exitCriteria with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExitCriterion
final WorkItemUpdateParams.Body.Builder addExitCriterion(String exitCriterion)
Adds a single String to exitCriteria.
-
instructions
final WorkItemUpdateParams.Body.Builder instructions(String instructions)
-
instructions
final WorkItemUpdateParams.Body.Builder instructions(Optional<String> instructions)
Alias for calling Builder.instructions with
instructions.orElse(null).
-
instructions
final WorkItemUpdateParams.Body.Builder instructions(JsonField<String> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final WorkItemUpdateParams.Body.Builder metadata(WorkItemUpdateParams.Metadata metadata)
-
metadata
final WorkItemUpdateParams.Body.Builder metadata(JsonField<WorkItemUpdateParams.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
priority
final WorkItemUpdateParams.Body.Builder priority(WorkItemUpdateParams.Priority priority)
-
priority
final WorkItemUpdateParams.Body.Builder priority(JsonField<WorkItemUpdateParams.Priority> priority)
Sets Builder.priority to an arbitrary JSON value.
You should usually call Builder.priority with a well-typed Priority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startedAt
final WorkItemUpdateParams.Body.Builder startedAt(OffsetDateTime startedAt)
-
startedAt
final WorkItemUpdateParams.Body.Builder startedAt(Optional<OffsetDateTime> startedAt)
Alias for calling Builder.startedAt with
startedAt.orElse(null).
-
startedAt
final WorkItemUpdateParams.Body.Builder startedAt(JsonField<OffsetDateTime> startedAt)
Sets Builder.startedAt to an arbitrary JSON value.
You should usually call Builder.startedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final WorkItemUpdateParams.Body.Builder status(WorkItemUpdateParams.Status status)
-
status
final WorkItemUpdateParams.Body.Builder status(JsonField<WorkItemUpdateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
title
final WorkItemUpdateParams.Body.Builder title(String title)
-
title
final WorkItemUpdateParams.Body.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final WorkItemUpdateParams.Body.Builder type(WorkItemUpdateParams.Type type)
-
type
final WorkItemUpdateParams.Body.Builder type(JsonField<WorkItemUpdateParams.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WorkItemUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WorkItemUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WorkItemUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WorkItemUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WorkItemUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WorkItemUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-