Class V1CreateParams.Builder
-
- All Implemented Interfaces:
public final class V1CreateParams.BuilderA builder for V1CreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final V1CreateParams.Builder body(V1CreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
messages
final V1CreateParams.Builder messages(List<V1CreateParams.Message> messages)
Conversation messages to extract memories from
-
messages
final V1CreateParams.Builder messages(JsonField<List<V1CreateParams.Message>> messages)
Sets Builder.messages to an arbitrary JSON value.
You should usually call Builder.messages with a well-typed
List<Message>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addMessage
final V1CreateParams.Builder addMessage(V1CreateParams.Message message)
-
category
final V1CreateParams.Builder category(String category)
Custom category (e.g., "fact", "preference", "deadline")
-
category
final V1CreateParams.Builder category(JsonField<String> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extractionPrompt
final V1CreateParams.Builder extractionPrompt(String extractionPrompt)
Optional custom prompt for fact extraction
-
extractionPrompt
final V1CreateParams.Builder extractionPrompt(JsonField<String> extractionPrompt)
Sets Builder.extractionPrompt to an arbitrary JSON value.
You should usually call Builder.extractionPrompt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
infer
final V1CreateParams.Builder infer(Boolean infer)
Whether to extract facts from messages (default: true)
-
infer
final V1CreateParams.Builder infer(JsonField<Boolean> infer)
Sets Builder.infer to an arbitrary JSON value.
You should usually call Builder.infer with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1CreateParams.Builder metadata(V1CreateParams.Metadata metadata)
Additional metadata (not indexed)
-
metadata
final V1CreateParams.Builder metadata(JsonField<V1CreateParams.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag1
final V1CreateParams.Builder tag1(String tag1)
Generic indexed filter field 1 (you decide what it means)
-
tag1
final V1CreateParams.Builder tag1(JsonField<String> tag1)
Sets Builder.tag1 to an arbitrary JSON value.
You should usually call Builder.tag1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag10
final V1CreateParams.Builder tag10(String tag10)
Generic indexed filter field 10
-
tag10
final V1CreateParams.Builder tag10(JsonField<String> tag10)
Sets Builder.tag10 to an arbitrary JSON value.
You should usually call Builder.tag10 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag11
final V1CreateParams.Builder tag11(String tag11)
Generic indexed filter field 11
-
tag11
final V1CreateParams.Builder tag11(JsonField<String> tag11)
Sets Builder.tag11 to an arbitrary JSON value.
You should usually call Builder.tag11 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag12
final V1CreateParams.Builder tag12(String tag12)
Generic indexed filter field 12
-
tag12
final V1CreateParams.Builder tag12(JsonField<String> tag12)
Sets Builder.tag12 to an arbitrary JSON value.
You should usually call Builder.tag12 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag2
final V1CreateParams.Builder tag2(String tag2)
Generic indexed filter field 2
-
tag2
final V1CreateParams.Builder tag2(JsonField<String> tag2)
Sets Builder.tag2 to an arbitrary JSON value.
You should usually call Builder.tag2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag3
final V1CreateParams.Builder tag3(String tag3)
Generic indexed filter field 3
-
tag3
final V1CreateParams.Builder tag3(JsonField<String> tag3)
Sets Builder.tag3 to an arbitrary JSON value.
You should usually call Builder.tag3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag4
final V1CreateParams.Builder tag4(String tag4)
Generic indexed filter field 4
-
tag4
final V1CreateParams.Builder tag4(JsonField<String> tag4)
Sets Builder.tag4 to an arbitrary JSON value.
You should usually call Builder.tag4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag5
final V1CreateParams.Builder tag5(String tag5)
Generic indexed filter field 5
-
tag5
final V1CreateParams.Builder tag5(JsonField<String> tag5)
Sets Builder.tag5 to an arbitrary JSON value.
You should usually call Builder.tag5 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag6
final V1CreateParams.Builder tag6(String tag6)
Generic indexed filter field 6
-
tag6
final V1CreateParams.Builder tag6(JsonField<String> tag6)
Sets Builder.tag6 to an arbitrary JSON value.
You should usually call Builder.tag6 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag7
final V1CreateParams.Builder tag7(String tag7)
Generic indexed filter field 7
-
tag7
final V1CreateParams.Builder tag7(JsonField<String> tag7)
Sets Builder.tag7 to an arbitrary JSON value.
You should usually call Builder.tag7 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag8
final V1CreateParams.Builder tag8(String tag8)
Generic indexed filter field 8
-
tag8
final V1CreateParams.Builder tag8(JsonField<String> tag8)
Sets Builder.tag8 to an arbitrary JSON value.
You should usually call Builder.tag8 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag9
final V1CreateParams.Builder tag9(String tag9)
Generic indexed filter field 9
-
tag9
final V1CreateParams.Builder tag9(JsonField<String> tag9)
Sets Builder.tag9 to an arbitrary JSON value.
You should usually call Builder.tag9 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final V1CreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final V1CreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final V1CreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final V1CreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final V1CreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final V1CreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final V1CreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final V1CreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final V1CreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final V1CreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final V1CreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final V1CreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final V1CreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final V1CreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final V1CreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final V1CreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final V1CreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final V1CreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final V1CreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final V1CreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final V1CreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final V1CreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final V1CreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final V1CreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final V1CreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final V1CreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final V1CreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final V1CreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final V1CreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final V1CreateParams build()
Returns an immutable instance of V1CreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.messages()
-
-
-
-