Package dev.case.api.models.memory.v1
Class V1CreateParams.Message
-
- All Implemented Interfaces:
public final class V1CreateParams.Message
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateParams.Message.BuilderA builder for Message.
public final classV1CreateParams.Message.RoleMessage role
-
Method Summary
Modifier and Type Method Description final Stringcontent()Message content final V1CreateParams.Message.Rolerole()Message role final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<V1CreateParams.Message.Role>_role()Returns the raw JSON value of role. final Map<String, JsonValue>_additionalProperties()final V1CreateParams.Message.BuildertoBuilder()final V1CreateParams.Messagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateParams.Message.Builderbuilder()Returns a mutable builder for constructing an instance of Message. -
-
Method Detail
-
role
final V1CreateParams.Message.Role role()
Message role
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<V1CreateParams.Message.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateParams.Message.Builder toBuilder()
-
validate
final V1CreateParams.Message validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1CreateParams.Message.Builder builder()
Returns a mutable builder for constructing an instance of Message.
The following fields are required:
.content() .role()
-
-
-
-