Package dev.case.api.models.memory.v1
Class V1CreateResponse
-
- All Implemented Interfaces:
public final class V1CreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateResponse.BuilderA builder for V1CreateResponse.
public final classV1CreateResponse.Result
-
Method Summary
Modifier and Type Method Description final Optional<List<V1CreateResponse.Result>>results()final JsonField<List<V1CreateResponse.Result>>_results()Returns the raw JSON value of results. final Map<String, JsonValue>_additionalProperties()final V1CreateResponse.BuildertoBuilder()final V1CreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1CreateResponse. -
-
Method Detail
-
results
final Optional<List<V1CreateResponse.Result>> results()
-
_results
final JsonField<List<V1CreateResponse.Result>> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateResponse.Builder toBuilder()
-
validate
final V1CreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1CreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateResponse.
-
-
-
-