Package dev.case.api.models.memory.v1
Class V1CreateResponse.Builder
-
- All Implemented Interfaces:
public final class V1CreateResponse.BuilderA builder for V1CreateResponse.
-
-
Method Summary
Modifier and Type Method Description final V1CreateResponse.Builderresults(List<V1CreateResponse.Result> results)final V1CreateResponse.Builderresults(JsonField<List<V1CreateResponse.Result>> results)Sets Builder.results to an arbitrary JSON value. final V1CreateResponse.BuilderaddResult(V1CreateResponse.Result result)Adds a single Result to results. final V1CreateResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final V1CreateResponse.BuilderputAdditionalProperty(String key, JsonValue value)final V1CreateResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final V1CreateResponse.BuilderremoveAdditionalProperty(String key)final V1CreateResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final V1CreateResponsebuild()Returns an immutable instance of V1CreateResponse. -
-
Method Detail
-
results
final V1CreateResponse.Builder results(List<V1CreateResponse.Result> results)
-
results
final V1CreateResponse.Builder results(JsonField<List<V1CreateResponse.Result>> results)
Sets Builder.results to an arbitrary JSON value.
You should usually call Builder.results with a well-typed
List<Result>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addResult
final V1CreateResponse.Builder addResult(V1CreateResponse.Result result)
-
additionalProperties
final V1CreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateResponse build()
Returns an immutable instance of V1CreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-