Package dev.case.api.models.memory.v1
Class V1CreateResponse.Result
-
- All Implemented Interfaces:
public final class V1CreateResponse.Result
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateResponse.Result.BuilderA builder for Result.
public final classV1CreateResponse.Result.EventWhat happened to this memory
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Memory ID final Optional<V1CreateResponse.Result.Event>event()What happened to this memory final Optional<String>memory()Extracted memory text final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<V1CreateResponse.Result.Event>_event()Returns the raw JSON value of event. final JsonField<String>_memory()Returns the raw JSON value of memory. final Map<String, JsonValue>_additionalProperties()final V1CreateResponse.Result.BuildertoBuilder()final V1CreateResponse.Resultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateResponse.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
event
final Optional<V1CreateResponse.Result.Event> event()
What happened to this memory
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_event
final JsonField<V1CreateResponse.Result.Event> _event()
Returns the raw JSON value of event.
Unlike event, this method doesn't throw if the JSON field has an unexpected type.
-
_memory
final JsonField<String> _memory()
Returns the raw JSON value of memory.
Unlike memory, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateResponse.Result.Builder toBuilder()
-
validate
final V1CreateResponse.Result validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1CreateResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-