Class V1CreateResponse.Result.Builder
-
- All Implemented Interfaces:
public final class V1CreateResponse.Result.BuilderA builder for Result.
-
-
Method Summary
-
-
Method Detail
-
id
final V1CreateResponse.Result.Builder id(String id)
Memory ID
-
id
final V1CreateResponse.Result.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
event
final V1CreateResponse.Result.Builder event(V1CreateResponse.Result.Event event)
What happened to this memory
-
event
final V1CreateResponse.Result.Builder event(JsonField<V1CreateResponse.Result.Event> event)
Sets Builder.event to an arbitrary JSON value.
You should usually call Builder.event with a well-typed Event value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memory
final V1CreateResponse.Result.Builder memory(String memory)
Extracted memory text
-
memory
final V1CreateResponse.Result.Builder memory(JsonField<String> memory)
Sets Builder.memory to an arbitrary JSON value.
You should usually call Builder.memory with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateResponse.Result.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateResponse.Result.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateResponse.Result.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateResponse.Result.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateResponse.Result.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateResponse.Result build()
Returns an immutable instance of Result.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-