Package dev.case.api.models.memory.v1
Class V1DeleteAllResponse
-
- All Implemented Interfaces:
public final class V1DeleteAllResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DeleteAllResponse.BuilderA builder for V1DeleteAllResponse.
-
Method Summary
Modifier and Type Method Description final Optional<Long>deleted()Number of memories deleted final JsonField<Long>_deleted()Returns the raw JSON value of deleted. final Map<String, JsonValue>_additionalProperties()final V1DeleteAllResponse.BuildertoBuilder()final V1DeleteAllResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DeleteAllResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1DeleteAllResponse. -
-
Method Detail
-
_deleted
final JsonField<Long> _deleted()
Returns the raw JSON value of deleted.
Unlike deleted, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DeleteAllResponse.Builder toBuilder()
-
validate
final V1DeleteAllResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1DeleteAllResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1DeleteAllResponse.
-
-
-
-