Package dev.case.api.models.memory.v1
Class V1DeleteResponse
-
- All Implemented Interfaces:
public final class V1DeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DeleteResponse.BuilderA builder for V1DeleteResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>message()final Optional<Boolean>success()final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final V1DeleteResponse.BuildertoBuilder()final V1DeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1DeleteResponse. -
-
Method Detail
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DeleteResponse.Builder toBuilder()
-
validate
final V1DeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1DeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1DeleteResponse.
-
-
-
-