Package dev.case.api.models.memory.v1
Class V1ListResponse
-
- All Implemented Interfaces:
public final class V1ListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListResponse.BuilderA builder for V1ListResponse.
public final classV1ListResponse.Result
-
Method Summary
Modifier and Type Method Description final Optional<Long>count()Total count matching filters final Optional<List<V1ListResponse.Result>>results()final JsonField<Long>_count()Returns the raw JSON value of count. final JsonField<List<V1ListResponse.Result>>_results()Returns the raw JSON value of results. final Map<String, JsonValue>_additionalProperties()final V1ListResponse.BuildertoBuilder()final V1ListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1ListResponse. -
-
Method Detail
-
results
final Optional<List<V1ListResponse.Result>> results()
-
_count
final JsonField<Long> _count()
Returns the raw JSON value of count.
Unlike count, this method doesn't throw if the JSON field has an unexpected type.
-
_results
final JsonField<List<V1ListResponse.Result>> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ListResponse.Builder toBuilder()
-
validate
final V1ListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ListResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1ListResponse.
-
-
-
-