Package dev.case.api.models.memory.v1
Class V1ListResponse.Builder
-
- All Implemented Interfaces:
public final class V1ListResponse.BuilderA builder for V1ListResponse.
-
-
Method Summary
-
-
Method Detail
-
count
final V1ListResponse.Builder count(Long count)
Total count matching filters
-
count
final V1ListResponse.Builder count(JsonField<Long> count)
Sets Builder.count to an arbitrary JSON value.
You should usually call Builder.count with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
results
final V1ListResponse.Builder results(List<V1ListResponse.Result> results)
-
results
final V1ListResponse.Builder results(JsonField<List<V1ListResponse.Result>> results)
Sets Builder.results to an arbitrary JSON value.
You should usually call Builder.results with a well-typed
List<Result>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addResult
final V1ListResponse.Builder addResult(V1ListResponse.Result result)
-
additionalProperties
final V1ListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1ListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1ListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1ListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1ListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1ListResponse build()
Returns an immutable instance of V1ListResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-