Class V1ListResponse.Result
-
- All Implemented Interfaces:
public final class V1ListResponse.Result
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListResponse.Result.BuilderA builder for Result.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<OffsetDateTime>createdAt()final Optional<String>memory()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = result.metadata().convert(MyClass.class);final JsonValue_tags()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = result.tags().convert(MyClass.class);final Optional<OffsetDateTime>updatedAt()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_memory()Returns the raw JSON value of memory. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final V1ListResponse.Result.BuildertoBuilder()final V1ListResponse.Resultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListResponse.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = result.metadata().convert(MyClass.class);
-
_tags
final JsonValue _tags()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = result.tags().convert(MyClass.class);
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_memory
final JsonField<String> _memory()
Returns the raw JSON value of memory.
Unlike memory, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ListResponse.Result.Builder toBuilder()
-
validate
final V1ListResponse.Result validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ListResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-