Class V1RetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class V1RetrieveResponse.BuilderA builder for V1RetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final V1RetrieveResponse.Builder id(String id)
Memory ID
-
id
final V1RetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final V1RetrieveResponse.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final V1RetrieveResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memory
final V1RetrieveResponse.Builder memory(String memory)
Memory content
-
memory
final V1RetrieveResponse.Builder memory(JsonField<String> memory)
Sets Builder.memory to an arbitrary JSON value.
You should usually call Builder.memory with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1RetrieveResponse.Builder metadata(JsonValue metadata)
Memory metadata
-
updatedAt
final V1RetrieveResponse.Builder updatedAt(OffsetDateTime updatedAt)
-
updatedAt
final V1RetrieveResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1RetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1RetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1RetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1RetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1RetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1RetrieveResponse build()
Returns an immutable instance of V1RetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-