Class V1SearchParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1SearchParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
query
final V1SearchParams.Body.Builder query(String query)
Search query for semantic matching
-
query
final V1SearchParams.Body.Builder query(JsonField<String> query)
Sets Builder.query to an arbitrary JSON value.
You should usually call Builder.query with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final V1SearchParams.Body.Builder category(String category)
Filter by category
-
category
final V1SearchParams.Body.Builder category(JsonField<String> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag1
final V1SearchParams.Body.Builder tag1(String tag1)
Filter by tag_1
-
tag1
final V1SearchParams.Body.Builder tag1(JsonField<String> tag1)
Sets Builder.tag1 to an arbitrary JSON value.
You should usually call Builder.tag1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag10
final V1SearchParams.Body.Builder tag10(String tag10)
Filter by tag_10
-
tag10
final V1SearchParams.Body.Builder tag10(JsonField<String> tag10)
Sets Builder.tag10 to an arbitrary JSON value.
You should usually call Builder.tag10 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag11
final V1SearchParams.Body.Builder tag11(String tag11)
Filter by tag_11
-
tag11
final V1SearchParams.Body.Builder tag11(JsonField<String> tag11)
Sets Builder.tag11 to an arbitrary JSON value.
You should usually call Builder.tag11 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag12
final V1SearchParams.Body.Builder tag12(String tag12)
Filter by tag_12
-
tag12
final V1SearchParams.Body.Builder tag12(JsonField<String> tag12)
Sets Builder.tag12 to an arbitrary JSON value.
You should usually call Builder.tag12 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag2
final V1SearchParams.Body.Builder tag2(String tag2)
Filter by tag_2
-
tag2
final V1SearchParams.Body.Builder tag2(JsonField<String> tag2)
Sets Builder.tag2 to an arbitrary JSON value.
You should usually call Builder.tag2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag3
final V1SearchParams.Body.Builder tag3(String tag3)
Filter by tag_3
-
tag3
final V1SearchParams.Body.Builder tag3(JsonField<String> tag3)
Sets Builder.tag3 to an arbitrary JSON value.
You should usually call Builder.tag3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag4
final V1SearchParams.Body.Builder tag4(String tag4)
Filter by tag_4
-
tag4
final V1SearchParams.Body.Builder tag4(JsonField<String> tag4)
Sets Builder.tag4 to an arbitrary JSON value.
You should usually call Builder.tag4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag5
final V1SearchParams.Body.Builder tag5(String tag5)
Filter by tag_5
-
tag5
final V1SearchParams.Body.Builder tag5(JsonField<String> tag5)
Sets Builder.tag5 to an arbitrary JSON value.
You should usually call Builder.tag5 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag6
final V1SearchParams.Body.Builder tag6(String tag6)
Filter by tag_6
-
tag6
final V1SearchParams.Body.Builder tag6(JsonField<String> tag6)
Sets Builder.tag6 to an arbitrary JSON value.
You should usually call Builder.tag6 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag7
final V1SearchParams.Body.Builder tag7(String tag7)
Filter by tag_7
-
tag7
final V1SearchParams.Body.Builder tag7(JsonField<String> tag7)
Sets Builder.tag7 to an arbitrary JSON value.
You should usually call Builder.tag7 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag8
final V1SearchParams.Body.Builder tag8(String tag8)
Filter by tag_8
-
tag8
final V1SearchParams.Body.Builder tag8(JsonField<String> tag8)
Sets Builder.tag8 to an arbitrary JSON value.
You should usually call Builder.tag8 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tag9
final V1SearchParams.Body.Builder tag9(String tag9)
Filter by tag_9
-
tag9
final V1SearchParams.Body.Builder tag9(JsonField<String> tag9)
Sets Builder.tag9 to an arbitrary JSON value.
You should usually call Builder.tag9 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topK
final V1SearchParams.Body.Builder topK(Long topK)
Maximum number of results to return
-
topK
final V1SearchParams.Body.Builder topK(JsonField<Long> topK)
Sets Builder.topK to an arbitrary JSON value.
You should usually call Builder.topK with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1SearchParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1SearchParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1SearchParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1SearchParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1SearchParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1SearchParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.query()
-
-
-
-