Package dev.case.api.models.memory.v1
Class V1SearchResponse
-
- All Implemented Interfaces:
public final class V1SearchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SearchResponse.BuilderA builder for V1SearchResponse.
public final classV1SearchResponse.Result
-
Method Summary
Modifier and Type Method Description final Optional<List<V1SearchResponse.Result>>results()final JsonField<List<V1SearchResponse.Result>>_results()Returns the raw JSON value of results. final Map<String, JsonValue>_additionalProperties()final V1SearchResponse.BuildertoBuilder()final V1SearchResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SearchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1SearchResponse. -
-
Method Detail
-
results
final Optional<List<V1SearchResponse.Result>> results()
-
_results
final JsonField<List<V1SearchResponse.Result>> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SearchResponse.Builder toBuilder()
-
validate
final V1SearchResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1SearchResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1SearchResponse.
-
-
-
-