Class V1SearchResponse.Result
-
- All Implemented Interfaces:
public final class V1SearchResponse.Result
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SearchResponse.Result.BuilderA builder for Result.
public final classV1SearchResponse.Result.TagsTag values for this memory
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Memory ID final Optional<OffsetDateTime>createdAt()final Optional<String>memory()Memory content final JsonValue_metadata()Additional metadataThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = result.metadata().convert(MyClass.class);final Optional<Double>score()Similarity score (0-1) final Optional<V1SearchResponse.Result.Tags>tags()Tag values for this memory final Optional<OffsetDateTime>updatedAt()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_memory()Returns the raw JSON value of memory. final JsonField<Double>_score()Returns the raw JSON value of score. final JsonField<V1SearchResponse.Result.Tags>_tags()Returns the raw JSON value of tags. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final V1SearchResponse.Result.BuildertoBuilder()final V1SearchResponse.Resultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SearchResponse.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
_metadata
final JsonValue _metadata()
Additional metadata
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = result.metadata().convert(MyClass.class);
-
tags
final Optional<V1SearchResponse.Result.Tags> tags()
Tag values for this memory
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_memory
final JsonField<String> _memory()
Returns the raw JSON value of memory.
Unlike memory, this method doesn't throw if the JSON field has an unexpected type.
-
_score
final JsonField<Double> _score()
Returns the raw JSON value of score.
Unlike score, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<V1SearchResponse.Result.Tags> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SearchResponse.Result.Builder toBuilder()
-
validate
final V1SearchResponse.Result validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1SearchResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-