Class V1SearchResponse.Result.Builder
-
- All Implemented Interfaces:
public final class V1SearchResponse.Result.BuilderA builder for Result.
-
-
Method Summary
-
-
Method Detail
-
id
final V1SearchResponse.Result.Builder id(String id)
Memory ID
-
id
final V1SearchResponse.Result.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final V1SearchResponse.Result.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final V1SearchResponse.Result.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memory
final V1SearchResponse.Result.Builder memory(String memory)
Memory content
-
memory
final V1SearchResponse.Result.Builder memory(JsonField<String> memory)
Sets Builder.memory to an arbitrary JSON value.
You should usually call Builder.memory with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1SearchResponse.Result.Builder metadata(JsonValue metadata)
Additional metadata
-
score
final V1SearchResponse.Result.Builder score(Double score)
Similarity score (0-1)
-
score
final V1SearchResponse.Result.Builder score(JsonField<Double> score)
Sets Builder.score to an arbitrary JSON value.
You should usually call Builder.score with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final V1SearchResponse.Result.Builder tags(V1SearchResponse.Result.Tags tags)
Tag values for this memory
-
tags
final V1SearchResponse.Result.Builder tags(JsonField<V1SearchResponse.Result.Tags> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed Tags value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final V1SearchResponse.Result.Builder updatedAt(OffsetDateTime updatedAt)
-
updatedAt
final V1SearchResponse.Result.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1SearchResponse.Result.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1SearchResponse.Result.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1SearchResponse.Result.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1SearchResponse.Result.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1SearchResponse.Result.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1SearchResponse.Result build()
Returns an immutable instance of Result.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-