Package dev.case.api.models.ocr.v1
Class V1DownloadParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1DownloadParams implements Params
Download OCR processing results in various formats. Returns the processed document as text extraction, structured JSON with coordinates, searchable PDF with text layer, or the original uploaded document.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DownloadParams.BuilderA builder for V1DownloadParams.
public final classV1DownloadParams.Type
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<V1DownloadParams.Type>type()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1DownloadParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DownloadParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1DownloadParams. -
-
Method Detail
-
type
final Optional<V1DownloadParams.Type> type()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1DownloadParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1DownloadParams.Builder builder()
Returns a mutable builder for constructing an instance of V1DownloadParams.
The following fields are required:
.id()
-
-
-
-