Class V1ProcessParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1ProcessParams implements Params
Submit a document for OCR processing to extract text, detect tables, forms, and other features. Supports PDFs, images, and scanned documents. Returns a job ID that can be used to track processing status.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ProcessParams.BuilderA builder for V1ProcessParams.
public final classV1ProcessParams.Bodypublic final classV1ProcessParams.EngineOCR engine to use
public final classV1ProcessParams.FeaturesAdditional processing options
-
Method Summary
Modifier and Type Method Description final StringdocumentUrl()URL or S3 path to the document to process final Optional<String>callbackUrl()URL to receive completion webhook final Optional<String>documentId()Optional custom document identifier final Optional<V1ProcessParams.Engine>engine()OCR engine to use final Optional<V1ProcessParams.Features>features()Additional processing options final Optional<String>resultBucket()S3 bucket to store results final Optional<String>resultPrefix()S3 key prefix for results final JsonField<String>_documentUrl()Returns the raw JSON value of documentUrl. final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final JsonField<String>_documentId()Returns the raw JSON value of documentId. final JsonField<V1ProcessParams.Engine>_engine()Returns the raw JSON value of engine. final JsonField<V1ProcessParams.Features>_features()Returns the raw JSON value of features. final JsonField<String>_resultBucket()Returns the raw JSON value of resultBucket. final JsonField<String>_resultPrefix()Returns the raw JSON value of resultPrefix. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1ProcessParams.BuildertoBuilder()final V1ProcessParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ProcessParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1ProcessParams. -
-
Method Detail
-
documentUrl
final String documentUrl()
URL or S3 path to the document to process
-
callbackUrl
final Optional<String> callbackUrl()
URL to receive completion webhook
-
documentId
final Optional<String> documentId()
Optional custom document identifier
-
engine
final Optional<V1ProcessParams.Engine> engine()
OCR engine to use
-
features
final Optional<V1ProcessParams.Features> features()
Additional processing options
-
resultBucket
final Optional<String> resultBucket()
S3 bucket to store results
-
resultPrefix
final Optional<String> resultPrefix()
S3 key prefix for results
-
_documentUrl
final JsonField<String> _documentUrl()
Returns the raw JSON value of documentUrl.
Unlike documentUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_documentId
final JsonField<String> _documentId()
Returns the raw JSON value of documentId.
Unlike documentId, this method doesn't throw if the JSON field has an unexpected type.
-
_engine
final JsonField<V1ProcessParams.Engine> _engine()
Returns the raw JSON value of engine.
Unlike engine, this method doesn't throw if the JSON field has an unexpected type.
-
_features
final JsonField<V1ProcessParams.Features> _features()
Returns the raw JSON value of features.
Unlike features, this method doesn't throw if the JSON field has an unexpected type.
-
_resultBucket
final JsonField<String> _resultBucket()
Returns the raw JSON value of resultBucket.
Unlike resultBucket, this method doesn't throw if the JSON field has an unexpected type.
-
_resultPrefix
final JsonField<String> _resultPrefix()
Returns the raw JSON value of resultPrefix.
Unlike resultPrefix, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1ProcessParams.Builder toBuilder()
-
_body
final V1ProcessParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1ProcessParams.Builder builder()
Returns a mutable builder for constructing an instance of V1ProcessParams.
The following fields are required:
.documentUrl()
-
-
-
-