Class V1ProcessParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1ProcessParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
documentUrl
final V1ProcessParams.Body.Builder documentUrl(String documentUrl)
URL or S3 path to the document to process
-
documentUrl
final V1ProcessParams.Body.Builder documentUrl(JsonField<String> documentUrl)
Sets Builder.documentUrl to an arbitrary JSON value.
You should usually call Builder.documentUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
callbackUrl
final V1ProcessParams.Body.Builder callbackUrl(String callbackUrl)
URL to receive completion webhook
-
callbackUrl
final V1ProcessParams.Body.Builder callbackUrl(JsonField<String> callbackUrl)
Sets Builder.callbackUrl to an arbitrary JSON value.
You should usually call Builder.callbackUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
documentId
final V1ProcessParams.Body.Builder documentId(String documentId)
Optional custom document identifier
-
documentId
final V1ProcessParams.Body.Builder documentId(JsonField<String> documentId)
Sets Builder.documentId to an arbitrary JSON value.
You should usually call Builder.documentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
engine
final V1ProcessParams.Body.Builder engine(V1ProcessParams.Engine engine)
OCR engine to use
-
engine
final V1ProcessParams.Body.Builder engine(JsonField<V1ProcessParams.Engine> engine)
Sets Builder.engine to an arbitrary JSON value.
You should usually call Builder.engine with a well-typed Engine value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
features
final V1ProcessParams.Body.Builder features(V1ProcessParams.Features features)
Additional processing options
-
features
final V1ProcessParams.Body.Builder features(JsonField<V1ProcessParams.Features> features)
Sets Builder.features to an arbitrary JSON value.
You should usually call Builder.features with a well-typed Features value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resultBucket
final V1ProcessParams.Body.Builder resultBucket(String resultBucket)
S3 bucket to store results
-
resultBucket
final V1ProcessParams.Body.Builder resultBucket(JsonField<String> resultBucket)
Sets Builder.resultBucket to an arbitrary JSON value.
You should usually call Builder.resultBucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resultPrefix
final V1ProcessParams.Body.Builder resultPrefix(String resultPrefix)
S3 key prefix for results
-
resultPrefix
final V1ProcessParams.Body.Builder resultPrefix(JsonField<String> resultPrefix)
Sets Builder.resultPrefix to an arbitrary JSON value.
You should usually call Builder.resultPrefix with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1ProcessParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1ProcessParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1ProcessParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1ProcessParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1ProcessParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1ProcessParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.documentUrl()
-
-
-
-