Package dev.case.api.models.ocr.v1
Class V1ProcessParams.Features
-
- All Implemented Interfaces:
public final class V1ProcessParams.FeaturesAdditional processing options
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ProcessParams.Features.BuilderA builder for Features.
public final classV1ProcessParams.Features.EmbedGenerate searchable PDF with text layer
public final classV1ProcessParams.Features.FormsDetect and extract form fields
public final classV1ProcessParams.Features.TablesExtract tables as structured data
-
Method Summary
Modifier and Type Method Description final Optional<V1ProcessParams.Features.Embed>embed()Generate searchable PDF with text layer final Optional<V1ProcessParams.Features.Forms>forms()Detect and extract form fields final Optional<V1ProcessParams.Features.Tables>tables()Extract tables as structured data final JsonField<V1ProcessParams.Features.Embed>_embed()Returns the raw JSON value of embed. final JsonField<V1ProcessParams.Features.Forms>_forms()Returns the raw JSON value of forms. final JsonField<V1ProcessParams.Features.Tables>_tables()Returns the raw JSON value of tables. final Map<String, JsonValue>_additionalProperties()final V1ProcessParams.Features.BuildertoBuilder()final V1ProcessParams.Featuresvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ProcessParams.Features.Builderbuilder()Returns a mutable builder for constructing an instance of Features. -
-
Method Detail
-
embed
final Optional<V1ProcessParams.Features.Embed> embed()
Generate searchable PDF with text layer
-
forms
final Optional<V1ProcessParams.Features.Forms> forms()
Detect and extract form fields
-
tables
final Optional<V1ProcessParams.Features.Tables> tables()
Extract tables as structured data
-
_embed
final JsonField<V1ProcessParams.Features.Embed> _embed()
Returns the raw JSON value of embed.
Unlike embed, this method doesn't throw if the JSON field has an unexpected type.
-
_forms
final JsonField<V1ProcessParams.Features.Forms> _forms()
Returns the raw JSON value of forms.
Unlike forms, this method doesn't throw if the JSON field has an unexpected type.
-
_tables
final JsonField<V1ProcessParams.Features.Tables> _tables()
Returns the raw JSON value of tables.
Unlike tables, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ProcessParams.Features.Builder toBuilder()
-
validate
final V1ProcessParams.Features validate()
-
builder
final static V1ProcessParams.Features.Builder builder()
Returns a mutable builder for constructing an instance of Features.
-
-
-
-