Package dev.case.api.models.ocr.v1
Class V1ProcessParams.Features.Tables
-
- All Implemented Interfaces:
public final class V1ProcessParams.Features.TablesExtract tables as structured data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ProcessParams.Features.Tables.BuilderA builder for Tables.
public final classV1ProcessParams.Features.Tables.FormatOutput format for extracted tables
-
Method Summary
Modifier and Type Method Description final Optional<V1ProcessParams.Features.Tables.Format>format()Output format for extracted tables final JsonField<V1ProcessParams.Features.Tables.Format>_format()Returns the raw JSON value of format. final Map<String, JsonValue>_additionalProperties()final V1ProcessParams.Features.Tables.BuildertoBuilder()final V1ProcessParams.Features.Tablesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ProcessParams.Features.Tables.Builderbuilder()Returns a mutable builder for constructing an instance of Tables. -
-
Method Detail
-
format
final Optional<V1ProcessParams.Features.Tables.Format> format()
Output format for extracted tables
-
_format
final JsonField<V1ProcessParams.Features.Tables.Format> _format()
Returns the raw JSON value of format.
Unlike format, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ProcessParams.Features.Tables.Builder toBuilder()
-
validate
final V1ProcessParams.Features.Tables validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ProcessParams.Features.Tables.Builder builder()
Returns a mutable builder for constructing an instance of Tables.
-
-
-
-