Package dev.case.api.models.ocr.v1
Class V1ProcessParams.Features.Tables.Builder
-
- All Implemented Interfaces:
public final class V1ProcessParams.Features.Tables.BuilderA builder for Tables.
-
-
Method Summary
Modifier and Type Method Description final V1ProcessParams.Features.Tables.Builderformat(V1ProcessParams.Features.Tables.Format format)Output format for extracted tables final V1ProcessParams.Features.Tables.Builderformat(JsonField<V1ProcessParams.Features.Tables.Format> format)Sets Builder.format to an arbitrary JSON value. final V1ProcessParams.Features.Tables.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final V1ProcessParams.Features.Tables.BuilderputAdditionalProperty(String key, JsonValue value)final V1ProcessParams.Features.Tables.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final V1ProcessParams.Features.Tables.BuilderremoveAdditionalProperty(String key)final V1ProcessParams.Features.Tables.BuilderremoveAllAdditionalProperties(Set<String> keys)final V1ProcessParams.Features.Tablesbuild()Returns an immutable instance of Tables. -
-
Method Detail
-
format
final V1ProcessParams.Features.Tables.Builder format(V1ProcessParams.Features.Tables.Format format)
Output format for extracted tables
-
format
final V1ProcessParams.Features.Tables.Builder format(JsonField<V1ProcessParams.Features.Tables.Format> format)
Sets Builder.format to an arbitrary JSON value.
You should usually call Builder.format with a well-typed Format value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1ProcessParams.Features.Tables.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1ProcessParams.Features.Tables.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1ProcessParams.Features.Tables.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1ProcessParams.Features.Tables.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1ProcessParams.Features.Tables.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1ProcessParams.Features.Tables build()
Returns an immutable instance of Tables.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-