Class V1ProcessResponse
-
- All Implemented Interfaces:
public final class V1ProcessResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ProcessResponse.BuilderA builder for V1ProcessResponse.
public final classV1ProcessResponse.StatusCurrent job status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique job identifier final Optional<OffsetDateTime>createdAt()Job creation timestamp final Optional<String>documentId()Document identifier final Optional<String>engine()OCR engine used final Optional<OffsetDateTime>estimatedCompletion()Estimated completion time final Optional<Long>pageCount()Number of pages detected final Optional<V1ProcessResponse.Status>status()Current job status final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_documentId()Returns the raw JSON value of documentId. final JsonField<String>_engine()Returns the raw JSON value of engine. final JsonField<OffsetDateTime>_estimatedCompletion()Returns the raw JSON value of estimatedCompletion. final JsonField<Long>_pageCount()Returns the raw JSON value of pageCount. final JsonField<V1ProcessResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final V1ProcessResponse.BuildertoBuilder()final V1ProcessResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ProcessResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1ProcessResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Job creation timestamp
-
documentId
final Optional<String> documentId()
Document identifier
-
estimatedCompletion
final Optional<OffsetDateTime> estimatedCompletion()
Estimated completion time
-
status
final Optional<V1ProcessResponse.Status> status()
Current job status
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_documentId
final JsonField<String> _documentId()
Returns the raw JSON value of documentId.
Unlike documentId, this method doesn't throw if the JSON field has an unexpected type.
-
_engine
final JsonField<String> _engine()
Returns the raw JSON value of engine.
Unlike engine, this method doesn't throw if the JSON field has an unexpected type.
-
_estimatedCompletion
final JsonField<OffsetDateTime> _estimatedCompletion()
Returns the raw JSON value of estimatedCompletion.
Unlike estimatedCompletion, this method doesn't throw if the JSON field has an unexpected type.
-
_pageCount
final JsonField<Long> _pageCount()
Returns the raw JSON value of pageCount.
Unlike pageCount, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<V1ProcessResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ProcessResponse.Builder toBuilder()
-
validate
final V1ProcessResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ProcessResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1ProcessResponse.
-
-
-
-