Class V1RetrieveResponse
-
- All Implemented Interfaces:
public final class V1RetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1RetrieveResponse.BuilderA builder for V1RetrieveResponse.
public final classV1RetrieveResponse.StatusCurrent job status
-
Method Summary
Modifier and Type Method Description final Stringid()OCR job ID final OffsetDateTimecreatedAt()Job creation timestamp final V1RetrieveResponse.Statusstatus()Current job status final Optional<OffsetDateTime>completedAt()Job completion timestamp final JsonValue_metadata()Additional processing metadataThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = v1RetrieveResponse.metadata().convert(MyClass.class);final Optional<Long>pageCount()Number of pages processed final Optional<String>text()Extracted text content (when completed) final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<V1RetrieveResponse.Status>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final JsonField<Long>_pageCount()Returns the raw JSON value of pageCount. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final V1RetrieveResponse.BuildertoBuilder()final V1RetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1RetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1RetrieveResponse. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
Job creation timestamp
-
status
final V1RetrieveResponse.Status status()
Current job status
-
completedAt
final Optional<OffsetDateTime> completedAt()
Job completion timestamp
-
_metadata
final JsonValue _metadata()
Additional processing metadata
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = v1RetrieveResponse.metadata().convert(MyClass.class);
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<V1RetrieveResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_pageCount
final JsonField<Long> _pageCount()
Returns the raw JSON value of pageCount.
Unlike pageCount, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1RetrieveResponse.Builder toBuilder()
-
validate
final V1RetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1RetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1RetrieveResponse.
The following fields are required:
.id() .createdAt() .status()
-
-
-
-