Class V1RetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class V1RetrieveResponse.BuilderA builder for V1RetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final V1RetrieveResponse.Builder id(String id)
OCR job ID
-
id
final V1RetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final V1RetrieveResponse.Builder createdAt(OffsetDateTime createdAt)
Job creation timestamp
-
createdAt
final V1RetrieveResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final V1RetrieveResponse.Builder status(V1RetrieveResponse.Status status)
Current job status
-
status
final V1RetrieveResponse.Builder status(JsonField<V1RetrieveResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final V1RetrieveResponse.Builder completedAt(OffsetDateTime completedAt)
Job completion timestamp
-
completedAt
final V1RetrieveResponse.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final V1RetrieveResponse.Builder metadata(JsonValue metadata)
Additional processing metadata
-
pageCount
final V1RetrieveResponse.Builder pageCount(Long pageCount)
Number of pages processed
-
pageCount
final V1RetrieveResponse.Builder pageCount(JsonField<Long> pageCount)
Sets Builder.pageCount to an arbitrary JSON value.
You should usually call Builder.pageCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final V1RetrieveResponse.Builder text(String text)
Extracted text content (when completed)
-
text
final V1RetrieveResponse.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1RetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1RetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1RetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1RetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1RetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1RetrieveResponse build()
Returns an immutable instance of V1RetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .status()
-
-
-
-