Class V1CreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1CreateParams implements Params
Provision a new operator instance for the organization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateParams.BuilderA builder for V1CreateParams.
public final classV1CreateParams.Bodypublic final classV1CreateParams.SizeInstance size
-
Method Summary
Modifier and Type Method Description final Stringname()Operator name final Optional<String>model()Model to use final Optional<V1CreateParams.Size>size()Instance size final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<V1CreateParams.Size>_size()Returns the raw JSON value of size. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1CreateParams.BuildertoBuilder()final V1CreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1CreateParams. -
-
Method Detail
-
size
final Optional<V1CreateParams.Size> size()
Instance size
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_size
final JsonField<V1CreateParams.Size> _size()
Returns the raw JSON value of size.
Unlike size, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1CreateParams.Builder toBuilder()
-
_body
final V1CreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1CreateParams.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateParams.
The following fields are required:
.name()
-
-
-
-