Package dev.case.api.models.operator.v1
Class V1CreateParams.Body
-
- All Implemented Interfaces:
public final class V1CreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()Operator name final Optional<String>model()Model to use final Optional<V1CreateParams.Size>size()Instance size final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<V1CreateParams.Size>_size()Returns the raw JSON value of size. final Map<String, JsonValue>_additionalProperties()final V1CreateParams.Body.BuildertoBuilder()final V1CreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
size
final Optional<V1CreateParams.Size> size()
Instance size
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_size
final JsonField<V1CreateParams.Size> _size()
Returns the raw JSON value of size.
Unlike size, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateParams.Body.Builder toBuilder()
-
validate
final V1CreateParams.Body validate()
-
builder
final static V1CreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-