Class V1CreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1CreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
name
final V1CreateParams.Body.Builder name(String name)
Operator name
-
name
final V1CreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final V1CreateParams.Body.Builder model(String model)
Model to use
-
model
final V1CreateParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
size
final V1CreateParams.Body.Builder size(V1CreateParams.Size size)
Instance size
-
size
final V1CreateParams.Body.Builder size(JsonField<V1CreateParams.Size> size)
Sets Builder.size to an arbitrary JSON value.
You should usually call Builder.size with a well-typed Size value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1CreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1CreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1CreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1CreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1CreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1CreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-