Class V1DetectParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1DetectParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
categories
final V1DetectParams.Body.Builder categories(List<V1DetectParams.Category> categories)
Privilege categories to check. Defaults to all: attorney_client, work_product, common_interest
-
categories
final V1DetectParams.Body.Builder categories(JsonField<List<V1DetectParams.Category>> categories)
Sets Builder.categories to an arbitrary JSON value.
You should usually call Builder.categories with a well-typed
List<Category>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCategory
final V1DetectParams.Body.Builder addCategory(V1DetectParams.Category category)
Adds a single Category to categories.
-
content
final V1DetectParams.Body.Builder content(String content)
Text content to analyze (required if document_id not provided)
-
content
final V1DetectParams.Body.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
documentId
final V1DetectParams.Body.Builder documentId(String documentId)
Vault object ID to analyze (required if content not provided)
-
documentId
final V1DetectParams.Body.Builder documentId(JsonField<String> documentId)
Sets Builder.documentId to an arbitrary JSON value.
You should usually call Builder.documentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
includeRationale
final V1DetectParams.Body.Builder includeRationale(Boolean includeRationale)
Include detailed rationale for each category
-
includeRationale
final V1DetectParams.Body.Builder includeRationale(JsonField<Boolean> includeRationale)
Sets Builder.includeRationale to an arbitrary JSON value.
You should usually call Builder.includeRationale with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jurisdiction
final V1DetectParams.Body.Builder jurisdiction(V1DetectParams.Jurisdiction jurisdiction)
Jurisdiction for privilege rules
-
jurisdiction
final V1DetectParams.Body.Builder jurisdiction(JsonField<V1DetectParams.Jurisdiction> jurisdiction)
Sets Builder.jurisdiction to an arbitrary JSON value.
You should usually call Builder.jurisdiction with a well-typed Jurisdiction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final V1DetectParams.Body.Builder model(String model)
LLM model to use for analysis
-
model
final V1DetectParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final V1DetectParams.Body.Builder vaultId(String vaultId)
Vault ID (required when using document_id)
-
vaultId
final V1DetectParams.Body.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1DetectParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1DetectParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1DetectParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1DetectParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1DetectParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1DetectParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-