Class V1DetectResponse.Builder
-
- All Implemented Interfaces:
public final class V1DetectResponse.BuilderA builder for V1DetectResponse.
-
-
Method Summary
-
-
Method Detail
-
categories
final V1DetectResponse.Builder categories(List<V1DetectResponse.Category> categories)
-
categories
final V1DetectResponse.Builder categories(JsonField<List<V1DetectResponse.Category>> categories)
Sets Builder.categories to an arbitrary JSON value.
You should usually call Builder.categories with a well-typed
List<Category>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCategory
final V1DetectResponse.Builder addCategory(V1DetectResponse.Category category)
Adds a single Category to categories.
-
confidence
final V1DetectResponse.Builder confidence(Double confidence)
Overall confidence score (0-1)
-
confidence
final V1DetectResponse.Builder confidence(JsonField<Double> confidence)
Sets Builder.confidence to an arbitrary JSON value.
You should usually call Builder.confidence with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
policyRationale
final V1DetectResponse.Builder policyRationale(String policyRationale)
Policy-friendly explanation for privilege log
-
policyRationale
final V1DetectResponse.Builder policyRationale(JsonField<String> policyRationale)
Sets Builder.policyRationale to an arbitrary JSON value.
You should usually call Builder.policyRationale with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
privileged
final V1DetectResponse.Builder privileged(Boolean privileged)
Whether any privilege was detected
-
privileged
final V1DetectResponse.Builder privileged(JsonField<Boolean> privileged)
Sets Builder.privileged to an arbitrary JSON value.
You should usually call Builder.privileged with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recommendation
final V1DetectResponse.Builder recommendation(V1DetectResponse.Recommendation recommendation)
Recommended action for discovery
-
recommendation
final V1DetectResponse.Builder recommendation(JsonField<V1DetectResponse.Recommendation> recommendation)
Sets Builder.recommendation to an arbitrary JSON value.
You should usually call Builder.recommendation with a well-typed Recommendation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1DetectResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1DetectResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1DetectResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1DetectResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1DetectResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1DetectResponse build()
Returns an immutable instance of V1DetectResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.categories() .confidence() .policyRationale() .privileged() .recommendation()
-
-
-
-