Class V1DetectResponse.Category.Builder
-
- All Implemented Interfaces:
public final class V1DetectResponse.Category.BuilderA builder for Category.
-
-
Method Summary
-
-
Method Detail
-
confidence
final V1DetectResponse.Category.Builder confidence(Double confidence)
Confidence for this category (0-1)
-
confidence
final V1DetectResponse.Category.Builder confidence(JsonField<Double> confidence)
Sets Builder.confidence to an arbitrary JSON value.
You should usually call Builder.confidence with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
detected
final V1DetectResponse.Category.Builder detected(Boolean detected)
Whether this privilege type was detected
-
detected
final V1DetectResponse.Category.Builder detected(JsonField<Boolean> detected)
Sets Builder.detected to an arbitrary JSON value.
You should usually call Builder.detected with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
indicators
final V1DetectResponse.Category.Builder indicators(List<String> indicators)
Specific phrases or patterns found
-
indicators
final V1DetectResponse.Category.Builder indicators(JsonField<List<String>> indicators)
Sets Builder.indicators to an arbitrary JSON value.
You should usually call Builder.indicators with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addIndicator
final V1DetectResponse.Category.Builder addIndicator(String indicator)
Adds a single String to indicators.
-
rationale
final V1DetectResponse.Category.Builder rationale(String rationale)
Explanation of detection result
-
rationale
final V1DetectResponse.Category.Builder rationale(JsonField<String> rationale)
Sets Builder.rationale to an arbitrary JSON value.
You should usually call Builder.rationale with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final V1DetectResponse.Category.Builder type(String type)
Privilege category
-
type
final V1DetectResponse.Category.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1DetectResponse.Category.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1DetectResponse.Category.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1DetectResponse.Category.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1DetectResponse.Category.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1DetectResponse.Category.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1DetectResponse.Category build()
Returns an immutable instance of Category.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-