Class V1AnswerParams.Body
-
- All Implemented Interfaces:
public final class V1AnswerParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnswerParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringquery()The question or topic to research and answer final Optional<List<String>>excludeDomains()Exclude these domains from search final Optional<List<String>>includeDomains()Only search within these domains final Optional<Long>maxTokens()Maximum tokens for LLM response final Optional<String>model()LLM model to use when useCustomLLM is true final Optional<Long>numResults()Number of search results to consider final Optional<V1AnswerParams.SearchType>searchType()Type of search to perform final Optional<Boolean>stream()Stream the response (only for native provider answers) final Optional<Double>temperature()LLM temperature for answer generation final Optional<Boolean>text()Include text content in response final Optional<Boolean>useCustomLlm()Use Case. final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<List<String>>_excludeDomains()Returns the raw JSON value of excludeDomains. final JsonField<List<String>>_includeDomains()Returns the raw JSON value of includeDomains. final JsonField<Long>_maxTokens()Returns the raw JSON value of maxTokens. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<Long>_numResults()Returns the raw JSON value of numResults. final JsonField<V1AnswerParams.SearchType>_searchType()Returns the raw JSON value of searchType. final JsonField<Boolean>_stream()Returns the raw JSON value of stream. final JsonField<Double>_temperature()Returns the raw JSON value of temperature. final JsonField<Boolean>_text()Returns the raw JSON value of text. final JsonField<Boolean>_useCustomLlm()Returns the raw JSON value of useCustomLlm. final Map<String, JsonValue>_additionalProperties()final V1AnswerParams.Body.BuildertoBuilder()final V1AnswerParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnswerParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
excludeDomains
final Optional<List<String>> excludeDomains()
Exclude these domains from search
-
includeDomains
final Optional<List<String>> includeDomains()
Only search within these domains
-
numResults
final Optional<Long> numResults()
Number of search results to consider
-
searchType
final Optional<V1AnswerParams.SearchType> searchType()
Type of search to perform
-
temperature
final Optional<Double> temperature()
LLM temperature for answer generation
-
useCustomLlm
final Optional<Boolean> useCustomLlm()
Use Case.dev LLM for answer generation instead of provider's native answer
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_excludeDomains
final JsonField<List<String>> _excludeDomains()
Returns the raw JSON value of excludeDomains.
Unlike excludeDomains, this method doesn't throw if the JSON field has an unexpected type.
-
_includeDomains
final JsonField<List<String>> _includeDomains()
Returns the raw JSON value of includeDomains.
Unlike includeDomains, this method doesn't throw if the JSON field has an unexpected type.
-
_maxTokens
final JsonField<Long> _maxTokens()
Returns the raw JSON value of maxTokens.
Unlike maxTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_numResults
final JsonField<Long> _numResults()
Returns the raw JSON value of numResults.
Unlike numResults, this method doesn't throw if the JSON field has an unexpected type.
-
_searchType
final JsonField<V1AnswerParams.SearchType> _searchType()
Returns the raw JSON value of searchType.
Unlike searchType, this method doesn't throw if the JSON field has an unexpected type.
-
_stream
final JsonField<Boolean> _stream()
Returns the raw JSON value of stream.
Unlike stream, this method doesn't throw if the JSON field has an unexpected type.
-
_temperature
final JsonField<Double> _temperature()
Returns the raw JSON value of temperature.
Unlike temperature, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<Boolean> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_useCustomLlm
final JsonField<Boolean> _useCustomLlm()
Returns the raw JSON value of useCustomLlm.
Unlike useCustomLlm, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1AnswerParams.Body.Builder toBuilder()
-
validate
final V1AnswerParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1AnswerParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.query()
-
-
-
-