Class V1AnswerParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1AnswerParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
query
final V1AnswerParams.Body.Builder query(String query)
The question or topic to research and answer
-
query
final V1AnswerParams.Body.Builder query(JsonField<String> query)
Sets Builder.query to an arbitrary JSON value.
You should usually call Builder.query with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
excludeDomains
final V1AnswerParams.Body.Builder excludeDomains(List<String> excludeDomains)
Exclude these domains from search
-
excludeDomains
final V1AnswerParams.Body.Builder excludeDomains(JsonField<List<String>> excludeDomains)
Sets Builder.excludeDomains to an arbitrary JSON value.
You should usually call Builder.excludeDomains with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExcludeDomain
final V1AnswerParams.Body.Builder addExcludeDomain(String excludeDomain)
Adds a single String to excludeDomains.
-
includeDomains
final V1AnswerParams.Body.Builder includeDomains(List<String> includeDomains)
Only search within these domains
-
includeDomains
final V1AnswerParams.Body.Builder includeDomains(JsonField<List<String>> includeDomains)
Sets Builder.includeDomains to an arbitrary JSON value.
You should usually call Builder.includeDomains with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addIncludeDomain
final V1AnswerParams.Body.Builder addIncludeDomain(String includeDomain)
Adds a single String to includeDomains.
-
maxTokens
final V1AnswerParams.Body.Builder maxTokens(Long maxTokens)
Maximum tokens for LLM response
-
maxTokens
final V1AnswerParams.Body.Builder maxTokens(JsonField<Long> maxTokens)
Sets Builder.maxTokens to an arbitrary JSON value.
You should usually call Builder.maxTokens with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final V1AnswerParams.Body.Builder model(String model)
LLM model to use when useCustomLLM is true
-
model
final V1AnswerParams.Body.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
numResults
final V1AnswerParams.Body.Builder numResults(Long numResults)
Number of search results to consider
-
numResults
final V1AnswerParams.Body.Builder numResults(JsonField<Long> numResults)
Sets Builder.numResults to an arbitrary JSON value.
You should usually call Builder.numResults with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
searchType
final V1AnswerParams.Body.Builder searchType(V1AnswerParams.SearchType searchType)
Type of search to perform
-
searchType
final V1AnswerParams.Body.Builder searchType(JsonField<V1AnswerParams.SearchType> searchType)
Sets Builder.searchType to an arbitrary JSON value.
You should usually call Builder.searchType with a well-typed SearchType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stream
final V1AnswerParams.Body.Builder stream(Boolean stream)
Stream the response (only for native provider answers)
-
stream
final V1AnswerParams.Body.Builder stream(JsonField<Boolean> stream)
Sets Builder.stream to an arbitrary JSON value.
You should usually call Builder.stream with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
temperature
final V1AnswerParams.Body.Builder temperature(Double temperature)
LLM temperature for answer generation
-
temperature
final V1AnswerParams.Body.Builder temperature(JsonField<Double> temperature)
Sets Builder.temperature to an arbitrary JSON value.
You should usually call Builder.temperature with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final V1AnswerParams.Body.Builder text(Boolean text)
Include text content in response
-
text
final V1AnswerParams.Body.Builder text(JsonField<Boolean> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
useCustomLlm
final V1AnswerParams.Body.Builder useCustomLlm(Boolean useCustomLlm)
Use Case.dev LLM for answer generation instead of provider's native answer
-
useCustomLlm
final V1AnswerParams.Body.Builder useCustomLlm(JsonField<Boolean> useCustomLlm)
Sets Builder.useCustomLlm to an arbitrary JSON value.
You should usually call Builder.useCustomLlm with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1AnswerParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1AnswerParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1AnswerParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1AnswerParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1AnswerParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1AnswerParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.query()
-
-
-
-