Class V1AnswerResponse
-
- All Implemented Interfaces:
public final class V1AnswerResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnswerResponse.BuilderA builder for V1AnswerResponse.
public final classV1AnswerResponse.Citation
-
Method Summary
Modifier and Type Method Description final Optional<String>answer()The generated answer with citations final Optional<List<V1AnswerResponse.Citation>>citations()Sources used to generate the answer final Optional<String>model()Model used for answer generation final Optional<String>searchType()Type of search performed final JsonField<String>_answer()Returns the raw JSON value of answer. final JsonField<List<V1AnswerResponse.Citation>>_citations()Returns the raw JSON value of citations. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_searchType()Returns the raw JSON value of searchType. final Map<String, JsonValue>_additionalProperties()final V1AnswerResponse.BuildertoBuilder()final V1AnswerResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnswerResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1AnswerResponse. -
-
Method Detail
-
citations
final Optional<List<V1AnswerResponse.Citation>> citations()
Sources used to generate the answer
-
searchType
final Optional<String> searchType()
Type of search performed
-
_answer
final JsonField<String> _answer()
Returns the raw JSON value of answer.
Unlike answer, this method doesn't throw if the JSON field has an unexpected type.
-
_citations
final JsonField<List<V1AnswerResponse.Citation>> _citations()
Returns the raw JSON value of citations.
Unlike citations, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_searchType
final JsonField<String> _searchType()
Returns the raw JSON value of searchType.
Unlike searchType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1AnswerResponse.Builder toBuilder()
-
validate
final V1AnswerResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1AnswerResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1AnswerResponse.
-
-
-
-