Class V1AnswerResponse.Builder
-
- All Implemented Interfaces:
public final class V1AnswerResponse.BuilderA builder for V1AnswerResponse.
-
-
Method Summary
-
-
Method Detail
-
answer
final V1AnswerResponse.Builder answer(String answer)
The generated answer with citations
-
answer
final V1AnswerResponse.Builder answer(JsonField<String> answer)
Sets Builder.answer to an arbitrary JSON value.
You should usually call Builder.answer with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
citations
final V1AnswerResponse.Builder citations(List<V1AnswerResponse.Citation> citations)
Sources used to generate the answer
-
citations
final V1AnswerResponse.Builder citations(JsonField<List<V1AnswerResponse.Citation>> citations)
Sets Builder.citations to an arbitrary JSON value.
You should usually call Builder.citations with a well-typed
List<Citation>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCitation
final V1AnswerResponse.Builder addCitation(V1AnswerResponse.Citation citation)
-
model
final V1AnswerResponse.Builder model(String model)
Model used for answer generation
-
model
final V1AnswerResponse.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
searchType
final V1AnswerResponse.Builder searchType(String searchType)
Type of search performed
-
searchType
final V1AnswerResponse.Builder searchType(JsonField<String> searchType)
Sets Builder.searchType to an arbitrary JSON value.
You should usually call Builder.searchType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1AnswerResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1AnswerResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1AnswerResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1AnswerResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1AnswerResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1AnswerResponse build()
Returns an immutable instance of V1AnswerResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-