Class V1AnswerResponse.Citation
-
- All Implemented Interfaces:
public final class V1AnswerResponse.Citation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnswerResponse.Citation.BuilderA builder for Citation.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>publishedDate()final Optional<String>text()final Optional<String>title()final Optional<String>url()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_publishedDate()Returns the raw JSON value of publishedDate. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final V1AnswerResponse.Citation.BuildertoBuilder()final V1AnswerResponse.Citationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnswerResponse.Citation.Builderbuilder()Returns a mutable builder for constructing an instance of Citation. -
-
Method Detail
-
publishedDate
final Optional<String> publishedDate()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_publishedDate
final JsonField<String> _publishedDate()
Returns the raw JSON value of publishedDate.
Unlike publishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1AnswerResponse.Citation.Builder toBuilder()
-
validate
final V1AnswerResponse.Citation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1AnswerResponse.Citation.Builder builder()
Returns a mutable builder for constructing an instance of Citation.
-
-
-
-