Class V1ContentsParams.Body
-
- All Implemented Interfaces:
public final class V1ContentsParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ContentsParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<String>urls()Array of URLs to scrape and extract content from final Optional<String>context()Context to guide content extraction and summarization final JsonValue_extras()Additional extraction optionsThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.extras().convert(MyClass.class);final Optional<Boolean>highlights()Whether to include content highlights final Optional<Boolean>livecrawl()Whether to perform live crawling for dynamic content final Optional<Long>livecrawlTimeout()Timeout in seconds for live crawling final Optional<Boolean>subpages()Whether to extract content from linked subpages final Optional<Long>subpageTarget()Maximum number of subpages to crawl final Optional<Boolean>summary()Whether to generate content summaries final Optional<Boolean>text()Whether to extract text content final JsonField<List<String>>_urls()Returns the raw JSON value of urls. final JsonField<String>_context()Returns the raw JSON value of context. final JsonField<Boolean>_highlights()Returns the raw JSON value of highlights. final JsonField<Boolean>_livecrawl()Returns the raw JSON value of livecrawl. final JsonField<Long>_livecrawlTimeout()Returns the raw JSON value of livecrawlTimeout. final JsonField<Boolean>_subpages()Returns the raw JSON value of subpages. final JsonField<Long>_subpageTarget()Returns the raw JSON value of subpageTarget. final JsonField<Boolean>_summary()Returns the raw JSON value of summary. final JsonField<Boolean>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final V1ContentsParams.Body.BuildertoBuilder()final V1ContentsParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ContentsParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_extras
final JsonValue _extras()
Additional extraction options
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.extras().convert(MyClass.class);
-
highlights
final Optional<Boolean> highlights()
Whether to include content highlights
-
livecrawlTimeout
final Optional<Long> livecrawlTimeout()
Timeout in seconds for live crawling
-
subpageTarget
final Optional<Long> subpageTarget()
Maximum number of subpages to crawl
-
_urls
final JsonField<List<String>> _urls()
Returns the raw JSON value of urls.
Unlike urls, this method doesn't throw if the JSON field has an unexpected type.
-
_context
final JsonField<String> _context()
Returns the raw JSON value of context.
Unlike context, this method doesn't throw if the JSON field has an unexpected type.
-
_highlights
final JsonField<Boolean> _highlights()
Returns the raw JSON value of highlights.
Unlike highlights, this method doesn't throw if the JSON field has an unexpected type.
-
_livecrawl
final JsonField<Boolean> _livecrawl()
Returns the raw JSON value of livecrawl.
Unlike livecrawl, this method doesn't throw if the JSON field has an unexpected type.
-
_livecrawlTimeout
final JsonField<Long> _livecrawlTimeout()
Returns the raw JSON value of livecrawlTimeout.
Unlike livecrawlTimeout, this method doesn't throw if the JSON field has an unexpected type.
-
_subpages
final JsonField<Boolean> _subpages()
Returns the raw JSON value of subpages.
Unlike subpages, this method doesn't throw if the JSON field has an unexpected type.
-
_subpageTarget
final JsonField<Long> _subpageTarget()
Returns the raw JSON value of subpageTarget.
Unlike subpageTarget, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<Boolean> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<Boolean> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ContentsParams.Body.Builder toBuilder()
-
validate
final V1ContentsParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ContentsParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.urls()
-
-
-
-