Class V1ContentsParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1ContentsParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
urls
final V1ContentsParams.Body.Builder urls(List<String> urls)
Array of URLs to scrape and extract content from
-
urls
final V1ContentsParams.Body.Builder urls(JsonField<List<String>> urls)
Sets Builder.urls to an arbitrary JSON value.
You should usually call Builder.urls with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addUrl
final V1ContentsParams.Body.Builder addUrl(String url)
-
context
final V1ContentsParams.Body.Builder context(String context)
Context to guide content extraction and summarization
-
context
final V1ContentsParams.Body.Builder context(JsonField<String> context)
Sets Builder.context to an arbitrary JSON value.
You should usually call Builder.context with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extras
final V1ContentsParams.Body.Builder extras(JsonValue extras)
Additional extraction options
-
highlights
final V1ContentsParams.Body.Builder highlights(Boolean highlights)
Whether to include content highlights
-
highlights
final V1ContentsParams.Body.Builder highlights(JsonField<Boolean> highlights)
Sets Builder.highlights to an arbitrary JSON value.
You should usually call Builder.highlights with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
livecrawl
final V1ContentsParams.Body.Builder livecrawl(Boolean livecrawl)
Whether to perform live crawling for dynamic content
-
livecrawl
final V1ContentsParams.Body.Builder livecrawl(JsonField<Boolean> livecrawl)
Sets Builder.livecrawl to an arbitrary JSON value.
You should usually call Builder.livecrawl with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
livecrawlTimeout
final V1ContentsParams.Body.Builder livecrawlTimeout(Long livecrawlTimeout)
Timeout in seconds for live crawling
-
livecrawlTimeout
final V1ContentsParams.Body.Builder livecrawlTimeout(JsonField<Long> livecrawlTimeout)
Sets Builder.livecrawlTimeout to an arbitrary JSON value.
You should usually call Builder.livecrawlTimeout with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
subpages
final V1ContentsParams.Body.Builder subpages(Boolean subpages)
Whether to extract content from linked subpages
-
subpages
final V1ContentsParams.Body.Builder subpages(JsonField<Boolean> subpages)
Sets Builder.subpages to an arbitrary JSON value.
You should usually call Builder.subpages with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
subpageTarget
final V1ContentsParams.Body.Builder subpageTarget(Long subpageTarget)
Maximum number of subpages to crawl
-
subpageTarget
final V1ContentsParams.Body.Builder subpageTarget(JsonField<Long> subpageTarget)
Sets Builder.subpageTarget to an arbitrary JSON value.
You should usually call Builder.subpageTarget with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
summary
final V1ContentsParams.Body.Builder summary(Boolean summary)
Whether to generate content summaries
-
summary
final V1ContentsParams.Body.Builder summary(JsonField<Boolean> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final V1ContentsParams.Body.Builder text(Boolean text)
Whether to extract text content
-
text
final V1ContentsParams.Body.Builder text(JsonField<Boolean> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1ContentsParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1ContentsParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1ContentsParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1ContentsParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1ContentsParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1ContentsParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.urls()
-
-
-
-