Class V1ContentsResponse.Result.Builder
-
- All Implemented Interfaces:
public final class V1ContentsResponse.Result.BuilderA builder for Result.
-
-
Method Summary
-
-
Method Detail
-
highlights
final V1ContentsResponse.Result.Builder highlights(List<String> highlights)
Content highlights if requested
-
highlights
final V1ContentsResponse.Result.Builder highlights(JsonField<List<String>> highlights)
Sets Builder.highlights to an arbitrary JSON value.
You should usually call Builder.highlights with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addHighlight
final V1ContentsResponse.Result.Builder addHighlight(String highlight)
Adds a single String to highlights.
-
metadata
final V1ContentsResponse.Result.Builder metadata(JsonValue metadata)
Additional metadata about the content
-
summary
final V1ContentsResponse.Result.Builder summary(String summary)
Content summary if requested
-
summary
final V1ContentsResponse.Result.Builder summary(JsonField<String> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final V1ContentsResponse.Result.Builder text(String text)
Extracted text content
-
text
final V1ContentsResponse.Result.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
title
final V1ContentsResponse.Result.Builder title(String title)
Page title
-
title
final V1ContentsResponse.Result.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final V1ContentsResponse.Result.Builder url(String url)
Source URL
-
url
final V1ContentsResponse.Result.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1ContentsResponse.Result.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1ContentsResponse.Result.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1ContentsResponse.Result.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1ContentsResponse.Result.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1ContentsResponse.Result.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1ContentsResponse.Result build()
Returns an immutable instance of Result.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-