Class V1ResearchParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1ResearchParams implements Params
Performs deep research by conducting multi-step analysis, gathering information from multiple sources, and providing comprehensive insights. Ideal for legal research, case analysis, and due diligence investigations.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ResearchParams.BuilderA builder for V1ResearchParams.
public final classV1ResearchParams.Bodypublic final classV1ResearchParams.ModelResearch quality level - fast (quick), normal (balanced), pro (comprehensive)
-
Method Summary
Modifier and Type Method Description final Stringinstructions()Research instructions or query final Optional<V1ResearchParams.Model>model()Research quality level - fast (quick), normal (balanced), pro (comprehensive) final JsonValue_outputSchema()Optional JSON schema to structure the research outputThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = v1ResearchParams.outputSchema().convert(MyClass.class);final Optional<String>query()Alias for instructions (for convenience) final JsonField<String>_instructions()Returns the raw JSON value of instructions. final JsonField<V1ResearchParams.Model>_model()Returns the raw JSON value of model. final JsonField<String>_query()Returns the raw JSON value of query. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1ResearchParams.BuildertoBuilder()final V1ResearchParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ResearchParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1ResearchParams. -
-
Method Detail
-
instructions
final String instructions()
Research instructions or query
-
model
final Optional<V1ResearchParams.Model> model()
Research quality level - fast (quick), normal (balanced), pro (comprehensive)
-
_outputSchema
final JsonValue _outputSchema()
Optional JSON schema to structure the research output
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = v1ResearchParams.outputSchema().convert(MyClass.class);
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<V1ResearchParams.Model> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1ResearchParams.Builder toBuilder()
-
_body
final V1ResearchParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1ResearchParams.Builder builder()
Returns a mutable builder for constructing an instance of V1ResearchParams.
The following fields are required:
.instructions()
-
-
-
-