Package dev.case.api.models.search.v1
Class V1ResearchParams.Body
-
- All Implemented Interfaces:
public final class V1ResearchParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ResearchParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringinstructions()Research instructions or query final Optional<V1ResearchParams.Model>model()Research quality level - fast (quick), normal (balanced), pro (comprehensive) final JsonValue_outputSchema()Optional JSON schema to structure the research outputThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.outputSchema().convert(MyClass.class);final Optional<String>query()Alias for instructions (for convenience) final JsonField<String>_instructions()Returns the raw JSON value of instructions. final JsonField<V1ResearchParams.Model>_model()Returns the raw JSON value of model. final JsonField<String>_query()Returns the raw JSON value of query. final Map<String, JsonValue>_additionalProperties()final V1ResearchParams.Body.BuildertoBuilder()final V1ResearchParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ResearchParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
instructions
final String instructions()
Research instructions or query
-
model
final Optional<V1ResearchParams.Model> model()
Research quality level - fast (quick), normal (balanced), pro (comprehensive)
-
_outputSchema
final JsonValue _outputSchema()
Optional JSON schema to structure the research output
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.outputSchema().convert(MyClass.class);
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<V1ResearchParams.Model> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ResearchParams.Body.Builder toBuilder()
-
validate
final V1ResearchParams.Body validate()
-
builder
final static V1ResearchParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.instructions()
-
-
-
-