Class V1RetrieveResearchResponse.Builder
-
- All Implemented Interfaces:
public final class V1RetrieveResearchResponse.BuilderA builder for V1RetrieveResearchResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final V1RetrieveResearchResponse.Builder id(String id)
Research task ID
-
id
final V1RetrieveResearchResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final V1RetrieveResearchResponse.Builder completedAt(OffsetDateTime completedAt)
Task completion timestamp
-
completedAt
final V1RetrieveResearchResponse.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final V1RetrieveResearchResponse.Builder createdAt(OffsetDateTime createdAt)
Task creation timestamp
-
createdAt
final V1RetrieveResearchResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final V1RetrieveResearchResponse.Builder model(V1RetrieveResearchResponse.Model model)
Research model used
-
model
final V1RetrieveResearchResponse.Builder model(JsonField<V1RetrieveResearchResponse.Model> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed Model value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
progress
final V1RetrieveResearchResponse.Builder progress(Double progress)
Completion percentage (0-100)
-
progress
final V1RetrieveResearchResponse.Builder progress(JsonField<Double> progress)
Sets Builder.progress to an arbitrary JSON value.
You should usually call Builder.progress with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
query
final V1RetrieveResearchResponse.Builder query(String query)
Original research query
-
query
final V1RetrieveResearchResponse.Builder query(JsonField<String> query)
Sets Builder.query to an arbitrary JSON value.
You should usually call Builder.query with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
results
final V1RetrieveResearchResponse.Builder results(V1RetrieveResearchResponse.Results results)
Research findings and analysis
-
results
final V1RetrieveResearchResponse.Builder results(JsonField<V1RetrieveResearchResponse.Results> results)
Sets Builder.results to an arbitrary JSON value.
You should usually call Builder.results with a well-typed Results value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final V1RetrieveResearchResponse.Builder status(V1RetrieveResearchResponse.Status status)
Current status of the research task
-
status
final V1RetrieveResearchResponse.Builder status(JsonField<V1RetrieveResearchResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1RetrieveResearchResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1RetrieveResearchResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1RetrieveResearchResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1RetrieveResearchResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1RetrieveResearchResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1RetrieveResearchResponse build()
Returns an immutable instance of V1RetrieveResearchResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-