Package dev.case.api.models.search.v1
Class V1RetrieveResearchResponse.Results.Source
-
- All Implemented Interfaces:
public final class V1RetrieveResearchResponse.Results.Source
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1RetrieveResearchResponse.Results.Source.BuilderA builder for Source.
-
Method Summary
Modifier and Type Method Description final Optional<String>snippet()final Optional<String>title()final Optional<String>url()final JsonField<String>_snippet()Returns the raw JSON value of snippet. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final V1RetrieveResearchResponse.Results.Source.BuildertoBuilder()final V1RetrieveResearchResponse.Results.Sourcevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1RetrieveResearchResponse.Results.Source.Builderbuilder()Returns a mutable builder for constructing an instance of Source. -
-
Method Detail
-
_snippet
final JsonField<String> _snippet()
Returns the raw JSON value of snippet.
Unlike snippet, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1RetrieveResearchResponse.Results.Source.Builder toBuilder()
-
validate
final V1RetrieveResearchResponse.Results.Source validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1RetrieveResearchResponse.Results.Source.Builder builder()
Returns a mutable builder for constructing an instance of Source.
-
-
-
-