Class V1SearchParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1SearchParams implements Params
Executes intelligent web search queries with advanced filtering and customization options. Ideal for legal research, case law discovery, and gathering supporting documentation for litigation or compliance matters.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SearchParams.BuilderA builder for V1SearchParams.
public final classV1SearchParams.Bodypublic final classV1SearchParams.TypeType of search to perform
-
Method Summary
Modifier and Type Method Description final Stringquery()Primary search query final Optional<List<String>>additionalQueries()Additional related search queries to enhance results final Optional<String>category()Category filter for search results final Optional<String>contents()Specific content type to search for final Optional<LocalDate>endCrawlDate()End date for crawl date filtering final Optional<LocalDate>endPublishedDate()End date for published date filtering final Optional<List<String>>excludeDomains()Domains to exclude from search results final Optional<List<String>>includeDomains()Domains to include in search results final Optional<Boolean>includeText()Whether to include full text content in results final Optional<Long>numResults()Number of search results to return final Optional<LocalDate>startCrawlDate()Start date for crawl date filtering final Optional<LocalDate>startPublishedDate()Start date for published date filtering final Optional<V1SearchParams.Type>type()Type of search to perform final Optional<String>userLocation()Geographic location for localized results final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<List<String>>_additionalQueries()Returns the raw JSON value of additionalQueries. final JsonField<String>_category()Returns the raw JSON value of category. final JsonField<String>_contents()Returns the raw JSON value of contents. final JsonField<LocalDate>_endCrawlDate()Returns the raw JSON value of endCrawlDate. final JsonField<LocalDate>_endPublishedDate()Returns the raw JSON value of endPublishedDate. final JsonField<List<String>>_excludeDomains()Returns the raw JSON value of excludeDomains. final JsonField<List<String>>_includeDomains()Returns the raw JSON value of includeDomains. final JsonField<Boolean>_includeText()Returns the raw JSON value of includeText. final JsonField<Long>_numResults()Returns the raw JSON value of numResults. final JsonField<LocalDate>_startCrawlDate()Returns the raw JSON value of startCrawlDate. final JsonField<LocalDate>_startPublishedDate()Returns the raw JSON value of startPublishedDate. final JsonField<V1SearchParams.Type>_type()Returns the raw JSON value of type. final JsonField<String>_userLocation()Returns the raw JSON value of userLocation. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1SearchParams.BuildertoBuilder()final V1SearchParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SearchParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1SearchParams. -
-
Method Detail
-
additionalQueries
final Optional<List<String>> additionalQueries()
Additional related search queries to enhance results
-
endCrawlDate
final Optional<LocalDate> endCrawlDate()
End date for crawl date filtering
-
endPublishedDate
final Optional<LocalDate> endPublishedDate()
End date for published date filtering
-
excludeDomains
final Optional<List<String>> excludeDomains()
Domains to exclude from search results
-
includeDomains
final Optional<List<String>> includeDomains()
Domains to include in search results
-
includeText
final Optional<Boolean> includeText()
Whether to include full text content in results
-
numResults
final Optional<Long> numResults()
Number of search results to return
-
startCrawlDate
final Optional<LocalDate> startCrawlDate()
Start date for crawl date filtering
-
startPublishedDate
final Optional<LocalDate> startPublishedDate()
Start date for published date filtering
-
type
final Optional<V1SearchParams.Type> type()
Type of search to perform
-
userLocation
final Optional<String> userLocation()
Geographic location for localized results
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalQueries
final JsonField<List<String>> _additionalQueries()
Returns the raw JSON value of additionalQueries.
Unlike additionalQueries, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<String> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_contents
final JsonField<String> _contents()
Returns the raw JSON value of contents.
Unlike contents, this method doesn't throw if the JSON field has an unexpected type.
-
_endCrawlDate
final JsonField<LocalDate> _endCrawlDate()
Returns the raw JSON value of endCrawlDate.
Unlike endCrawlDate, this method doesn't throw if the JSON field has an unexpected type.
-
_endPublishedDate
final JsonField<LocalDate> _endPublishedDate()
Returns the raw JSON value of endPublishedDate.
Unlike endPublishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_excludeDomains
final JsonField<List<String>> _excludeDomains()
Returns the raw JSON value of excludeDomains.
Unlike excludeDomains, this method doesn't throw if the JSON field has an unexpected type.
-
_includeDomains
final JsonField<List<String>> _includeDomains()
Returns the raw JSON value of includeDomains.
Unlike includeDomains, this method doesn't throw if the JSON field has an unexpected type.
-
_includeText
final JsonField<Boolean> _includeText()
Returns the raw JSON value of includeText.
Unlike includeText, this method doesn't throw if the JSON field has an unexpected type.
-
_numResults
final JsonField<Long> _numResults()
Returns the raw JSON value of numResults.
Unlike numResults, this method doesn't throw if the JSON field has an unexpected type.
-
_startCrawlDate
final JsonField<LocalDate> _startCrawlDate()
Returns the raw JSON value of startCrawlDate.
Unlike startCrawlDate, this method doesn't throw if the JSON field has an unexpected type.
-
_startPublishedDate
final JsonField<LocalDate> _startPublishedDate()
Returns the raw JSON value of startPublishedDate.
Unlike startPublishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<V1SearchParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_userLocation
final JsonField<String> _userLocation()
Returns the raw JSON value of userLocation.
Unlike userLocation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1SearchParams.Builder toBuilder()
-
_body
final V1SearchParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1SearchParams.Builder builder()
Returns a mutable builder for constructing an instance of V1SearchParams.
The following fields are required:
.query()
-
-
-
-