Package dev.case.api.models.search.v1
Class V1SearchResponse
-
- All Implemented Interfaces:
public final class V1SearchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SearchResponse.BuilderA builder for V1SearchResponse.
public final classV1SearchResponse.Result
-
Method Summary
Modifier and Type Method Description final Optional<String>query()Original search query final Optional<List<V1SearchResponse.Result>>results()Array of search results final Optional<Long>totalResults()Total number of results found final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<List<V1SearchResponse.Result>>_results()Returns the raw JSON value of results. final JsonField<Long>_totalResults()Returns the raw JSON value of totalResults. final Map<String, JsonValue>_additionalProperties()final V1SearchResponse.BuildertoBuilder()final V1SearchResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SearchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1SearchResponse. -
-
Method Detail
-
results
final Optional<List<V1SearchResponse.Result>> results()
Array of search results
-
totalResults
final Optional<Long> totalResults()
Total number of results found
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_results
final JsonField<List<V1SearchResponse.Result>> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_totalResults
final JsonField<Long> _totalResults()
Returns the raw JSON value of totalResults.
Unlike totalResults, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SearchResponse.Builder toBuilder()
-
validate
final V1SearchResponse validate()
-
builder
final static V1SearchResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1SearchResponse.
-
-
-
-