Class V1SearchResponse.Builder
-
- All Implemented Interfaces:
public final class V1SearchResponse.BuilderA builder for V1SearchResponse.
-
-
Method Summary
-
-
Method Detail
-
query
final V1SearchResponse.Builder query(String query)
Original search query
-
query
final V1SearchResponse.Builder query(JsonField<String> query)
Sets Builder.query to an arbitrary JSON value.
You should usually call Builder.query with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
results
final V1SearchResponse.Builder results(List<V1SearchResponse.Result> results)
Array of search results
-
results
final V1SearchResponse.Builder results(JsonField<List<V1SearchResponse.Result>> results)
Sets Builder.results to an arbitrary JSON value.
You should usually call Builder.results with a well-typed
List<Result>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addResult
final V1SearchResponse.Builder addResult(V1SearchResponse.Result result)
-
totalResults
final V1SearchResponse.Builder totalResults(Long totalResults)
Total number of results found
-
totalResults
final V1SearchResponse.Builder totalResults(JsonField<Long> totalResults)
Sets Builder.totalResults to an arbitrary JSON value.
You should usually call Builder.totalResults with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1SearchResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1SearchResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1SearchResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1SearchResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1SearchResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1SearchResponse build()
Returns an immutable instance of V1SearchResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-