Class V1SimilarParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1SimilarParams implements Params
Find web pages and documents similar to a given URL. Useful for legal research to discover related case law, statutes, or legal commentary that shares similar themes or content structure.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SimilarParams.BuilderA builder for V1SimilarParams.
public final classV1SimilarParams.Body
-
Method Summary
Modifier and Type Method Description final Stringurl()The URL to find similar content for final Optional<String>contents()Additional content to consider for similarity matching final Optional<LocalDate>endCrawlDate()Only include pages crawled before this date final Optional<LocalDate>endPublishedDate()Only include pages published before this date final Optional<List<String>>excludeDomains()Exclude results from these domains final Optional<List<String>>includeDomains()Only search within these domains final Optional<Boolean>includeText()Whether to include extracted text content in results final Optional<Long>numResults()Number of similar results to return final Optional<LocalDate>startCrawlDate()Only include pages crawled after this date final Optional<LocalDate>startPublishedDate()Only include pages published after this date final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_contents()Returns the raw JSON value of contents. final JsonField<LocalDate>_endCrawlDate()Returns the raw JSON value of endCrawlDate. final JsonField<LocalDate>_endPublishedDate()Returns the raw JSON value of endPublishedDate. final JsonField<List<String>>_excludeDomains()Returns the raw JSON value of excludeDomains. final JsonField<List<String>>_includeDomains()Returns the raw JSON value of includeDomains. final JsonField<Boolean>_includeText()Returns the raw JSON value of includeText. final JsonField<Long>_numResults()Returns the raw JSON value of numResults. final JsonField<LocalDate>_startCrawlDate()Returns the raw JSON value of startCrawlDate. final JsonField<LocalDate>_startPublishedDate()Returns the raw JSON value of startPublishedDate. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1SimilarParams.BuildertoBuilder()final V1SimilarParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SimilarParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1SimilarParams. -
-
Method Detail
-
endCrawlDate
final Optional<LocalDate> endCrawlDate()
Only include pages crawled before this date
-
endPublishedDate
final Optional<LocalDate> endPublishedDate()
Only include pages published before this date
-
excludeDomains
final Optional<List<String>> excludeDomains()
Exclude results from these domains
-
includeDomains
final Optional<List<String>> includeDomains()
Only search within these domains
-
includeText
final Optional<Boolean> includeText()
Whether to include extracted text content in results
-
numResults
final Optional<Long> numResults()
Number of similar results to return
-
startCrawlDate
final Optional<LocalDate> startCrawlDate()
Only include pages crawled after this date
-
startPublishedDate
final Optional<LocalDate> startPublishedDate()
Only include pages published after this date
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_contents
final JsonField<String> _contents()
Returns the raw JSON value of contents.
Unlike contents, this method doesn't throw if the JSON field has an unexpected type.
-
_endCrawlDate
final JsonField<LocalDate> _endCrawlDate()
Returns the raw JSON value of endCrawlDate.
Unlike endCrawlDate, this method doesn't throw if the JSON field has an unexpected type.
-
_endPublishedDate
final JsonField<LocalDate> _endPublishedDate()
Returns the raw JSON value of endPublishedDate.
Unlike endPublishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_excludeDomains
final JsonField<List<String>> _excludeDomains()
Returns the raw JSON value of excludeDomains.
Unlike excludeDomains, this method doesn't throw if the JSON field has an unexpected type.
-
_includeDomains
final JsonField<List<String>> _includeDomains()
Returns the raw JSON value of includeDomains.
Unlike includeDomains, this method doesn't throw if the JSON field has an unexpected type.
-
_includeText
final JsonField<Boolean> _includeText()
Returns the raw JSON value of includeText.
Unlike includeText, this method doesn't throw if the JSON field has an unexpected type.
-
_numResults
final JsonField<Long> _numResults()
Returns the raw JSON value of numResults.
Unlike numResults, this method doesn't throw if the JSON field has an unexpected type.
-
_startCrawlDate
final JsonField<LocalDate> _startCrawlDate()
Returns the raw JSON value of startCrawlDate.
Unlike startCrawlDate, this method doesn't throw if the JSON field has an unexpected type.
-
_startPublishedDate
final JsonField<LocalDate> _startPublishedDate()
Returns the raw JSON value of startPublishedDate.
Unlike startPublishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1SimilarParams.Builder toBuilder()
-
_body
final V1SimilarParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1SimilarParams.Builder builder()
Returns a mutable builder for constructing an instance of V1SimilarParams.
The following fields are required:
.url()
-
-
-
-