Class V1SimilarResponse.Result
-
- All Implemented Interfaces:
public final class V1SimilarResponse.Result
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SimilarResponse.Result.BuilderA builder for Result.
-
Method Summary
-
-
Method Detail
-
publishedDate
final Optional<String> publishedDate()
-
similarityScore
final Optional<Double> similarityScore()
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_publishedDate
final JsonField<String> _publishedDate()
Returns the raw JSON value of publishedDate.
Unlike publishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_similarityScore
final JsonField<Double> _similarityScore()
Returns the raw JSON value of similarityScore.
Unlike similarityScore, this method doesn't throw if the JSON field has an unexpected type.
-
_snippet
final JsonField<String> _snippet()
Returns the raw JSON value of snippet.
Unlike snippet, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SimilarResponse.Result.Builder toBuilder()
-
validate
final V1SimilarResponse.Result validate()
-
builder
final static V1SimilarResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-