Class ReadResponseFileBundle
-
- All Implemented Interfaces:
public final class ReadResponseFileBundle
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReadResponseFileBundle.BuilderA builder for ReadResponseFileBundle.
public final classReadResponseFileBundle.Role
-
Method Summary
Modifier and Type Method Description final Stringpath()final ReadResponseFileBundle.Rolerole()final StringrootSlug()final Optional<String>contentType()final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<ReadResponseFileBundle.Role>_role()Returns the raw JSON value of role. final JsonField<String>_rootSlug()Returns the raw JSON value of rootSlug. final JsonField<String>_contentType()Returns the raw JSON value of contentType. final Map<String, JsonValue>_additionalProperties()final ReadResponseFileBundle.BuildertoBuilder()final ReadResponseFileBundlevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReadResponseFileBundle.Builderbuilder()Returns a mutable builder for constructing an instance of ReadResponseFileBundle. -
-
Method Detail
-
role
final ReadResponseFileBundle.Role role()
-
contentType
final Optional<String> contentType()
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<ReadResponseFileBundle.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_rootSlug
final JsonField<String> _rootSlug()
Returns the raw JSON value of rootSlug.
Unlike rootSlug, this method doesn't throw if the JSON field has an unexpected type.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReadResponseFileBundle.Builder toBuilder()
-
validate
final ReadResponseFileBundle validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReadResponseFileBundle.Builder builder()
Returns a mutable builder for constructing an instance of ReadResponseFileBundle.
The following fields are required:
.path() .role() .rootSlug()
-
-
-
-