Class ReadResponseFileBundle.Builder
-
- All Implemented Interfaces:
public final class ReadResponseFileBundle.BuilderA builder for ReadResponseFileBundle.
-
-
Method Summary
-
-
Method Detail
-
path
final ReadResponseFileBundle.Builder path(String path)
-
path
final ReadResponseFileBundle.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
role
final ReadResponseFileBundle.Builder role(ReadResponseFileBundle.Role role)
-
role
final ReadResponseFileBundle.Builder role(JsonField<ReadResponseFileBundle.Role> role)
Sets Builder.role to an arbitrary JSON value.
You should usually call Builder.role with a well-typed Role value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rootSlug
final ReadResponseFileBundle.Builder rootSlug(String rootSlug)
-
rootSlug
final ReadResponseFileBundle.Builder rootSlug(JsonField<String> rootSlug)
Sets Builder.rootSlug to an arbitrary JSON value.
You should usually call Builder.rootSlug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contentType
final ReadResponseFileBundle.Builder contentType(String contentType)
-
contentType
final ReadResponseFileBundle.Builder contentType(Optional<String> contentType)
Alias for calling Builder.contentType with
contentType.orElse(null).
-
contentType
final ReadResponseFileBundle.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ReadResponseFileBundle.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ReadResponseFileBundle.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ReadResponseFileBundle.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ReadResponseFileBundle.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ReadResponseFileBundle.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ReadResponseFileBundle build()
Returns an immutable instance of ReadResponseFileBundle.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.path() .role() .rootSlug()
-
-
-
-