Package dev.case.api.models.skills
Class ReadResponseRootBundle
-
- All Implemented Interfaces:
public final class ReadResponseRootBundle
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReadResponseRootBundle.BuilderA builder for ReadResponseRootBundle.
public final classReadResponseRootBundle.Filepublic final classReadResponseRootBundle.Role
-
Method Summary
Modifier and Type Method Description final List<ReadResponseRootBundle.File>files()final ReadResponseRootBundle.Rolerole()final JsonField<List<ReadResponseRootBundle.File>>_files()Returns the raw JSON value of files. final JsonField<ReadResponseRootBundle.Role>_role()Returns the raw JSON value of role. final Map<String, JsonValue>_additionalProperties()final ReadResponseRootBundle.BuildertoBuilder()final ReadResponseRootBundlevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReadResponseRootBundle.Builderbuilder()Returns a mutable builder for constructing an instance of ReadResponseRootBundle. -
-
Method Detail
-
files
final List<ReadResponseRootBundle.File> files()
-
role
final ReadResponseRootBundle.Role role()
-
_files
final JsonField<List<ReadResponseRootBundle.File>> _files()
Returns the raw JSON value of files.
Unlike files, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<ReadResponseRootBundle.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReadResponseRootBundle.Builder toBuilder()
-
validate
final ReadResponseRootBundle validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReadResponseRootBundle.Builder builder()
Returns a mutable builder for constructing an instance of ReadResponseRootBundle.
The following fields are required:
.files() .role()
-
-
-
-