Class ReadResponseRootBundle.File
-
- All Implemented Interfaces:
public final class ReadResponseRootBundle.File
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReadResponseRootBundle.File.BuilderA builder for File.
-
Method Summary
Modifier and Type Method Description final Stringpath()final Stringslug()final Optional<String>contentType()final Optional<String>name()final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final ReadResponseRootBundle.File.BuildertoBuilder()final ReadResponseRootBundle.Filevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReadResponseRootBundle.File.Builderbuilder()Returns a mutable builder for constructing an instance of File. -
-
Method Detail
-
contentType
final Optional<String> contentType()
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReadResponseRootBundle.File.Builder toBuilder()
-
validate
final ReadResponseRootBundle.File validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReadResponseRootBundle.File.Builder builder()
Returns a mutable builder for constructing an instance of File.
The following fields are required:
.path() .slug()
-
-
-
-