Class SkillCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SkillCreateParams implements Params
Create an org-scoped custom skill. The skill will be searchable via /skills/resolve alongside curated skills.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillCreateParams.BuilderA builder for SkillCreateParams.
public final classSkillCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Stringcontent()Full skill content in markdown final Stringname()Skill name final JsonValue_metadata()Arbitrary metadata (author, license, etc. final Optional<String>slug()URL-safe slug. final Optional<String>summary()Brief description (1-2 sentences) final Optional<List<String>>tags()Tags for categorization and search boosting final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SkillCreateParams.BuildertoBuilder()final SkillCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SkillCreateParams. -
-
Method Detail
-
_metadata
final JsonValue _metadata()
Arbitrary metadata (author, license, etc.)
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = skillCreateParams.metadata().convert(MyClass.class);
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SkillCreateParams.Builder toBuilder()
-
_body
final SkillCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SkillCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of SkillCreateParams.
The following fields are required:
.content() .name()
-
-
-
-