Class SkillCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SkillCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
content
final SkillCreateParams.Body.Builder content(String content)
Full skill content in markdown
-
content
final SkillCreateParams.Body.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final SkillCreateParams.Body.Builder name(String name)
Skill name
-
name
final SkillCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final SkillCreateParams.Body.Builder metadata(JsonValue metadata)
Arbitrary metadata (author, license, etc.)
-
slug
final SkillCreateParams.Body.Builder slug(String slug)
URL-safe slug. Auto-generated from name if omitted.
-
slug
final SkillCreateParams.Body.Builder slug(JsonField<String> slug)
Sets Builder.slug to an arbitrary JSON value.
You should usually call Builder.slug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
summary
final SkillCreateParams.Body.Builder summary(String summary)
Brief description (1-2 sentences)
-
summary
final SkillCreateParams.Body.Builder summary(JsonField<String> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final SkillCreateParams.Body.Builder tags(List<String> tags)
Tags for categorization and search boosting
-
tags
final SkillCreateParams.Body.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final SkillCreateParams.Body.Builder addTag(String tag)
-
additionalProperties
final SkillCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SkillCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SkillCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SkillCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SkillCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SkillCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.content() .name()
-
-
-
-