Class SkillCreateResponse
-
- All Implemented Interfaces:
public final class SkillCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillCreateResponse.BuilderA builder for SkillCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>content()final Optional<OffsetDateTime>createdAt()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = skillCreateResponse.metadata().convert(MyClass.class);final Optional<String>name()final Optional<String>slug()final Optional<String>summary()final Optional<List<String>>tags()final Optional<Long>version()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<Long>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final SkillCreateResponse.BuildertoBuilder()final SkillCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SkillCreateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = skillCreateResponse.metadata().convert(MyClass.class);
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillCreateResponse.Builder toBuilder()
-
validate
final SkillCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SkillCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of SkillCreateResponse.
-
-
-
-