Class SkillCreateResponse.Builder
-
- All Implemented Interfaces:
public final class SkillCreateResponse.BuilderA builder for SkillCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
content
final SkillCreateResponse.Builder content(String content)
-
content
final SkillCreateResponse.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final SkillCreateResponse.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final SkillCreateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final SkillCreateResponse.Builder metadata(JsonValue metadata)
-
name
final SkillCreateResponse.Builder name(String name)
-
name
final SkillCreateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
slug
final SkillCreateResponse.Builder slug(String slug)
-
slug
final SkillCreateResponse.Builder slug(JsonField<String> slug)
Sets Builder.slug to an arbitrary JSON value.
You should usually call Builder.slug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
summary
final SkillCreateResponse.Builder summary(String summary)
-
summary
final SkillCreateResponse.Builder summary(Optional<String> summary)
Alias for calling Builder.summary with
summary.orElse(null).
-
summary
final SkillCreateResponse.Builder summary(JsonField<String> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final SkillCreateResponse.Builder tags(List<String> tags)
-
tags
final SkillCreateResponse.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final SkillCreateResponse.Builder addTag(String tag)
-
version
final SkillCreateResponse.Builder version(Long version)
-
version
final SkillCreateResponse.Builder version(JsonField<Long> version)
Sets Builder.version to an arbitrary JSON value.
You should usually call Builder.version with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SkillCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SkillCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SkillCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SkillCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SkillCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SkillCreateResponse build()
Returns an immutable instance of SkillCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-