Class SkillReadResponse
-
- All Implemented Interfaces:
public final class SkillReadResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillReadResponse.BuilderA builder for SkillReadResponse.
public final classSkillReadResponse.BundleSkill bundle metadata for root skills and companion file rows
public final classSkillReadResponse.SourceSkill source (authenticated requests only)
-
Method Summary
Modifier and Type Method Description final Optional<String>authorName()Skill author final Optional<SkillReadResponse.Bundle>bundle()Skill bundle metadata for root skills and companion file rows final Optional<String>content()Full skill content in markdown final Optional<String>license()Skill license final JsonValue_metadata()Custom metadata (custom skills only)This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = skillReadResponse.metadata().convert(MyClass.class);final Optional<String>name()Skill name final Optional<String>slug()Unique skill identifier final Optional<SkillReadResponse.Source>source()Skill source (authenticated requests only) final Optional<String>summary()Brief skill description final Optional<List<String>>tags()Skill tags final Optional<String>version()Skill version final JsonField<String>_authorName()Returns the raw JSON value of authorName. final JsonField<SkillReadResponse.Bundle>_bundle()Returns the raw JSON value of bundle. final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_license()Returns the raw JSON value of license. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<SkillReadResponse.Source>_source()Returns the raw JSON value of source. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<String>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final SkillReadResponse.BuildertoBuilder()final SkillReadResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillReadResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SkillReadResponse. -
-
Method Detail
-
authorName
final Optional<String> authorName()
Skill author
-
bundle
final Optional<SkillReadResponse.Bundle> bundle()
Skill bundle metadata for root skills and companion file rows
-
_metadata
final JsonValue _metadata()
Custom metadata (custom skills only)
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = skillReadResponse.metadata().convert(MyClass.class);
-
source
final Optional<SkillReadResponse.Source> source()
Skill source (authenticated requests only)
-
_authorName
final JsonField<String> _authorName()
Returns the raw JSON value of authorName.
Unlike authorName, this method doesn't throw if the JSON field has an unexpected type.
-
_bundle
final JsonField<SkillReadResponse.Bundle> _bundle()
Returns the raw JSON value of bundle.
Unlike bundle, this method doesn't throw if the JSON field has an unexpected type.
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_license
final JsonField<String> _license()
Returns the raw JSON value of license.
Unlike license, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<SkillReadResponse.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<String> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillReadResponse.Builder toBuilder()
-
validate
final SkillReadResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SkillReadResponse.Builder builder()
Returns a mutable builder for constructing an instance of SkillReadResponse.
-
-
-
-