Class SkillReadResponse.Builder
-
- All Implemented Interfaces:
public final class SkillReadResponse.BuilderA builder for SkillReadResponse.
-
-
Method Summary
-
-
Method Detail
-
authorName
final SkillReadResponse.Builder authorName(String authorName)
Skill author
-
authorName
final SkillReadResponse.Builder authorName(JsonField<String> authorName)
Sets Builder.authorName to an arbitrary JSON value.
You should usually call Builder.authorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
content
final SkillReadResponse.Builder content(String content)
Full skill content in markdown
-
content
final SkillReadResponse.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
license
final SkillReadResponse.Builder license(String license)
Skill license
-
license
final SkillReadResponse.Builder license(JsonField<String> license)
Sets Builder.license to an arbitrary JSON value.
You should usually call Builder.license with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final SkillReadResponse.Builder name(String name)
Skill name
-
name
final SkillReadResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
slug
final SkillReadResponse.Builder slug(String slug)
Unique skill identifier
-
slug
final SkillReadResponse.Builder slug(JsonField<String> slug)
Sets Builder.slug to an arbitrary JSON value.
You should usually call Builder.slug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
summary
final SkillReadResponse.Builder summary(String summary)
Brief skill description
-
summary
final SkillReadResponse.Builder summary(JsonField<String> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final SkillReadResponse.Builder tags(List<String> tags)
Skill tags
-
tags
final SkillReadResponse.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final SkillReadResponse.Builder addTag(String tag)
-
version
final SkillReadResponse.Builder version(String version)
Skill version
-
version
final SkillReadResponse.Builder version(JsonField<String> version)
Sets Builder.version to an arbitrary JSON value.
You should usually call Builder.version with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SkillReadResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SkillReadResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SkillReadResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SkillReadResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SkillReadResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SkillReadResponse build()
Returns an immutable instance of SkillReadResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-