Package dev.case.api.models.skills
Class SkillReadResponse.Bundle.UnionMember0
-
- All Implemented Interfaces:
public final class SkillReadResponse.Bundle.UnionMember0
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillReadResponse.Bundle.UnionMember0.BuilderA builder for UnionMember0.
public final classSkillReadResponse.Bundle.UnionMember0.Filepublic final classSkillReadResponse.Bundle.UnionMember0.Role
-
Method Summary
Modifier and Type Method Description final List<SkillReadResponse.Bundle.UnionMember0.File>files()final SkillReadResponse.Bundle.UnionMember0.Rolerole()final JsonField<List<SkillReadResponse.Bundle.UnionMember0.File>>_files()Returns the raw JSON value of files. final JsonField<SkillReadResponse.Bundle.UnionMember0.Role>_role()Returns the raw JSON value of role. final Map<String, JsonValue>_additionalProperties()final SkillReadResponse.Bundle.UnionMember0.BuildertoBuilder()final SkillReadResponse.Bundle.UnionMember0validate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillReadResponse.Bundle.UnionMember0.Builderbuilder()Returns a mutable builder for constructing an instance of UnionMember0. -
-
Method Detail
-
files
final List<SkillReadResponse.Bundle.UnionMember0.File> files()
-
role
final SkillReadResponse.Bundle.UnionMember0.Role role()
-
_files
final JsonField<List<SkillReadResponse.Bundle.UnionMember0.File>> _files()
Returns the raw JSON value of files.
Unlike files, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<SkillReadResponse.Bundle.UnionMember0.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillReadResponse.Bundle.UnionMember0.Builder toBuilder()
-
validate
final SkillReadResponse.Bundle.UnionMember0 validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SkillReadResponse.Bundle.UnionMember0.Builder builder()
Returns a mutable builder for constructing an instance of UnionMember0.
The following fields are required:
.files() .role()
-
-
-
-