Class SkillReadResponse.Bundle.UnionMember1.Builder
-
- All Implemented Interfaces:
public final class SkillReadResponse.Bundle.UnionMember1.BuilderA builder for UnionMember1.
-
-
Method Summary
-
-
Method Detail
-
path
final SkillReadResponse.Bundle.UnionMember1.Builder path(String path)
-
path
final SkillReadResponse.Bundle.UnionMember1.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
role
final SkillReadResponse.Bundle.UnionMember1.Builder role(SkillReadResponse.Bundle.UnionMember1.Role role)
-
role
final SkillReadResponse.Bundle.UnionMember1.Builder role(JsonField<SkillReadResponse.Bundle.UnionMember1.Role> role)
Sets Builder.role to an arbitrary JSON value.
You should usually call Builder.role with a well-typed Role value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rootSlug
final SkillReadResponse.Bundle.UnionMember1.Builder rootSlug(String rootSlug)
-
rootSlug
final SkillReadResponse.Bundle.UnionMember1.Builder rootSlug(JsonField<String> rootSlug)
Sets Builder.rootSlug to an arbitrary JSON value.
You should usually call Builder.rootSlug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contentType
final SkillReadResponse.Bundle.UnionMember1.Builder contentType(String contentType)
-
contentType
final SkillReadResponse.Bundle.UnionMember1.Builder contentType(Optional<String> contentType)
Alias for calling Builder.contentType with
contentType.orElse(null).
-
contentType
final SkillReadResponse.Bundle.UnionMember1.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SkillReadResponse.Bundle.UnionMember1.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SkillReadResponse.Bundle.UnionMember1.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SkillReadResponse.Bundle.UnionMember1.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SkillReadResponse.Bundle.UnionMember1.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SkillReadResponse.Bundle.UnionMember1.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SkillReadResponse.Bundle.UnionMember1 build()
Returns an immutable instance of UnionMember1.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.path() .role() .rootSlug()
-
-
-
-