Package dev.case.api.models.skills
Interface SkillReadResponse.Bundle.Visitor
-
- All Implemented Interfaces:
public interface SkillReadResponse.Bundle.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitReadResponseRoot(ReadResponseRootBundle readResponseRoot)abstract TvisitReadResponseFile(ReadResponseFileBundle readResponseFile)Tunknown(JsonValue json)Maps an unknown variant of Bundle to a value of type T. -
-
Method Detail
-
visitReadResponseRoot
abstract T visitReadResponseRoot(ReadResponseRootBundle readResponseRoot)
-
visitReadResponseFile
abstract T visitReadResponseFile(ReadResponseFileBundle readResponseFile)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Bundle to a value of type T.
An instance of Bundle can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-