Package dev.case.api.models.skills
Class SkillResolveParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SkillResolveParams implements Params
Search the Legal Skills Store using hybrid search (text + tag + semantic). Returns ranked results with relevance scores.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillResolveParams.BuilderA builder for SkillResolveParams.
-
Method Summary
Modifier and Type Method Description final Stringq()Search query string final Optional<Long>limit()Maximum number of results to return (1-20) final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SkillResolveParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillResolveParams.Builderbuilder()Returns a mutable builder for constructing an instance of SkillResolveParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SkillResolveParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SkillResolveParams.Builder builder()
Returns a mutable builder for constructing an instance of SkillResolveParams.
The following fields are required:
.q()
-
-
-
-