Package dev.case.api.models.skills
Class SkillResolveResponse
-
- All Implemented Interfaces:
public final class SkillResolveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillResolveResponse.BuilderA builder for SkillResolveResponse.
public final classSkillResolveResponse.Result
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>methodsUsed()Search methods used (text, tag, semantic) final Optional<List<SkillResolveResponse.Result>>results()final JsonField<List<String>>_methodsUsed()Returns the raw JSON value of methodsUsed. final JsonField<List<SkillResolveResponse.Result>>_results()Returns the raw JSON value of results. final Map<String, JsonValue>_additionalProperties()final SkillResolveResponse.BuildertoBuilder()final SkillResolveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillResolveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SkillResolveResponse. -
-
Method Detail
-
methodsUsed
final Optional<List<String>> methodsUsed()
Search methods used (text, tag, semantic)
-
results
final Optional<List<SkillResolveResponse.Result>> results()
-
_methodsUsed
final JsonField<List<String>> _methodsUsed()
Returns the raw JSON value of methodsUsed.
Unlike methodsUsed, this method doesn't throw if the JSON field has an unexpected type.
-
_results
final JsonField<List<SkillResolveResponse.Result>> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillResolveResponse.Builder toBuilder()
-
validate
final SkillResolveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SkillResolveResponse.Builder builder()
Returns a mutable builder for constructing an instance of SkillResolveResponse.
-
-
-
-