Class SkillResolveResponse.Result
-
- All Implemented Interfaces:
public final class SkillResolveResponse.Result
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillResolveResponse.Result.BuilderA builder for Result.
public final classSkillResolveResponse.Result.SourceWhether the skill is curated or org-custom
-
Method Summary
Modifier and Type Method Description final Optional<String>name()Skill name final Optional<Double>score()Relevance score final Optional<String>slug()Unique skill identifier final Optional<SkillResolveResponse.Result.Source>source()Whether the skill is curated or org-custom final Optional<String>summary()Brief skill description final Optional<List<String>>tags()Skill tags final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Double>_score()Returns the raw JSON value of score. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<SkillResolveResponse.Result.Source>_source()Returns the raw JSON value of source. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalProperties()final SkillResolveResponse.Result.BuildertoBuilder()final SkillResolveResponse.Resultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillResolveResponse.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
source
final Optional<SkillResolveResponse.Result.Source> source()
Whether the skill is curated or org-custom
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_score
final JsonField<Double> _score()
Returns the raw JSON value of score.
Unlike score, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<SkillResolveResponse.Result.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillResolveResponse.Result.Builder toBuilder()
-
validate
final SkillResolveResponse.Result validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SkillResolveResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-