Class SkillResolveResponse.Result.Builder
-
- All Implemented Interfaces:
public final class SkillResolveResponse.Result.BuilderA builder for Result.
-
-
Method Summary
-
-
Method Detail
-
name
final SkillResolveResponse.Result.Builder name(String name)
Skill name
-
name
final SkillResolveResponse.Result.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
score
final SkillResolveResponse.Result.Builder score(Double score)
Relevance score
-
score
final SkillResolveResponse.Result.Builder score(JsonField<Double> score)
Sets Builder.score to an arbitrary JSON value.
You should usually call Builder.score with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
slug
final SkillResolveResponse.Result.Builder slug(String slug)
Unique skill identifier
-
slug
final SkillResolveResponse.Result.Builder slug(JsonField<String> slug)
Sets Builder.slug to an arbitrary JSON value.
You should usually call Builder.slug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final SkillResolveResponse.Result.Builder source(SkillResolveResponse.Result.Source source)
Whether the skill is curated or org-custom
-
source
final SkillResolveResponse.Result.Builder source(JsonField<SkillResolveResponse.Result.Source> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed Source value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
summary
final SkillResolveResponse.Result.Builder summary(String summary)
Brief skill description
-
summary
final SkillResolveResponse.Result.Builder summary(JsonField<String> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final SkillResolveResponse.Result.Builder tags(List<String> tags)
Skill tags
-
tags
final SkillResolveResponse.Result.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final SkillResolveResponse.Result.Builder addTag(String tag)
-
additionalProperties
final SkillResolveResponse.Result.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SkillResolveResponse.Result.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SkillResolveResponse.Result.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SkillResolveResponse.Result.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SkillResolveResponse.Result.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SkillResolveResponse.Result build()
Returns an immutable instance of Result.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-