Class SkillUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SkillUpdateParams implements Params
Update an org-scoped custom skill by slug. Only provided fields are updated. Version is auto-incremented.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillUpdateParams.BuilderA builder for SkillUpdateParams.
public final classSkillUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>pathSlug()final Optional<String>content()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = skillUpdateParams.metadata().convert(MyClass.class);final Optional<String>name()final Optional<String>bodySlug()New slug (renames the skill) final Optional<String>summary()final Optional<List<String>>tags()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_bodySlug()Returns the raw JSON value of bodySlug. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SkillUpdateParams.BuildertoBuilder()final SkillUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillUpdateParamsnone()final static SkillUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SkillUpdateParams. -
-
Method Detail
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = skillUpdateParams.metadata().convert(MyClass.class);
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_bodySlug
final JsonField<String> _bodySlug()
Returns the raw JSON value of bodySlug.
Unlike bodySlug, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SkillUpdateParams.Builder toBuilder()
-
_body
final SkillUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SkillUpdateParams none()
-
builder
final static SkillUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of SkillUpdateParams.
-
-
-
-