Class CustomListParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class CustomListParams implements Params
List all custom skills for the authenticated organization. Supports cursor-based pagination.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomListParams.BuilderA builder for CustomListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>cursor()Cursor for pagination (skill ID from previous page) final Optional<Long>limit()Maximum number of results (1-100) final Optional<String>tag()Filter by tag final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CustomListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomListParamsnone()final static CustomListParams.Builderbuilder()Returns a mutable builder for constructing an instance of CustomListParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CustomListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CustomListParams none()
-
builder
final static CustomListParams.Builder builder()
Returns a mutable builder for constructing an instance of CustomListParams.
-
-
-
-