Class CustomListResponse
-
- All Implemented Interfaces:
public final class CustomListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomListResponse.BuilderA builder for CustomListResponse.
public final classCustomListResponse.Skill
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>hasMore()final Optional<String>nextCursor()final Optional<List<CustomListResponse.Skill>>skills()final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final JsonField<List<CustomListResponse.Skill>>_skills()Returns the raw JSON value of skills. final Map<String, JsonValue>_additionalProperties()final CustomListResponse.BuildertoBuilder()final CustomListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CustomListResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
-
skills
final Optional<List<CustomListResponse.Skill>> skills()
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_skills
final JsonField<List<CustomListResponse.Skill>> _skills()
Returns the raw JSON value of skills.
Unlike skills, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomListResponse.Builder toBuilder()
-
validate
final CustomListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CustomListResponse.Builder builder()
Returns a mutable builder for constructing an instance of CustomListResponse.
-
-
-
-