Class CustomListResponse.Builder
-
- All Implemented Interfaces:
public final class CustomListResponse.BuilderA builder for CustomListResponse.
-
-
Method Summary
-
-
Method Detail
-
hasMore
final CustomListResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final CustomListResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nextCursor
final CustomListResponse.Builder nextCursor(String nextCursor)
-
nextCursor
final CustomListResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final CustomListResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
skills
final CustomListResponse.Builder skills(List<CustomListResponse.Skill> skills)
-
skills
final CustomListResponse.Builder skills(JsonField<List<CustomListResponse.Skill>> skills)
Sets Builder.skills to an arbitrary JSON value.
You should usually call Builder.skills with a well-typed
List<Skill>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSkill
final CustomListResponse.Builder addSkill(CustomListResponse.Skill skill)
-
additionalProperties
final CustomListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CustomListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CustomListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CustomListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CustomListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CustomListResponse build()
Returns an immutable instance of CustomListResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-