Class CustomListResponse.Skill.Builder
-
- All Implemented Interfaces:
public final class CustomListResponse.Skill.BuilderA builder for Skill.
-
-
Method Summary
-
-
Method Detail
-
createdAt
final CustomListResponse.Skill.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final CustomListResponse.Skill.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final CustomListResponse.Skill.Builder metadata(JsonValue metadata)
-
name
final CustomListResponse.Skill.Builder name(String name)
-
name
final CustomListResponse.Skill.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
slug
final CustomListResponse.Skill.Builder slug(String slug)
-
slug
final CustomListResponse.Skill.Builder slug(JsonField<String> slug)
Sets Builder.slug to an arbitrary JSON value.
You should usually call Builder.slug with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
summary
final CustomListResponse.Skill.Builder summary(String summary)
-
summary
final CustomListResponse.Skill.Builder summary(Optional<String> summary)
Alias for calling Builder.summary with
summary.orElse(null).
-
summary
final CustomListResponse.Skill.Builder summary(JsonField<String> summary)
Sets Builder.summary to an arbitrary JSON value.
You should usually call Builder.summary with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final CustomListResponse.Skill.Builder tags(List<String> tags)
-
tags
final CustomListResponse.Skill.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final CustomListResponse.Skill.Builder addTag(String tag)
-
updatedAt
final CustomListResponse.Skill.Builder updatedAt(OffsetDateTime updatedAt)
-
updatedAt
final CustomListResponse.Skill.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
version
final CustomListResponse.Skill.Builder version(Long version)
-
version
final CustomListResponse.Skill.Builder version(JsonField<Long> version)
Sets Builder.version to an arbitrary JSON value.
You should usually call Builder.version with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CustomListResponse.Skill.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CustomListResponse.Skill.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CustomListResponse.Skill.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CustomListResponse.Skill.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CustomListResponse.Skill.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CustomListResponse.Skill build()
Returns an immutable instance of Skill.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-