Class V1AnnotateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1AnnotateParams implements Params
Populate fields inside a DOCX template using SuperDoc annotations. Supports text, images, dates, and numbers. Can target individual fields by ID or multiple fields by group.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnnotateParams.BuilderA builder for V1AnnotateParams.
public final classV1AnnotateParams.Bodypublic final classV1AnnotateParams.DocumentDocument source - provide either URL or base64
public final classV1AnnotateParams.Fieldpublic final classV1AnnotateParams.OutputFormatOutput format for the annotated document
-
Method Summary
Modifier and Type Method Description final V1AnnotateParams.Documentdocument()Document source - provide either URL or base64 final List<V1AnnotateParams.Field>fields()Fields to populate in the template final Optional<V1AnnotateParams.OutputFormat>outputFormat()Output format for the annotated document final JsonField<V1AnnotateParams.Document>_document()Returns the raw JSON value of document. final JsonField<List<V1AnnotateParams.Field>>_fields()Returns the raw JSON value of fields. final JsonField<V1AnnotateParams.OutputFormat>_outputFormat()Returns the raw JSON value of outputFormat. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1AnnotateParams.BuildertoBuilder()final V1AnnotateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnnotateParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1AnnotateParams. -
-
Method Detail
-
document
final V1AnnotateParams.Document document()
Document source - provide either URL or base64
-
fields
final List<V1AnnotateParams.Field> fields()
Fields to populate in the template
-
outputFormat
final Optional<V1AnnotateParams.OutputFormat> outputFormat()
Output format for the annotated document
-
_document
final JsonField<V1AnnotateParams.Document> _document()
Returns the raw JSON value of document.
Unlike document, this method doesn't throw if the JSON field has an unexpected type.
-
_fields
final JsonField<List<V1AnnotateParams.Field>> _fields()
Returns the raw JSON value of fields.
Unlike fields, this method doesn't throw if the JSON field has an unexpected type.
-
_outputFormat
final JsonField<V1AnnotateParams.OutputFormat> _outputFormat()
Returns the raw JSON value of outputFormat.
Unlike outputFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1AnnotateParams.Builder toBuilder()
-
_body
final V1AnnotateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1AnnotateParams.Builder builder()
Returns a mutable builder for constructing an instance of V1AnnotateParams.
The following fields are required:
.document() .fields()
-
-
-
-