Package dev.case.api.models.superdoc.v1
Class V1AnnotateParams.Body
-
- All Implemented Interfaces:
public final class V1AnnotateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnnotateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final V1AnnotateParams.Documentdocument()Document source - provide either URL or base64 final List<V1AnnotateParams.Field>fields()Fields to populate in the template final Optional<V1AnnotateParams.OutputFormat>outputFormat()Output format for the annotated document final JsonField<V1AnnotateParams.Document>_document()Returns the raw JSON value of document. final JsonField<List<V1AnnotateParams.Field>>_fields()Returns the raw JSON value of fields. final JsonField<V1AnnotateParams.OutputFormat>_outputFormat()Returns the raw JSON value of outputFormat. final Map<String, JsonValue>_additionalProperties()final V1AnnotateParams.Body.BuildertoBuilder()final V1AnnotateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnnotateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
document
final V1AnnotateParams.Document document()
Document source - provide either URL or base64
-
fields
final List<V1AnnotateParams.Field> fields()
Fields to populate in the template
-
outputFormat
final Optional<V1AnnotateParams.OutputFormat> outputFormat()
Output format for the annotated document
-
_document
final JsonField<V1AnnotateParams.Document> _document()
Returns the raw JSON value of document.
Unlike document, this method doesn't throw if the JSON field has an unexpected type.
-
_fields
final JsonField<List<V1AnnotateParams.Field>> _fields()
Returns the raw JSON value of fields.
Unlike fields, this method doesn't throw if the JSON field has an unexpected type.
-
_outputFormat
final JsonField<V1AnnotateParams.OutputFormat> _outputFormat()
Returns the raw JSON value of outputFormat.
Unlike outputFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1AnnotateParams.Body.Builder toBuilder()
-
validate
final V1AnnotateParams.Body validate()
-
builder
final static V1AnnotateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.document() .fields()
-
-
-
-