Package dev.case.api.models.superdoc.v1
Class V1AnnotateParams.Document
-
- All Implemented Interfaces:
public final class V1AnnotateParams.DocumentDocument source - provide either URL or base64
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnnotateParams.Document.BuilderA builder for Document.
-
Method Summary
Modifier and Type Method Description final Optional<String>base64()Base64-encoded DOCX template final Optional<String>url()URL to the DOCX template final JsonField<String>_base64()Returns the raw JSON value of base64. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final V1AnnotateParams.Document.BuildertoBuilder()final V1AnnotateParams.Documentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnnotateParams.Document.Builderbuilder()Returns a mutable builder for constructing an instance of Document. -
-
Method Detail
-
_base64
final JsonField<String> _base64()
Returns the raw JSON value of base64.
Unlike base64, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1AnnotateParams.Document.Builder toBuilder()
-
validate
final V1AnnotateParams.Document validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1AnnotateParams.Document.Builder builder()
Returns a mutable builder for constructing an instance of Document.
-
-
-
-