Class V1AnnotateParams.Field
-
- All Implemented Interfaces:
public final class V1AnnotateParams.Field
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnnotateParams.Field.BuilderA builder for Field.
public final classV1AnnotateParams.Field.TypeField data type
public final classV1AnnotateParams.Field.ValueValue to populate
public final classV1AnnotateParams.Field.OptionsOptional configuration (e.g., image dimensions)
-
Method Summary
Modifier and Type Method Description final V1AnnotateParams.Field.Typetype()Field data type final V1AnnotateParams.Field.Valuevalue()Value to populate final Optional<String>id()Target field ID (for single field) final Optional<String>group()Target field group (for multiple fields with same tag) final Optional<V1AnnotateParams.Field.Options>options()Optional configuration (e.g. final JsonField<V1AnnotateParams.Field.Type>_type()Returns the raw JSON value of type. final JsonField<V1AnnotateParams.Field.Value>_value()Returns the raw JSON value of value. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_group()Returns the raw JSON value of group. final JsonField<V1AnnotateParams.Field.Options>_options()Returns the raw JSON value of options. final Map<String, JsonValue>_additionalProperties()final V1AnnotateParams.Field.BuildertoBuilder()final V1AnnotateParams.Fieldvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnnotateParams.Field.Builderbuilder()Returns a mutable builder for constructing an instance of Field. -
-
Method Detail
-
type
final V1AnnotateParams.Field.Type type()
Field data type
-
value
final V1AnnotateParams.Field.Value value()
Value to populate
-
options
final Optional<V1AnnotateParams.Field.Options> options()
Optional configuration (e.g., image dimensions)
-
_type
final JsonField<V1AnnotateParams.Field.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<V1AnnotateParams.Field.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_group
final JsonField<String> _group()
Returns the raw JSON value of group.
Unlike group, this method doesn't throw if the JSON field has an unexpected type.
-
_options
final JsonField<V1AnnotateParams.Field.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1AnnotateParams.Field.Builder toBuilder()
-
validate
final V1AnnotateParams.Field validate()
-
builder
final static V1AnnotateParams.Field.Builder builder()
Returns a mutable builder for constructing an instance of Field.
The following fields are required:
.type() .value()
-
-
-
-