Package dev.case.api.models.superdoc.v1
Class V1AnnotateParams.Field.Options
-
- All Implemented Interfaces:
public final class V1AnnotateParams.Field.OptionsOptional configuration (e.g., image dimensions)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1AnnotateParams.Field.Options.BuilderA builder for Options.
-
Method Summary
Modifier and Type Method Description final Optional<Double>height()Image height in pixels final Optional<Double>width()Image width in pixels final JsonField<Double>_height()Returns the raw JSON value of height. final JsonField<Double>_width()Returns the raw JSON value of width. final Map<String, JsonValue>_additionalProperties()final V1AnnotateParams.Field.Options.BuildertoBuilder()final V1AnnotateParams.Field.Optionsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1AnnotateParams.Field.Options.Builderbuilder()Returns a mutable builder for constructing an instance of Options. -
-
Method Detail
-
_height
final JsonField<Double> _height()
Returns the raw JSON value of height.
Unlike height, this method doesn't throw if the JSON field has an unexpected type.
-
_width
final JsonField<Double> _width()
Returns the raw JSON value of width.
Unlike width, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1AnnotateParams.Field.Options.Builder toBuilder()
-
validate
final V1AnnotateParams.Field.Options validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1AnnotateParams.Field.Options.Builder builder()
Returns a mutable builder for constructing an instance of Options.
-
-
-
-