Class V1ConvertParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1ConvertParams implements Params
Convert documents between formats using SuperDoc. Supports DOCX to PDF, Markdown to DOCX, and HTML to DOCX conversions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ConvertParams.BuilderA builder for V1ConvertParams.
public final classV1ConvertParams.Bodypublic final classV1ConvertParams.FromSource format of the document
public final classV1ConvertParams.ToTarget format for conversion
-
Method Summary
Modifier and Type Method Description final V1ConvertParams.Fromfrom()Source format of the document final Optional<String>documentBase64()Base64-encoded document content final Optional<String>documentUrl()URL to the document to convert final Optional<V1ConvertParams.To>to()Target format for conversion final MultipartField<V1ConvertParams.From>_from()Returns the raw multipart value of from. final MultipartField<String>_documentBase64()Returns the raw multipart value of documentBase64. final MultipartField<String>_documentUrl()Returns the raw multipart value of documentUrl. final MultipartField<V1ConvertParams.To>_to()Returns the raw multipart value of to. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1ConvertParams.BuildertoBuilder()final Map<String, MultipartField<?>>_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ConvertParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1ConvertParams. -
-
Method Detail
-
from
final V1ConvertParams.From from()
Source format of the document
-
documentBase64
final Optional<String> documentBase64()
Base64-encoded document content
-
documentUrl
final Optional<String> documentUrl()
URL to the document to convert
-
to
final Optional<V1ConvertParams.To> to()
Target format for conversion
-
_from
final MultipartField<V1ConvertParams.From> _from()
Returns the raw multipart value of from.
Unlike from, this method doesn't throw if the multipart field has an unexpected type.
-
_documentBase64
final MultipartField<String> _documentBase64()
Returns the raw multipart value of documentBase64.
Unlike documentBase64, this method doesn't throw if the multipart field has an unexpected type.
-
_documentUrl
final MultipartField<String> _documentUrl()
Returns the raw multipart value of documentUrl.
Unlike documentUrl, this method doesn't throw if the multipart field has an unexpected type.
-
_to
final MultipartField<V1ConvertParams.To> _to()
Returns the raw multipart value of to.
Unlike to, this method doesn't throw if the multipart field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1ConvertParams.Builder toBuilder()
-
_body
final Map<String, MultipartField<?>> _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1ConvertParams.Builder builder()
Returns a mutable builder for constructing an instance of V1ConvertParams.
The following fields are required:
.from()
-
-
-
-