Class V1ConvertParams.Body
-
- All Implemented Interfaces:
public final class V1ConvertParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ConvertParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final V1ConvertParams.Fromfrom()Source format of the document final Optional<String>documentBase64()Base64-encoded document content final Optional<String>documentUrl()URL to the document to convert final Optional<V1ConvertParams.To>to()Target format for conversion final MultipartField<V1ConvertParams.From>_from()Returns the raw multipart value of from. final MultipartField<String>_documentBase64()Returns the raw multipart value of documentBase64. final MultipartField<String>_documentUrl()Returns the raw multipart value of documentUrl. final MultipartField<V1ConvertParams.To>_to()Returns the raw multipart value of to. final Map<String, JsonValue>_additionalProperties()final V1ConvertParams.Body.BuildertoBuilder()final V1ConvertParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ConvertParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
from
final V1ConvertParams.From from()
Source format of the document
-
documentBase64
final Optional<String> documentBase64()
Base64-encoded document content
-
documentUrl
final Optional<String> documentUrl()
URL to the document to convert
-
to
final Optional<V1ConvertParams.To> to()
Target format for conversion
-
_from
final MultipartField<V1ConvertParams.From> _from()
Returns the raw multipart value of from.
Unlike from, this method doesn't throw if the multipart field has an unexpected type.
-
_documentBase64
final MultipartField<String> _documentBase64()
Returns the raw multipart value of documentBase64.
Unlike documentBase64, this method doesn't throw if the multipart field has an unexpected type.
-
_documentUrl
final MultipartField<String> _documentUrl()
Returns the raw multipart value of documentUrl.
Unlike documentUrl, this method doesn't throw if the multipart field has an unexpected type.
-
_to
final MultipartField<V1ConvertParams.To> _to()
Returns the raw multipart value of to.
Unlike to, this method doesn't throw if the multipart field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ConvertParams.Body.Builder toBuilder()
-
validate
final V1ConvertParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ConvertParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.from()
-
-
-
-