Class V1ConvertParams.Body.Builder
-
- All Implemented Interfaces:
public final class V1ConvertParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
from
final V1ConvertParams.Body.Builder from(V1ConvertParams.From from)
Source format of the document
-
from
final V1ConvertParams.Body.Builder from(MultipartField<V1ConvertParams.From> from)
Sets Builder.from to an arbitrary multipart value.
You should usually call Builder.from with a well-typed From value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
documentBase64
final V1ConvertParams.Body.Builder documentBase64(String documentBase64)
Base64-encoded document content
-
documentBase64
final V1ConvertParams.Body.Builder documentBase64(MultipartField<String> documentBase64)
Sets Builder.documentBase64 to an arbitrary multipart value.
You should usually call Builder.documentBase64 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
documentUrl
final V1ConvertParams.Body.Builder documentUrl(String documentUrl)
URL to the document to convert
-
documentUrl
final V1ConvertParams.Body.Builder documentUrl(MultipartField<String> documentUrl)
Sets Builder.documentUrl to an arbitrary multipart value.
You should usually call Builder.documentUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
to
final V1ConvertParams.Body.Builder to(V1ConvertParams.To to)
Target format for conversion
-
to
final V1ConvertParams.Body.Builder to(MultipartField<V1ConvertParams.To> to)
Sets Builder.to to an arbitrary multipart value.
You should usually call Builder.to with a well-typed To value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1ConvertParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1ConvertParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1ConvertParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1ConvertParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1ConvertParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1ConvertParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.from()
-
-
-
-