Enum V1ConvertParams.To.Known

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      PDF
      DOCX
    • Method Summary

      Modifier and Type Method Description
      final V1ConvertParams.To.Known valueOf(String value) Returns the enum constant of this type with the specified name.
      final Array<V1ConvertParams.To.Known> values() Returns an array containing the constants of this enum type, in the order they're declared.
      final EnumEntries<V1ConvertParams.To.Known> getEntries() An enum containing To's known values.
      • Methods inherited from class kotlin.Enum

        getName, getOrdinal
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait