Package dev.case.api.models.system
Class SystemListServicesResponse
-
- All Implemented Interfaces:
public final class SystemListServicesResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSystemListServicesResponse.BuilderA builder for SystemListServicesResponse.
public final classSystemListServicesResponse.Service
-
Method Summary
Modifier and Type Method Description final List<SystemListServicesResponse.Service>services()final JsonField<List<SystemListServicesResponse.Service>>_services()Returns the raw JSON value of services. final Map<String, JsonValue>_additionalProperties()final SystemListServicesResponse.BuildertoBuilder()final SystemListServicesResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SystemListServicesResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SystemListServicesResponse. -
-
Method Detail
-
services
final List<SystemListServicesResponse.Service> services()
-
_services
final JsonField<List<SystemListServicesResponse.Service>> _services()
Returns the raw JSON value of services.
Unlike services, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SystemListServicesResponse.Builder toBuilder()
-
validate
final SystemListServicesResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SystemListServicesResponse.Builder builder()
Returns a mutable builder for constructing an instance of SystemListServicesResponse.
The following fields are required:
.services()
-
-
-
-