Package dev.case.api.models.system
Class SystemListServicesResponse.Builder
-
- All Implemented Interfaces:
public final class SystemListServicesResponse.BuilderA builder for SystemListServicesResponse.
-
-
Method Summary
-
-
Method Detail
-
services
final SystemListServicesResponse.Builder services(List<SystemListServicesResponse.Service> services)
-
services
final SystemListServicesResponse.Builder services(JsonField<List<SystemListServicesResponse.Service>> services)
Sets Builder.services to an arbitrary JSON value.
You should usually call Builder.services with a well-typed
List<Service>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addService
final SystemListServicesResponse.Builder addService(SystemListServicesResponse.Service service)
-
additionalProperties
final SystemListServicesResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SystemListServicesResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SystemListServicesResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SystemListServicesResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SystemListServicesResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SystemListServicesResponse build()
Returns an immutable instance of SystemListServicesResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.services()
-
-
-
-