Class SystemListServicesResponse.Service.Builder
-
- All Implemented Interfaces:
public final class SystemListServicesResponse.Service.BuilderA builder for Service.
-
-
Method Summary
-
-
Method Detail
-
id
final SystemListServicesResponse.Service.Builder id(String id)
-
id
final SystemListServicesResponse.Service.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final SystemListServicesResponse.Service.Builder description(String description)
-
description
final SystemListServicesResponse.Service.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
href
final SystemListServicesResponse.Service.Builder href(String href)
-
href
final SystemListServicesResponse.Service.Builder href(JsonField<String> href)
Sets Builder.href to an arbitrary JSON value.
You should usually call Builder.href with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
icon
final SystemListServicesResponse.Service.Builder icon(String icon)
-
icon
final SystemListServicesResponse.Service.Builder icon(JsonField<String> icon)
Sets Builder.icon to an arbitrary JSON value.
You should usually call Builder.icon with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final SystemListServicesResponse.Service.Builder name(String name)
-
name
final SystemListServicesResponse.Service.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
order
final SystemListServicesResponse.Service.Builder order(Long order)
-
order
final SystemListServicesResponse.Service.Builder order(JsonField<Long> order)
Sets Builder.order to an arbitrary JSON value.
You should usually call Builder.order with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SystemListServicesResponse.Service.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SystemListServicesResponse.Service.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SystemListServicesResponse.Service.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SystemListServicesResponse.Service.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SystemListServicesResponse.Service.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SystemListServicesResponse.Service build()
Returns an immutable instance of Service.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .description() .href() .icon() .name() .order()
-
-
-
-