Class V1DetectParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1DetectParams implements Params
Detect the language of text. Returns the most likely language code and confidence score. Supports batch detection for multiple texts.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectParams.BuilderA builder for V1DetectParams.
public final classV1DetectParams.Bodypublic final classV1DetectParams.QText to detect language for. Can be a single string or an array for batch detection.
-
Method Summary
Modifier and Type Method Description final V1DetectParams.Qq()Text to detect language for. final JsonField<V1DetectParams.Q>_q()Returns the raw JSON value of q. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1DetectParams.BuildertoBuilder()final V1DetectParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1DetectParams. -
-
Method Detail
-
q
final V1DetectParams.Q q()
Text to detect language for. Can be a single string or an array for batch detection.
-
_q
final JsonField<V1DetectParams.Q> _q()
Returns the raw JSON value of q.
Unlike q, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1DetectParams.Builder toBuilder()
-
_body
final V1DetectParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1DetectParams.Builder builder()
Returns a mutable builder for constructing an instance of V1DetectParams.
The following fields are required:
.q()
-
-
-
-