Package dev.case.api.models.translate.v1
Class V1DetectParams.Body
-
- All Implemented Interfaces:
public final class V1DetectParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final V1DetectParams.Qq()Text to detect language for. final JsonField<V1DetectParams.Q>_q()Returns the raw JSON value of q. final Map<String, JsonValue>_additionalProperties()final V1DetectParams.Body.BuildertoBuilder()final V1DetectParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
q
final V1DetectParams.Q q()
Text to detect language for. Can be a single string or an array for batch detection.
-
_q
final JsonField<V1DetectParams.Q> _q()
Returns the raw JSON value of q.
Unlike q, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DetectParams.Body.Builder toBuilder()
-
validate
final V1DetectParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1DetectParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.q()
-
-
-
-