Package dev.case.api.models.translate.v1
Class V1DetectResponse
-
- All Implemented Interfaces:
public final class V1DetectResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectResponse.BuilderA builder for V1DetectResponse.
public final classV1DetectResponse.Data
-
Method Summary
Modifier and Type Method Description final Optional<V1DetectResponse.Data>data()final JsonField<V1DetectResponse.Data>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final V1DetectResponse.BuildertoBuilder()final V1DetectResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1DetectResponse. -
-
Method Detail
-
data
final Optional<V1DetectResponse.Data> data()
-
_data
final JsonField<V1DetectResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DetectResponse.Builder toBuilder()
-
validate
final V1DetectResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1DetectResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1DetectResponse.
-
-
-
-