Package dev.case.api.models.translate.v1
Class V1DetectResponse.Data.Builder
-
- All Implemented Interfaces:
public final class V1DetectResponse.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
detections
final V1DetectResponse.Data.Builder detections(List<List<V1DetectResponse.Data.UnnamedSchemaWithArrayParent0>> detections)
-
detections
final V1DetectResponse.Data.Builder detections(JsonField<List<List<V1DetectResponse.Data.UnnamedSchemaWithArrayParent0>>> detections)
Sets Builder.detections to an arbitrary JSON value.
You should usually call Builder.detections with a well-typed
List<List<UnnamedSchemaWithArrayParent0>>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDetection
final V1DetectResponse.Data.Builder addDetection(List<V1DetectResponse.Data.UnnamedSchemaWithArrayParent0> detection)
Adds a single List<UnnamedSchemaWithArrayParent0> to detections.
-
additionalProperties
final V1DetectResponse.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1DetectResponse.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1DetectResponse.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1DetectResponse.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1DetectResponse.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1DetectResponse.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-