Package dev.case.api.models.translate.v1
Class V1DetectResponse.Data.UnnamedSchemaWithArrayParent0
-
- All Implemented Interfaces:
public final class V1DetectResponse.Data.UnnamedSchemaWithArrayParent0
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectResponse.Data.UnnamedSchemaWithArrayParent0.BuilderA builder for UnnamedSchemaWithArrayParent0.
-
Method Summary
Modifier and Type Method Description final Optional<Double>confidence()Confidence score (0-1) final Optional<Boolean>isReliable()Whether the detection is reliable final Optional<String>language()Detected language code (ISO 639-1) final JsonField<Double>_confidence()Returns the raw JSON value of confidence. final JsonField<Boolean>_isReliable()Returns the raw JSON value of isReliable. final JsonField<String>_language()Returns the raw JSON value of language. final Map<String, JsonValue>_additionalProperties()final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.BuildertoBuilder()final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0validate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builderbuilder()Returns a mutable builder for constructing an instance of UnnamedSchemaWithArrayParent0. -
-
Method Detail
-
confidence
final Optional<Double> confidence()
Confidence score (0-1)
-
isReliable
final Optional<Boolean> isReliable()
Whether the detection is reliable
-
_confidence
final JsonField<Double> _confidence()
Returns the raw JSON value of confidence.
Unlike confidence, this method doesn't throw if the JSON field has an unexpected type.
-
_isReliable
final JsonField<Boolean> _isReliable()
Returns the raw JSON value of isReliable.
Unlike isReliable, this method doesn't throw if the JSON field has an unexpected type.
-
_language
final JsonField<String> _language()
Returns the raw JSON value of language.
Unlike language, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder toBuilder()
-
validate
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0 validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder builder()
Returns a mutable builder for constructing an instance of UnnamedSchemaWithArrayParent0.
-
-
-
-