Class V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder
-
- All Implemented Interfaces:
public final class V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.BuilderA builder for UnnamedSchemaWithArrayParent0.
-
-
Method Summary
-
-
Method Detail
-
confidence
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder confidence(Double confidence)
Confidence score (0-1)
-
confidence
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder confidence(JsonField<Double> confidence)
Sets Builder.confidence to an arbitrary JSON value.
You should usually call Builder.confidence with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isReliable
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder isReliable(Boolean isReliable)
Whether the detection is reliable
-
isReliable
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder isReliable(JsonField<Boolean> isReliable)
Sets Builder.isReliable to an arbitrary JSON value.
You should usually call Builder.isReliable with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
language
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder language(String language)
Detected language code (ISO 639-1)
-
language
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder language(JsonField<String> language)
Sets Builder.language to an arbitrary JSON value.
You should usually call Builder.language with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final V1DetectResponse.Data.UnnamedSchemaWithArrayParent0 build()
Returns an immutable instance of UnnamedSchemaWithArrayParent0.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-