Class V1ListLanguagesParams.Model
-
- All Implemented Interfaces:
-
dev.case.api.core.Enum
public final class V1ListLanguagesParams.Model implements EnumTranslation model to check language support for
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumV1ListLanguagesParams.Model.KnownAn enum containing Model's known values.
public enumV1ListLanguagesParams.Model.ValueAn enum containing Model's known values, as well as an _UNKNOWN member.
An instance of Model can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static V1ListLanguagesParams.ModelNMTpublic final static V1ListLanguagesParams.ModelBASE
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final V1ListLanguagesParams.Model.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final V1ListLanguagesParams.Model.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final V1ListLanguagesParams.Modelvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListLanguagesParams.Modelof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final V1ListLanguagesParams.Model.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final V1ListLanguagesParams.Model.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final V1ListLanguagesParams.Model validate()
-
of
final static V1ListLanguagesParams.Model of(String value)
-
-
-
-