Package dev.case.api.models.translate.v1
Class V1ListLanguagesResponse.Data
-
- All Implemented Interfaces:
public final class V1ListLanguagesResponse.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListLanguagesResponse.Data.BuilderA builder for Data.
public final classV1ListLanguagesResponse.Data.Language
-
Method Summary
Modifier and Type Method Description final Optional<List<V1ListLanguagesResponse.Data.Language>>languages()final JsonField<List<V1ListLanguagesResponse.Data.Language>>_languages()Returns the raw JSON value of languages. final Map<String, JsonValue>_additionalProperties()final V1ListLanguagesResponse.Data.BuildertoBuilder()final V1ListLanguagesResponse.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListLanguagesResponse.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
languages
final Optional<List<V1ListLanguagesResponse.Data.Language>> languages()
-
_languages
final JsonField<List<V1ListLanguagesResponse.Data.Language>> _languages()
Returns the raw JSON value of languages.
Unlike languages, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ListLanguagesResponse.Data.Builder toBuilder()
-
validate
final V1ListLanguagesResponse.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ListLanguagesResponse.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-