Package dev.case.api.models.translate.v1
Class V1ListLanguagesResponse.Data.Language
-
- All Implemented Interfaces:
public final class V1ListLanguagesResponse.Data.Language
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListLanguagesResponse.Data.Language.BuilderA builder for Language.
-
Method Summary
Modifier and Type Method Description final Optional<String>language()Language code (ISO 639-1) final Optional<String>name()Language name (if target specified) final JsonField<String>_language()Returns the raw JSON value of language. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final V1ListLanguagesResponse.Data.Language.BuildertoBuilder()final V1ListLanguagesResponse.Data.Languagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListLanguagesResponse.Data.Language.Builderbuilder()Returns a mutable builder for constructing an instance of Language. -
-
Method Detail
-
_language
final JsonField<String> _language()
Returns the raw JSON value of language.
Unlike language, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ListLanguagesResponse.Data.Language.Builder toBuilder()
-
validate
final V1ListLanguagesResponse.Data.Language validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1ListLanguagesResponse.Data.Language.Builder builder()
Returns a mutable builder for constructing an instance of Language.
-
-
-
-