Class V1TranslateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1TranslateParams implements Params
Translate text between languages using Google Cloud Translation API. Supports 100+ languages, automatic language detection, HTML preservation, and batch translation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1TranslateParams.BuilderA builder for V1TranslateParams.
public final classV1TranslateParams.Bodypublic final classV1TranslateParams.QText to translate. Can be a single string or an array for batch translation.
public final classV1TranslateParams.FormatFormat of the source text. Use 'html' to preserve HTML tags.
public final classV1TranslateParams.ModelTranslation model. 'nmt' (Neural Machine Translation) is recommended for quality.
-
Method Summary
Modifier and Type Method Description final V1TranslateParams.Qq()Text to translate. final Stringtarget()Target language code (ISO 639-1) final Optional<V1TranslateParams.Format>format()Format of the source text. final Optional<V1TranslateParams.Model>model()Translation model. final Optional<String>source()Source language code (ISO 639-1). final JsonField<V1TranslateParams.Q>_q()Returns the raw JSON value of q. final JsonField<String>_target()Returns the raw JSON value of target. final JsonField<V1TranslateParams.Format>_format()Returns the raw JSON value of format. final JsonField<V1TranslateParams.Model>_model()Returns the raw JSON value of model. final JsonField<String>_source()Returns the raw JSON value of source. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1TranslateParams.BuildertoBuilder()final V1TranslateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1TranslateParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1TranslateParams. -
-
Method Detail
-
q
final V1TranslateParams.Q q()
Text to translate. Can be a single string or an array for batch translation.
-
format
final Optional<V1TranslateParams.Format> format()
Format of the source text. Use 'html' to preserve HTML tags.
-
model
final Optional<V1TranslateParams.Model> model()
Translation model. 'nmt' (Neural Machine Translation) is recommended for quality.
-
source
final Optional<String> source()
Source language code (ISO 639-1). If not specified, language is auto-detected.
-
_q
final JsonField<V1TranslateParams.Q> _q()
Returns the raw JSON value of q.
Unlike q, this method doesn't throw if the JSON field has an unexpected type.
-
_target
final JsonField<String> _target()
Returns the raw JSON value of target.
Unlike target, this method doesn't throw if the JSON field has an unexpected type.
-
_format
final JsonField<V1TranslateParams.Format> _format()
Returns the raw JSON value of format.
Unlike format, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<V1TranslateParams.Model> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<String> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1TranslateParams.Builder toBuilder()
-
_body
final V1TranslateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1TranslateParams.Builder builder()
Returns a mutable builder for constructing an instance of V1TranslateParams.
The following fields are required:
.q() .target()
-
-
-
-