Package dev.case.api.models.translate.v1
Class V1TranslateResponse
-
- All Implemented Interfaces:
public final class V1TranslateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1TranslateResponse.BuilderA builder for V1TranslateResponse.
public final classV1TranslateResponse.Data
-
Method Summary
Modifier and Type Method Description final Optional<V1TranslateResponse.Data>data()final JsonField<V1TranslateResponse.Data>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final V1TranslateResponse.BuildertoBuilder()final V1TranslateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1TranslateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1TranslateResponse. -
-
Method Detail
-
data
final Optional<V1TranslateResponse.Data> data()
-
_data
final JsonField<V1TranslateResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1TranslateResponse.Builder toBuilder()
-
validate
final V1TranslateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1TranslateResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1TranslateResponse.
-
-
-
-