Package dev.case.api.models.translate.v1
Class V1TranslateResponse.Data.Translation
-
- All Implemented Interfaces:
public final class V1TranslateResponse.Data.Translation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1TranslateResponse.Data.Translation.BuilderA builder for Translation.
-
Method Summary
Modifier and Type Method Description final Optional<String>detectedSourceLanguage()Detected source language (if source not specified) final Optional<String>model()Model used for translation final Optional<String>translatedText()Translated text final JsonField<String>_detectedSourceLanguage()Returns the raw JSON value of detectedSourceLanguage. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_translatedText()Returns the raw JSON value of translatedText. final Map<String, JsonValue>_additionalProperties()final V1TranslateResponse.Data.Translation.BuildertoBuilder()final V1TranslateResponse.Data.Translationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1TranslateResponse.Data.Translation.Builderbuilder()Returns a mutable builder for constructing an instance of Translation. -
-
Method Detail
-
detectedSourceLanguage
final Optional<String> detectedSourceLanguage()
Detected source language (if source not specified)
-
translatedText
final Optional<String> translatedText()
Translated text
-
_detectedSourceLanguage
final JsonField<String> _detectedSourceLanguage()
Returns the raw JSON value of detectedSourceLanguage.
Unlike detectedSourceLanguage, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_translatedText
final JsonField<String> _translatedText()
Returns the raw JSON value of translatedText.
Unlike translatedText, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1TranslateResponse.Data.Translation.Builder toBuilder()
-
validate
final V1TranslateResponse.Data.Translation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V1TranslateResponse.Data.Translation.Builder builder()
Returns a mutable builder for constructing an instance of Translation.
-
-
-
-