Package dev.case.api.models.usage.v1
Enum V1RetrieveParams.Granularity.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum V1RetrieveParams.Granularity.Known extends Enum<V1RetrieveParams.Granularity.Known>
An enum containing Granularity's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<V1RetrieveParams.Granularity.Known>entries
-
Method Summary
Modifier and Type Method Description final V1RetrieveParams.Granularity.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<V1RetrieveParams.Granularity.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<V1RetrieveParams.Granularity.Known>getEntries()An enum containing Granularity's known values. -
-
Method Detail
-
valueOf
final V1RetrieveParams.Granularity.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<V1RetrieveParams.Granularity.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<V1RetrieveParams.Granularity.Known> getEntries()
An enum containing Granularity's known values.
-
-
-
-