Class SubscriptionTestParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class SubscriptionTestParams
     implements Params
                        

    Delivers a test event to a single usage webhook subscription using the same payload shape and signing behavior as production delivery.