Class SubscriptionUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SubscriptionUpdateParams implements Params
Updates callback URL, event filters, active state, or signing secret.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionUpdateParams.BuilderA builder for SubscriptionUpdateParams.
public final classSubscriptionUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>subscriptionId()final Optional<String>callbackUrl()final Optional<Boolean>clearSigningSecret()final Optional<List<String>>eventTypes()final Optional<Boolean>isActive()final Optional<String>signingSecret()final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final JsonField<Boolean>_clearSigningSecret()Returns the raw JSON value of clearSigningSecret. final JsonField<List<String>>_eventTypes()Returns the raw JSON value of eventTypes. final JsonField<Boolean>_isActive()Returns the raw JSON value of isActive. final JsonField<String>_signingSecret()Returns the raw JSON value of signingSecret. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SubscriptionUpdateParams.BuildertoBuilder()final SubscriptionUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SubscriptionUpdateParamsnone()final static SubscriptionUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SubscriptionUpdateParams. -
-
Method Detail
-
subscriptionId
final Optional<String> subscriptionId()
-
callbackUrl
final Optional<String> callbackUrl()
-
clearSigningSecret
final Optional<Boolean> clearSigningSecret()
-
eventTypes
final Optional<List<String>> eventTypes()
-
signingSecret
final Optional<String> signingSecret()
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_clearSigningSecret
final JsonField<Boolean> _clearSigningSecret()
Returns the raw JSON value of clearSigningSecret.
Unlike clearSigningSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<String>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_signingSecret
final JsonField<String> _signingSecret()
Returns the raw JSON value of signingSecret.
Unlike signingSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SubscriptionUpdateParams.Builder toBuilder()
-
_body
final SubscriptionUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SubscriptionUpdateParams none()
-
builder
final static SubscriptionUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of SubscriptionUpdateParams.
-
-
-
-