Class SubscriptionUpdateParams.Body
-
- All Implemented Interfaces:
public final class SubscriptionUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
callbackUrl
final Optional<String> callbackUrl()
-
clearSigningSecret
final Optional<Boolean> clearSigningSecret()
-
eventTypes
final Optional<List<String>> eventTypes()
-
signingSecret
final Optional<String> signingSecret()
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_clearSigningSecret
final JsonField<Boolean> _clearSigningSecret()
Returns the raw JSON value of clearSigningSecret.
Unlike clearSigningSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<String>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_signingSecret
final JsonField<String> _signingSecret()
Returns the raw JSON value of signingSecret.
Unlike signingSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SubscriptionUpdateParams.Body.Builder toBuilder()
-
validate
final SubscriptionUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SubscriptionUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-