Class SubscriptionUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SubscriptionUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
callbackUrl
final SubscriptionUpdateParams.Body.Builder callbackUrl(String callbackUrl)
-
callbackUrl
final SubscriptionUpdateParams.Body.Builder callbackUrl(JsonField<String> callbackUrl)
Sets Builder.callbackUrl to an arbitrary JSON value.
You should usually call Builder.callbackUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clearSigningSecret
final SubscriptionUpdateParams.Body.Builder clearSigningSecret(Boolean clearSigningSecret)
-
clearSigningSecret
final SubscriptionUpdateParams.Body.Builder clearSigningSecret(JsonField<Boolean> clearSigningSecret)
Sets Builder.clearSigningSecret to an arbitrary JSON value.
You should usually call Builder.clearSigningSecret with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventTypes
final SubscriptionUpdateParams.Body.Builder eventTypes(List<String> eventTypes)
-
eventTypes
final SubscriptionUpdateParams.Body.Builder eventTypes(JsonField<List<String>> eventTypes)
Sets Builder.eventTypes to an arbitrary JSON value.
You should usually call Builder.eventTypes with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEventType
final SubscriptionUpdateParams.Body.Builder addEventType(String eventType)
Adds a single String to eventTypes.
-
isActive
final SubscriptionUpdateParams.Body.Builder isActive(Boolean isActive)
-
isActive
final SubscriptionUpdateParams.Body.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
signingSecret
final SubscriptionUpdateParams.Body.Builder signingSecret(String signingSecret)
-
signingSecret
final SubscriptionUpdateParams.Body.Builder signingSecret(JsonField<String> signingSecret)
Sets Builder.signingSecret to an arbitrary JSON value.
You should usually call Builder.signingSecret with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SubscriptionUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SubscriptionUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SubscriptionUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SubscriptionUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SubscriptionUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SubscriptionUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-