Class VaultConfirmUploadResponse
-
- All Implemented Interfaces:
public final class VaultConfirmUploadResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultConfirmUploadResponse.BuilderA builder for VaultConfirmUploadResponse.
public final classVaultConfirmUploadResponse.Status
-
Method Summary
-
-
Method Detail
-
alreadyConfirmed
final Optional<Boolean> alreadyConfirmed()
-
status
final Optional<VaultConfirmUploadResponse.Status> status()
-
_alreadyConfirmed
final JsonField<Boolean> _alreadyConfirmed()
Returns the raw JSON value of alreadyConfirmed.
Unlike alreadyConfirmed, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<VaultConfirmUploadResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultConfirmUploadResponse.Builder toBuilder()
-
validate
final VaultConfirmUploadResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultConfirmUploadResponse.Builder builder()
Returns a mutable builder for constructing an instance of VaultConfirmUploadResponse.
-
-
-
-