Class VaultCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class VaultCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
name
final VaultCreateParams.Body.Builder name(String name)
Display name for the vault
-
name
final VaultCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final VaultCreateParams.Body.Builder description(String description)
Optional description of the vault's purpose
-
description
final VaultCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableGraph
final VaultCreateParams.Body.Builder enableGraph(Boolean enableGraph)
Enable knowledge graph for entity relationship mapping. Only applies when enableIndexing is true.
-
enableGraph
final VaultCreateParams.Body.Builder enableGraph(JsonField<Boolean> enableGraph)
Sets Builder.enableGraph to an arbitrary JSON value.
You should usually call Builder.enableGraph with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableIndexing
final VaultCreateParams.Body.Builder enableIndexing(Boolean enableIndexing)
Enable vector indexing and search capabilities. Set to false for storage-only vaults.
-
enableIndexing
final VaultCreateParams.Body.Builder enableIndexing(JsonField<Boolean> enableIndexing)
Sets Builder.enableIndexing to an arbitrary JSON value.
You should usually call Builder.enableIndexing with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
groupId
final VaultCreateParams.Body.Builder groupId(String groupId)
Assign the vault to a vault group for access control. Required when using a group-scoped API key.
-
groupId
final VaultCreateParams.Body.Builder groupId(JsonField<String> groupId)
Sets Builder.groupId to an arbitrary JSON value.
You should usually call Builder.groupId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final VaultCreateParams.Body.Builder metadata(JsonValue metadata)
Optional metadata to attach to the vault (e.g., { containsPHI: true } for HIPAA compliance tracking)
-
additionalProperties
final VaultCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-