Package dev.case.api.models.vault
Enum VaultCreateParams.EmbeddingModel.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum VaultCreateParams.EmbeddingModel.Known extends Enum<VaultCreateParams.EmbeddingModel.Known>
An enum containing EmbeddingModel's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<VaultCreateParams.EmbeddingModel.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description OPENAI_TEXT_EMBEDDING_3_SMALLOPENAI_TEXT_EMBEDDING_3_LARGEVOYAGE_VOYAGE_3_5VOYAGE_VOYAGE_LAW_2COHERE_EMBED_V4_0GOOGLE_GEMINI_EMBEDDING_2CASEMARK_EMBED_V1CASEMARK_LLAMA_NEMOTRON_EMBED_VL_1B_V2
-
Method Summary
Modifier and Type Method Description final VaultCreateParams.EmbeddingModel.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<VaultCreateParams.EmbeddingModel.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<VaultCreateParams.EmbeddingModel.Known>getEntries()An enum containing EmbeddingModel's known values. -
-
Method Detail
-
valueOf
final VaultCreateParams.EmbeddingModel.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<VaultCreateParams.EmbeddingModel.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<VaultCreateParams.EmbeddingModel.Known> getEntries()
An enum containing EmbeddingModel's known values.
-
-
-
-