Enum VaultCreateParams.EmbeddingModel.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum VaultCreateParams.EmbeddingModel.Value extends Enum<VaultCreateParams.EmbeddingModel.Value>
An enum containing EmbeddingModel's known values, as well as an _UNKNOWN member.
An instance of EmbeddingModel can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<VaultCreateParams.EmbeddingModel.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description OPENAI_TEXT_EMBEDDING_3_SMALLOPENAI_TEXT_EMBEDDING_3_LARGEVOYAGE_VOYAGE_3_5VOYAGE_VOYAGE_LAW_2COHERE_EMBED_V4_0GOOGLE_GEMINI_EMBEDDING_2CASEMARK_EMBED_V1CASEMARK_LLAMA_NEMOTRON_EMBED_VL_1B_V2_UNKNOWNAn enum member indicating that EmbeddingModel was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final VaultCreateParams.EmbeddingModel.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<VaultCreateParams.EmbeddingModel.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<VaultCreateParams.EmbeddingModel.Value>getEntries()An enum containing EmbeddingModel's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final VaultCreateParams.EmbeddingModel.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<VaultCreateParams.EmbeddingModel.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<VaultCreateParams.EmbeddingModel.Value> getEntries()
An enum containing EmbeddingModel's known values, as well as an _UNKNOWN member.
An instance of EmbeddingModel can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-