Class VaultCreateResponse.Builder
-
- All Implemented Interfaces:
public final class VaultCreateResponse.BuilderA builder for VaultCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final VaultCreateResponse.Builder id(String id)
Unique vault identifier
-
id
final VaultCreateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final VaultCreateResponse.Builder createdAt(OffsetDateTime createdAt)
Vault creation timestamp
-
createdAt
final VaultCreateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final VaultCreateResponse.Builder description(String description)
Vault description
-
description
final VaultCreateResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableIndexing
final VaultCreateResponse.Builder enableIndexing(Boolean enableIndexing)
Whether vector indexing is enabled for this vault
-
enableIndexing
final VaultCreateResponse.Builder enableIndexing(JsonField<Boolean> enableIndexing)
Sets Builder.enableIndexing to an arbitrary JSON value.
You should usually call Builder.enableIndexing with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filesBucket
final VaultCreateResponse.Builder filesBucket(String filesBucket)
S3 bucket name for document storage
-
filesBucket
final VaultCreateResponse.Builder filesBucket(JsonField<String> filesBucket)
Sets Builder.filesBucket to an arbitrary JSON value.
You should usually call Builder.filesBucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
indexName
final VaultCreateResponse.Builder indexName(String indexName)
Vector search index name. Null for storage-only vaults.
-
indexName
final VaultCreateResponse.Builder indexName(Optional<String> indexName)
Alias for calling Builder.indexName with
indexName.orElse(null).
-
indexName
final VaultCreateResponse.Builder indexName(JsonField<String> indexName)
Sets Builder.indexName to an arbitrary JSON value.
You should usually call Builder.indexName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final VaultCreateResponse.Builder name(String name)
Vault display name
-
name
final VaultCreateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final VaultCreateResponse.Builder region(String region)
AWS region for storage
-
region
final VaultCreateResponse.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vectorBucket
final VaultCreateResponse.Builder vectorBucket(String vectorBucket)
S3 bucket name for vector embeddings. Null for storage-only vaults.
-
vectorBucket
final VaultCreateResponse.Builder vectorBucket(Optional<String> vectorBucket)
Alias for calling Builder.vectorBucket with
vectorBucket.orElse(null).
-
vectorBucket
final VaultCreateResponse.Builder vectorBucket(JsonField<String> vectorBucket)
Sets Builder.vectorBucket to an arbitrary JSON value.
You should usually call Builder.vectorBucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultCreateResponse build()
Returns an immutable instance of VaultCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-