Class VaultCreateResponse.EmbeddingProfile
-
- All Implemented Interfaces:
public final class VaultCreateResponse.EmbeddingProfileThe resolved embedding profile for this vault. Null for storage-only vaults.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultCreateResponse.EmbeddingProfile.BuilderA builder for EmbeddingProfile.
-
Method Summary
Modifier and Type Method Description final Optional<Long>dimensions()Vector dimension used by this vault final Optional<String>model()Embedding model catalog key final Optional<String>provider()Embedding provider final JsonField<Long>_dimensions()Returns the raw JSON value of dimensions. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_provider()Returns the raw JSON value of provider. final Map<String, JsonValue>_additionalProperties()final VaultCreateResponse.EmbeddingProfile.BuildertoBuilder()final VaultCreateResponse.EmbeddingProfilevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultCreateResponse.EmbeddingProfile.Builderbuilder()Returns a mutable builder for constructing an instance of EmbeddingProfile. -
-
Method Detail
-
dimensions
final Optional<Long> dimensions()
Vector dimension used by this vault
-
_dimensions
final JsonField<Long> _dimensions()
Returns the raw JSON value of dimensions.
Unlike dimensions, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_provider
final JsonField<String> _provider()
Returns the raw JSON value of provider.
Unlike provider, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultCreateResponse.EmbeddingProfile.Builder toBuilder()
-
validate
final VaultCreateResponse.EmbeddingProfile validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultCreateResponse.EmbeddingProfile.Builder builder()
Returns a mutable builder for constructing an instance of EmbeddingProfile.
-
-
-
-