Class VaultCreateResponse.EmbeddingProfile.Builder
-
- All Implemented Interfaces:
public final class VaultCreateResponse.EmbeddingProfile.BuilderA builder for EmbeddingProfile.
-
-
Method Summary
-
-
Method Detail
-
dimensions
final VaultCreateResponse.EmbeddingProfile.Builder dimensions(Long dimensions)
Vector dimension used by this vault
-
dimensions
final VaultCreateResponse.EmbeddingProfile.Builder dimensions(JsonField<Long> dimensions)
Sets Builder.dimensions to an arbitrary JSON value.
You should usually call Builder.dimensions with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final VaultCreateResponse.EmbeddingProfile.Builder model(String model)
Embedding model catalog key
-
model
final VaultCreateResponse.EmbeddingProfile.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
provider
final VaultCreateResponse.EmbeddingProfile.Builder provider(String provider)
Embedding provider
-
provider
final VaultCreateResponse.EmbeddingProfile.Builder provider(JsonField<String> provider)
Sets Builder.provider to an arbitrary JSON value.
You should usually call Builder.provider with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultCreateResponse.EmbeddingProfile.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultCreateResponse.EmbeddingProfile.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultCreateResponse.EmbeddingProfile.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultCreateResponse.EmbeddingProfile.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultCreateResponse.EmbeddingProfile.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultCreateResponse.EmbeddingProfile build()
Returns an immutable instance of EmbeddingProfile.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-