Class VaultDeleteParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class VaultDeleteParams implements Params
Permanently deletes a vault and all its contents including documents, vectors, graph data, and S3 buckets. This operation cannot be undone. For large vaults, use the async=true query parameter to queue deletion in the background.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultDeleteParams.BuilderA builder for VaultDeleteParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Boolean>async()If true and vault has many objects, queue deletion in background and return immediately final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final VaultDeleteParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultDeleteParamsnone()final static VaultDeleteParams.Builderbuilder()Returns a mutable builder for constructing an instance of VaultDeleteParams. -
-
Method Detail
-
async
final Optional<Boolean> async()
If true and vault has many objects, queue deletion in background and return immediately
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final VaultDeleteParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static VaultDeleteParams none()
-
builder
final static VaultDeleteParams.Builder builder()
Returns a mutable builder for constructing an instance of VaultDeleteParams.
-
-
-
-