Class VaultIngestResponse.Builder
-
- All Implemented Interfaces:
public final class VaultIngestResponse.BuilderA builder for VaultIngestResponse.
-
-
Method Summary
-
-
Method Detail
-
enableGraphRag
final VaultIngestResponse.Builder enableGraphRag(Boolean enableGraphRag)
Always false - GraphRAG must be triggered separately via POST /vault/:id/graphrag/:objectId
-
enableGraphRag
final VaultIngestResponse.Builder enableGraphRag(JsonField<Boolean> enableGraphRag)
Sets Builder.enableGraphRag to an arbitrary JSON value.
You should usually call Builder.enableGraphRag with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
message
final VaultIngestResponse.Builder message(String message)
Human-readable status message
-
message
final VaultIngestResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final VaultIngestResponse.Builder objectId(String objectId)
ID of the vault object being processed
-
objectId
final VaultIngestResponse.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final VaultIngestResponse.Builder status(VaultIngestResponse.Status status)
Current ingestion status. 'stored' for file types without text extraction (no chunks/vectors created).
-
status
final VaultIngestResponse.Builder status(JsonField<VaultIngestResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workflowId
final VaultIngestResponse.Builder workflowId(String workflowId)
Workflow run ID for tracking progress. Null for file types that skip processing.
-
workflowId
final VaultIngestResponse.Builder workflowId(Optional<String> workflowId)
Alias for calling Builder.workflowId with
workflowId.orElse(null).
-
workflowId
final VaultIngestResponse.Builder workflowId(JsonField<String> workflowId)
Sets Builder.workflowId to an arbitrary JSON value.
You should usually call Builder.workflowId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultIngestResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultIngestResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultIngestResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultIngestResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultIngestResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultIngestResponse build()
Returns an immutable instance of VaultIngestResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.enableGraphRag() .message() .objectId() .status() .workflowId()
-
-
-
-