Class VaultListResponse.Vault
-
- All Implemented Interfaces:
public final class VaultListResponse.Vault
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultListResponse.Vault.BuilderA builder for Vault.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Vault identifier final Optional<OffsetDateTime>createdAt()Vault creation timestamp final Optional<String>description()Vault description final Optional<Boolean>enableGraph()Whether GraphRAG is enabled final Optional<String>name()Vault name final Optional<Long>totalBytes()Total storage size in bytes final Optional<Long>totalObjects()Number of stored documents final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_enableGraph()Returns the raw JSON value of enableGraph. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_totalBytes()Returns the raw JSON value of totalBytes. final JsonField<Long>_totalObjects()Returns the raw JSON value of totalObjects. final Map<String, JsonValue>_additionalProperties()final VaultListResponse.Vault.BuildertoBuilder()final VaultListResponse.Vaultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultListResponse.Vault.Builderbuilder()Returns a mutable builder for constructing an instance of Vault. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Vault creation timestamp
-
description
final Optional<String> description()
Vault description
-
enableGraph
final Optional<Boolean> enableGraph()
Whether GraphRAG is enabled
-
totalBytes
final Optional<Long> totalBytes()
Total storage size in bytes
-
totalObjects
final Optional<Long> totalObjects()
Number of stored documents
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_enableGraph
final JsonField<Boolean> _enableGraph()
Returns the raw JSON value of enableGraph.
Unlike enableGraph, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_totalBytes
final JsonField<Long> _totalBytes()
Returns the raw JSON value of totalBytes.
Unlike totalBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_totalObjects
final JsonField<Long> _totalObjects()
Returns the raw JSON value of totalObjects.
Unlike totalObjects, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultListResponse.Vault.Builder toBuilder()
-
validate
final VaultListResponse.Vault validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultListResponse.Vault.Builder builder()
Returns a mutable builder for constructing an instance of Vault.
-
-
-
-