Class VaultListResponse.Vault.Builder
-
- All Implemented Interfaces:
public final class VaultListResponse.Vault.BuilderA builder for Vault.
-
-
Method Summary
-
-
Method Detail
-
id
final VaultListResponse.Vault.Builder id(String id)
Vault identifier
-
id
final VaultListResponse.Vault.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final VaultListResponse.Vault.Builder createdAt(OffsetDateTime createdAt)
Vault creation timestamp
-
createdAt
final VaultListResponse.Vault.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final VaultListResponse.Vault.Builder description(String description)
Vault description
-
description
final VaultListResponse.Vault.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableGraph
final VaultListResponse.Vault.Builder enableGraph(Boolean enableGraph)
Whether GraphRAG is enabled
-
enableGraph
final VaultListResponse.Vault.Builder enableGraph(JsonField<Boolean> enableGraph)
Sets Builder.enableGraph to an arbitrary JSON value.
You should usually call Builder.enableGraph with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final VaultListResponse.Vault.Builder name(String name)
Vault name
-
name
final VaultListResponse.Vault.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalBytes
final VaultListResponse.Vault.Builder totalBytes(Long totalBytes)
Total storage size in bytes
-
totalBytes
final VaultListResponse.Vault.Builder totalBytes(JsonField<Long> totalBytes)
Sets Builder.totalBytes to an arbitrary JSON value.
You should usually call Builder.totalBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalObjects
final VaultListResponse.Vault.Builder totalObjects(Long totalObjects)
Number of stored documents
-
totalObjects
final VaultListResponse.Vault.Builder totalObjects(JsonField<Long> totalObjects)
Sets Builder.totalObjects to an arbitrary JSON value.
You should usually call Builder.totalObjects with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultListResponse.Vault.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultListResponse.Vault.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultListResponse.Vault.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultListResponse.Vault.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultListResponse.Vault.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultListResponse.Vault build()
Returns an immutable instance of Vault.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-