Class VaultRetrieveResponse
-
- All Implemented Interfaces:
public final class VaultRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultRetrieveResponse.BuilderA builder for VaultRetrieveResponse.
public final classVaultRetrieveResponse.ChunkStrategyDocument chunking strategy configuration
-
Method Summary
Modifier and Type Method Description final Stringid()Vault identifier final OffsetDateTimecreatedAt()Vault creation timestamp final StringfilesBucket()S3 bucket for document storage final Stringname()Vault name final Stringregion()AWS region final Optional<VaultRetrieveResponse.ChunkStrategy>chunkStrategy()Document chunking strategy configuration final Optional<String>description()Vault description final Optional<Boolean>enableGraph()Whether GraphRAG is enabled final Optional<String>indexName()Search index name final Optional<String>kmsKeyId()KMS key for encryption final JsonValue_metadata()Additional vault metadataThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = vaultRetrieveResponse.metadata().convert(MyClass.class);final Optional<Long>totalBytes()Total storage size in bytes final Optional<Long>totalObjects()Number of stored documents final Optional<Long>totalVectors()Number of vector embeddings final Optional<OffsetDateTime>updatedAt()Last update timestamp final Optional<String>vectorBucket()S3 bucket for vector embeddings final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_filesBucket()Returns the raw JSON value of filesBucket. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<VaultRetrieveResponse.ChunkStrategy>_chunkStrategy()Returns the raw JSON value of chunkStrategy. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_enableGraph()Returns the raw JSON value of enableGraph. final JsonField<String>_indexName()Returns the raw JSON value of indexName. final JsonField<String>_kmsKeyId()Returns the raw JSON value of kmsKeyId. final JsonField<Long>_totalBytes()Returns the raw JSON value of totalBytes. final JsonField<Long>_totalObjects()Returns the raw JSON value of totalObjects. final JsonField<Long>_totalVectors()Returns the raw JSON value of totalVectors. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<String>_vectorBucket()Returns the raw JSON value of vectorBucket. final Map<String, JsonValue>_additionalProperties()final VaultRetrieveResponse.BuildertoBuilder()final VaultRetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VaultRetrieveResponse. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
Vault creation timestamp
-
filesBucket
final String filesBucket()
S3 bucket for document storage
-
chunkStrategy
final Optional<VaultRetrieveResponse.ChunkStrategy> chunkStrategy()
Document chunking strategy configuration
-
description
final Optional<String> description()
Vault description
-
enableGraph
final Optional<Boolean> enableGraph()
Whether GraphRAG is enabled
-
_metadata
final JsonValue _metadata()
Additional vault metadata
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = vaultRetrieveResponse.metadata().convert(MyClass.class);
-
totalBytes
final Optional<Long> totalBytes()
Total storage size in bytes
-
totalObjects
final Optional<Long> totalObjects()
Number of stored documents
-
totalVectors
final Optional<Long> totalVectors()
Number of vector embeddings
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Last update timestamp
-
vectorBucket
final Optional<String> vectorBucket()
S3 bucket for vector embeddings
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_filesBucket
final JsonField<String> _filesBucket()
Returns the raw JSON value of filesBucket.
Unlike filesBucket, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_chunkStrategy
final JsonField<VaultRetrieveResponse.ChunkStrategy> _chunkStrategy()
Returns the raw JSON value of chunkStrategy.
Unlike chunkStrategy, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_enableGraph
final JsonField<Boolean> _enableGraph()
Returns the raw JSON value of enableGraph.
Unlike enableGraph, this method doesn't throw if the JSON field has an unexpected type.
-
_indexName
final JsonField<String> _indexName()
Returns the raw JSON value of indexName.
Unlike indexName, this method doesn't throw if the JSON field has an unexpected type.
-
_kmsKeyId
final JsonField<String> _kmsKeyId()
Returns the raw JSON value of kmsKeyId.
Unlike kmsKeyId, this method doesn't throw if the JSON field has an unexpected type.
-
_totalBytes
final JsonField<Long> _totalBytes()
Returns the raw JSON value of totalBytes.
Unlike totalBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_totalObjects
final JsonField<Long> _totalObjects()
Returns the raw JSON value of totalObjects.
Unlike totalObjects, this method doesn't throw if the JSON field has an unexpected type.
-
_totalVectors
final JsonField<Long> _totalVectors()
Returns the raw JSON value of totalVectors.
Unlike totalVectors, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_vectorBucket
final JsonField<String> _vectorBucket()
Returns the raw JSON value of vectorBucket.
Unlike vectorBucket, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultRetrieveResponse.Builder toBuilder()
-
validate
final VaultRetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of VaultRetrieveResponse.
The following fields are required:
.id() .createdAt() .filesBucket() .name() .region()
-
-
-
-