Class VaultRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class VaultRetrieveResponse.BuilderA builder for VaultRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final VaultRetrieveResponse.Builder id(String id)
Vault identifier
-
id
final VaultRetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final VaultRetrieveResponse.Builder createdAt(OffsetDateTime createdAt)
Vault creation timestamp
-
createdAt
final VaultRetrieveResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filesBucket
final VaultRetrieveResponse.Builder filesBucket(String filesBucket)
S3 bucket for document storage
-
filesBucket
final VaultRetrieveResponse.Builder filesBucket(JsonField<String> filesBucket)
Sets Builder.filesBucket to an arbitrary JSON value.
You should usually call Builder.filesBucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final VaultRetrieveResponse.Builder name(String name)
Vault name
-
name
final VaultRetrieveResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final VaultRetrieveResponse.Builder region(String region)
AWS region
-
region
final VaultRetrieveResponse.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chunkStrategy
final VaultRetrieveResponse.Builder chunkStrategy(VaultRetrieveResponse.ChunkStrategy chunkStrategy)
Document chunking strategy configuration
-
chunkStrategy
final VaultRetrieveResponse.Builder chunkStrategy(JsonField<VaultRetrieveResponse.ChunkStrategy> chunkStrategy)
Sets Builder.chunkStrategy to an arbitrary JSON value.
You should usually call Builder.chunkStrategy with a well-typed ChunkStrategy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final VaultRetrieveResponse.Builder description(String description)
Vault description
-
description
final VaultRetrieveResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableGraph
final VaultRetrieveResponse.Builder enableGraph(Boolean enableGraph)
Whether GraphRAG is enabled
-
enableGraph
final VaultRetrieveResponse.Builder enableGraph(JsonField<Boolean> enableGraph)
Sets Builder.enableGraph to an arbitrary JSON value.
You should usually call Builder.enableGraph with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
indexName
final VaultRetrieveResponse.Builder indexName(String indexName)
Search index name
-
indexName
final VaultRetrieveResponse.Builder indexName(JsonField<String> indexName)
Sets Builder.indexName to an arbitrary JSON value.
You should usually call Builder.indexName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
kmsKeyId
final VaultRetrieveResponse.Builder kmsKeyId(String kmsKeyId)
KMS key for encryption
-
kmsKeyId
final VaultRetrieveResponse.Builder kmsKeyId(JsonField<String> kmsKeyId)
Sets Builder.kmsKeyId to an arbitrary JSON value.
You should usually call Builder.kmsKeyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final VaultRetrieveResponse.Builder metadata(JsonValue metadata)
Additional vault metadata
-
totalBytes
final VaultRetrieveResponse.Builder totalBytes(Long totalBytes)
Total storage size in bytes
-
totalBytes
final VaultRetrieveResponse.Builder totalBytes(JsonField<Long> totalBytes)
Sets Builder.totalBytes to an arbitrary JSON value.
You should usually call Builder.totalBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalObjects
final VaultRetrieveResponse.Builder totalObjects(Long totalObjects)
Number of stored documents
-
totalObjects
final VaultRetrieveResponse.Builder totalObjects(JsonField<Long> totalObjects)
Sets Builder.totalObjects to an arbitrary JSON value.
You should usually call Builder.totalObjects with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalVectors
final VaultRetrieveResponse.Builder totalVectors(Long totalVectors)
Number of vector embeddings
-
totalVectors
final VaultRetrieveResponse.Builder totalVectors(JsonField<Long> totalVectors)
Sets Builder.totalVectors to an arbitrary JSON value.
You should usually call Builder.totalVectors with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final VaultRetrieveResponse.Builder updatedAt(OffsetDateTime updatedAt)
Last update timestamp
-
updatedAt
final VaultRetrieveResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vectorBucket
final VaultRetrieveResponse.Builder vectorBucket(String vectorBucket)
S3 bucket for vector embeddings
-
vectorBucket
final VaultRetrieveResponse.Builder vectorBucket(Optional<String> vectorBucket)
Alias for calling Builder.vectorBucket with
vectorBucket.orElse(null).
-
vectorBucket
final VaultRetrieveResponse.Builder vectorBucket(JsonField<String> vectorBucket)
Sets Builder.vectorBucket to an arbitrary JSON value.
You should usually call Builder.vectorBucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultRetrieveResponse build()
Returns an immutable instance of VaultRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .filesBucket() .name() .region()
-
-
-
-