Class VaultRetrieveResponse.ChunkStrategy.Builder
-
- All Implemented Interfaces:
public final class VaultRetrieveResponse.ChunkStrategy.BuilderA builder for ChunkStrategy.
-
-
Method Summary
-
-
Method Detail
-
chunkSize
final VaultRetrieveResponse.ChunkStrategy.Builder chunkSize(Long chunkSize)
Target size for each chunk in tokens
-
chunkSize
final VaultRetrieveResponse.ChunkStrategy.Builder chunkSize(JsonField<Long> chunkSize)
Sets Builder.chunkSize to an arbitrary JSON value.
You should usually call Builder.chunkSize with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
method
final VaultRetrieveResponse.ChunkStrategy.Builder method(String method)
Chunking method (e.g., 'semantic', 'fixed')
-
method
final VaultRetrieveResponse.ChunkStrategy.Builder method(JsonField<String> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minChunkSize
final VaultRetrieveResponse.ChunkStrategy.Builder minChunkSize(Long minChunkSize)
Minimum chunk size in tokens
-
minChunkSize
final VaultRetrieveResponse.ChunkStrategy.Builder minChunkSize(JsonField<Long> minChunkSize)
Sets Builder.minChunkSize to an arbitrary JSON value.
You should usually call Builder.minChunkSize with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
overlap
final VaultRetrieveResponse.ChunkStrategy.Builder overlap(Long overlap)
Number of overlapping tokens between chunks
-
overlap
final VaultRetrieveResponse.ChunkStrategy.Builder overlap(JsonField<Long> overlap)
Sets Builder.overlap to an arbitrary JSON value.
You should usually call Builder.overlap with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultRetrieveResponse.ChunkStrategy.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultRetrieveResponse.ChunkStrategy.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultRetrieveResponse.ChunkStrategy.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultRetrieveResponse.ChunkStrategy.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultRetrieveResponse.ChunkStrategy.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultRetrieveResponse.ChunkStrategy build()
Returns an immutable instance of ChunkStrategy.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-