Class VaultSearchParams.Body
-
- All Implemented Interfaces:
public final class VaultSearchParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultSearchParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringquery()Search query or question to find relevant documents final Optional<VaultSearchParams.Filters>filters()Filters to narrow search results to specific documents final Optional<VaultSearchParams.Method>method()Search method: 'global' for comprehensive questions, 'entity' for specific entities, 'fast' for quick similarity search, 'hybrid' for combined approach final Optional<Long>topK()Maximum number of results to return final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<VaultSearchParams.Filters>_filters()Returns the raw JSON value of filters. final JsonField<VaultSearchParams.Method>_method()Returns the raw JSON value of method. final JsonField<Long>_topK()Returns the raw JSON value of topK. final Map<String, JsonValue>_additionalProperties()final VaultSearchParams.Body.BuildertoBuilder()final VaultSearchParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultSearchParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
filters
final Optional<VaultSearchParams.Filters> filters()
Filters to narrow search results to specific documents
-
method
final Optional<VaultSearchParams.Method> method()
Search method: 'global' for comprehensive questions, 'entity' for specific entities, 'fast' for quick similarity search, 'hybrid' for combined approach
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_filters
final JsonField<VaultSearchParams.Filters> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<VaultSearchParams.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_topK
final JsonField<Long> _topK()
Returns the raw JSON value of topK.
Unlike topK, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultSearchParams.Body.Builder toBuilder()
-
validate
final VaultSearchParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultSearchParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.query()
-
-
-
-