Class VaultSearchResponse.Builder
-
- All Implemented Interfaces:
public final class VaultSearchResponse.BuilderA builder for VaultSearchResponse.
-
-
Method Summary
-
-
Method Detail
-
chunks
final VaultSearchResponse.Builder chunks(List<VaultSearchResponse.Chunk> chunks)
Relevant text chunks with similarity scores and page locations
-
chunks
final VaultSearchResponse.Builder chunks(JsonField<List<VaultSearchResponse.Chunk>> chunks)
Sets Builder.chunks to an arbitrary JSON value.
You should usually call Builder.chunks with a well-typed
List<Chunk>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addChunk
final VaultSearchResponse.Builder addChunk(VaultSearchResponse.Chunk chunk)
-
method
final VaultSearchResponse.Builder method(String method)
Search method used
-
method
final VaultSearchResponse.Builder method(JsonField<String> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
query
final VaultSearchResponse.Builder query(String query)
Original search query
-
query
final VaultSearchResponse.Builder query(JsonField<String> query)
Sets Builder.query to an arbitrary JSON value.
You should usually call Builder.query with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
response
final VaultSearchResponse.Builder response(String response)
AI-generated answer based on search results (for global/entity methods)
-
response
final VaultSearchResponse.Builder response(JsonField<String> response)
Sets Builder.response to an arbitrary JSON value.
You should usually call Builder.response with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sources
final VaultSearchResponse.Builder sources(List<VaultSearchResponse.Source> sources)
-
sources
final VaultSearchResponse.Builder sources(JsonField<List<VaultSearchResponse.Source>> sources)
Sets Builder.sources to an arbitrary JSON value.
You should usually call Builder.sources with a well-typed
List<Source>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSource
final VaultSearchResponse.Builder addSource(VaultSearchResponse.Source source)
-
vaultId
final VaultSearchResponse.Builder vaultId(String vaultId)
ID of the searched vault
-
vaultId
final VaultSearchResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultSearchResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultSearchResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultSearchResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultSearchResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultSearchResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultSearchResponse build()
Returns an immutable instance of VaultSearchResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-