Class VaultSearchResponse.Chunk.Builder
-
- All Implemented Interfaces:
public final class VaultSearchResponse.Chunk.BuilderA builder for Chunk.
-
-
Method Summary
-
-
Method Detail
-
chunkIndex
final VaultSearchResponse.Chunk.Builder chunkIndex(Long chunkIndex)
Index of the chunk within the document (0-based)
-
chunkIndex
final VaultSearchResponse.Chunk.Builder chunkIndex(JsonField<Long> chunkIndex)
Sets Builder.chunkIndex to an arbitrary JSON value.
You should usually call Builder.chunkIndex with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
distance
final VaultSearchResponse.Chunk.Builder distance(Double distance)
Vector similarity distance (lower is more similar)
-
distance
final VaultSearchResponse.Chunk.Builder distance(JsonField<Double> distance)
Sets Builder.distance to an arbitrary JSON value.
You should usually call Builder.distance with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final VaultSearchResponse.Chunk.Builder objectId(String objectId)
ID of the source document
-
objectId
final VaultSearchResponse.Chunk.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pageEnd
final VaultSearchResponse.Chunk.Builder pageEnd(Long pageEnd)
PDF page number where the chunk ends (1-indexed). Null for non-PDF documents or documents ingested before page tracking was added.
-
pageEnd
final VaultSearchResponse.Chunk.Builder pageEnd(Long pageEnd)
Alias for Builder.pageEnd.
This unboxed primitive overload exists for backwards compatibility.
-
pageEnd
final VaultSearchResponse.Chunk.Builder pageEnd(Optional<Long> pageEnd)
Alias for calling Builder.pageEnd with
pageEnd.orElse(null).
-
pageEnd
final VaultSearchResponse.Chunk.Builder pageEnd(JsonField<Long> pageEnd)
Sets Builder.pageEnd to an arbitrary JSON value.
You should usually call Builder.pageEnd with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pageStart
final VaultSearchResponse.Chunk.Builder pageStart(Long pageStart)
PDF page number where the chunk begins (1-indexed). Null for non-PDF documents or documents ingested before page tracking was added.
-
pageStart
final VaultSearchResponse.Chunk.Builder pageStart(Long pageStart)
Alias for Builder.pageStart.
This unboxed primitive overload exists for backwards compatibility.
-
pageStart
final VaultSearchResponse.Chunk.Builder pageStart(Optional<Long> pageStart)
Alias for calling Builder.pageStart with
pageStart.orElse(null).
-
pageStart
final VaultSearchResponse.Chunk.Builder pageStart(JsonField<Long> pageStart)
Sets Builder.pageStart to an arbitrary JSON value.
You should usually call Builder.pageStart with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
score
final VaultSearchResponse.Chunk.Builder score(Double score)
Relevance score (deprecated, use distance or hybridScore)
-
score
final VaultSearchResponse.Chunk.Builder score(JsonField<Double> score)
Sets Builder.score to an arbitrary JSON value.
You should usually call Builder.score with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final VaultSearchResponse.Chunk.Builder source(String source)
Source identifier (deprecated, use object_id)
-
source
final VaultSearchResponse.Chunk.Builder source(JsonField<String> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final VaultSearchResponse.Chunk.Builder text(String text)
Preview of the chunk text (up to 500 characters)
-
text
final VaultSearchResponse.Chunk.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wordEndIndex
final VaultSearchResponse.Chunk.Builder wordEndIndex(Long wordEndIndex)
Ending word index (0-based) in the OCR word list. Use with GET /vault/:id/objects/:objectId/ocr-words to retrieve bounding boxes for highlighting.
-
wordEndIndex
final VaultSearchResponse.Chunk.Builder wordEndIndex(Long wordEndIndex)
Alias for Builder.wordEndIndex.
This unboxed primitive overload exists for backwards compatibility.
-
wordEndIndex
final VaultSearchResponse.Chunk.Builder wordEndIndex(Optional<Long> wordEndIndex)
Alias for calling Builder.wordEndIndex with
wordEndIndex.orElse(null).
-
wordEndIndex
final VaultSearchResponse.Chunk.Builder wordEndIndex(JsonField<Long> wordEndIndex)
Sets Builder.wordEndIndex to an arbitrary JSON value.
You should usually call Builder.wordEndIndex with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wordStartIndex
final VaultSearchResponse.Chunk.Builder wordStartIndex(Long wordStartIndex)
Starting word index (0-based) in the OCR word list. Use with GET /vault/:id/objects/:objectId/ocr-words to retrieve bounding boxes for highlighting.
-
wordStartIndex
final VaultSearchResponse.Chunk.Builder wordStartIndex(Long wordStartIndex)
Alias for Builder.wordStartIndex.
This unboxed primitive overload exists for backwards compatibility.
-
wordStartIndex
final VaultSearchResponse.Chunk.Builder wordStartIndex(Optional<Long> wordStartIndex)
Alias for calling Builder.wordStartIndex with
wordStartIndex.orElse(null).
-
wordStartIndex
final VaultSearchResponse.Chunk.Builder wordStartIndex(JsonField<Long> wordStartIndex)
Sets Builder.wordStartIndex to an arbitrary JSON value.
You should usually call Builder.wordStartIndex with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultSearchResponse.Chunk.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultSearchResponse.Chunk.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultSearchResponse.Chunk.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultSearchResponse.Chunk.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultSearchResponse.Chunk.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultSearchResponse.Chunk build()
Returns an immutable instance of Chunk.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-