Class VaultSearchResponse.Source
-
- All Implemented Interfaces:
public final class VaultSearchResponse.Source
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultSearchResponse.Source.BuilderA builder for Source.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Long>chunkCount()final Optional<OffsetDateTime>createdAt()final Optional<String>filename()final Optional<OffsetDateTime>ingestionCompletedAt()final Optional<Long>pageCount()final Optional<Long>textLength()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_chunkCount()Returns the raw JSON value of chunkCount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<OffsetDateTime>_ingestionCompletedAt()Returns the raw JSON value of ingestionCompletedAt. final JsonField<Long>_pageCount()Returns the raw JSON value of pageCount. final JsonField<Long>_textLength()Returns the raw JSON value of textLength. final Map<String, JsonValue>_additionalProperties()final VaultSearchResponse.Source.BuildertoBuilder()final VaultSearchResponse.Sourcevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultSearchResponse.Source.Builderbuilder()Returns a mutable builder for constructing an instance of Source. -
-
Method Detail
-
chunkCount
final Optional<Long> chunkCount()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
ingestionCompletedAt
final Optional<OffsetDateTime> ingestionCompletedAt()
-
textLength
final Optional<Long> textLength()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_chunkCount
final JsonField<Long> _chunkCount()
Returns the raw JSON value of chunkCount.
Unlike chunkCount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionCompletedAt
final JsonField<OffsetDateTime> _ingestionCompletedAt()
Returns the raw JSON value of ingestionCompletedAt.
Unlike ingestionCompletedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_pageCount
final JsonField<Long> _pageCount()
Returns the raw JSON value of pageCount.
Unlike pageCount, this method doesn't throw if the JSON field has an unexpected type.
-
_textLength
final JsonField<Long> _textLength()
Returns the raw JSON value of textLength.
Unlike textLength, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultSearchResponse.Source.Builder toBuilder()
-
validate
final VaultSearchResponse.Source validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultSearchResponse.Source.Builder builder()
Returns a mutable builder for constructing an instance of Source.
-
-
-
-