Class VaultSearchResponse.Source.Builder
-
- All Implemented Interfaces:
public final class VaultSearchResponse.Source.BuilderA builder for Source.
-
-
Method Summary
-
-
Method Detail
-
id
final VaultSearchResponse.Source.Builder id(String id)
-
id
final VaultSearchResponse.Source.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chunkCount
final VaultSearchResponse.Source.Builder chunkCount(Long chunkCount)
-
chunkCount
final VaultSearchResponse.Source.Builder chunkCount(JsonField<Long> chunkCount)
Sets Builder.chunkCount to an arbitrary JSON value.
You should usually call Builder.chunkCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final VaultSearchResponse.Source.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final VaultSearchResponse.Source.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final VaultSearchResponse.Source.Builder filename(String filename)
-
filename
final VaultSearchResponse.Source.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionCompletedAt
final VaultSearchResponse.Source.Builder ingestionCompletedAt(OffsetDateTime ingestionCompletedAt)
-
ingestionCompletedAt
final VaultSearchResponse.Source.Builder ingestionCompletedAt(JsonField<OffsetDateTime> ingestionCompletedAt)
Sets Builder.ingestionCompletedAt to an arbitrary JSON value.
You should usually call Builder.ingestionCompletedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pageCount
final VaultSearchResponse.Source.Builder pageCount(Long pageCount)
-
pageCount
final VaultSearchResponse.Source.Builder pageCount(JsonField<Long> pageCount)
Sets Builder.pageCount to an arbitrary JSON value.
You should usually call Builder.pageCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
textLength
final VaultSearchResponse.Source.Builder textLength(Long textLength)
-
textLength
final VaultSearchResponse.Source.Builder textLength(JsonField<Long> textLength)
Sets Builder.textLength to an arbitrary JSON value.
You should usually call Builder.textLength with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultSearchResponse.Source.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultSearchResponse.Source.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultSearchResponse.Source.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultSearchResponse.Source.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultSearchResponse.Source.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultSearchResponse.Source build()
Returns an immutable instance of Source.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-