Class VaultUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class VaultUpdateParams implements Params
Update vault settings including name, description, and enableGraph. Changing enableGraph only affects future document uploads - existing documents retain their current graph/non-graph state.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultUpdateParams.BuilderA builder for VaultUpdateParams.
public final classVaultUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>description()New description for the vault. final Optional<Boolean>enableGraph()Whether to enable GraphRAG for future document uploads final Optional<String>groupId()Move the vault to a different group, or set to null to remove from its current group. final Optional<String>name()New name for the vault final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_enableGraph()Returns the raw JSON value of enableGraph. final JsonField<String>_groupId()Returns the raw JSON value of groupId. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final VaultUpdateParams.BuildertoBuilder()final VaultUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultUpdateParamsnone()final static VaultUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of VaultUpdateParams. -
-
Method Detail
-
description
final Optional<String> description()
New description for the vault. Set to null to remove.
-
enableGraph
final Optional<Boolean> enableGraph()
Whether to enable GraphRAG for future document uploads
-
groupId
final Optional<String> groupId()
Move the vault to a different group, or set to null to remove from its current group.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_enableGraph
final JsonField<Boolean> _enableGraph()
Returns the raw JSON value of enableGraph.
Unlike enableGraph, this method doesn't throw if the JSON field has an unexpected type.
-
_groupId
final JsonField<String> _groupId()
Returns the raw JSON value of groupId.
Unlike groupId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final VaultUpdateParams.Builder toBuilder()
-
_body
final VaultUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static VaultUpdateParams none()
-
builder
final static VaultUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of VaultUpdateParams.
-
-
-
-