Class VaultUpdateParams.Body
-
- All Implemented Interfaces:
public final class VaultUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()New description for the vault. final Optional<Boolean>enableGraph()Whether to enable GraphRAG for future document uploads final Optional<String>groupId()Move the vault to a different group, or set to null to remove from its current group. final Optional<String>name()New name for the vault final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_enableGraph()Returns the raw JSON value of enableGraph. final JsonField<String>_groupId()Returns the raw JSON value of groupId. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final VaultUpdateParams.Body.BuildertoBuilder()final VaultUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
New description for the vault. Set to null to remove.
-
enableGraph
final Optional<Boolean> enableGraph()
Whether to enable GraphRAG for future document uploads
-
groupId
final Optional<String> groupId()
Move the vault to a different group, or set to null to remove from its current group.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_enableGraph
final JsonField<Boolean> _enableGraph()
Returns the raw JSON value of enableGraph.
Unlike enableGraph, this method doesn't throw if the JSON field has an unexpected type.
-
_groupId
final JsonField<String> _groupId()
Returns the raw JSON value of groupId.
Unlike groupId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultUpdateParams.Body.Builder toBuilder()
-
validate
final VaultUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-