Class VaultUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class VaultUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
description
final VaultUpdateParams.Body.Builder description(String description)
New description for the vault. Set to null to remove.
-
description
final VaultUpdateParams.Body.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final VaultUpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableGraph
final VaultUpdateParams.Body.Builder enableGraph(Boolean enableGraph)
Whether to enable GraphRAG for future document uploads
-
enableGraph
final VaultUpdateParams.Body.Builder enableGraph(JsonField<Boolean> enableGraph)
Sets Builder.enableGraph to an arbitrary JSON value.
You should usually call Builder.enableGraph with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
groupId
final VaultUpdateParams.Body.Builder groupId(String groupId)
Move the vault to a different group, or set to null to remove from its current group.
-
groupId
final VaultUpdateParams.Body.Builder groupId(Optional<String> groupId)
Alias for calling Builder.groupId with
groupId.orElse(null).
-
groupId
final VaultUpdateParams.Body.Builder groupId(JsonField<String> groupId)
Sets Builder.groupId to an arbitrary JSON value.
You should usually call Builder.groupId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final VaultUpdateParams.Body.Builder name(String name)
New name for the vault
-
name
final VaultUpdateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-