Class VaultUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class VaultUpdateResponse.BuilderA builder for VaultUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final VaultUpdateResponse.Builder id(String id)
Vault identifier
-
id
final VaultUpdateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chunkStrategy
final VaultUpdateResponse.Builder chunkStrategy(JsonValue chunkStrategy)
Document chunking strategy configuration
-
createdAt
final VaultUpdateResponse.Builder createdAt(OffsetDateTime createdAt)
Vault creation timestamp
-
createdAt
final VaultUpdateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final VaultUpdateResponse.Builder description(String description)
Vault description
-
description
final VaultUpdateResponse.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final VaultUpdateResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableGraph
final VaultUpdateResponse.Builder enableGraph(Boolean enableGraph)
Whether GraphRAG is enabled for future uploads
-
enableGraph
final VaultUpdateResponse.Builder enableGraph(JsonField<Boolean> enableGraph)
Sets Builder.enableGraph to an arbitrary JSON value.
You should usually call Builder.enableGraph with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filesBucket
final VaultUpdateResponse.Builder filesBucket(String filesBucket)
S3 bucket for document storage
-
filesBucket
final VaultUpdateResponse.Builder filesBucket(JsonField<String> filesBucket)
Sets Builder.filesBucket to an arbitrary JSON value.
You should usually call Builder.filesBucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
indexName
final VaultUpdateResponse.Builder indexName(String indexName)
Search index name
-
indexName
final VaultUpdateResponse.Builder indexName(JsonField<String> indexName)
Sets Builder.indexName to an arbitrary JSON value.
You should usually call Builder.indexName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
kmsKeyId
final VaultUpdateResponse.Builder kmsKeyId(String kmsKeyId)
KMS key for encryption
-
kmsKeyId
final VaultUpdateResponse.Builder kmsKeyId(JsonField<String> kmsKeyId)
Sets Builder.kmsKeyId to an arbitrary JSON value.
You should usually call Builder.kmsKeyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final VaultUpdateResponse.Builder metadata(JsonValue metadata)
Additional vault metadata
-
name
final VaultUpdateResponse.Builder name(String name)
Vault name
-
name
final VaultUpdateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final VaultUpdateResponse.Builder region(String region)
AWS region
-
region
final VaultUpdateResponse.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalBytes
final VaultUpdateResponse.Builder totalBytes(Long totalBytes)
Total storage size in bytes
-
totalBytes
final VaultUpdateResponse.Builder totalBytes(JsonField<Long> totalBytes)
Sets Builder.totalBytes to an arbitrary JSON value.
You should usually call Builder.totalBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalObjects
final VaultUpdateResponse.Builder totalObjects(Long totalObjects)
Number of stored documents
-
totalObjects
final VaultUpdateResponse.Builder totalObjects(JsonField<Long> totalObjects)
Sets Builder.totalObjects to an arbitrary JSON value.
You should usually call Builder.totalObjects with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalVectors
final VaultUpdateResponse.Builder totalVectors(Long totalVectors)
Number of vector embeddings
-
totalVectors
final VaultUpdateResponse.Builder totalVectors(JsonField<Long> totalVectors)
Sets Builder.totalVectors to an arbitrary JSON value.
You should usually call Builder.totalVectors with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final VaultUpdateResponse.Builder updatedAt(OffsetDateTime updatedAt)
Last update timestamp
-
updatedAt
final VaultUpdateResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vectorBucket
final VaultUpdateResponse.Builder vectorBucket(String vectorBucket)
S3 bucket for vector embeddings
-
vectorBucket
final VaultUpdateResponse.Builder vectorBucket(Optional<String> vectorBucket)
Alias for calling Builder.vectorBucket with
vectorBucket.orElse(null).
-
vectorBucket
final VaultUpdateResponse.Builder vectorBucket(JsonField<String> vectorBucket)
Sets Builder.vectorBucket to an arbitrary JSON value.
You should usually call Builder.vectorBucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultUpdateResponse build()
Returns an immutable instance of VaultUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-