Class VaultUploadParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class VaultUploadParams implements Params
Generate a presigned URL for uploading files directly to a vault's S3 storage. After uploading to S3, confirm the upload result via POST /vault/:vaultId/upload/:objectId/confirm before triggering ingestion.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultUploadParams.BuilderA builder for VaultUploadParams.
public final classVaultUploadParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final StringcontentType()MIME type of the file (e.g. final Stringfilename()Name of the file to upload final Optional<Boolean>autoIndex()Whether to automatically process and index the file for search final JsonValue_metadata()Additional metadata to associate with the fileThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = vaultUploadParams.metadata().convert(MyClass.class);final Optional<String>path()Optional folder path for hierarchy preservation. final Optional<Long>sizeBytes()File size in bytes (optional, max 5GB for single PUT uploads). final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<Boolean>_autoIndex()Returns the raw JSON value of autoIndex. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final VaultUploadParams.BuildertoBuilder()final VaultUploadParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultUploadParams.Builderbuilder()Returns a mutable builder for constructing an instance of VaultUploadParams. -
-
Method Detail
-
contentType
final String contentType()
MIME type of the file (e.g., application/pdf, image/jpeg)
-
autoIndex
final Optional<Boolean> autoIndex()
Whether to automatically process and index the file for search
-
_metadata
final JsonValue _metadata()
Additional metadata to associate with the file
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = vaultUploadParams.metadata().convert(MyClass.class);
-
path
final Optional<String> path()
Optional folder path for hierarchy preservation. Allows integrations to maintain source folder structure from systems like NetDocs, Clio, or Smokeball. Example: '/Discovery/Depositions/2024'
-
sizeBytes
final Optional<Long> sizeBytes()
File size in bytes (optional, max 5GB for single PUT uploads). When provided, enforces exact file size at S3 level.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_autoIndex
final JsonField<Boolean> _autoIndex()
Returns the raw JSON value of autoIndex.
Unlike autoIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final VaultUploadParams.Builder toBuilder()
-
_body
final VaultUploadParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static VaultUploadParams.Builder builder()
Returns a mutable builder for constructing an instance of VaultUploadParams.
The following fields are required:
.contentType() .filename()
-
-
-
-