Class VaultUploadParams.Body.Builder
-
- All Implemented Interfaces:
public final class VaultUploadParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
contentType
final VaultUploadParams.Body.Builder contentType(String contentType)
MIME type of the file (e.g., application/pdf, image/jpeg)
-
contentType
final VaultUploadParams.Body.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final VaultUploadParams.Body.Builder filename(String filename)
Name of the file to upload
-
filename
final VaultUploadParams.Body.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
autoIndex
final VaultUploadParams.Body.Builder autoIndex(Boolean autoIndex)
Whether to automatically process and index the file for search
-
autoIndex
final VaultUploadParams.Body.Builder autoIndex(JsonField<Boolean> autoIndex)
Sets Builder.autoIndex to an arbitrary JSON value.
You should usually call Builder.autoIndex with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final VaultUploadParams.Body.Builder metadata(JsonValue metadata)
Additional metadata to associate with the file
-
path
final VaultUploadParams.Body.Builder path(String path)
Optional folder path for hierarchy preservation. Allows integrations to maintain source folder structure from systems like NetDocs, Clio, or Smokeball. Example: '/Discovery/Depositions/2024'
-
path
final VaultUploadParams.Body.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final VaultUploadParams.Body.Builder sizeBytes(Long sizeBytes)
File size in bytes (optional, max 5GB for single PUT uploads). When provided, enforces exact file size at S3 level.
-
sizeBytes
final VaultUploadParams.Body.Builder sizeBytes(JsonField<Long> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultUploadParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultUploadParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultUploadParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultUploadParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultUploadParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultUploadParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.contentType() .filename()
-
-
-
-