Class VaultUploadResponse.Builder
-
- All Implemented Interfaces:
public final class VaultUploadResponse.BuilderA builder for VaultUploadResponse.
-
-
Method Summary
-
-
Method Detail
-
autoIndex
final VaultUploadResponse.Builder autoIndex(Boolean autoIndex)
Whether the file will be automatically indexed
-
autoIndex
final VaultUploadResponse.Builder autoIndex(JsonField<Boolean> autoIndex)
Sets Builder.autoIndex to an arbitrary JSON value.
You should usually call Builder.autoIndex with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
enableIndexing
final VaultUploadResponse.Builder enableIndexing(Boolean enableIndexing)
Whether the vault supports indexing. False for storage-only vaults.
-
enableIndexing
final VaultUploadResponse.Builder enableIndexing(JsonField<Boolean> enableIndexing)
Sets Builder.enableIndexing to an arbitrary JSON value.
You should usually call Builder.enableIndexing with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiresIn
final VaultUploadResponse.Builder expiresIn(Double expiresIn)
URL expiration time in seconds
-
expiresIn
final VaultUploadResponse.Builder expiresIn(JsonField<Double> expiresIn)
Sets Builder.expiresIn to an arbitrary JSON value.
You should usually call Builder.expiresIn with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructions
final VaultUploadResponse.Builder instructions(VaultUploadResponse.Instructions instructions)
-
instructions
final VaultUploadResponse.Builder instructions(JsonField<VaultUploadResponse.Instructions> instructions)
Sets Builder.instructions to an arbitrary JSON value.
You should usually call Builder.instructions with a well-typed Instructions value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nextStep
final VaultUploadResponse.Builder nextStep(String nextStep)
Next API endpoint to call for processing
-
nextStep
final VaultUploadResponse.Builder nextStep(Optional<String> nextStep)
Alias for calling Builder.nextStep with
nextStep.orElse(null).
-
nextStep
final VaultUploadResponse.Builder nextStep(JsonField<String> nextStep)
Sets Builder.nextStep to an arbitrary JSON value.
You should usually call Builder.nextStep with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final VaultUploadResponse.Builder objectId(String objectId)
Unique identifier for the uploaded object
-
objectId
final VaultUploadResponse.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
path
final VaultUploadResponse.Builder path(String path)
Folder path for hierarchy if provided
-
path
final VaultUploadResponse.Builder path(Optional<String> path)
Alias for calling Builder.path with
path.orElse(null).
-
path
final VaultUploadResponse.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
s3Key
final VaultUploadResponse.Builder s3Key(String s3Key)
S3 object key for the file
-
s3Key
final VaultUploadResponse.Builder s3Key(JsonField<String> s3Key)
Sets Builder.s3Key to an arbitrary JSON value.
You should usually call Builder.s3Key with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadUrl
final VaultUploadResponse.Builder uploadUrl(String uploadUrl)
Presigned URL for uploading the file
-
uploadUrl
final VaultUploadResponse.Builder uploadUrl(JsonField<String> uploadUrl)
Sets Builder.uploadUrl to an arbitrary JSON value.
You should usually call Builder.uploadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultUploadResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultUploadResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultUploadResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultUploadResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultUploadResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultUploadResponse build()
Returns an immutable instance of VaultUploadResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-