Package dev.case.api.models.vault
Class VaultUploadResponse.Instructions
-
- All Implemented Interfaces:
public final class VaultUploadResponse.Instructions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultUploadResponse.Instructions.BuilderA builder for Instructions.
-
Method Summary
Modifier and Type Method Description final JsonValue_headers()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = instructions.headers().convert(MyClass.class);final Optional<String>method()final Optional<String>note()final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_note()Returns the raw JSON value of note. final Map<String, JsonValue>_additionalProperties()final VaultUploadResponse.Instructions.BuildertoBuilder()final VaultUploadResponse.Instructionsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultUploadResponse.Instructions.Builderbuilder()Returns a mutable builder for constructing an instance of Instructions. -
-
Method Detail
-
_headers
final JsonValue _headers()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = instructions.headers().convert(MyClass.class);
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_note
final JsonField<String> _note()
Returns the raw JSON value of note.
Unlike note, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultUploadResponse.Instructions.Builder toBuilder()
-
validate
final VaultUploadResponse.Instructions validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VaultUploadResponse.Instructions.Builder builder()
Returns a mutable builder for constructing an instance of Instructions.
-
-
-
-