Package dev.case.api.models.vault
Class VaultUploadResponse.Instructions.Builder
-
- All Implemented Interfaces:
public final class VaultUploadResponse.Instructions.BuilderA builder for Instructions.
-
-
Method Summary
-
-
Method Detail
-
headers
final VaultUploadResponse.Instructions.Builder headers(JsonValue headers)
-
method
final VaultUploadResponse.Instructions.Builder method(String method)
-
method
final VaultUploadResponse.Instructions.Builder method(JsonField<String> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
note
final VaultUploadResponse.Instructions.Builder note(String note)
-
note
final VaultUploadResponse.Instructions.Builder note(JsonField<String> note)
Sets Builder.note to an arbitrary JSON value.
You should usually call Builder.note with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VaultUploadResponse.Instructions.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VaultUploadResponse.Instructions.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VaultUploadResponse.Instructions.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VaultUploadResponse.Instructions.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VaultUploadResponse.Instructions.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VaultUploadResponse.Instructions build()
Returns an immutable instance of Instructions.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-