Class SubscriptionCreateParams.Body
-
- All Implemented Interfaces:
public final class SubscriptionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcallbackUrl()Webhook endpoint URL that will receive vault event deliveries final Optional<List<String>>eventTypes()Vault event types to deliver. final Optional<List<String>>objectIds()Vault object IDs to limit notifications to. final Optional<String>signingSecret()Optional secret used to sign outbound webhook deliveries final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final JsonField<List<String>>_eventTypes()Returns the raw JSON value of eventTypes. final JsonField<List<String>>_objectIds()Returns the raw JSON value of objectIds. final JsonField<String>_signingSecret()Returns the raw JSON value of signingSecret. final Map<String, JsonValue>_additionalProperties()final SubscriptionCreateParams.Body.BuildertoBuilder()final SubscriptionCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SubscriptionCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
callbackUrl
final String callbackUrl()
Webhook endpoint URL that will receive vault event deliveries
-
eventTypes
final Optional<List<String>> eventTypes()
Vault event types to deliver. Omit to receive the default supported set.
-
objectIds
final Optional<List<String>> objectIds()
Vault object IDs to limit notifications to. Omit to receive events for all objects in the vault.
-
signingSecret
final Optional<String> signingSecret()
Optional secret used to sign outbound webhook deliveries
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<String>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_objectIds
final JsonField<List<String>> _objectIds()
Returns the raw JSON value of objectIds.
Unlike objectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_signingSecret
final JsonField<String> _signingSecret()
Returns the raw JSON value of signingSecret.
Unlike signingSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SubscriptionCreateParams.Body.Builder toBuilder()
-
validate
final SubscriptionCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SubscriptionCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.callbackUrl()
-
-
-
-