Class SubscriptionCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SubscriptionCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
callbackUrl
final SubscriptionCreateParams.Body.Builder callbackUrl(String callbackUrl)
Webhook endpoint URL that will receive vault event deliveries
-
callbackUrl
final SubscriptionCreateParams.Body.Builder callbackUrl(JsonField<String> callbackUrl)
Sets Builder.callbackUrl to an arbitrary JSON value.
You should usually call Builder.callbackUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventTypes
final SubscriptionCreateParams.Body.Builder eventTypes(List<String> eventTypes)
Vault event types to deliver. Omit to receive the default supported set.
-
eventTypes
final SubscriptionCreateParams.Body.Builder eventTypes(JsonField<List<String>> eventTypes)
Sets Builder.eventTypes to an arbitrary JSON value.
You should usually call Builder.eventTypes with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEventType
final SubscriptionCreateParams.Body.Builder addEventType(String eventType)
Adds a single String to eventTypes.
-
objectIds
final SubscriptionCreateParams.Body.Builder objectIds(List<String> objectIds)
Vault object IDs to limit notifications to. Omit to receive events for all objects in the vault.
-
objectIds
final SubscriptionCreateParams.Body.Builder objectIds(JsonField<List<String>> objectIds)
Sets Builder.objectIds to an arbitrary JSON value.
You should usually call Builder.objectIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addObjectId
final SubscriptionCreateParams.Body.Builder addObjectId(String objectId)
-
signingSecret
final SubscriptionCreateParams.Body.Builder signingSecret(String signingSecret)
Optional secret used to sign outbound webhook deliveries
-
signingSecret
final SubscriptionCreateParams.Body.Builder signingSecret(JsonField<String> signingSecret)
Sets Builder.signingSecret to an arbitrary JSON value.
You should usually call Builder.signingSecret with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SubscriptionCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SubscriptionCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SubscriptionCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SubscriptionCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SubscriptionCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SubscriptionCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.callbackUrl()
-
-
-
-