Class GraphragGetStatsResponse.Builder
-
- All Implemented Interfaces:
public final class GraphragGetStatsResponse.BuilderA builder for GraphragGetStatsResponse.
-
-
Method Summary
-
-
Method Detail
-
communities
final GraphragGetStatsResponse.Builder communities(Long communities)
Number of entity communities identified
-
communities
final GraphragGetStatsResponse.Builder communities(JsonField<Long> communities)
Sets Builder.communities to an arbitrary JSON value.
You should usually call Builder.communities with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
documents
final GraphragGetStatsResponse.Builder documents(Long documents)
Number of processed documents
-
documents
final GraphragGetStatsResponse.Builder documents(JsonField<Long> documents)
Sets Builder.documents to an arbitrary JSON value.
You should usually call Builder.documents with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entities
final GraphragGetStatsResponse.Builder entities(Long entities)
Total number of entities extracted from documents
-
entities
final GraphragGetStatsResponse.Builder entities(JsonField<Long> entities)
Sets Builder.entities to an arbitrary JSON value.
You should usually call Builder.entities with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastProcessed
final GraphragGetStatsResponse.Builder lastProcessed(OffsetDateTime lastProcessed)
Timestamp of last GraphRAG processing
-
lastProcessed
final GraphragGetStatsResponse.Builder lastProcessed(JsonField<OffsetDateTime> lastProcessed)
Sets Builder.lastProcessed to an arbitrary JSON value.
You should usually call Builder.lastProcessed with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
relationships
final GraphragGetStatsResponse.Builder relationships(Long relationships)
Total number of relationships between entities
-
relationships
final GraphragGetStatsResponse.Builder relationships(JsonField<Long> relationships)
Sets Builder.relationships to an arbitrary JSON value.
You should usually call Builder.relationships with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final GraphragGetStatsResponse.Builder status(GraphragGetStatsResponse.Status status)
Current processing status
-
status
final GraphragGetStatsResponse.Builder status(JsonField<GraphragGetStatsResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final GraphragGetStatsResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final GraphragGetStatsResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final GraphragGetStatsResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final GraphragGetStatsResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final GraphragGetStatsResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final GraphragGetStatsResponse build()
Returns an immutable instance of GraphragGetStatsResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-