Class GraphragInitResponse
-
- All Implemented Interfaces:
public final class GraphragInitResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragInitResponse.BuilderA builder for GraphragInitResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>message()final Optional<String>status()final Optional<Boolean>success()final Optional<String>vaultId()final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<Boolean>_success()Returns the raw JSON value of success. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final GraphragInitResponse.BuildertoBuilder()final GraphragInitResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static GraphragInitResponse.Builderbuilder()Returns a mutable builder for constructing an instance of GraphragInitResponse. -
-
Method Detail
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final GraphragInitResponse.Builder toBuilder()
-
validate
final GraphragInitResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static GraphragInitResponse.Builder builder()
Returns a mutable builder for constructing an instance of GraphragInitResponse.
-
-
-
-