Class GraphragInitResponse.Builder
-
- All Implemented Interfaces:
public final class GraphragInitResponse.BuilderA builder for GraphragInitResponse.
-
-
Method Summary
-
-
Method Detail
-
message
final GraphragInitResponse.Builder message(String message)
-
message
final GraphragInitResponse.Builder message(JsonField<String> message)
Sets Builder.message to an arbitrary JSON value.
You should usually call Builder.message with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final GraphragInitResponse.Builder status(String status)
-
status
final GraphragInitResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
success
final GraphragInitResponse.Builder success(Boolean success)
-
success
final GraphragInitResponse.Builder success(JsonField<Boolean> success)
Sets Builder.success to an arbitrary JSON value.
You should usually call Builder.success with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final GraphragInitResponse.Builder vaultId(String vaultId)
-
vaultId
final GraphragInitResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final GraphragInitResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final GraphragInitResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final GraphragInitResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final GraphragInitResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final GraphragInitResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final GraphragInitResponse build()
Returns an immutable instance of GraphragInitResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-