Class GraphragProcessObjectResponse
-
- All Implemented Interfaces:
public final class GraphragProcessObjectResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragProcessObjectResponse.BuilderA builder for GraphragProcessObjectResponse.
public final classGraphragProcessObjectResponse.StatsExtraction statistics
-
Method Summary
Modifier and Type Method Description final Longcommunities()Number of communities detected final Longentities()Number of entities extracted final StringobjectId()ID of the indexed object final Longrelationships()Number of relationships extracted final GraphragProcessObjectResponse.Statsstats()Extraction statistics final Stringstatus()Status from GraphRAG service final Booleansuccess()Whether indexing completed successfully final StringvaultId()ID of the vault final JsonField<Long>_communities()Returns the raw JSON value of communities. final JsonField<Long>_entities()Returns the raw JSON value of entities. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<Long>_relationships()Returns the raw JSON value of relationships. final JsonField<GraphragProcessObjectResponse.Stats>_stats()Returns the raw JSON value of stats. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<Boolean>_success()Returns the raw JSON value of success. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final GraphragProcessObjectResponse.BuildertoBuilder()final GraphragProcessObjectResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static GraphragProcessObjectResponse.Builderbuilder()Returns a mutable builder for constructing an instance of GraphragProcessObjectResponse. -
-
Method Detail
-
communities
final Long communities()
Number of communities detected
-
relationships
final Long relationships()
Number of relationships extracted
-
stats
final GraphragProcessObjectResponse.Stats stats()
Extraction statistics
-
_communities
final JsonField<Long> _communities()
Returns the raw JSON value of communities.
Unlike communities, this method doesn't throw if the JSON field has an unexpected type.
-
_entities
final JsonField<Long> _entities()
Returns the raw JSON value of entities.
Unlike entities, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_relationships
final JsonField<Long> _relationships()
Returns the raw JSON value of relationships.
Unlike relationships, this method doesn't throw if the JSON field has an unexpected type.
-
_stats
final JsonField<GraphragProcessObjectResponse.Stats> _stats()
Returns the raw JSON value of stats.
Unlike stats, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final GraphragProcessObjectResponse.Builder toBuilder()
-
validate
final GraphragProcessObjectResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static GraphragProcessObjectResponse.Builder builder()
Returns a mutable builder for constructing an instance of GraphragProcessObjectResponse.
The following fields are required:
.communities() .entities() .objectId() .relationships() .stats() .status() .success() .vaultId()
-
-
-
-