Class GraphragProcessObjectResponse.Builder
-
- All Implemented Interfaces:
public final class GraphragProcessObjectResponse.BuilderA builder for GraphragProcessObjectResponse.
-
-
Method Summary
-
-
Method Detail
-
communities
final GraphragProcessObjectResponse.Builder communities(Long communities)
Number of communities detected
-
communities
final GraphragProcessObjectResponse.Builder communities(JsonField<Long> communities)
Sets Builder.communities to an arbitrary JSON value.
You should usually call Builder.communities with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entities
final GraphragProcessObjectResponse.Builder entities(Long entities)
Number of entities extracted
-
entities
final GraphragProcessObjectResponse.Builder entities(JsonField<Long> entities)
Sets Builder.entities to an arbitrary JSON value.
You should usually call Builder.entities with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final GraphragProcessObjectResponse.Builder objectId(String objectId)
ID of the indexed object
-
objectId
final GraphragProcessObjectResponse.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
relationships
final GraphragProcessObjectResponse.Builder relationships(Long relationships)
Number of relationships extracted
-
relationships
final GraphragProcessObjectResponse.Builder relationships(JsonField<Long> relationships)
Sets Builder.relationships to an arbitrary JSON value.
You should usually call Builder.relationships with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stats
final GraphragProcessObjectResponse.Builder stats(GraphragProcessObjectResponse.Stats stats)
Extraction statistics
-
stats
final GraphragProcessObjectResponse.Builder stats(JsonField<GraphragProcessObjectResponse.Stats> stats)
Sets Builder.stats to an arbitrary JSON value.
You should usually call Builder.stats with a well-typed Stats value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final GraphragProcessObjectResponse.Builder status(String status)
Status from GraphRAG service
-
status
final GraphragProcessObjectResponse.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
success
final GraphragProcessObjectResponse.Builder success(Boolean success)
Whether indexing completed successfully
-
success
final GraphragProcessObjectResponse.Builder success(JsonField<Boolean> success)
Sets Builder.success to an arbitrary JSON value.
You should usually call Builder.success with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final GraphragProcessObjectResponse.Builder vaultId(String vaultId)
ID of the vault
-
vaultId
final GraphragProcessObjectResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final GraphragProcessObjectResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final GraphragProcessObjectResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final GraphragProcessObjectResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final GraphragProcessObjectResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final GraphragProcessObjectResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final GraphragProcessObjectResponse build()
Returns an immutable instance of GraphragProcessObjectResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.communities() .entities() .objectId() .relationships() .stats() .status() .success() .vaultId()
-
-
-
-