Class GraphragProcessObjectResponse.Stats
-
- All Implemented Interfaces:
public final class GraphragProcessObjectResponse.StatsExtraction statistics
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragProcessObjectResponse.Stats.BuilderA builder for Stats.
-
Method Summary
Modifier and Type Method Description final Optional<Long>communityCount()final Optional<Long>entityCount()final Optional<Long>relationshipCount()final JsonField<Long>_communityCount()Returns the raw JSON value of communityCount. final JsonField<Long>_entityCount()Returns the raw JSON value of entityCount. final JsonField<Long>_relationshipCount()Returns the raw JSON value of relationshipCount. final Map<String, JsonValue>_additionalProperties()final GraphragProcessObjectResponse.Stats.BuildertoBuilder()final GraphragProcessObjectResponse.Statsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static GraphragProcessObjectResponse.Stats.Builderbuilder()Returns a mutable builder for constructing an instance of Stats. -
-
Method Detail
-
communityCount
final Optional<Long> communityCount()
-
entityCount
final Optional<Long> entityCount()
-
relationshipCount
final Optional<Long> relationshipCount()
-
_communityCount
final JsonField<Long> _communityCount()
Returns the raw JSON value of communityCount.
Unlike communityCount, this method doesn't throw if the JSON field has an unexpected type.
-
_entityCount
final JsonField<Long> _entityCount()
Returns the raw JSON value of entityCount.
Unlike entityCount, this method doesn't throw if the JSON field has an unexpected type.
-
_relationshipCount
final JsonField<Long> _relationshipCount()
Returns the raw JSON value of relationshipCount.
Unlike relationshipCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final GraphragProcessObjectResponse.Stats.Builder toBuilder()
-
validate
final GraphragProcessObjectResponse.Stats validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static GraphragProcessObjectResponse.Stats.Builder builder()
Returns a mutable builder for constructing an instance of Stats.
-
-
-
-