Class GroupUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class GroupUpdateParams implements Params
Updates a vault group for the authenticated organization. Only provided fields are changed, and setting description to null removes the current description.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroupUpdateParams.BuilderA builder for GroupUpdateParams.
public final classGroupUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>groupId()final Optional<String>description()Updated vault group description. final Optional<String>name()New human-readable name for the vault group final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final GroupUpdateParams.BuildertoBuilder()final GroupUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static GroupUpdateParamsnone()final static GroupUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of GroupUpdateParams. -
-
Method Detail
-
description
final Optional<String> description()
Updated vault group description. Pass null to remove the current description.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final GroupUpdateParams.Builder toBuilder()
-
_body
final GroupUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static GroupUpdateParams none()
-
builder
final static GroupUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of GroupUpdateParams.
-
-
-
-