Package dev.case.api.models.vault.groups
Class GroupUpdateParams.Body
-
- All Implemented Interfaces:
public final class GroupUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroupUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()Updated vault group description. final Optional<String>name()New human-readable name for the vault group final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final GroupUpdateParams.Body.BuildertoBuilder()final GroupUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static GroupUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
Updated vault group description. Pass null to remove the current description.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final GroupUpdateParams.Body.Builder toBuilder()
-
validate
final GroupUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static GroupUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-