Package dev.case.api.models.vault.memory
Class MemoryCreateParams.Body
-
- All Implemented Interfaces:
public final class MemoryCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringcontent()final MemoryCreateParams.Typetype()final Optional<String>source()final Optional<List<String>>tags()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<MemoryCreateParams.Type>_type()Returns the raw JSON value of type. final JsonField<String>_source()Returns the raw JSON value of source. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalProperties()final MemoryCreateParams.Body.BuildertoBuilder()final MemoryCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MemoryCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
type
final MemoryCreateParams.Type type()
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<MemoryCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<String> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MemoryCreateParams.Body.Builder toBuilder()
-
validate
final MemoryCreateParams.Body validate()
-
builder
final static MemoryCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.content() .type()
-
-
-
-