Package dev.case.api.models.vault.memory
Class MemoryCreateResponse
-
- All Implemented Interfaces:
public final class MemoryCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryCreateResponse.BuilderA builder for MemoryCreateResponse.
public final classMemoryCreateResponse.Entry
-
Method Summary
Modifier and Type Method Description final Optional<MemoryCreateResponse.Entry>entry()final JsonField<MemoryCreateResponse.Entry>_entry()Returns the raw JSON value of entry. final Map<String, JsonValue>_additionalProperties()final MemoryCreateResponse.BuildertoBuilder()final MemoryCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MemoryCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of MemoryCreateResponse. -
-
Method Detail
-
entry
final Optional<MemoryCreateResponse.Entry> entry()
-
_entry
final JsonField<MemoryCreateResponse.Entry> _entry()
Returns the raw JSON value of entry.
Unlike entry, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MemoryCreateResponse.Builder toBuilder()
-
validate
final MemoryCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static MemoryCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of MemoryCreateResponse.
-
-
-
-