Class MemorySearchParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class MemorySearchParams implements Params
Search file-backed vault memory using simple full-text matching over content and tags.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemorySearchParams.BuilderA builder for MemorySearchParams.
public final classMemorySearchParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Stringquery()final Optional<Long>limit()final Optional<List<String>>tags()final Optional<List<String>>types()final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<Long>_limit()Returns the raw JSON value of limit. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<List<String>>_types()Returns the raw JSON value of types. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final MemorySearchParams.BuildertoBuilder()final MemorySearchParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static MemorySearchParams.Builderbuilder()Returns a mutable builder for constructing an instance of MemorySearchParams. -
-
Method Detail
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_limit
final JsonField<Long> _limit()
Returns the raw JSON value of limit.
Unlike limit, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_types
final JsonField<List<String>> _types()
Returns the raw JSON value of types.
Unlike types, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final MemorySearchParams.Builder toBuilder()
-
_body
final MemorySearchParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static MemorySearchParams.Builder builder()
Returns a mutable builder for constructing an instance of MemorySearchParams.
The following fields are required:
.query()
-
-
-
-