Class MemorySearchParams.Body.Builder
-
- All Implemented Interfaces:
public final class MemorySearchParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
query
final MemorySearchParams.Body.Builder query(String query)
-
query
final MemorySearchParams.Body.Builder query(JsonField<String> query)
Sets Builder.query to an arbitrary JSON value.
You should usually call Builder.query with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
limit
final MemorySearchParams.Body.Builder limit(Long limit)
-
limit
final MemorySearchParams.Body.Builder limit(JsonField<Long> limit)
Sets Builder.limit to an arbitrary JSON value.
You should usually call Builder.limit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final MemorySearchParams.Body.Builder tags(List<String> tags)
-
tags
final MemorySearchParams.Body.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final MemorySearchParams.Body.Builder addTag(String tag)
-
types
final MemorySearchParams.Body.Builder types(List<String> types)
-
types
final MemorySearchParams.Body.Builder types(JsonField<List<String>> types)
Sets Builder.types to an arbitrary JSON value.
You should usually call Builder.types with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addType
final MemorySearchParams.Body.Builder addType(String type)
-
additionalProperties
final MemorySearchParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final MemorySearchParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final MemorySearchParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final MemorySearchParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final MemorySearchParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final MemorySearchParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.query()
-
-
-
-