Package dev.case.api.models.vault.memory
Class MemorySearchResponse.Builder
-
- All Implemented Interfaces:
public final class MemorySearchResponse.BuilderA builder for MemorySearchResponse.
-
-
Method Summary
Modifier and Type Method Description final MemorySearchResponse.Builderresults(List<MemorySearchResponse.Result> results)final MemorySearchResponse.Builderresults(JsonField<List<MemorySearchResponse.Result>> results)Sets Builder.results to an arbitrary JSON value. final MemorySearchResponse.BuilderaddResult(MemorySearchResponse.Result result)Adds a single Result to results. final MemorySearchResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final MemorySearchResponse.BuilderputAdditionalProperty(String key, JsonValue value)final MemorySearchResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final MemorySearchResponse.BuilderremoveAdditionalProperty(String key)final MemorySearchResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final MemorySearchResponsebuild()Returns an immutable instance of MemorySearchResponse. -
-
Method Detail
-
results
final MemorySearchResponse.Builder results(List<MemorySearchResponse.Result> results)
-
results
final MemorySearchResponse.Builder results(JsonField<List<MemorySearchResponse.Result>> results)
Sets Builder.results to an arbitrary JSON value.
You should usually call Builder.results with a well-typed
List<Result>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addResult
final MemorySearchResponse.Builder addResult(MemorySearchResponse.Result result)
-
additionalProperties
final MemorySearchResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final MemorySearchResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final MemorySearchResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final MemorySearchResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final MemorySearchResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final MemorySearchResponse build()
Returns an immutable instance of MemorySearchResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-