Class MemorySearchResponse.Result.Builder
-
- All Implemented Interfaces:
public final class MemorySearchResponse.Result.BuilderA builder for Result.
-
-
Method Summary
-
-
Method Detail
-
id
final MemorySearchResponse.Result.Builder id(String id)
-
id
final MemorySearchResponse.Result.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
content
final MemorySearchResponse.Result.Builder content(String content)
-
content
final MemorySearchResponse.Result.Builder content(JsonField<String> content)
Sets Builder.content to an arbitrary JSON value.
You should usually call Builder.content with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final MemorySearchResponse.Result.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final MemorySearchResponse.Result.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdBy
final MemorySearchResponse.Result.Builder createdBy(String createdBy)
-
createdBy
final MemorySearchResponse.Result.Builder createdBy(Optional<String> createdBy)
Alias for calling Builder.createdBy with
createdBy.orElse(null).
-
createdBy
final MemorySearchResponse.Result.Builder createdBy(JsonField<String> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final MemorySearchResponse.Result.Builder source(String source)
-
source
final MemorySearchResponse.Result.Builder source(Optional<String> source)
Alias for calling Builder.source with
source.orElse(null).
-
source
final MemorySearchResponse.Result.Builder source(JsonField<String> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final MemorySearchResponse.Result.Builder tags(List<String> tags)
-
tags
final MemorySearchResponse.Result.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final MemorySearchResponse.Result.Builder addTag(String tag)
-
type
final MemorySearchResponse.Result.Builder type(String type)
-
type
final MemorySearchResponse.Result.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final MemorySearchResponse.Result.Builder updatedAt(OffsetDateTime updatedAt)
-
updatedAt
final MemorySearchResponse.Result.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final MemorySearchResponse.Result.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final MemorySearchResponse.Result.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final MemorySearchResponse.Result.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final MemorySearchResponse.Result.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final MemorySearchResponse.Result.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final MemorySearchResponse.Result build()
Returns an immutable instance of Result.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-