Class MemoryUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class MemoryUpdateParams implements Params
Rewrite a file-backed vault memory entry with updated content, source, or tags.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryUpdateParams.BuilderA builder for MemoryUpdateParams.
public final classMemoryUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>entryId()final Optional<String>content()final Optional<String>source()final Optional<List<String>>tags()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_source()Returns the raw JSON value of source. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final MemoryUpdateParams.BuildertoBuilder()final MemoryUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static MemoryUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of MemoryUpdateParams. -
-
Method Detail
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<String> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final MemoryUpdateParams.Builder toBuilder()
-
_body
final MemoryUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static MemoryUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of MemoryUpdateParams.
The following fields are required:
.id()
-
-
-
-