Class MultipartGetPartUrlsParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class MultipartGetPartUrlsParams implements Params
Generate presigned URLs for individual multipart upload parts (live).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMultipartGetPartUrlsParams.BuilderA builder for MultipartGetPartUrlsParams.
public final classMultipartGetPartUrlsParams.Bodypublic final classMultipartGetPartUrlsParams.Part
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final StringobjectId()Vault object ID associated with the multipart upload final List<MultipartGetPartUrlsParams.Part>parts()Multipart parts that need presigned upload URLs final StringuploadId()Multipart upload ID returned when the upload was initialized final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<List<MultipartGetPartUrlsParams.Part>>_parts()Returns the raw JSON value of parts. final JsonField<String>_uploadId()Returns the raw JSON value of uploadId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final MultipartGetPartUrlsParams.BuildertoBuilder()final MultipartGetPartUrlsParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static MultipartGetPartUrlsParams.Builderbuilder()Returns a mutable builder for constructing an instance of MultipartGetPartUrlsParams. -
-
Method Detail
-
parts
final List<MultipartGetPartUrlsParams.Part> parts()
Multipart parts that need presigned upload URLs
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_parts
final JsonField<List<MultipartGetPartUrlsParams.Part>> _parts()
Returns the raw JSON value of parts.
Unlike parts, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadId
final JsonField<String> _uploadId()
Returns the raw JSON value of uploadId.
Unlike uploadId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final MultipartGetPartUrlsParams.Builder toBuilder()
-
_body
final MultipartGetPartUrlsParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static MultipartGetPartUrlsParams.Builder builder()
Returns a mutable builder for constructing an instance of MultipartGetPartUrlsParams.
The following fields are required:
.objectId() .parts() .uploadId()
-
-
-
-