Class MultipartGetPartUrlsParams.Body
-
- All Implemented Interfaces:
public final class MultipartGetPartUrlsParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMultipartGetPartUrlsParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringobjectId()Vault object ID associated with the multipart upload final List<MultipartGetPartUrlsParams.Part>parts()Multipart parts that need presigned upload URLs final StringuploadId()Multipart upload ID returned when the upload was initialized final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<List<MultipartGetPartUrlsParams.Part>>_parts()Returns the raw JSON value of parts. final JsonField<String>_uploadId()Returns the raw JSON value of uploadId. final Map<String, JsonValue>_additionalProperties()final MultipartGetPartUrlsParams.Body.BuildertoBuilder()final MultipartGetPartUrlsParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MultipartGetPartUrlsParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
parts
final List<MultipartGetPartUrlsParams.Part> parts()
Multipart parts that need presigned upload URLs
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_parts
final JsonField<List<MultipartGetPartUrlsParams.Part>> _parts()
Returns the raw JSON value of parts.
Unlike parts, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadId
final JsonField<String> _uploadId()
Returns the raw JSON value of uploadId.
Unlike uploadId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MultipartGetPartUrlsParams.Body.Builder toBuilder()
-
validate
final MultipartGetPartUrlsParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static MultipartGetPartUrlsParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.objectId() .parts() .uploadId()
-
-
-
-