Class MultipartGetPartUrlsParams.Part
-
- All Implemented Interfaces:
public final class MultipartGetPartUrlsParams.Part
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMultipartGetPartUrlsParams.Part.BuilderA builder for Part.
-
Method Summary
Modifier and Type Method Description final LongpartNumber()1-based multipart part number final LongsizeBytes()Part size in bytes (min 5MB except final part, max 5GB). final JsonField<Long>_partNumber()Returns the raw JSON value of partNumber. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final Map<String, JsonValue>_additionalProperties()final MultipartGetPartUrlsParams.Part.BuildertoBuilder()final MultipartGetPartUrlsParams.Partvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MultipartGetPartUrlsParams.Part.Builderbuilder()Returns a mutable builder for constructing an instance of Part. -
-
Method Detail
-
partNumber
final Long partNumber()
1-based multipart part number
-
_partNumber
final JsonField<Long> _partNumber()
Returns the raw JSON value of partNumber.
Unlike partNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MultipartGetPartUrlsParams.Part.Builder toBuilder()
-
validate
final MultipartGetPartUrlsParams.Part validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static MultipartGetPartUrlsParams.Part.Builder builder()
Returns a mutable builder for constructing an instance of Part.
The following fields are required:
.partNumber() .sizeBytes()
-
-
-
-