Class MultipartGetPartUrlsParams.Part.Builder
-
- All Implemented Interfaces:
public final class MultipartGetPartUrlsParams.Part.BuilderA builder for Part.
-
-
Method Summary
-
-
Method Detail
-
partNumber
final MultipartGetPartUrlsParams.Part.Builder partNumber(Long partNumber)
1-based multipart part number
-
partNumber
final MultipartGetPartUrlsParams.Part.Builder partNumber(JsonField<Long> partNumber)
Sets Builder.partNumber to an arbitrary JSON value.
You should usually call Builder.partNumber with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final MultipartGetPartUrlsParams.Part.Builder sizeBytes(Long sizeBytes)
Part size in bytes (min 5MB except final part, max 5GB).
-
sizeBytes
final MultipartGetPartUrlsParams.Part.Builder sizeBytes(JsonField<Long> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final MultipartGetPartUrlsParams.Part.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final MultipartGetPartUrlsParams.Part.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final MultipartGetPartUrlsParams.Part.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final MultipartGetPartUrlsParams.Part.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final MultipartGetPartUrlsParams.Part.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final MultipartGetPartUrlsParams.Part build()
Returns an immutable instance of Part.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.partNumber() .sizeBytes()
-
-
-
-