Class MultipartGetPartUrlsResponse
-
- All Implemented Interfaces:
public final class MultipartGetPartUrlsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMultipartGetPartUrlsResponse.BuilderA builder for MultipartGetPartUrlsResponse.
public final classMultipartGetPartUrlsResponse.Url
-
Method Summary
Modifier and Type Method Description final Optional<List<MultipartGetPartUrlsResponse.Url>>urls()final JsonField<List<MultipartGetPartUrlsResponse.Url>>_urls()Returns the raw JSON value of urls. final Map<String, JsonValue>_additionalProperties()final MultipartGetPartUrlsResponse.BuildertoBuilder()final MultipartGetPartUrlsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MultipartGetPartUrlsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of MultipartGetPartUrlsResponse. -
-
Method Detail
-
urls
final Optional<List<MultipartGetPartUrlsResponse.Url>> urls()
-
_urls
final JsonField<List<MultipartGetPartUrlsResponse.Url>> _urls()
Returns the raw JSON value of urls.
Unlike urls, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MultipartGetPartUrlsResponse.Builder toBuilder()
-
validate
final MultipartGetPartUrlsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static MultipartGetPartUrlsResponse.Builder builder()
Returns a mutable builder for constructing an instance of MultipartGetPartUrlsResponse.
-
-
-
-