Class MultipartGetPartUrlsResponse.Url
-
- All Implemented Interfaces:
public final class MultipartGetPartUrlsResponse.Url
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMultipartGetPartUrlsResponse.Url.BuilderA builder for Url.
-
Method Summary
Modifier and Type Method Description final Optional<Long>partNumber()final Optional<String>url()final JsonField<Long>_partNumber()Returns the raw JSON value of partNumber. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final MultipartGetPartUrlsResponse.Url.BuildertoBuilder()final MultipartGetPartUrlsResponse.Urlvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MultipartGetPartUrlsResponse.Url.Builderbuilder()Returns a mutable builder for constructing an instance of Url. -
-
Method Detail
-
partNumber
final Optional<Long> partNumber()
-
_partNumber
final JsonField<Long> _partNumber()
Returns the raw JSON value of partNumber.
Unlike partNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MultipartGetPartUrlsResponse.Url.Builder toBuilder()
-
validate
final MultipartGetPartUrlsResponse.Url validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static MultipartGetPartUrlsResponse.Url.Builder builder()
Returns a mutable builder for constructing an instance of Url.
-
-
-
-