Class ObjectCreatePresignedUrlParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ObjectCreatePresignedUrlParams implements Params
Generate presigned URLs for direct S3 operations (GET, PUT, DELETE, HEAD) on vault objects. This allows secure, time-limited access to files without proxying through the API. Essential for large document uploads/downloads in legal workflows.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectCreatePresignedUrlParams.BuilderA builder for ObjectCreatePresignedUrlParams.
public final classObjectCreatePresignedUrlParams.Bodypublic final classObjectCreatePresignedUrlParams.OperationThe S3 operation to generate URL for
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>objectId()final Optional<String>contentType()Content type for PUT operations (optional, defaults to object's content type) final Optional<Long>expiresIn()URL expiration time in seconds (1 minute to 7 days) final Optional<ObjectCreatePresignedUrlParams.Operation>operation()The S3 operation to generate URL for final Optional<Long>sizeBytes()File size in bytes (optional, max 5GB for single PUT uploads). final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<Long>_expiresIn()Returns the raw JSON value of expiresIn. final JsonField<ObjectCreatePresignedUrlParams.Operation>_operation()Returns the raw JSON value of operation. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ObjectCreatePresignedUrlParams.BuildertoBuilder()final ObjectCreatePresignedUrlParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectCreatePresignedUrlParams.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectCreatePresignedUrlParams. -
-
Method Detail
-
contentType
final Optional<String> contentType()
Content type for PUT operations (optional, defaults to object's content type)
-
operation
final Optional<ObjectCreatePresignedUrlParams.Operation> operation()
The S3 operation to generate URL for
-
sizeBytes
final Optional<Long> sizeBytes()
File size in bytes (optional, max 5GB for single PUT uploads). When provided for PUT operations, enforces exact file size at S3 level.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresIn
final JsonField<Long> _expiresIn()
Returns the raw JSON value of expiresIn.
Unlike expiresIn, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ObjectCreatePresignedUrlParams.Operation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ObjectCreatePresignedUrlParams.Builder toBuilder()
-
_body
final ObjectCreatePresignedUrlParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ObjectCreatePresignedUrlParams.Builder builder()
Returns a mutable builder for constructing an instance of ObjectCreatePresignedUrlParams.
The following fields are required:
.id()
-
-
-
-