Class ObjectCreatePresignedUrlParams.Body
-
- All Implemented Interfaces:
public final class ObjectCreatePresignedUrlParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectCreatePresignedUrlParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>contentType()Content type for PUT operations (optional, defaults to object's content type) final Optional<Long>expiresIn()URL expiration time in seconds (1 minute to 7 days) final Optional<ObjectCreatePresignedUrlParams.Operation>operation()The S3 operation to generate URL for final Optional<Long>sizeBytes()File size in bytes (optional, max 5GB for single PUT uploads). final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<Long>_expiresIn()Returns the raw JSON value of expiresIn. final JsonField<ObjectCreatePresignedUrlParams.Operation>_operation()Returns the raw JSON value of operation. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final Map<String, JsonValue>_additionalProperties()final ObjectCreatePresignedUrlParams.Body.BuildertoBuilder()final ObjectCreatePresignedUrlParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectCreatePresignedUrlParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
contentType
final Optional<String> contentType()
Content type for PUT operations (optional, defaults to object's content type)
-
operation
final Optional<ObjectCreatePresignedUrlParams.Operation> operation()
The S3 operation to generate URL for
-
sizeBytes
final Optional<Long> sizeBytes()
File size in bytes (optional, max 5GB for single PUT uploads). When provided for PUT operations, enforces exact file size at S3 level.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresIn
final JsonField<Long> _expiresIn()
Returns the raw JSON value of expiresIn.
Unlike expiresIn, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ObjectCreatePresignedUrlParams.Operation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectCreatePresignedUrlParams.Body.Builder toBuilder()
-
validate
final ObjectCreatePresignedUrlParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectCreatePresignedUrlParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-