Class ObjectCreatePresignedUrlParams.Body.Builder
-
- All Implemented Interfaces:
public final class ObjectCreatePresignedUrlParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
contentType
final ObjectCreatePresignedUrlParams.Body.Builder contentType(String contentType)
Content type for PUT operations (optional, defaults to object's content type)
-
contentType
final ObjectCreatePresignedUrlParams.Body.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiresIn
final ObjectCreatePresignedUrlParams.Body.Builder expiresIn(Long expiresIn)
URL expiration time in seconds (1 minute to 7 days)
-
expiresIn
final ObjectCreatePresignedUrlParams.Body.Builder expiresIn(JsonField<Long> expiresIn)
Sets Builder.expiresIn to an arbitrary JSON value.
You should usually call Builder.expiresIn with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
operation
final ObjectCreatePresignedUrlParams.Body.Builder operation(ObjectCreatePresignedUrlParams.Operation operation)
The S3 operation to generate URL for
-
operation
final ObjectCreatePresignedUrlParams.Body.Builder operation(JsonField<ObjectCreatePresignedUrlParams.Operation> operation)
Sets Builder.operation to an arbitrary JSON value.
You should usually call Builder.operation with a well-typed Operation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final ObjectCreatePresignedUrlParams.Body.Builder sizeBytes(Long sizeBytes)
File size in bytes (optional, max 5GB for single PUT uploads). When provided for PUT operations, enforces exact file size at S3 level.
-
sizeBytes
final ObjectCreatePresignedUrlParams.Body.Builder sizeBytes(JsonField<Long> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectCreatePresignedUrlParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectCreatePresignedUrlParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectCreatePresignedUrlParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectCreatePresignedUrlParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectCreatePresignedUrlParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectCreatePresignedUrlParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-