Class ObjectCreatePresignedUrlResponse
-
- All Implemented Interfaces:
public final class ObjectCreatePresignedUrlResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectCreatePresignedUrlResponse.BuilderA builder for ObjectCreatePresignedUrlResponse.
public final classObjectCreatePresignedUrlResponse.Metadata
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>expiresAt()URL expiration timestamp final Optional<Long>expiresIn()URL expiration time in seconds final Optional<String>filename()Original filename final JsonValue_instructions()Usage instructions and examplesThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = objectCreatePresignedUrlResponse.instructions().convert(MyClass.class);final Optional<ObjectCreatePresignedUrlResponse.Metadata>metadata()final Optional<String>objectId()The object identifier final Optional<String>operation()The operation type final Optional<String>presignedUrl()The presigned URL for direct S3 access final Optional<String>s3Key()S3 object key final Optional<String>vaultId()The vault identifier final JsonField<OffsetDateTime>_expiresAt()Returns the raw JSON value of expiresAt. final JsonField<Long>_expiresIn()Returns the raw JSON value of expiresIn. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<ObjectCreatePresignedUrlResponse.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<String>_operation()Returns the raw JSON value of operation. final JsonField<String>_presignedUrl()Returns the raw JSON value of presignedUrl. final JsonField<String>_s3Key()Returns the raw JSON value of s3Key. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final ObjectCreatePresignedUrlResponse.BuildertoBuilder()final ObjectCreatePresignedUrlResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectCreatePresignedUrlResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectCreatePresignedUrlResponse. -
-
Method Detail
-
expiresAt
final Optional<OffsetDateTime> expiresAt()
URL expiration timestamp
-
_instructions
final JsonValue _instructions()
Usage instructions and examples
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = objectCreatePresignedUrlResponse.instructions().convert(MyClass.class);
-
metadata
final Optional<ObjectCreatePresignedUrlResponse.Metadata> metadata()
-
presignedUrl
final Optional<String> presignedUrl()
The presigned URL for direct S3 access
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresIn
final JsonField<Long> _expiresIn()
Returns the raw JSON value of expiresIn.
Unlike expiresIn, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<ObjectCreatePresignedUrlResponse.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<String> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_presignedUrl
final JsonField<String> _presignedUrl()
Returns the raw JSON value of presignedUrl.
Unlike presignedUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_s3Key
final JsonField<String> _s3Key()
Returns the raw JSON value of s3Key.
Unlike s3Key, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectCreatePresignedUrlResponse.Builder toBuilder()
-
validate
final ObjectCreatePresignedUrlResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectCreatePresignedUrlResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectCreatePresignedUrlResponse.
-
-
-
-