Class ObjectCreatePresignedUrlResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectCreatePresignedUrlResponse.BuilderA builder for ObjectCreatePresignedUrlResponse.
-
-
Method Summary
-
-
Method Detail
-
expiresAt
final ObjectCreatePresignedUrlResponse.Builder expiresAt(OffsetDateTime expiresAt)
URL expiration timestamp
-
expiresAt
final ObjectCreatePresignedUrlResponse.Builder expiresAt(JsonField<OffsetDateTime> expiresAt)
Sets Builder.expiresAt to an arbitrary JSON value.
You should usually call Builder.expiresAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiresIn
final ObjectCreatePresignedUrlResponse.Builder expiresIn(Long expiresIn)
URL expiration time in seconds
-
expiresIn
final ObjectCreatePresignedUrlResponse.Builder expiresIn(JsonField<Long> expiresIn)
Sets Builder.expiresIn to an arbitrary JSON value.
You should usually call Builder.expiresIn with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final ObjectCreatePresignedUrlResponse.Builder filename(String filename)
Original filename
-
filename
final ObjectCreatePresignedUrlResponse.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructions
final ObjectCreatePresignedUrlResponse.Builder instructions(JsonValue instructions)
Usage instructions and examples
-
metadata
final ObjectCreatePresignedUrlResponse.Builder metadata(ObjectCreatePresignedUrlResponse.Metadata metadata)
-
metadata
final ObjectCreatePresignedUrlResponse.Builder metadata(JsonField<ObjectCreatePresignedUrlResponse.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final ObjectCreatePresignedUrlResponse.Builder objectId(String objectId)
The object identifier
-
objectId
final ObjectCreatePresignedUrlResponse.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
operation
final ObjectCreatePresignedUrlResponse.Builder operation(String operation)
The operation type
-
operation
final ObjectCreatePresignedUrlResponse.Builder operation(JsonField<String> operation)
Sets Builder.operation to an arbitrary JSON value.
You should usually call Builder.operation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presignedUrl
final ObjectCreatePresignedUrlResponse.Builder presignedUrl(String presignedUrl)
The presigned URL for direct S3 access
-
presignedUrl
final ObjectCreatePresignedUrlResponse.Builder presignedUrl(JsonField<String> presignedUrl)
Sets Builder.presignedUrl to an arbitrary JSON value.
You should usually call Builder.presignedUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
s3Key
final ObjectCreatePresignedUrlResponse.Builder s3Key(String s3Key)
S3 object key
-
s3Key
final ObjectCreatePresignedUrlResponse.Builder s3Key(JsonField<String> s3Key)
Sets Builder.s3Key to an arbitrary JSON value.
You should usually call Builder.s3Key with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final ObjectCreatePresignedUrlResponse.Builder vaultId(String vaultId)
The vault identifier
-
vaultId
final ObjectCreatePresignedUrlResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectCreatePresignedUrlResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectCreatePresignedUrlResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectCreatePresignedUrlResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectCreatePresignedUrlResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectCreatePresignedUrlResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectCreatePresignedUrlResponse build()
Returns an immutable instance of ObjectCreatePresignedUrlResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-