Class ObjectCreatePresignedUrlResponse.Metadata
-
- All Implemented Interfaces:
public final class ObjectCreatePresignedUrlResponse.Metadata
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectCreatePresignedUrlResponse.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final Optional<String>bucket()final Optional<String>contentType()final Optional<String>region()final Optional<Long>sizeBytes()final JsonField<String>_bucket()Returns the raw JSON value of bucket. final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final Map<String, JsonValue>_additionalProperties()final ObjectCreatePresignedUrlResponse.Metadata.BuildertoBuilder()final ObjectCreatePresignedUrlResponse.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectCreatePresignedUrlResponse.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
contentType
final Optional<String> contentType()
-
_bucket
final JsonField<String> _bucket()
Returns the raw JSON value of bucket.
Unlike bucket, this method doesn't throw if the JSON field has an unexpected type.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectCreatePresignedUrlResponse.Metadata.Builder toBuilder()
-
validate
final ObjectCreatePresignedUrlResponse.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectCreatePresignedUrlResponse.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-