Class ObjectCreatePresignedUrlResponse.Metadata.Builder
-
- All Implemented Interfaces:
public final class ObjectCreatePresignedUrlResponse.Metadata.BuilderA builder for Metadata.
-
-
Method Summary
-
-
Method Detail
-
bucket
final ObjectCreatePresignedUrlResponse.Metadata.Builder bucket(String bucket)
-
bucket
final ObjectCreatePresignedUrlResponse.Metadata.Builder bucket(JsonField<String> bucket)
Sets Builder.bucket to an arbitrary JSON value.
You should usually call Builder.bucket with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contentType
final ObjectCreatePresignedUrlResponse.Metadata.Builder contentType(String contentType)
-
contentType
final ObjectCreatePresignedUrlResponse.Metadata.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
region
final ObjectCreatePresignedUrlResponse.Metadata.Builder region(String region)
-
region
final ObjectCreatePresignedUrlResponse.Metadata.Builder region(JsonField<String> region)
Sets Builder.region to an arbitrary JSON value.
You should usually call Builder.region with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final ObjectCreatePresignedUrlResponse.Metadata.Builder sizeBytes(Long sizeBytes)
-
sizeBytes
final ObjectCreatePresignedUrlResponse.Metadata.Builder sizeBytes(JsonField<Long> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectCreatePresignedUrlResponse.Metadata.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectCreatePresignedUrlResponse.Metadata.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectCreatePresignedUrlResponse.Metadata.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectCreatePresignedUrlResponse.Metadata.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectCreatePresignedUrlResponse.Metadata.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectCreatePresignedUrlResponse.Metadata build()
Returns an immutable instance of Metadata.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-