Class ObjectDeleteParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ObjectDeleteParams implements Params
Permanently deletes a document from the vault including all associated vectors, chunks, graph data, and the original file. This operation cannot be undone.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectDeleteParams.BuilderA builder for ObjectDeleteParams.
public final classObjectDeleteParams.ForceForce delete a stuck document that is still in 'processing' state. Use this if a document got stuck during ingestion (e.g., OCR timeout).
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>objectId()final Optional<ObjectDeleteParams.Force>force()Force delete a stuck document that is still in 'processing' state. final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ObjectDeleteParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectDeleteParams.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectDeleteParams. -
-
Method Detail
-
force
final Optional<ObjectDeleteParams.Force> force()
Force delete a stuck document that is still in 'processing' state. Use this if a document got stuck during ingestion (e.g., OCR timeout).
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ObjectDeleteParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ObjectDeleteParams.Builder builder()
Returns a mutable builder for constructing an instance of ObjectDeleteParams.
The following fields are required:
.id()
-
-
-
-