Class ObjectDeleteParams.Force

  • All Implemented Interfaces:
    dev.case.api.core.Enum

    
    public final class ObjectDeleteParams.Force
     implements Enum
                        

    Force delete a stuck document that is still in 'processing' state. Use this if a document got stuck during ingestion (e.g., OCR timeout).

    • Constructor Detail