Class ObjectDeleteResponse
-
- All Implemented Interfaces:
public final class ObjectDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectDeleteResponse.BuilderA builder for ObjectDeleteResponse.
public final classObjectDeleteResponse.DeletedObject
-
Method Summary
Modifier and Type Method Description final Optional<ObjectDeleteResponse.DeletedObject>deletedObject()final Optional<Boolean>success()final JsonField<ObjectDeleteResponse.DeletedObject>_deletedObject()Returns the raw JSON value of deletedObject. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final ObjectDeleteResponse.BuildertoBuilder()final ObjectDeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectDeleteResponse. -
-
Method Detail
-
deletedObject
final Optional<ObjectDeleteResponse.DeletedObject> deletedObject()
-
_deletedObject
final JsonField<ObjectDeleteResponse.DeletedObject> _deletedObject()
Returns the raw JSON value of deletedObject.
Unlike deletedObject, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectDeleteResponse.Builder toBuilder()
-
validate
final ObjectDeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectDeleteResponse.
-
-
-
-