Class ObjectDeleteResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectDeleteResponse.BuilderA builder for ObjectDeleteResponse.
-
-
Method Summary
-
-
Method Detail
-
deletedObject
final ObjectDeleteResponse.Builder deletedObject(ObjectDeleteResponse.DeletedObject deletedObject)
-
deletedObject
final ObjectDeleteResponse.Builder deletedObject(JsonField<ObjectDeleteResponse.DeletedObject> deletedObject)
Sets Builder.deletedObject to an arbitrary JSON value.
You should usually call Builder.deletedObject with a well-typed DeletedObject value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
success
final ObjectDeleteResponse.Builder success(Boolean success)
-
success
final ObjectDeleteResponse.Builder success(JsonField<Boolean> success)
Sets Builder.success to an arbitrary JSON value.
You should usually call Builder.success with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectDeleteResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectDeleteResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectDeleteResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectDeleteResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectDeleteResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectDeleteResponse build()
Returns an immutable instance of ObjectDeleteResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-