Class ObjectDeleteResponse.DeletedObject
-
- All Implemented Interfaces:
public final class ObjectDeleteResponse.DeletedObject
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectDeleteResponse.DeletedObject.BuilderA builder for DeletedObject.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Deleted object ID final Optional<String>filename()Original filename final Optional<Long>sizeBytes()Size of deleted file in bytes final Optional<Long>vectorsDeleted()Number of vectors deleted final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final JsonField<Long>_vectorsDeleted()Returns the raw JSON value of vectorsDeleted. final Map<String, JsonValue>_additionalProperties()final ObjectDeleteResponse.DeletedObject.BuildertoBuilder()final ObjectDeleteResponse.DeletedObjectvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectDeleteResponse.DeletedObject.Builderbuilder()Returns a mutable builder for constructing an instance of DeletedObject. -
-
Method Detail
-
vectorsDeleted
final Optional<Long> vectorsDeleted()
Number of vectors deleted
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_vectorsDeleted
final JsonField<Long> _vectorsDeleted()
Returns the raw JSON value of vectorsDeleted.
Unlike vectorsDeleted, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectDeleteResponse.DeletedObject.Builder toBuilder()
-
validate
final ObjectDeleteResponse.DeletedObject validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectDeleteResponse.DeletedObject.Builder builder()
Returns a mutable builder for constructing an instance of DeletedObject.
-
-
-
-