Class ObjectDeleteResponse.DeletedObject.Builder
-
- All Implemented Interfaces:
public final class ObjectDeleteResponse.DeletedObject.BuilderA builder for DeletedObject.
-
-
Method Summary
-
-
Method Detail
-
id
final ObjectDeleteResponse.DeletedObject.Builder id(String id)
Deleted object ID
-
id
final ObjectDeleteResponse.DeletedObject.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final ObjectDeleteResponse.DeletedObject.Builder filename(String filename)
Original filename
-
filename
final ObjectDeleteResponse.DeletedObject.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final ObjectDeleteResponse.DeletedObject.Builder sizeBytes(Long sizeBytes)
Size of deleted file in bytes
-
sizeBytes
final ObjectDeleteResponse.DeletedObject.Builder sizeBytes(JsonField<Long> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vectorsDeleted
final ObjectDeleteResponse.DeletedObject.Builder vectorsDeleted(Long vectorsDeleted)
Number of vectors deleted
-
vectorsDeleted
final ObjectDeleteResponse.DeletedObject.Builder vectorsDeleted(JsonField<Long> vectorsDeleted)
Sets Builder.vectorsDeleted to an arbitrary JSON value.
You should usually call Builder.vectorsDeleted with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectDeleteResponse.DeletedObject.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectDeleteResponse.DeletedObject.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectDeleteResponse.DeletedObject.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectDeleteResponse.DeletedObject.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectDeleteResponse.DeletedObject.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectDeleteResponse.DeletedObject build()
Returns an immutable instance of DeletedObject.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-