Class ObjectGetChunksResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectGetChunksResponse.BuilderA builder for ObjectGetChunksResponse.
-
-
Method Summary
-
-
Method Detail
-
chunks
final ObjectGetChunksResponse.Builder chunks(List<ObjectGetChunksResponse.Chunk> chunks)
Full chunk objects for the requested range
-
chunks
final ObjectGetChunksResponse.Builder chunks(JsonField<List<ObjectGetChunksResponse.Chunk>> chunks)
Sets Builder.chunks to an arbitrary JSON value.
You should usually call Builder.chunks with a well-typed
List<Chunk>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addChunk
final ObjectGetChunksResponse.Builder addChunk(ObjectGetChunksResponse.Chunk chunk)
-
objectId
final ObjectGetChunksResponse.Builder objectId(String objectId)
The object ID
-
objectId
final ObjectGetChunksResponse.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalChunks
final ObjectGetChunksResponse.Builder totalChunks(Long totalChunks)
Total number of chunks stored for the object
-
totalChunks
final ObjectGetChunksResponse.Builder totalChunks(JsonField<Long> totalChunks)
Sets Builder.totalChunks to an arbitrary JSON value.
You should usually call Builder.totalChunks with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final ObjectGetChunksResponse.Builder vaultId(String vaultId)
The vault ID
-
vaultId
final ObjectGetChunksResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetChunksResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetChunksResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetChunksResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetChunksResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetChunksResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetChunksResponse build()
Returns an immutable instance of ObjectGetChunksResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.chunks() .objectId() .totalChunks() .vaultId()
-
-
-
-