Class ObjectGetChunksResponse.Chunk
-
- All Implemented Interfaces:
public final class ObjectGetChunksResponse.Chunk
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetChunksResponse.Chunk.BuilderA builder for Chunk.
-
Method Summary
Modifier and Type Method Description final Longindex()Chunk index within the document final Optional<Long>pageEnd()Last page covered by the chunk, if page mapping is available final Optional<Long>pageStart()First page covered by the chunk, if page mapping is available final Stringtext()Full text for the chunk final Optional<Long>wordEndIndex()Last OCR word index covered by the chunk, if available final Optional<Long>wordStartIndex()First OCR word index covered by the chunk, if available final JsonField<Long>_index()Returns the raw JSON value of index. final JsonField<Long>_pageEnd()Returns the raw JSON value of pageEnd. final JsonField<Long>_pageStart()Returns the raw JSON value of pageStart. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<Long>_wordEndIndex()Returns the raw JSON value of wordEndIndex. final JsonField<Long>_wordStartIndex()Returns the raw JSON value of wordStartIndex. final Map<String, JsonValue>_additionalProperties()final ObjectGetChunksResponse.Chunk.BuildertoBuilder()final ObjectGetChunksResponse.Chunkvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetChunksResponse.Chunk.Builderbuilder()Returns a mutable builder for constructing an instance of Chunk. -
-
Method Detail
-
pageStart
final Optional<Long> pageStart()
First page covered by the chunk, if page mapping is available
-
wordEndIndex
final Optional<Long> wordEndIndex()
Last OCR word index covered by the chunk, if available
-
wordStartIndex
final Optional<Long> wordStartIndex()
First OCR word index covered by the chunk, if available
-
_index
final JsonField<Long> _index()
Returns the raw JSON value of index.
Unlike index, this method doesn't throw if the JSON field has an unexpected type.
-
_pageEnd
final JsonField<Long> _pageEnd()
Returns the raw JSON value of pageEnd.
Unlike pageEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_pageStart
final JsonField<Long> _pageStart()
Returns the raw JSON value of pageStart.
Unlike pageStart, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_wordEndIndex
final JsonField<Long> _wordEndIndex()
Returns the raw JSON value of wordEndIndex.
Unlike wordEndIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_wordStartIndex
final JsonField<Long> _wordStartIndex()
Returns the raw JSON value of wordStartIndex.
Unlike wordStartIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetChunksResponse.Chunk.Builder toBuilder()
-
validate
final ObjectGetChunksResponse.Chunk validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectGetChunksResponse.Chunk.Builder builder()
Returns a mutable builder for constructing an instance of Chunk.
The following fields are required:
.index() .pageEnd() .pageStart() .text() .wordEndIndex() .wordStartIndex()
-
-
-
-