Class ObjectGetChunksResponse.Chunk.Builder
-
- All Implemented Interfaces:
public final class ObjectGetChunksResponse.Chunk.BuilderA builder for Chunk.
-
-
Method Summary
-
-
Method Detail
-
index
final ObjectGetChunksResponse.Chunk.Builder index(Long index)
Chunk index within the document
-
index
final ObjectGetChunksResponse.Chunk.Builder index(JsonField<Long> index)
Sets Builder.index to an arbitrary JSON value.
You should usually call Builder.index with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pageEnd
final ObjectGetChunksResponse.Chunk.Builder pageEnd(Long pageEnd)
Last page covered by the chunk, if page mapping is available
-
pageEnd
final ObjectGetChunksResponse.Chunk.Builder pageEnd(Long pageEnd)
Alias for Builder.pageEnd.
This unboxed primitive overload exists for backwards compatibility.
-
pageEnd
final ObjectGetChunksResponse.Chunk.Builder pageEnd(Optional<Long> pageEnd)
Alias for calling Builder.pageEnd with
pageEnd.orElse(null).
-
pageEnd
final ObjectGetChunksResponse.Chunk.Builder pageEnd(JsonField<Long> pageEnd)
Sets Builder.pageEnd to an arbitrary JSON value.
You should usually call Builder.pageEnd with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pageStart
final ObjectGetChunksResponse.Chunk.Builder pageStart(Long pageStart)
First page covered by the chunk, if page mapping is available
-
pageStart
final ObjectGetChunksResponse.Chunk.Builder pageStart(Long pageStart)
Alias for Builder.pageStart.
This unboxed primitive overload exists for backwards compatibility.
-
pageStart
final ObjectGetChunksResponse.Chunk.Builder pageStart(Optional<Long> pageStart)
Alias for calling Builder.pageStart with
pageStart.orElse(null).
-
pageStart
final ObjectGetChunksResponse.Chunk.Builder pageStart(JsonField<Long> pageStart)
Sets Builder.pageStart to an arbitrary JSON value.
You should usually call Builder.pageStart with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final ObjectGetChunksResponse.Chunk.Builder text(String text)
Full text for the chunk
-
text
final ObjectGetChunksResponse.Chunk.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wordEndIndex
final ObjectGetChunksResponse.Chunk.Builder wordEndIndex(Long wordEndIndex)
Last OCR word index covered by the chunk, if available
-
wordEndIndex
final ObjectGetChunksResponse.Chunk.Builder wordEndIndex(Long wordEndIndex)
Alias for Builder.wordEndIndex.
This unboxed primitive overload exists for backwards compatibility.
-
wordEndIndex
final ObjectGetChunksResponse.Chunk.Builder wordEndIndex(Optional<Long> wordEndIndex)
Alias for calling Builder.wordEndIndex with
wordEndIndex.orElse(null).
-
wordEndIndex
final ObjectGetChunksResponse.Chunk.Builder wordEndIndex(JsonField<Long> wordEndIndex)
Sets Builder.wordEndIndex to an arbitrary JSON value.
You should usually call Builder.wordEndIndex with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wordStartIndex
final ObjectGetChunksResponse.Chunk.Builder wordStartIndex(Long wordStartIndex)
First OCR word index covered by the chunk, if available
-
wordStartIndex
final ObjectGetChunksResponse.Chunk.Builder wordStartIndex(Long wordStartIndex)
Alias for Builder.wordStartIndex.
This unboxed primitive overload exists for backwards compatibility.
-
wordStartIndex
final ObjectGetChunksResponse.Chunk.Builder wordStartIndex(Optional<Long> wordStartIndex)
Alias for calling Builder.wordStartIndex with
wordStartIndex.orElse(null).
-
wordStartIndex
final ObjectGetChunksResponse.Chunk.Builder wordStartIndex(JsonField<Long> wordStartIndex)
Sets Builder.wordStartIndex to an arbitrary JSON value.
You should usually call Builder.wordStartIndex with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetChunksResponse.Chunk.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetChunksResponse.Chunk.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetChunksResponse.Chunk.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetChunksResponse.Chunk.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetChunksResponse.Chunk.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetChunksResponse.Chunk build()
Returns an immutable instance of Chunk.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.index() .pageEnd() .pageStart() .text() .wordEndIndex() .wordStartIndex()
-
-
-
-