Class ObjectGetOcrWordsResponse
-
- All Implemented Interfaces:
public final class ObjectGetOcrWordsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetOcrWordsResponse.BuilderA builder for ObjectGetOcrWordsResponse.
public final classObjectGetOcrWordsResponse.Page
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>createdAt()When the OCR data was extracted final Optional<String>objectId()The object ID final Optional<Long>pageCount()Total number of pages in the document final Optional<List<ObjectGetOcrWordsResponse.Page>>pages()Per-page word data with bounding boxes final Optional<Long>totalWords()Total number of words extracted from the document final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<Long>_pageCount()Returns the raw JSON value of pageCount. final JsonField<List<ObjectGetOcrWordsResponse.Page>>_pages()Returns the raw JSON value of pages. final JsonField<Long>_totalWords()Returns the raw JSON value of totalWords. final Map<String, JsonValue>_additionalProperties()final ObjectGetOcrWordsResponse.BuildertoBuilder()final ObjectGetOcrWordsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetOcrWordsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectGetOcrWordsResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
When the OCR data was extracted
-
pages
final Optional<List<ObjectGetOcrWordsResponse.Page>> pages()
Per-page word data with bounding boxes
-
totalWords
final Optional<Long> totalWords()
Total number of words extracted from the document
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_pageCount
final JsonField<Long> _pageCount()
Returns the raw JSON value of pageCount.
Unlike pageCount, this method doesn't throw if the JSON field has an unexpected type.
-
_pages
final JsonField<List<ObjectGetOcrWordsResponse.Page>> _pages()
Returns the raw JSON value of pages.
Unlike pages, this method doesn't throw if the JSON field has an unexpected type.
-
_totalWords
final JsonField<Long> _totalWords()
Returns the raw JSON value of totalWords.
Unlike totalWords, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetOcrWordsResponse.Builder toBuilder()
-
validate
final ObjectGetOcrWordsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectGetOcrWordsResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectGetOcrWordsResponse.
-
-
-
-