Class ObjectGetOcrWordsResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectGetOcrWordsResponse.BuilderA builder for ObjectGetOcrWordsResponse.
-
-
Method Summary
-
-
Method Detail
-
createdAt
final ObjectGetOcrWordsResponse.Builder createdAt(OffsetDateTime createdAt)
When the OCR data was extracted
-
createdAt
final ObjectGetOcrWordsResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final ObjectGetOcrWordsResponse.Builder objectId(String objectId)
The object ID
-
objectId
final ObjectGetOcrWordsResponse.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pageCount
final ObjectGetOcrWordsResponse.Builder pageCount(Long pageCount)
Total number of pages in the document
-
pageCount
final ObjectGetOcrWordsResponse.Builder pageCount(JsonField<Long> pageCount)
Sets Builder.pageCount to an arbitrary JSON value.
You should usually call Builder.pageCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pages
final ObjectGetOcrWordsResponse.Builder pages(List<ObjectGetOcrWordsResponse.Page> pages)
Per-page word data with bounding boxes
-
pages
final ObjectGetOcrWordsResponse.Builder pages(JsonField<List<ObjectGetOcrWordsResponse.Page>> pages)
Sets Builder.pages to an arbitrary JSON value.
You should usually call Builder.pages with a well-typed
List<Page>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPage
final ObjectGetOcrWordsResponse.Builder addPage(ObjectGetOcrWordsResponse.Page page)
-
totalWords
final ObjectGetOcrWordsResponse.Builder totalWords(Long totalWords)
Total number of words extracted from the document
-
totalWords
final ObjectGetOcrWordsResponse.Builder totalWords(JsonField<Long> totalWords)
Sets Builder.totalWords to an arbitrary JSON value.
You should usually call Builder.totalWords with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetOcrWordsResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetOcrWordsResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetOcrWordsResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetOcrWordsResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetOcrWordsResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetOcrWordsResponse build()
Returns an immutable instance of ObjectGetOcrWordsResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-