Class ObjectGetOcrWordsResponse.Page.Word.Builder
-
- All Implemented Interfaces:
public final class ObjectGetOcrWordsResponse.Page.Word.BuilderA builder for Word.
-
-
Method Summary
-
-
Method Detail
-
bbox
final ObjectGetOcrWordsResponse.Page.Word.Builder bbox(List<Double> bbox)
Bounding box x0, y0, x1, y1 normalized to 0-1 range
-
bbox
final ObjectGetOcrWordsResponse.Page.Word.Builder bbox(JsonField<List<Double>> bbox)
Sets Builder.bbox to an arbitrary JSON value.
You should usually call Builder.bbox with a well-typed
List<Double>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBbox
final ObjectGetOcrWordsResponse.Page.Word.Builder addBbox(Double bbox)
Adds a single Double to Builder.bbox.
-
confidence
final ObjectGetOcrWordsResponse.Page.Word.Builder confidence(Double confidence)
OCR confidence score (0-1)
-
confidence
final ObjectGetOcrWordsResponse.Page.Word.Builder confidence(Double confidence)
Alias for Builder.confidence.
This unboxed primitive overload exists for backwards compatibility.
-
confidence
final ObjectGetOcrWordsResponse.Page.Word.Builder confidence(Optional<Double> confidence)
Alias for calling Builder.confidence with
confidence.orElse(null).
-
confidence
final ObjectGetOcrWordsResponse.Page.Word.Builder confidence(JsonField<Double> confidence)
Sets Builder.confidence to an arbitrary JSON value.
You should usually call Builder.confidence with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final ObjectGetOcrWordsResponse.Page.Word.Builder text(String text)
The word text
-
text
final ObjectGetOcrWordsResponse.Page.Word.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wordIndex
final ObjectGetOcrWordsResponse.Page.Word.Builder wordIndex(Long wordIndex)
Global word index across the entire document (0-based)
-
wordIndex
final ObjectGetOcrWordsResponse.Page.Word.Builder wordIndex(JsonField<Long> wordIndex)
Sets Builder.wordIndex to an arbitrary JSON value.
You should usually call Builder.wordIndex with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetOcrWordsResponse.Page.Word.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetOcrWordsResponse.Page.Word.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetOcrWordsResponse.Page.Word.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetOcrWordsResponse.Page.Word.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetOcrWordsResponse.Page.Word.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetOcrWordsResponse.Page.Word build()
Returns an immutable instance of Word.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-