Class ObjectGetPagesResponse.Metadata
-
- All Implemented Interfaces:
public final class ObjectGetPagesResponse.Metadata
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetPagesResponse.Metadata.BuilderA builder for Metadata.
public final classObjectGetPagesResponse.Metadata.SourceWhere the page text came from.
ocrfor PDFs (per-page OCR sidecar).txtfor plain-text files split on form-feed (\f) characters.
-
Method Summary
Modifier and Type Method Description final Stringfilename()final StringobjectId()final LongpageCount()Total number of pages with extracted text in the document final LongreturnedPages()Number of pages returned after applying the range filter final ObjectGetPagesResponse.Metadata.Sourcesource()Where the page text came from. final StringvaultId()final Optional<Long>end()Echoes the end query param if provided final Optional<Long>start()Echoes the start query param if provided final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<Long>_pageCount()Returns the raw JSON value of pageCount. final JsonField<Long>_returnedPages()Returns the raw JSON value of returnedPages. final JsonField<ObjectGetPagesResponse.Metadata.Source>_source()Returns the raw JSON value of source. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final JsonField<Long>_end()Returns the raw JSON value of end. final JsonField<Long>_start()Returns the raw JSON value of start. final Map<String, JsonValue>_additionalProperties()final ObjectGetPagesResponse.Metadata.BuildertoBuilder()final ObjectGetPagesResponse.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetPagesResponse.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
returnedPages
final Long returnedPages()
Number of pages returned after applying the range filter
-
source
final ObjectGetPagesResponse.Metadata.Source source()
Where the page text came from.
ocrfor PDFs (per-page OCR sidecar).txtfor plain-text files split on form-feed (\f) characters.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_pageCount
final JsonField<Long> _pageCount()
Returns the raw JSON value of pageCount.
Unlike pageCount, this method doesn't throw if the JSON field has an unexpected type.
-
_returnedPages
final JsonField<Long> _returnedPages()
Returns the raw JSON value of returnedPages.
Unlike returnedPages, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<ObjectGetPagesResponse.Metadata.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_end
final JsonField<Long> _end()
Returns the raw JSON value of end.
Unlike end, this method doesn't throw if the JSON field has an unexpected type.
-
_start
final JsonField<Long> _start()
Returns the raw JSON value of start.
Unlike start, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetPagesResponse.Metadata.Builder toBuilder()
-
validate
final ObjectGetPagesResponse.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectGetPagesResponse.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
The following fields are required:
.filename() .objectId() .pageCount() .returnedPages() .source() .vaultId()
-
-
-
-