Class ObjectGetPagesResponse.Metadata.Builder
-
- All Implemented Interfaces:
public final class ObjectGetPagesResponse.Metadata.BuilderA builder for Metadata.
-
-
Method Summary
-
-
Method Detail
-
filename
final ObjectGetPagesResponse.Metadata.Builder filename(String filename)
-
filename
final ObjectGetPagesResponse.Metadata.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final ObjectGetPagesResponse.Metadata.Builder objectId(String objectId)
-
objectId
final ObjectGetPagesResponse.Metadata.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pageCount
final ObjectGetPagesResponse.Metadata.Builder pageCount(Long pageCount)
Total number of pages with extracted text in the document
-
pageCount
final ObjectGetPagesResponse.Metadata.Builder pageCount(JsonField<Long> pageCount)
Sets Builder.pageCount to an arbitrary JSON value.
You should usually call Builder.pageCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
returnedPages
final ObjectGetPagesResponse.Metadata.Builder returnedPages(Long returnedPages)
Number of pages returned after applying the range filter
-
returnedPages
final ObjectGetPagesResponse.Metadata.Builder returnedPages(JsonField<Long> returnedPages)
Sets Builder.returnedPages to an arbitrary JSON value.
You should usually call Builder.returnedPages with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final ObjectGetPagesResponse.Metadata.Builder source(ObjectGetPagesResponse.Metadata.Source source)
Where the page text came from.
ocrfor PDFs (per-page OCR sidecar).txtfor plain-text files split on form-feed (\f) characters.
-
source
final ObjectGetPagesResponse.Metadata.Builder source(JsonField<ObjectGetPagesResponse.Metadata.Source> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed Source value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final ObjectGetPagesResponse.Metadata.Builder vaultId(String vaultId)
-
vaultId
final ObjectGetPagesResponse.Metadata.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
end
final ObjectGetPagesResponse.Metadata.Builder end(Long end)
Echoes the end query param if provided
-
end
final ObjectGetPagesResponse.Metadata.Builder end(Long end)
Alias for Builder.end.
This unboxed primitive overload exists for backwards compatibility.
-
end
final ObjectGetPagesResponse.Metadata.Builder end(Optional<Long> end)
Alias for calling Builder.end with
end.orElse(null).
-
end
final ObjectGetPagesResponse.Metadata.Builder end(JsonField<Long> end)
Sets Builder.end to an arbitrary JSON value.
You should usually call Builder.end with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
start
final ObjectGetPagesResponse.Metadata.Builder start(Long start)
Echoes the start query param if provided
-
start
final ObjectGetPagesResponse.Metadata.Builder start(Long start)
Alias for Builder.start.
This unboxed primitive overload exists for backwards compatibility.
-
start
final ObjectGetPagesResponse.Metadata.Builder start(Optional<Long> start)
Alias for calling Builder.start with
start.orElse(null).
-
start
final ObjectGetPagesResponse.Metadata.Builder start(JsonField<Long> start)
Sets Builder.start to an arbitrary JSON value.
You should usually call Builder.start with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetPagesResponse.Metadata.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetPagesResponse.Metadata.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetPagesResponse.Metadata.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetPagesResponse.Metadata.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetPagesResponse.Metadata.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetPagesResponse.Metadata build()
Returns an immutable instance of Metadata.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.filename() .objectId() .pageCount() .returnedPages() .source() .vaultId()
-
-
-
-