Class ObjectGetPagesResponse.Page
-
- All Implemented Interfaces:
public final class ObjectGetPagesResponse.Page
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetPagesResponse.Page.BuilderA builder for Page.
-
Method Summary
Modifier and Type Method Description final Longpage()Page number (1-indexed) final Stringtext()OCR text for this page final JsonField<Long>_page()Returns the raw JSON value of page. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final ObjectGetPagesResponse.Page.BuildertoBuilder()final ObjectGetPagesResponse.Pagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetPagesResponse.Page.Builderbuilder()Returns a mutable builder for constructing an instance of Page. -
-
Method Detail
-
_page
final JsonField<Long> _page()
Returns the raw JSON value of page.
Unlike page, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetPagesResponse.Page.Builder toBuilder()
-
validate
final ObjectGetPagesResponse.Page validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectGetPagesResponse.Page.Builder builder()
Returns a mutable builder for constructing an instance of Page.
The following fields are required:
.page() .text()
-
-
-
-