Class ObjectGetPagesResponse.Page.Builder
-
- All Implemented Interfaces:
public final class ObjectGetPagesResponse.Page.BuilderA builder for Page.
-
-
Method Summary
Modifier and Type Method Description final ObjectGetPagesResponse.Page.Builderpage(Long page)Page number (1-indexed) final ObjectGetPagesResponse.Page.Builderpage(JsonField<Long> page)Sets Builder.page to an arbitrary JSON value. final ObjectGetPagesResponse.Page.Buildertext(String text)OCR text for this page final ObjectGetPagesResponse.Page.Buildertext(JsonField<String> text)Sets Builder.text to an arbitrary JSON value. final ObjectGetPagesResponse.Page.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ObjectGetPagesResponse.Page.BuilderputAdditionalProperty(String key, JsonValue value)final ObjectGetPagesResponse.Page.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ObjectGetPagesResponse.Page.BuilderremoveAdditionalProperty(String key)final ObjectGetPagesResponse.Page.BuilderremoveAllAdditionalProperties(Set<String> keys)final ObjectGetPagesResponse.Pagebuild()Returns an immutable instance of Page. -
-
Method Detail
-
page
final ObjectGetPagesResponse.Page.Builder page(Long page)
Page number (1-indexed)
-
page
final ObjectGetPagesResponse.Page.Builder page(JsonField<Long> page)
Sets Builder.page to an arbitrary JSON value.
You should usually call Builder.page with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final ObjectGetPagesResponse.Page.Builder text(String text)
OCR text for this page
-
text
final ObjectGetPagesResponse.Page.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetPagesResponse.Page.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetPagesResponse.Page.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetPagesResponse.Page.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetPagesResponse.Page.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetPagesResponse.Page.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetPagesResponse.Page build()
Returns an immutable instance of Page.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.page() .text()
-
-
-
-