Class ObjectGetSummarizeJobResponse
-
- All Implemented Interfaces:
public final class ObjectGetSummarizeJobResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetSummarizeJobResponse.BuilderA builder for ObjectGetSummarizeJobResponse.
public final classObjectGetSummarizeJobResponse.StatusCurrent job status
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>completedAt()When the job completed final Optional<OffsetDateTime>createdAt()When the job was created final Optional<String>error()Error message (if failed) final Optional<String>jobId()Case. final Optional<String>resultFilename()Filename of the result document (if completed) final Optional<String>resultObjectId()ID of the result document (if completed) final Optional<String>sourceObjectId()ID of the source document final Optional<ObjectGetSummarizeJobResponse.Status>status()Current job status final Optional<String>workflowType()Type of workflow being executed final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_error()Returns the raw JSON value of error. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final JsonField<String>_resultFilename()Returns the raw JSON value of resultFilename. final JsonField<String>_resultObjectId()Returns the raw JSON value of resultObjectId. final JsonField<String>_sourceObjectId()Returns the raw JSON value of sourceObjectId. final JsonField<ObjectGetSummarizeJobResponse.Status>_status()Returns the raw JSON value of status. final JsonField<String>_workflowType()Returns the raw JSON value of workflowType. final Map<String, JsonValue>_additionalProperties()final ObjectGetSummarizeJobResponse.BuildertoBuilder()final ObjectGetSummarizeJobResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetSummarizeJobResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectGetSummarizeJobResponse. -
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
When the job completed
-
createdAt
final Optional<OffsetDateTime> createdAt()
When the job was created
-
resultFilename
final Optional<String> resultFilename()
Filename of the result document (if completed)
-
resultObjectId
final Optional<String> resultObjectId()
ID of the result document (if completed)
-
sourceObjectId
final Optional<String> sourceObjectId()
ID of the source document
-
status
final Optional<ObjectGetSummarizeJobResponse.Status> status()
Current job status
-
workflowType
final Optional<String> workflowType()
Type of workflow being executed
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<String> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_resultFilename
final JsonField<String> _resultFilename()
Returns the raw JSON value of resultFilename.
Unlike resultFilename, this method doesn't throw if the JSON field has an unexpected type.
-
_resultObjectId
final JsonField<String> _resultObjectId()
Returns the raw JSON value of resultObjectId.
Unlike resultObjectId, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceObjectId
final JsonField<String> _sourceObjectId()
Returns the raw JSON value of sourceObjectId.
Unlike sourceObjectId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ObjectGetSummarizeJobResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_workflowType
final JsonField<String> _workflowType()
Returns the raw JSON value of workflowType.
Unlike workflowType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetSummarizeJobResponse.Builder toBuilder()
-
validate
final ObjectGetSummarizeJobResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectGetSummarizeJobResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectGetSummarizeJobResponse.
-
-
-
-