Class ObjectGetSummarizeJobResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectGetSummarizeJobResponse.BuilderA builder for ObjectGetSummarizeJobResponse.
-
-
Method Summary
-
-
Method Detail
-
completedAt
final ObjectGetSummarizeJobResponse.Builder completedAt(OffsetDateTime completedAt)
When the job completed
-
completedAt
final ObjectGetSummarizeJobResponse.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final ObjectGetSummarizeJobResponse.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ObjectGetSummarizeJobResponse.Builder createdAt(OffsetDateTime createdAt)
When the job was created
-
createdAt
final ObjectGetSummarizeJobResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
error
final ObjectGetSummarizeJobResponse.Builder error(String error)
Error message (if failed)
-
error
final ObjectGetSummarizeJobResponse.Builder error(Optional<String> error)
Alias for calling Builder.error with
error.orElse(null).
-
error
final ObjectGetSummarizeJobResponse.Builder error(JsonField<String> error)
Sets Builder.error to an arbitrary JSON value.
You should usually call Builder.error with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
jobId
final ObjectGetSummarizeJobResponse.Builder jobId(String jobId)
Case.dev job ID
-
jobId
final ObjectGetSummarizeJobResponse.Builder jobId(JsonField<String> jobId)
Sets Builder.jobId to an arbitrary JSON value.
You should usually call Builder.jobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resultFilename
final ObjectGetSummarizeJobResponse.Builder resultFilename(String resultFilename)
Filename of the result document (if completed)
-
resultFilename
final ObjectGetSummarizeJobResponse.Builder resultFilename(Optional<String> resultFilename)
Alias for calling Builder.resultFilename with
resultFilename.orElse(null).
-
resultFilename
final ObjectGetSummarizeJobResponse.Builder resultFilename(JsonField<String> resultFilename)
Sets Builder.resultFilename to an arbitrary JSON value.
You should usually call Builder.resultFilename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resultObjectId
final ObjectGetSummarizeJobResponse.Builder resultObjectId(String resultObjectId)
ID of the result document (if completed)
-
resultObjectId
final ObjectGetSummarizeJobResponse.Builder resultObjectId(Optional<String> resultObjectId)
Alias for calling Builder.resultObjectId with
resultObjectId.orElse(null).
-
resultObjectId
final ObjectGetSummarizeJobResponse.Builder resultObjectId(JsonField<String> resultObjectId)
Sets Builder.resultObjectId to an arbitrary JSON value.
You should usually call Builder.resultObjectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceObjectId
final ObjectGetSummarizeJobResponse.Builder sourceObjectId(String sourceObjectId)
ID of the source document
-
sourceObjectId
final ObjectGetSummarizeJobResponse.Builder sourceObjectId(JsonField<String> sourceObjectId)
Sets Builder.sourceObjectId to an arbitrary JSON value.
You should usually call Builder.sourceObjectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ObjectGetSummarizeJobResponse.Builder status(ObjectGetSummarizeJobResponse.Status status)
Current job status
-
status
final ObjectGetSummarizeJobResponse.Builder status(JsonField<ObjectGetSummarizeJobResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
workflowType
final ObjectGetSummarizeJobResponse.Builder workflowType(String workflowType)
Type of workflow being executed
-
workflowType
final ObjectGetSummarizeJobResponse.Builder workflowType(JsonField<String> workflowType)
Sets Builder.workflowType to an arbitrary JSON value.
You should usually call Builder.workflowType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetSummarizeJobResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetSummarizeJobResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetSummarizeJobResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetSummarizeJobResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetSummarizeJobResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetSummarizeJobResponse build()
Returns an immutable instance of ObjectGetSummarizeJobResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-