Class ObjectGetTextResponse
-
- All Implemented Interfaces:
public final class ObjectGetTextResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetTextResponse.BuilderA builder for ObjectGetTextResponse.
public final classObjectGetTextResponse.Metadata
-
Method Summary
Modifier and Type Method Description final ObjectGetTextResponse.Metadatametadata()final Stringtext()Full concatenated text content from all chunks final JsonField<ObjectGetTextResponse.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final ObjectGetTextResponse.BuildertoBuilder()final ObjectGetTextResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetTextResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectGetTextResponse. -
-
Method Detail
-
metadata
final ObjectGetTextResponse.Metadata metadata()
-
_metadata
final JsonField<ObjectGetTextResponse.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetTextResponse.Builder toBuilder()
-
validate
final ObjectGetTextResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectGetTextResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectGetTextResponse.
The following fields are required:
.metadata() .text()
-
-
-
-