Class ObjectGetTextResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectGetTextResponse.BuilderA builder for ObjectGetTextResponse.
-
-
Method Summary
-
-
Method Detail
-
metadata
final ObjectGetTextResponse.Builder metadata(ObjectGetTextResponse.Metadata metadata)
-
metadata
final ObjectGetTextResponse.Builder metadata(JsonField<ObjectGetTextResponse.Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final ObjectGetTextResponse.Builder text(String text)
Full concatenated text content from all chunks
-
text
final ObjectGetTextResponse.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetTextResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetTextResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetTextResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetTextResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetTextResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetTextResponse build()
Returns an immutable instance of ObjectGetTextResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.metadata() .text()
-
-
-
-