Class ObjectGetTextResponse.Metadata
-
- All Implemented Interfaces:
public final class ObjectGetTextResponse.Metadata
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetTextResponse.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final LongchunkCount()Number of text chunks the document was split into final Stringfilename()Original filename of the document final Longlength()Total character count of the extracted text final StringobjectId()The object ID final StringvaultId()The vault ID final Optional<OffsetDateTime>ingestionCompletedAt()When the document processing completed final JsonField<Long>_chunkCount()Returns the raw JSON value of chunkCount. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<Long>_length()Returns the raw JSON value of length. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final JsonField<OffsetDateTime>_ingestionCompletedAt()Returns the raw JSON value of ingestionCompletedAt. final Map<String, JsonValue>_additionalProperties()final ObjectGetTextResponse.Metadata.BuildertoBuilder()final ObjectGetTextResponse.Metadatavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetTextResponse.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
chunkCount
final Long chunkCount()
Number of text chunks the document was split into
-
ingestionCompletedAt
final Optional<OffsetDateTime> ingestionCompletedAt()
When the document processing completed
-
_chunkCount
final JsonField<Long> _chunkCount()
Returns the raw JSON value of chunkCount.
Unlike chunkCount, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_length
final JsonField<Long> _length()
Returns the raw JSON value of length.
Unlike length, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionCompletedAt
final JsonField<OffsetDateTime> _ingestionCompletedAt()
Returns the raw JSON value of ingestionCompletedAt.
Unlike ingestionCompletedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetTextResponse.Metadata.Builder toBuilder()
-
validate
final ObjectGetTextResponse.Metadata validate()
-
builder
final static ObjectGetTextResponse.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
The following fields are required:
.chunkCount() .filename() .length() .objectId() .vaultId()
-
-
-
-