Class ObjectGetTextResponse.Metadata.Builder
-
- All Implemented Interfaces:
public final class ObjectGetTextResponse.Metadata.BuilderA builder for Metadata.
-
-
Method Summary
-
-
Method Detail
-
chunkCount
final ObjectGetTextResponse.Metadata.Builder chunkCount(Long chunkCount)
Number of text chunks the document was split into
-
chunkCount
final ObjectGetTextResponse.Metadata.Builder chunkCount(JsonField<Long> chunkCount)
Sets Builder.chunkCount to an arbitrary JSON value.
You should usually call Builder.chunkCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final ObjectGetTextResponse.Metadata.Builder filename(String filename)
Original filename of the document
-
filename
final ObjectGetTextResponse.Metadata.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
length
final ObjectGetTextResponse.Metadata.Builder length(Long length)
Total character count of the extracted text
-
length
final ObjectGetTextResponse.Metadata.Builder length(JsonField<Long> length)
Sets Builder.length to an arbitrary JSON value.
You should usually call Builder.length with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectId
final ObjectGetTextResponse.Metadata.Builder objectId(String objectId)
The object ID
-
objectId
final ObjectGetTextResponse.Metadata.Builder objectId(JsonField<String> objectId)
Sets Builder.objectId to an arbitrary JSON value.
You should usually call Builder.objectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final ObjectGetTextResponse.Metadata.Builder vaultId(String vaultId)
The vault ID
-
vaultId
final ObjectGetTextResponse.Metadata.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionCompletedAt
final ObjectGetTextResponse.Metadata.Builder ingestionCompletedAt(OffsetDateTime ingestionCompletedAt)
When the document processing completed
-
ingestionCompletedAt
final ObjectGetTextResponse.Metadata.Builder ingestionCompletedAt(JsonField<OffsetDateTime> ingestionCompletedAt)
Sets Builder.ingestionCompletedAt to an arbitrary JSON value.
You should usually call Builder.ingestionCompletedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectGetTextResponse.Metadata.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectGetTextResponse.Metadata.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectGetTextResponse.Metadata.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectGetTextResponse.Metadata.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectGetTextResponse.Metadata.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectGetTextResponse.Metadata build()
Returns an immutable instance of Metadata.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.chunkCount() .filename() .length() .objectId() .vaultId()
-
-
-
-