Class ObjectListResponse
-
- All Implemented Interfaces:
public final class ObjectListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectListResponse.BuilderA builder for ObjectListResponse.
public final classObjectListResponse.Object
-
Method Summary
Modifier and Type Method Description final Doublecount()Total number of objects in the vault final List<ObjectListResponse.Object>objects()final StringvaultId()The ID of the vault final JsonField<Double>_count()Returns the raw JSON value of count. final JsonField<List<ObjectListResponse.Object>>_objects()Returns the raw JSON value of objects. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final ObjectListResponse.BuildertoBuilder()final ObjectListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectListResponse. -
-
Method Detail
-
objects
final List<ObjectListResponse.Object> objects()
-
_count
final JsonField<Double> _count()
Returns the raw JSON value of count.
Unlike count, this method doesn't throw if the JSON field has an unexpected type.
-
_objects
final JsonField<List<ObjectListResponse.Object>> _objects()
Returns the raw JSON value of objects.
Unlike objects, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectListResponse.Builder toBuilder()
-
validate
final ObjectListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectListResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectListResponse.
The following fields are required:
.count() .objects() .vaultId()
-
-
-
-