Class ObjectListResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectListResponse.BuilderA builder for ObjectListResponse.
-
-
Method Summary
-
-
Method Detail
-
count
final ObjectListResponse.Builder count(Double count)
Total number of objects in the vault
-
count
final ObjectListResponse.Builder count(JsonField<Double> count)
Sets Builder.count to an arbitrary JSON value.
You should usually call Builder.count with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objects
final ObjectListResponse.Builder objects(List<ObjectListResponse.Object> objects)
-
objects
final ObjectListResponse.Builder objects(JsonField<List<ObjectListResponse.Object>> objects)
Sets Builder.objects to an arbitrary JSON value.
You should usually call Builder.objects with a well-typed
List<Object>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addObject
final ObjectListResponse.Builder addObject(ObjectListResponse.Object object_)
-
vaultId
final ObjectListResponse.Builder vaultId(String vaultId)
The ID of the vault
-
vaultId
final ObjectListResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectListResponse build()
Returns an immutable instance of ObjectListResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.count() .objects() .vaultId()
-
-
-
-