Class ObjectListResponse.Object
-
- All Implemented Interfaces:
public final class ObjectListResponse.Object
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectListResponse.Object.BuilderA builder for Object.
-
Method Summary
Modifier and Type Method Description final Stringid()Unique object identifier final StringcontentType()MIME type of the document final OffsetDateTimecreatedAt()Document upload timestamp final Stringfilename()Original filename of the uploaded document final StringingestionStatus()Processing status of the document final Optional<Double>chunkCount()Number of text chunks created for vectorization final Optional<OffsetDateTime>ingestionCompletedAt()Processing completion timestamp final Optional<String>ingestionError()Failure reason when ingestion status is a failed state final Optional<OffsetDateTime>ingestionStartedAt()When ingestion processing began final Optional<String>ingestionWorkflowId()Durable workflow run ID for the active or last ingestion attempt final JsonValue_metadata()Custom metadata associated with the documentThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = object_.metadata().convert(MyClass.class);final Optional<Double>pageCount()Number of pages in the document final Optional<String>path()Optional folder path for hierarchy preservation from source systems final Optional<Double>sizeBytes()File size in bytes final Optional<List<String>>tags()Custom tags associated with the document final Optional<Double>textLength()Total character count of extracted text final Optional<Double>vectorCount()Number of vectors generated for semantic search final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_ingestionStatus()Returns the raw JSON value of ingestionStatus. final JsonField<Double>_chunkCount()Returns the raw JSON value of chunkCount. final JsonField<OffsetDateTime>_ingestionCompletedAt()Returns the raw JSON value of ingestionCompletedAt. final JsonField<String>_ingestionError()Returns the raw JSON value of ingestionError. final JsonField<OffsetDateTime>_ingestionStartedAt()Returns the raw JSON value of ingestionStartedAt. final JsonField<String>_ingestionWorkflowId()Returns the raw JSON value of ingestionWorkflowId. final JsonField<Double>_pageCount()Returns the raw JSON value of pageCount. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<Double>_sizeBytes()Returns the raw JSON value of sizeBytes. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<Double>_textLength()Returns the raw JSON value of textLength. final JsonField<Double>_vectorCount()Returns the raw JSON value of vectorCount. final Map<String, JsonValue>_additionalProperties()final ObjectListResponse.Object.BuildertoBuilder()final ObjectListResponse.Objectvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectListResponse.Object.Builderbuilder()Returns a mutable builder for constructing an instance of Object. -
-
Method Detail
-
contentType
final String contentType()
MIME type of the document
-
createdAt
final OffsetDateTime createdAt()
Document upload timestamp
-
ingestionStatus
final String ingestionStatus()
Processing status of the document
-
chunkCount
final Optional<Double> chunkCount()
Number of text chunks created for vectorization
-
ingestionCompletedAt
final Optional<OffsetDateTime> ingestionCompletedAt()
Processing completion timestamp
-
ingestionError
final Optional<String> ingestionError()
Failure reason when ingestion status is a failed state
-
ingestionStartedAt
final Optional<OffsetDateTime> ingestionStartedAt()
When ingestion processing began
-
ingestionWorkflowId
final Optional<String> ingestionWorkflowId()
Durable workflow run ID for the active or last ingestion attempt
-
_metadata
final JsonValue _metadata()
Custom metadata associated with the document
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = object_.metadata().convert(MyClass.class);
-
path
final Optional<String> path()
Optional folder path for hierarchy preservation from source systems
-
textLength
final Optional<Double> textLength()
Total character count of extracted text
-
vectorCount
final Optional<Double> vectorCount()
Number of vectors generated for semantic search
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionStatus
final JsonField<String> _ingestionStatus()
Returns the raw JSON value of ingestionStatus.
Unlike ingestionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_chunkCount
final JsonField<Double> _chunkCount()
Returns the raw JSON value of chunkCount.
Unlike chunkCount, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionCompletedAt
final JsonField<OffsetDateTime> _ingestionCompletedAt()
Returns the raw JSON value of ingestionCompletedAt.
Unlike ingestionCompletedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionError
final JsonField<String> _ingestionError()
Returns the raw JSON value of ingestionError.
Unlike ingestionError, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionStartedAt
final JsonField<OffsetDateTime> _ingestionStartedAt()
Returns the raw JSON value of ingestionStartedAt.
Unlike ingestionStartedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionWorkflowId
final JsonField<String> _ingestionWorkflowId()
Returns the raw JSON value of ingestionWorkflowId.
Unlike ingestionWorkflowId, this method doesn't throw if the JSON field has an unexpected type.
-
_pageCount
final JsonField<Double> _pageCount()
Returns the raw JSON value of pageCount.
Unlike pageCount, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Double> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_textLength
final JsonField<Double> _textLength()
Returns the raw JSON value of textLength.
Unlike textLength, this method doesn't throw if the JSON field has an unexpected type.
-
_vectorCount
final JsonField<Double> _vectorCount()
Returns the raw JSON value of vectorCount.
Unlike vectorCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectListResponse.Object.Builder toBuilder()
-
validate
final ObjectListResponse.Object validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectListResponse.Object.Builder builder()
Returns a mutable builder for constructing an instance of Object.
The following fields are required:
.id() .contentType() .createdAt() .filename() .ingestionStatus()
-
-
-
-