Class ObjectListResponse.Object.Builder
-
- All Implemented Interfaces:
public final class ObjectListResponse.Object.BuilderA builder for Object.
-
-
Method Summary
-
-
Method Detail
-
id
final ObjectListResponse.Object.Builder id(String id)
Unique object identifier
-
id
final ObjectListResponse.Object.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contentType
final ObjectListResponse.Object.Builder contentType(String contentType)
MIME type of the document
-
contentType
final ObjectListResponse.Object.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ObjectListResponse.Object.Builder createdAt(OffsetDateTime createdAt)
Document upload timestamp
-
createdAt
final ObjectListResponse.Object.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final ObjectListResponse.Object.Builder filename(String filename)
Original filename of the uploaded document
-
filename
final ObjectListResponse.Object.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionStatus
final ObjectListResponse.Object.Builder ingestionStatus(String ingestionStatus)
Processing status of the document
-
ingestionStatus
final ObjectListResponse.Object.Builder ingestionStatus(JsonField<String> ingestionStatus)
Sets Builder.ingestionStatus to an arbitrary JSON value.
You should usually call Builder.ingestionStatus with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chunkCount
final ObjectListResponse.Object.Builder chunkCount(Double chunkCount)
Number of text chunks created for vectorization
-
chunkCount
final ObjectListResponse.Object.Builder chunkCount(JsonField<Double> chunkCount)
Sets Builder.chunkCount to an arbitrary JSON value.
You should usually call Builder.chunkCount with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionCompletedAt
final ObjectListResponse.Object.Builder ingestionCompletedAt(OffsetDateTime ingestionCompletedAt)
Processing completion timestamp
-
ingestionCompletedAt
final ObjectListResponse.Object.Builder ingestionCompletedAt(JsonField<OffsetDateTime> ingestionCompletedAt)
Sets Builder.ingestionCompletedAt to an arbitrary JSON value.
You should usually call Builder.ingestionCompletedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionError
final ObjectListResponse.Object.Builder ingestionError(String ingestionError)
Failure reason when ingestion status is a failed state
-
ingestionError
final ObjectListResponse.Object.Builder ingestionError(Optional<String> ingestionError)
Alias for calling Builder.ingestionError with
ingestionError.orElse(null).
-
ingestionError
final ObjectListResponse.Object.Builder ingestionError(JsonField<String> ingestionError)
Sets Builder.ingestionError to an arbitrary JSON value.
You should usually call Builder.ingestionError with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionStartedAt
final ObjectListResponse.Object.Builder ingestionStartedAt(OffsetDateTime ingestionStartedAt)
When ingestion processing began
-
ingestionStartedAt
final ObjectListResponse.Object.Builder ingestionStartedAt(Optional<OffsetDateTime> ingestionStartedAt)
Alias for calling Builder.ingestionStartedAt with
ingestionStartedAt.orElse(null).
-
ingestionStartedAt
final ObjectListResponse.Object.Builder ingestionStartedAt(JsonField<OffsetDateTime> ingestionStartedAt)
Sets Builder.ingestionStartedAt to an arbitrary JSON value.
You should usually call Builder.ingestionStartedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionWorkflowId
final ObjectListResponse.Object.Builder ingestionWorkflowId(String ingestionWorkflowId)
Durable workflow run ID for the active or last ingestion attempt
-
ingestionWorkflowId
final ObjectListResponse.Object.Builder ingestionWorkflowId(Optional<String> ingestionWorkflowId)
Alias for calling Builder.ingestionWorkflowId with
ingestionWorkflowId.orElse(null).
-
ingestionWorkflowId
final ObjectListResponse.Object.Builder ingestionWorkflowId(JsonField<String> ingestionWorkflowId)
Sets Builder.ingestionWorkflowId to an arbitrary JSON value.
You should usually call Builder.ingestionWorkflowId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final ObjectListResponse.Object.Builder metadata(JsonValue metadata)
Custom metadata associated with the document
-
pageCount
final ObjectListResponse.Object.Builder pageCount(Double pageCount)
Number of pages in the document
-
pageCount
final ObjectListResponse.Object.Builder pageCount(JsonField<Double> pageCount)
Sets Builder.pageCount to an arbitrary JSON value.
You should usually call Builder.pageCount with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
path
final ObjectListResponse.Object.Builder path(String path)
Optional folder path for hierarchy preservation from source systems
-
path
final ObjectListResponse.Object.Builder path(Optional<String> path)
Alias for calling Builder.path with
path.orElse(null).
-
path
final ObjectListResponse.Object.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final ObjectListResponse.Object.Builder sizeBytes(Double sizeBytes)
File size in bytes
-
sizeBytes
final ObjectListResponse.Object.Builder sizeBytes(JsonField<Double> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final ObjectListResponse.Object.Builder tags(List<String> tags)
Custom tags associated with the document
-
tags
final ObjectListResponse.Object.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final ObjectListResponse.Object.Builder addTag(String tag)
-
textLength
final ObjectListResponse.Object.Builder textLength(Double textLength)
Total character count of extracted text
-
textLength
final ObjectListResponse.Object.Builder textLength(JsonField<Double> textLength)
Sets Builder.textLength to an arbitrary JSON value.
You should usually call Builder.textLength with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vectorCount
final ObjectListResponse.Object.Builder vectorCount(Double vectorCount)
Number of vectors generated for semantic search
-
vectorCount
final ObjectListResponse.Object.Builder vectorCount(JsonField<Double> vectorCount)
Sets Builder.vectorCount to an arbitrary JSON value.
You should usually call Builder.vectorCount with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectListResponse.Object.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectListResponse.Object.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectListResponse.Object.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectListResponse.Object.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectListResponse.Object.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectListResponse.Object build()
Returns an immutable instance of Object.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .contentType() .createdAt() .filename() .ingestionStatus()
-
-
-
-