Class ObjectRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectRetrieveResponse.BuilderA builder for ObjectRetrieveResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ObjectRetrieveResponse.Builder id(String id)
Object ID
-
id
final ObjectRetrieveResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contentType
final ObjectRetrieveResponse.Builder contentType(String contentType)
MIME type
-
contentType
final ObjectRetrieveResponse.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ObjectRetrieveResponse.Builder createdAt(OffsetDateTime createdAt)
Upload timestamp
-
createdAt
final ObjectRetrieveResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
downloadUrl
final ObjectRetrieveResponse.Builder downloadUrl(String downloadUrl)
Presigned S3 download URL
-
downloadUrl
final ObjectRetrieveResponse.Builder downloadUrl(JsonField<String> downloadUrl)
Sets Builder.downloadUrl to an arbitrary JSON value.
You should usually call Builder.downloadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiresIn
final ObjectRetrieveResponse.Builder expiresIn(Long expiresIn)
URL expiration time in seconds
-
expiresIn
final ObjectRetrieveResponse.Builder expiresIn(JsonField<Long> expiresIn)
Sets Builder.expiresIn to an arbitrary JSON value.
You should usually call Builder.expiresIn with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final ObjectRetrieveResponse.Builder filename(String filename)
Original filename
-
filename
final ObjectRetrieveResponse.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionStatus
final ObjectRetrieveResponse.Builder ingestionStatus(String ingestionStatus)
Processing status (pending, processing, completed, failed)
-
ingestionStatus
final ObjectRetrieveResponse.Builder ingestionStatus(JsonField<String> ingestionStatus)
Sets Builder.ingestionStatus to an arbitrary JSON value.
You should usually call Builder.ingestionStatus with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final ObjectRetrieveResponse.Builder vaultId(String vaultId)
Vault ID
-
vaultId
final ObjectRetrieveResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chunkCount
final ObjectRetrieveResponse.Builder chunkCount(Long chunkCount)
Number of text chunks created
-
chunkCount
final ObjectRetrieveResponse.Builder chunkCount(JsonField<Long> chunkCount)
Sets Builder.chunkCount to an arbitrary JSON value.
You should usually call Builder.chunkCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final ObjectRetrieveResponse.Builder metadata(JsonValue metadata)
Additional metadata
-
pageCount
final ObjectRetrieveResponse.Builder pageCount(Long pageCount)
Number of pages (for documents)
-
pageCount
final ObjectRetrieveResponse.Builder pageCount(JsonField<Long> pageCount)
Sets Builder.pageCount to an arbitrary JSON value.
You should usually call Builder.pageCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
path
final ObjectRetrieveResponse.Builder path(String path)
Optional folder path for hierarchy preservation
-
path
final ObjectRetrieveResponse.Builder path(Optional<String> path)
Alias for calling Builder.path with
path.orElse(null).
-
path
final ObjectRetrieveResponse.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final ObjectRetrieveResponse.Builder sizeBytes(Long sizeBytes)
File size in bytes
-
sizeBytes
final ObjectRetrieveResponse.Builder sizeBytes(JsonField<Long> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
textLength
final ObjectRetrieveResponse.Builder textLength(Long textLength)
Length of extracted text
-
textLength
final ObjectRetrieveResponse.Builder textLength(JsonField<Long> textLength)
Sets Builder.textLength to an arbitrary JSON value.
You should usually call Builder.textLength with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vectorCount
final ObjectRetrieveResponse.Builder vectorCount(Long vectorCount)
Number of embedding vectors generated
-
vectorCount
final ObjectRetrieveResponse.Builder vectorCount(JsonField<Long> vectorCount)
Sets Builder.vectorCount to an arbitrary JSON value.
You should usually call Builder.vectorCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectRetrieveResponse build()
Returns an immutable instance of ObjectRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .contentType() .createdAt() .downloadUrl() .expiresIn() .filename() .ingestionStatus() .vaultId()
-
-
-
-