Class ObjectUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ObjectUpdateParams implements Params
Update a document's filename, path, or metadata. Use this to rename files or organize them into virtual folders. The path is stored in metadata.path and can be used to build folder hierarchies in your application.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectUpdateParams.BuilderA builder for ObjectUpdateParams.
public final classObjectUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>objectId()final Optional<String>filename()New filename for the document (affects display name and downloads) final JsonValue_metadata()Additional metadata to merge with existing metadataThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = objectUpdateParams.metadata().convert(MyClass.class);final Optional<String>path()Folder path for hierarchy preservation (e.g., '/Discovery/Depositions'). final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_path()Returns the raw JSON value of path. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ObjectUpdateParams.BuildertoBuilder()final ObjectUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectUpdateParams. -
-
Method Detail
-
filename
final Optional<String> filename()
New filename for the document (affects display name and downloads)
-
_metadata
final JsonValue _metadata()
Additional metadata to merge with existing metadata
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = objectUpdateParams.metadata().convert(MyClass.class);
-
path
final Optional<String> path()
Folder path for hierarchy preservation (e.g., '/Discovery/Depositions'). Set to null or empty string to remove.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ObjectUpdateParams.Builder toBuilder()
-
_body
final ObjectUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ObjectUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of ObjectUpdateParams.
The following fields are required:
.id()
-
-
-
-