Class ObjectUpdateParams.Body
-
- All Implemented Interfaces:
public final class ObjectUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>filename()New filename for the document (affects display name and downloads) final JsonValue_metadata()Additional metadata to merge with existing metadataThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);final Optional<String>path()Folder path for hierarchy preservation (e.g., '/Discovery/Depositions'). final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_path()Returns the raw JSON value of path. final Map<String, JsonValue>_additionalProperties()final ObjectUpdateParams.Body.BuildertoBuilder()final ObjectUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
filename
final Optional<String> filename()
New filename for the document (affects display name and downloads)
-
_metadata
final JsonValue _metadata()
Additional metadata to merge with existing metadata
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);
-
path
final Optional<String> path()
Folder path for hierarchy preservation (e.g., '/Discovery/Depositions'). Set to null or empty string to remove.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectUpdateParams.Body.Builder toBuilder()
-
validate
final ObjectUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-