Class ObjectUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ObjectUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
filename
final ObjectUpdateParams.Body.Builder filename(String filename)
New filename for the document (affects display name and downloads)
-
filename
final ObjectUpdateParams.Body.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final ObjectUpdateParams.Body.Builder metadata(JsonValue metadata)
Additional metadata to merge with existing metadata
-
path
final ObjectUpdateParams.Body.Builder path(String path)
Folder path for hierarchy preservation (e.g., '/Discovery/Depositions'). Set to null or empty string to remove.
-
path
final ObjectUpdateParams.Body.Builder path(Optional<String> path)
Alias for calling Builder.path with
path.orElse(null).
-
path
final ObjectUpdateParams.Body.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-