Class ObjectUpdateResponse
-
- All Implemented Interfaces:
public final class ObjectUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectUpdateResponse.BuilderA builder for ObjectUpdateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Object ID final Optional<String>contentType()MIME type final Optional<String>filename()Updated filename final Optional<String>ingestionStatus()Processing status final JsonValue_metadata()Full metadata objectThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = objectUpdateResponse.metadata().convert(MyClass.class);final Optional<String>path()Folder path for hierarchy preservation final Optional<Long>sizeBytes()File size in bytes final Optional<OffsetDateTime>updatedAt()Last update timestamp final Optional<String>vaultId()Vault ID final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_ingestionStatus()Returns the raw JSON value of ingestionStatus. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final ObjectUpdateResponse.BuildertoBuilder()final ObjectUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectUpdateResponse. -
-
Method Detail
-
contentType
final Optional<String> contentType()
MIME type
-
ingestionStatus
final Optional<String> ingestionStatus()
Processing status
-
_metadata
final JsonValue _metadata()
Full metadata object
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = objectUpdateResponse.metadata().convert(MyClass.class);
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Last update timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_ingestionStatus
final JsonField<String> _ingestionStatus()
Returns the raw JSON value of ingestionStatus.
Unlike ingestionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectUpdateResponse.Builder toBuilder()
-
validate
final ObjectUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ObjectUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectUpdateResponse.
-
-
-
-