Class ObjectUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class ObjectUpdateResponse.BuilderA builder for ObjectUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final ObjectUpdateResponse.Builder id(String id)
Object ID
-
id
final ObjectUpdateResponse.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contentType
final ObjectUpdateResponse.Builder contentType(String contentType)
MIME type
-
contentType
final ObjectUpdateResponse.Builder contentType(JsonField<String> contentType)
Sets Builder.contentType to an arbitrary JSON value.
You should usually call Builder.contentType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final ObjectUpdateResponse.Builder filename(String filename)
Updated filename
-
filename
final ObjectUpdateResponse.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ingestionStatus
final ObjectUpdateResponse.Builder ingestionStatus(String ingestionStatus)
Processing status
-
ingestionStatus
final ObjectUpdateResponse.Builder ingestionStatus(JsonField<String> ingestionStatus)
Sets Builder.ingestionStatus to an arbitrary JSON value.
You should usually call Builder.ingestionStatus with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final ObjectUpdateResponse.Builder metadata(JsonValue metadata)
Full metadata object
-
path
final ObjectUpdateResponse.Builder path(String path)
Folder path for hierarchy preservation
-
path
final ObjectUpdateResponse.Builder path(Optional<String> path)
Alias for calling Builder.path with
path.orElse(null).
-
path
final ObjectUpdateResponse.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizeBytes
final ObjectUpdateResponse.Builder sizeBytes(Long sizeBytes)
File size in bytes
-
sizeBytes
final ObjectUpdateResponse.Builder sizeBytes(JsonField<Long> sizeBytes)
Sets Builder.sizeBytes to an arbitrary JSON value.
You should usually call Builder.sizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final ObjectUpdateResponse.Builder updatedAt(OffsetDateTime updatedAt)
Last update timestamp
-
updatedAt
final ObjectUpdateResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vaultId
final ObjectUpdateResponse.Builder vaultId(String vaultId)
Vault ID
-
vaultId
final ObjectUpdateResponse.Builder vaultId(JsonField<String> vaultId)
Sets Builder.vaultId to an arbitrary JSON value.
You should usually call Builder.vaultId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ObjectUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ObjectUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ObjectUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ObjectUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ObjectUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ObjectUpdateResponse build()
Returns an immutable instance of ObjectUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-