Class BoostListGenerateParams.Body
-
- All Implemented Interfaces:
public final class BoostListGenerateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBoostListGenerateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringtranscriptionJobId()Completed pass-1 transcription job ID (tr_... final Optional<List<BoostListGenerateParams.Category>>categories()Optional filter for entity categories to extract final JsonField<String>_transcriptionJobId()Returns the raw JSON value of transcriptionJobId. final JsonField<List<BoostListGenerateParams.Category>>_categories()Returns the raw JSON value of categories. final Map<String, JsonValue>_additionalProperties()final BoostListGenerateParams.Body.BuildertoBuilder()final BoostListGenerateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BoostListGenerateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
transcriptionJobId
final String transcriptionJobId()
Completed pass-1 transcription job ID (tr_...)
-
categories
final Optional<List<BoostListGenerateParams.Category>> categories()
Optional filter for entity categories to extract
-
_transcriptionJobId
final JsonField<String> _transcriptionJobId()
Returns the raw JSON value of transcriptionJobId.
Unlike transcriptionJobId, this method doesn't throw if the JSON field has an unexpected type.
-
_categories
final JsonField<List<BoostListGenerateParams.Category>> _categories()
Returns the raw JSON value of categories.
Unlike categories, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BoostListGenerateParams.Body.Builder toBuilder()
-
validate
final BoostListGenerateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BoostListGenerateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.transcriptionJobId()
-
-
-
-