Class BoostListGenerateParams.Body.Builder
-
- All Implemented Interfaces:
public final class BoostListGenerateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
transcriptionJobId
final BoostListGenerateParams.Body.Builder transcriptionJobId(String transcriptionJobId)
Completed pass-1 transcription job ID (tr_...)
-
transcriptionJobId
final BoostListGenerateParams.Body.Builder transcriptionJobId(JsonField<String> transcriptionJobId)
Sets Builder.transcriptionJobId to an arbitrary JSON value.
You should usually call Builder.transcriptionJobId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
categories
final BoostListGenerateParams.Body.Builder categories(List<BoostListGenerateParams.Category> categories)
Optional filter for entity categories to extract
-
categories
final BoostListGenerateParams.Body.Builder categories(JsonField<List<BoostListGenerateParams.Category>> categories)
Sets Builder.categories to an arbitrary JSON value.
You should usually call Builder.categories with a well-typed
List<Category>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCategory
final BoostListGenerateParams.Body.Builder addCategory(BoostListGenerateParams.Category category)
Adds a single Category to categories.
-
additionalProperties
final BoostListGenerateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BoostListGenerateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BoostListGenerateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BoostListGenerateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BoostListGenerateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BoostListGenerateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.transcriptionJobId()
-
-
-
-