Class BoostListGenerateResponse.Builder
-
- All Implemented Interfaces:
public final class BoostListGenerateResponse.BuilderA builder for BoostListGenerateResponse.
-
-
Method Summary
-
-
Method Detail
-
items
final BoostListGenerateResponse.Builder items(List<BoostListGenerateResponse.Item> items)
-
items
final BoostListGenerateResponse.Builder items(JsonField<List<BoostListGenerateResponse.Item>> items)
Sets Builder.items to an arbitrary JSON value.
You should usually call Builder.items with a well-typed
List<Item>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addItem
final BoostListGenerateResponse.Builder addItem(BoostListGenerateResponse.Item item)
-
source
final BoostListGenerateResponse.Builder source(BoostListGenerateResponse.Source source)
-
source
final BoostListGenerateResponse.Builder source(JsonField<BoostListGenerateResponse.Source> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed Source value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceIds
final BoostListGenerateResponse.Builder sourceIds(List<String> sourceIds)
-
sourceIds
final BoostListGenerateResponse.Builder sourceIds(JsonField<List<String>> sourceIds)
Sets Builder.sourceIds to an arbitrary JSON value.
You should usually call Builder.sourceIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSourceId
final BoostListGenerateResponse.Builder addSourceId(String sourceId)
-
additionalProperties
final BoostListGenerateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BoostListGenerateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BoostListGenerateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BoostListGenerateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BoostListGenerateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BoostListGenerateResponse build()
Returns an immutable instance of BoostListGenerateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-