Class BoostListGenerateResponse.Item
-
- All Implemented Interfaces:
public final class BoostListGenerateResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBoostListGenerateResponse.Item.BuilderA builder for Item.
public final classBoostListGenerateResponse.Item.BoostParam
-
Method Summary
Modifier and Type Method Description final Optional<BoostListGenerateResponse.Item.BoostParam>boostParam()final Optional<String>category()final Optional<String>word()final JsonField<BoostListGenerateResponse.Item.BoostParam>_boostParam()Returns the raw JSON value of boostParam. final JsonField<String>_category()Returns the raw JSON value of category. final JsonField<String>_word()Returns the raw JSON value of word. final Map<String, JsonValue>_additionalProperties()final BoostListGenerateResponse.Item.BuildertoBuilder()final BoostListGenerateResponse.Itemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BoostListGenerateResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
boostParam
final Optional<BoostListGenerateResponse.Item.BoostParam> boostParam()
-
_boostParam
final JsonField<BoostListGenerateResponse.Item.BoostParam> _boostParam()
Returns the raw JSON value of boostParam.
Unlike boostParam, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<String> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_word
final JsonField<String> _word()
Returns the raw JSON value of word.
Unlike word, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BoostListGenerateResponse.Item.Builder toBuilder()
-
validate
final BoostListGenerateResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BoostListGenerateResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
-
-
-
-