Class BoostListGenerateResponse.Item.Builder
-
- All Implemented Interfaces:
public final class BoostListGenerateResponse.Item.BuilderA builder for Item.
-
-
Method Summary
-
-
Method Detail
-
boostParam
final BoostListGenerateResponse.Item.Builder boostParam(BoostListGenerateResponse.Item.BoostParam boostParam)
-
boostParam
final BoostListGenerateResponse.Item.Builder boostParam(JsonField<BoostListGenerateResponse.Item.BoostParam> boostParam)
Sets Builder.boostParam to an arbitrary JSON value.
You should usually call Builder.boostParam with a well-typed BoostParam value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final BoostListGenerateResponse.Item.Builder category(String category)
-
category
final BoostListGenerateResponse.Item.Builder category(JsonField<String> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
word
final BoostListGenerateResponse.Item.Builder word(String word)
-
word
final BoostListGenerateResponse.Item.Builder word(JsonField<String> word)
Sets Builder.word to an arbitrary JSON value.
You should usually call Builder.word with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BoostListGenerateResponse.Item.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BoostListGenerateResponse.Item.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BoostListGenerateResponse.Item.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BoostListGenerateResponse.Item.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BoostListGenerateResponse.Item.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BoostListGenerateResponse.Item build()
Returns an immutable instance of Item.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-