Class StreamingGetUrlParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class StreamingGetUrlParams implements Params
Returns the WebSocket URL and connection details for real-time audio transcription. The returned URL can be used to establish a WebSocket connection for streaming audio data and receiving transcribed text in real-time.
Audio Requirements:
Sample Rate: 16kHz
Encoding: PCM 16-bit little-endian
Channels: Mono (1 channel)
Pricing:
$0.01 per minute ($
0.60 per hour)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamingGetUrlParams.BuilderA builder for StreamingGetUrlParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final StreamingGetUrlParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamingGetUrlParamsnone()final static StreamingGetUrlParams.Builderbuilder()Returns a mutable builder for constructing an instance of StreamingGetUrlParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final StreamingGetUrlParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static StreamingGetUrlParams none()
-
builder
final static StreamingGetUrlParams.Builder builder()
Returns a mutable builder for constructing an instance of StreamingGetUrlParams.
-
-
-
-