Class StreamingGetUrlResponse
-
- All Implemented Interfaces:
public final class StreamingGetUrlResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamingGetUrlResponse.BuilderA builder for StreamingGetUrlResponse.
public final classStreamingGetUrlResponse.AudioFormatpublic final classStreamingGetUrlResponse.Pricing
-
Method Summary
Modifier and Type Method Description final Optional<StreamingGetUrlResponse.AudioFormat>audioFormat()final Optional<String>connectUrl()Complete WebSocket URL with authentication token final Optional<StreamingGetUrlResponse.Pricing>pricing()final Optional<String>protocol()Connection protocol final Optional<String>url()Base WebSocket URL for streaming transcription final JsonField<StreamingGetUrlResponse.AudioFormat>_audioFormat()Returns the raw JSON value of audioFormat. final JsonField<String>_connectUrl()Returns the raw JSON value of connectUrl. final JsonField<StreamingGetUrlResponse.Pricing>_pricing()Returns the raw JSON value of pricing. final JsonField<String>_protocol()Returns the raw JSON value of protocol. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final StreamingGetUrlResponse.BuildertoBuilder()final StreamingGetUrlResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamingGetUrlResponse.Builderbuilder()Returns a mutable builder for constructing an instance of StreamingGetUrlResponse. -
-
Method Detail
-
audioFormat
final Optional<StreamingGetUrlResponse.AudioFormat> audioFormat()
-
connectUrl
final Optional<String> connectUrl()
Complete WebSocket URL with authentication token
-
pricing
final Optional<StreamingGetUrlResponse.Pricing> pricing()
-
_audioFormat
final JsonField<StreamingGetUrlResponse.AudioFormat> _audioFormat()
Returns the raw JSON value of audioFormat.
Unlike audioFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_connectUrl
final JsonField<String> _connectUrl()
Returns the raw JSON value of connectUrl.
Unlike connectUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_pricing
final JsonField<StreamingGetUrlResponse.Pricing> _pricing()
Returns the raw JSON value of pricing.
Unlike pricing, this method doesn't throw if the JSON field has an unexpected type.
-
_protocol
final JsonField<String> _protocol()
Returns the raw JSON value of protocol.
Unlike protocol, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamingGetUrlResponse.Builder toBuilder()
-
validate
final StreamingGetUrlResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamingGetUrlResponse.Builder builder()
Returns a mutable builder for constructing an instance of StreamingGetUrlResponse.
-
-
-
-