Class StreamingGetUrlResponse.AudioFormat
-
- All Implemented Interfaces:
public final class StreamingGetUrlResponse.AudioFormat
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamingGetUrlResponse.AudioFormat.BuilderA builder for AudioFormat.
-
Method Summary
Modifier and Type Method Description final Optional<Long>channels()Number of audio channels final Optional<String>encoding()Required audio encoding format final Optional<Long>sampleRate()Required audio sample rate in Hz final JsonField<Long>_channels()Returns the raw JSON value of channels. final JsonField<String>_encoding()Returns the raw JSON value of encoding. final JsonField<Long>_sampleRate()Returns the raw JSON value of sampleRate. final Map<String, JsonValue>_additionalProperties()final StreamingGetUrlResponse.AudioFormat.BuildertoBuilder()final StreamingGetUrlResponse.AudioFormatvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamingGetUrlResponse.AudioFormat.Builderbuilder()Returns a mutable builder for constructing an instance of AudioFormat. -
-
Method Detail
-
sampleRate
final Optional<Long> sampleRate()
Required audio sample rate in Hz
-
_channels
final JsonField<Long> _channels()
Returns the raw JSON value of channels.
Unlike channels, this method doesn't throw if the JSON field has an unexpected type.
-
_encoding
final JsonField<String> _encoding()
Returns the raw JSON value of encoding.
Unlike encoding, this method doesn't throw if the JSON field has an unexpected type.
-
_sampleRate
final JsonField<Long> _sampleRate()
Returns the raw JSON value of sampleRate.
Unlike sampleRate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamingGetUrlResponse.AudioFormat.Builder toBuilder()
-
validate
final StreamingGetUrlResponse.AudioFormat validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamingGetUrlResponse.AudioFormat.Builder builder()
Returns a mutable builder for constructing an instance of AudioFormat.
-
-
-
-