Class StreamingGetUrlResponse.Builder
-
- All Implemented Interfaces:
public final class StreamingGetUrlResponse.BuilderA builder for StreamingGetUrlResponse.
-
-
Method Summary
-
-
Method Detail
-
audioFormat
final StreamingGetUrlResponse.Builder audioFormat(StreamingGetUrlResponse.AudioFormat audioFormat)
-
audioFormat
final StreamingGetUrlResponse.Builder audioFormat(JsonField<StreamingGetUrlResponse.AudioFormat> audioFormat)
Sets Builder.audioFormat to an arbitrary JSON value.
You should usually call Builder.audioFormat with a well-typed AudioFormat value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
connectUrl
final StreamingGetUrlResponse.Builder connectUrl(String connectUrl)
Complete WebSocket URL with authentication token
-
connectUrl
final StreamingGetUrlResponse.Builder connectUrl(JsonField<String> connectUrl)
Sets Builder.connectUrl to an arbitrary JSON value.
You should usually call Builder.connectUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pricing
final StreamingGetUrlResponse.Builder pricing(StreamingGetUrlResponse.Pricing pricing)
-
pricing
final StreamingGetUrlResponse.Builder pricing(JsonField<StreamingGetUrlResponse.Pricing> pricing)
Sets Builder.pricing to an arbitrary JSON value.
You should usually call Builder.pricing with a well-typed Pricing value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
protocol
final StreamingGetUrlResponse.Builder protocol(String protocol)
Connection protocol
-
protocol
final StreamingGetUrlResponse.Builder protocol(JsonField<String> protocol)
Sets Builder.protocol to an arbitrary JSON value.
You should usually call Builder.protocol with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final StreamingGetUrlResponse.Builder url(String url)
Base WebSocket URL for streaming transcription
-
url
final StreamingGetUrlResponse.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final StreamingGetUrlResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final StreamingGetUrlResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final StreamingGetUrlResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final StreamingGetUrlResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final StreamingGetUrlResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final StreamingGetUrlResponse build()
Returns an immutable instance of StreamingGetUrlResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-