Class StreamingGetUrlResponse.Pricing
-
- All Implemented Interfaces:
public final class StreamingGetUrlResponse.Pricing
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamingGetUrlResponse.Pricing.BuilderA builder for Pricing.
-
Method Summary
Modifier and Type Method Description final Optional<String>currency()Currency for pricing final Optional<Double>perHour()Cost per hour of transcription final Optional<Double>perMinute()Cost per minute of transcription final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<Double>_perHour()Returns the raw JSON value of perHour. final JsonField<Double>_perMinute()Returns the raw JSON value of perMinute. final Map<String, JsonValue>_additionalProperties()final StreamingGetUrlResponse.Pricing.BuildertoBuilder()final StreamingGetUrlResponse.Pricingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamingGetUrlResponse.Pricing.Builderbuilder()Returns a mutable builder for constructing an instance of Pricing. -
-
Method Detail
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_perHour
final JsonField<Double> _perHour()
Returns the raw JSON value of perHour.
Unlike perHour, this method doesn't throw if the JSON field has an unexpected type.
-
_perMinute
final JsonField<Double> _perMinute()
Returns the raw JSON value of perMinute.
Unlike perMinute, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamingGetUrlResponse.Pricing.Builder toBuilder()
-
validate
final StreamingGetUrlResponse.Pricing validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamingGetUrlResponse.Pricing.Builder builder()
Returns a mutable builder for constructing an instance of Pricing.
-
-
-
-