Class StreamingGetUrlResponse.Pricing.Builder
-
- All Implemented Interfaces:
public final class StreamingGetUrlResponse.Pricing.BuilderA builder for Pricing.
-
-
Method Summary
-
-
Method Detail
-
currency
final StreamingGetUrlResponse.Pricing.Builder currency(String currency)
Currency for pricing
-
currency
final StreamingGetUrlResponse.Pricing.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
perHour
final StreamingGetUrlResponse.Pricing.Builder perHour(Double perHour)
Cost per hour of transcription
-
perHour
final StreamingGetUrlResponse.Pricing.Builder perHour(JsonField<Double> perHour)
Sets Builder.perHour to an arbitrary JSON value.
You should usually call Builder.perHour with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
perMinute
final StreamingGetUrlResponse.Pricing.Builder perMinute(Double perMinute)
Cost per minute of transcription
-
perMinute
final StreamingGetUrlResponse.Pricing.Builder perMinute(JsonField<Double> perMinute)
Sets Builder.perMinute to an arbitrary JSON value.
You should usually call Builder.perMinute with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final StreamingGetUrlResponse.Pricing.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final StreamingGetUrlResponse.Pricing.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final StreamingGetUrlResponse.Pricing.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final StreamingGetUrlResponse.Pricing.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final StreamingGetUrlResponse.Pricing.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final StreamingGetUrlResponse.Pricing build()
Returns an immutable instance of Pricing.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-