Class V1ListVoicesParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1ListVoicesParams implements Params
Retrieve a list of available voices for text-to-speech synthesis. This endpoint provides access to a comprehensive catalog of voices with various characteristics, languages, and styles suitable for legal document narration, client presentations, and accessibility purposes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListVoicesParams.BuilderA builder for V1ListVoicesParams.
public final classV1ListVoicesParams.SortField to sort by
public final classV1ListVoicesParams.SortDirectionSort direction
public final classV1ListVoicesParams.VoiceTypeFilter by voice type
-
Method Summary
Modifier and Type Method Description final Optional<String>category()Filter by voice category final Optional<String>collectionId()Filter by voice collection ID final Optional<Boolean>includeTotalCount()Whether to include total count in response final Optional<String>nextPageToken()Token for retrieving the next page of results final Optional<Long>pageSize()Number of voices to return per page (max 100) final Optional<String>search()Search term to filter voices by name or description final Optional<V1ListVoicesParams.Sort>sort()Field to sort by final Optional<V1ListVoicesParams.SortDirection>sortDirection()Sort direction final Optional<V1ListVoicesParams.VoiceType>voiceType()Filter by voice type final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1ListVoicesParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListVoicesParamsnone()final static V1ListVoicesParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1ListVoicesParams. -
-
Method Detail
-
collectionId
final Optional<String> collectionId()
Filter by voice collection ID
-
includeTotalCount
final Optional<Boolean> includeTotalCount()
Whether to include total count in response
-
nextPageToken
final Optional<String> nextPageToken()
Token for retrieving the next page of results
-
sort
final Optional<V1ListVoicesParams.Sort> sort()
Field to sort by
-
sortDirection
final Optional<V1ListVoicesParams.SortDirection> sortDirection()
Sort direction
-
voiceType
final Optional<V1ListVoicesParams.VoiceType> voiceType()
Filter by voice type
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1ListVoicesParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static V1ListVoicesParams none()
-
builder
final static V1ListVoicesParams.Builder builder()
Returns a mutable builder for constructing an instance of V1ListVoicesParams.
-
-
-
-