Class EndpointCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class EndpointCreateParams implements Params
Creates a webhook endpoint that receives platform events matching the supplied event-type filters. Returns the generated signing secret ONCE — the response is the only time it is shown in plaintext.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointCreateParams.BuilderA builder for EndpointCreateParams.
public final classEndpointCreateParams.Bodypublic final classEndpointCreateParams.ResourceScopesOptional per-resource allowlists. If vaultIds is set, only events for those vaults are delivered. Same for matterIds.
-
Method Summary
Modifier and Type Method Description final List<String>eventTypeFilters()Glob patterns of event types to deliver (e.g. final Stringurl()HTTPS callback URL that will receive event deliveries final Optional<String>description()Human-readable label for this endpoint final Optional<EndpointCreateParams.ResourceScopes>resourceScopes()Optional per-resource allowlists. final JsonField<List<String>>_eventTypeFilters()Returns the raw JSON value of eventTypeFilters. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<EndpointCreateParams.ResourceScopes>_resourceScopes()Returns the raw JSON value of resourceScopes. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EndpointCreateParams.BuildertoBuilder()final EndpointCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EndpointCreateParams. -
-
Method Detail
-
eventTypeFilters
final List<String> eventTypeFilters()
Glob patterns of event types to deliver (e.g. "vault.", "ocr.job.completed", "")
-
description
final Optional<String> description()
Human-readable label for this endpoint
-
resourceScopes
final Optional<EndpointCreateParams.ResourceScopes> resourceScopes()
Optional per-resource allowlists. If vaultIds is set, only events for those vaults are delivered. Same for matterIds.
-
_eventTypeFilters
final JsonField<List<String>> _eventTypeFilters()
Returns the raw JSON value of eventTypeFilters.
Unlike eventTypeFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_resourceScopes
final JsonField<EndpointCreateParams.ResourceScopes> _resourceScopes()
Returns the raw JSON value of resourceScopes.
Unlike resourceScopes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EndpointCreateParams.Builder toBuilder()
-
_body
final EndpointCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EndpointCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of EndpointCreateParams.
The following fields are required:
.eventTypeFilters() .url()
-
-
-
-