Class EndpointCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EndpointCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
eventTypeFilters
final EndpointCreateParams.Body.Builder eventTypeFilters(List<String> eventTypeFilters)
Glob patterns of event types to deliver (e.g. "vault.", "ocr.job.completed", "")
-
eventTypeFilters
final EndpointCreateParams.Body.Builder eventTypeFilters(JsonField<List<String>> eventTypeFilters)
Sets Builder.eventTypeFilters to an arbitrary JSON value.
You should usually call Builder.eventTypeFilters with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEventTypeFilter
final EndpointCreateParams.Body.Builder addEventTypeFilter(String eventTypeFilter)
Adds a single String to eventTypeFilters.
-
url
final EndpointCreateParams.Body.Builder url(String url)
HTTPS callback URL that will receive event deliveries
-
url
final EndpointCreateParams.Body.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final EndpointCreateParams.Body.Builder description(String description)
Human-readable label for this endpoint
-
description
final EndpointCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resourceScopes
final EndpointCreateParams.Body.Builder resourceScopes(EndpointCreateParams.ResourceScopes resourceScopes)
Optional per-resource allowlists. If vaultIds is set, only events for those vaults are delivered. Same for matterIds.
-
resourceScopes
final EndpointCreateParams.Body.Builder resourceScopes(JsonField<EndpointCreateParams.ResourceScopes> resourceScopes)
Sets Builder.resourceScopes to an arbitrary JSON value.
You should usually call Builder.resourceScopes with a well-typed ResourceScopes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EndpointCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EndpointCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EndpointCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EndpointCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EndpointCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EndpointCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventTypeFilters() .url()
-
-
-
-