Class EndpointCreateParams.ResourceScopes
-
- All Implemented Interfaces:
public final class EndpointCreateParams.ResourceScopesOptional per-resource allowlists. If vaultIds is set, only events for those vaults are delivered. Same for matterIds.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointCreateParams.ResourceScopes.BuilderA builder for ResourceScopes.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>matterIds()final Optional<List<String>>vaultIds()final JsonField<List<String>>_matterIds()Returns the raw JSON value of matterIds. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final EndpointCreateParams.ResourceScopes.BuildertoBuilder()final EndpointCreateParams.ResourceScopesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointCreateParams.ResourceScopes.Builderbuilder()Returns a mutable builder for constructing an instance of ResourceScopes. -
-
Method Detail
-
_matterIds
final JsonField<List<String>> _matterIds()
Returns the raw JSON value of matterIds.
Unlike matterIds, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EndpointCreateParams.ResourceScopes.Builder toBuilder()
-
validate
final EndpointCreateParams.ResourceScopes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EndpointCreateParams.ResourceScopes.Builder builder()
Returns a mutable builder for constructing an instance of ResourceScopes.
-
-
-
-