Class EndpointListParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class EndpointListParams implements Params
Returns the organization's webhook endpoints, newest first. Signing secrets are never included.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointListParams.BuilderA builder for EndpointListParams.
public final classEndpointListParams.StatusFilter by endpoint status
-
Method Summary
Modifier and Type Method Description final Optional<Long>limit()final Optional<EndpointListParams.Status>status()Filter by endpoint status final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EndpointListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointListParamsnone()final static EndpointListParams.Builderbuilder()Returns a mutable builder for constructing an instance of EndpointListParams. -
-
Method Detail
-
status
final Optional<EndpointListParams.Status> status()
Filter by endpoint status
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EndpointListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EndpointListParams none()
-
builder
final static EndpointListParams.Builder builder()
Returns a mutable builder for constructing an instance of EndpointListParams.
-
-
-
-