Class EndpointRotateSecretParams.Body
-
- All Implemented Interfaces:
public final class EndpointRotateSecretParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointRotateSecretParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<Long>previousSecretExpiresInSec()How long (seconds) the old secret continues to be accepted. final JsonField<Long>_previousSecretExpiresInSec()Returns the raw JSON value of previousSecretExpiresInSec. final Map<String, JsonValue>_additionalProperties()final EndpointRotateSecretParams.Body.BuildertoBuilder()final EndpointRotateSecretParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointRotateSecretParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
previousSecretExpiresInSec
final Optional<Long> previousSecretExpiresInSec()
How long (seconds) the old secret continues to be accepted. 0 invalidates immediately. Default: 86400 (24h).
-
_previousSecretExpiresInSec
final JsonField<Long> _previousSecretExpiresInSec()
Returns the raw JSON value of previousSecretExpiresInSec.
Unlike previousSecretExpiresInSec, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EndpointRotateSecretParams.Body.Builder toBuilder()
-
validate
final EndpointRotateSecretParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EndpointRotateSecretParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-