Class EndpointTestParams.Body
-
- All Implemented Interfaces:
public final class EndpointTestParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointTestParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>eventType()Event type to simulate. final JsonValue_payload()Custom datapayload.final JsonField<String>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final EndpointTestParams.Body.BuildertoBuilder()final EndpointTestParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointTestParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_payload
final JsonValue _payload()
Custom
datapayload. Defaults to a small placeholder.This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.payload().convert(MyClass.class);
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EndpointTestParams.Body.Builder toBuilder()
-
validate
final EndpointTestParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EndpointTestParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-