Class EndpointUpdateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class EndpointUpdateParams implements Params
Partially updates a webhook endpoint. Any omitted field is left unchanged. Signing secrets are rotated via the separate /rotate_secret endpoint.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointUpdateParams.BuilderA builder for EndpointUpdateParams.
public final classEndpointUpdateParams.Bodypublic final classEndpointUpdateParams.ResourceScopespublic final classEndpointUpdateParams.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>description()final Optional<List<String>>eventTypeFilters()final Optional<EndpointUpdateParams.ResourceScopes>resourceScopes()final Optional<EndpointUpdateParams.Status>status()final Optional<String>url()final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<String>>_eventTypeFilters()Returns the raw JSON value of eventTypeFilters. final JsonField<EndpointUpdateParams.ResourceScopes>_resourceScopes()Returns the raw JSON value of resourceScopes. final JsonField<EndpointUpdateParams.Status>_status()Returns the raw JSON value of status. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EndpointUpdateParams.BuildertoBuilder()final EndpointUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointUpdateParamsnone()final static EndpointUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EndpointUpdateParams. -
-
Method Detail
-
description
final Optional<String> description()
-
eventTypeFilters
final Optional<List<String>> eventTypeFilters()
-
resourceScopes
final Optional<EndpointUpdateParams.ResourceScopes> resourceScopes()
-
status
final Optional<EndpointUpdateParams.Status> status()
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypeFilters
final JsonField<List<String>> _eventTypeFilters()
Returns the raw JSON value of eventTypeFilters.
Unlike eventTypeFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_resourceScopes
final JsonField<EndpointUpdateParams.ResourceScopes> _resourceScopes()
Returns the raw JSON value of resourceScopes.
Unlike resourceScopes, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EndpointUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EndpointUpdateParams.Builder toBuilder()
-
_body
final EndpointUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EndpointUpdateParams none()
-
builder
final static EndpointUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of EndpointUpdateParams.
-
-
-
-