Class EndpointUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EndpointUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
description
final EndpointUpdateParams.Body.Builder description(String description)
-
description
final EndpointUpdateParams.Body.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final EndpointUpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventTypeFilters
final EndpointUpdateParams.Body.Builder eventTypeFilters(List<String> eventTypeFilters)
-
eventTypeFilters
final EndpointUpdateParams.Body.Builder eventTypeFilters(JsonField<List<String>> eventTypeFilters)
Sets Builder.eventTypeFilters to an arbitrary JSON value.
You should usually call Builder.eventTypeFilters with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEventTypeFilter
final EndpointUpdateParams.Body.Builder addEventTypeFilter(String eventTypeFilter)
Adds a single String to eventTypeFilters.
-
resourceScopes
final EndpointUpdateParams.Body.Builder resourceScopes(EndpointUpdateParams.ResourceScopes resourceScopes)
-
resourceScopes
final EndpointUpdateParams.Body.Builder resourceScopes(Optional<EndpointUpdateParams.ResourceScopes> resourceScopes)
Alias for calling Builder.resourceScopes with
resourceScopes.orElse(null).
-
resourceScopes
final EndpointUpdateParams.Body.Builder resourceScopes(JsonField<EndpointUpdateParams.ResourceScopes> resourceScopes)
Sets Builder.resourceScopes to an arbitrary JSON value.
You should usually call Builder.resourceScopes with a well-typed ResourceScopes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final EndpointUpdateParams.Body.Builder status(EndpointUpdateParams.Status status)
-
status
final EndpointUpdateParams.Body.Builder status(JsonField<EndpointUpdateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final EndpointUpdateParams.Body.Builder url(String url)
-
url
final EndpointUpdateParams.Body.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EndpointUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EndpointUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EndpointUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EndpointUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EndpointUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EndpointUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-