Class EndpointUpdateParams.ResourceScopes.Builder
-
- All Implemented Interfaces:
public final class EndpointUpdateParams.ResourceScopes.BuilderA builder for ResourceScopes.
-
-
Method Summary
-
-
Method Detail
-
matterIds
final EndpointUpdateParams.ResourceScopes.Builder matterIds(List<String> matterIds)
-
matterIds
final EndpointUpdateParams.ResourceScopes.Builder matterIds(JsonField<List<String>> matterIds)
Sets Builder.matterIds to an arbitrary JSON value.
You should usually call Builder.matterIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addMatterId
final EndpointUpdateParams.ResourceScopes.Builder addMatterId(String matterId)
-
vaultIds
final EndpointUpdateParams.ResourceScopes.Builder vaultIds(List<String> vaultIds)
-
vaultIds
final EndpointUpdateParams.ResourceScopes.Builder vaultIds(JsonField<List<String>> vaultIds)
Sets Builder.vaultIds to an arbitrary JSON value.
You should usually call Builder.vaultIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVaultId
final EndpointUpdateParams.ResourceScopes.Builder addVaultId(String vaultId)
-
additionalProperties
final EndpointUpdateParams.ResourceScopes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EndpointUpdateParams.ResourceScopes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EndpointUpdateParams.ResourceScopes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EndpointUpdateParams.ResourceScopes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EndpointUpdateParams.ResourceScopes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EndpointUpdateParams.ResourceScopes build()
Returns an immutable instance of ResourceScopes.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-