Package dev.case.api.models.worker.v1
Class V1CreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1CreateParams implements Params
Creates a Daytona-backed worker runtime. The worker exposes its native runtime API through /worker/v1/:id/* without reshaping payloads or events.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateParams.BuilderA builder for V1CreateParams.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1CreateParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateParamsnone()final static V1CreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1CreateParams. -
-
Method Detail
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1CreateParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static V1CreateParams none()
-
builder
final static V1CreateParams.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateParams.
-
-
-
-