Package dev.case.api.services.async
Interface AgentServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface AgentServiceAsync.WithRawResponseA view of AgentServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AgentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
abstract AgentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
-
-
-
-