Package dev.case.api.services.async
Class AgentServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.AgentServiceAsync
public final class AgentServiceAsyncImpl implements AgentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AgentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AgentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SkillServiceAsyncskills()V1ServiceAsyncv1()-
-
Method Detail
-
withRawResponse
AgentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AgentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
skills
SkillServiceAsync skills()
-
v1
V1ServiceAsync v1()
-
-
-
-