Package dev.case.api.services.async
Class AgentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.AgentServiceAsync.WithRawResponse
public final class AgentServiceAsyncImpl.WithRawResponseImpl implements AgentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AgentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
AgentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-