Package dev.case.api.services.async
Class ApplicationServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.ApplicationServiceAsync
public final class ApplicationServiceAsyncImpl implements ApplicationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classApplicationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ApplicationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ApplicationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()-
-
Method Detail
-
withRawResponse
ApplicationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ApplicationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
-
-
-
-