Package dev.case.api.services.async
Interface ComputeServiceAsync
-
- All Implemented Interfaces:
public interface ComputeServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceComputeServiceAsync.WithRawResponseA view of ComputeServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ComputeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ComputeServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()-
-
Method Detail
-
withRawResponse
abstract ComputeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ComputeServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
-
-
-
-