Package dev.case.api.services.async
Interface ComputeServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ComputeServiceAsync.WithRawResponseA view of ComputeServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ComputeServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()Serverless GPU and CPU infrastructure -
-
Method Detail
-
withOptions
abstract ComputeServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Serverless GPU and CPU infrastructure
-
-
-
-