Package dev.case.api.services.async
Class ComputeServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.ComputeServiceAsync
public final class ComputeServiceAsyncImpl implements ComputeServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classComputeServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ComputeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ComputeServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()-
-
Method Detail
-
withRawResponse
ComputeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ComputeServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
-
-
-
-