Package dev.case.api.services.async
Class ComputeServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.ComputeServiceAsync.WithRawResponse
public final class ComputeServiceAsyncImpl.WithRawResponseImpl implements ComputeServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ComputeServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()Serverless GPU and CPU infrastructure -
-
Method Detail
-
withOptions
ComputeServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync.WithRawResponse v1()
Serverless GPU and CPU infrastructure
-
-
-
-