Package dev.case.api.services.async
Interface DatabaseServiceAsync
-
- All Implemented Interfaces:
public interface DatabaseServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDatabaseServiceAsync.WithRawResponseA view of DatabaseServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DatabaseServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract DatabaseServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()Serverless PostgreSQL databases with instant branching -
-
Method Detail
-
withRawResponse
abstract DatabaseServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DatabaseServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
Serverless PostgreSQL databases with instant branching
-
-
-
-