Package dev.case.api.services.async
Interface DatabaseServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface DatabaseServiceAsync.WithRawResponseA view of DatabaseServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract DatabaseServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()Serverless PostgreSQL databases with instant branching -
-
Method Detail
-
withOptions
abstract DatabaseServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Serverless PostgreSQL databases with instant branching
-
-
-
-