Package dev.case.api.services.async
Class DatabaseServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.DatabaseServiceAsync
public final class DatabaseServiceAsyncImpl implements DatabaseServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDatabaseServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DatabaseServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DatabaseServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Serverless PostgreSQL databases with instant branching -
-
Method Detail
-
withRawResponse
DatabaseServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DatabaseServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Serverless PostgreSQL databases with instant branching
-
-
-
-