Package dev.case.api.services.async
Interface FormatServiceAsync
-
- All Implemented Interfaces:
public interface FormatServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFormatServiceAsync.WithRawResponseA view of FormatServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FormatServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FormatServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()Document formatting and template rendering (MD/JSON to PDF/DOCX) -
-
Method Detail
-
withRawResponse
abstract FormatServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FormatServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
Document formatting and template rendering (MD/JSON to PDF/DOCX)
-
-
-
-