Package dev.case.api.services.async
Class FormatServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.FormatServiceAsync
public final class FormatServiceAsyncImpl implements FormatServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFormatServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FormatServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FormatServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Document formatting and template rendering (MD/JSON to PDF/DOCX) -
-
Method Detail
-
withRawResponse
FormatServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FormatServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Document formatting and template rendering (MD/JSON to PDF/DOCX)
-
-
-
-