Package dev.case.api.services.async
Interface LegalServiceAsync
-
- All Implemented Interfaces:
public interface LegalServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLegalServiceAsync.WithRawResponseA view of LegalServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract LegalServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract LegalServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()Legal research tools including citation verification -
-
Method Detail
-
withRawResponse
abstract LegalServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract LegalServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
Legal research tools including citation verification
-
-
-
-