Package dev.case.api.services.async
Interface LegalServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface LegalServiceAsync.WithRawResponseA view of LegalServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract LegalServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()Legal research tools including citation verification -
-
Method Detail
-
withOptions
abstract LegalServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Legal research tools including citation verification
-
-
-
-