Package dev.case.api.services.async
Interface LlmServiceAsync
-
- All Implemented Interfaces:
public interface LlmServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLlmServiceAsync.WithRawResponseA view of LlmServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract LlmServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract LlmServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()CompletableFuture<LlmGetConfigResponse>getConfig()Retrieves the AI Gateway configuration including all available language models and their specifications. abstract CompletableFuture<LlmGetConfigResponse>getConfig(LlmGetConfigParams params, RequestOptions requestOptions)CompletableFuture<LlmGetConfigResponse>getConfig(LlmGetConfigParams params)CompletableFuture<LlmGetConfigResponse>getConfig(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract LlmServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract LlmServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
-
getConfig
CompletableFuture<LlmGetConfigResponse> getConfig()
Retrieves the AI Gateway configuration including all available language models and their specifications. This endpoint returns model information compatible with the Vercel AI SDK Gateway format, making it easy to integrate with existing AI applications.
Use this endpoint to:
Discover available language models
Get model specifications and pricing
Configure AI SDK clients
Build model selection interfaces
-
getConfig
abstract CompletableFuture<LlmGetConfigResponse> getConfig(LlmGetConfigParams params, RequestOptions requestOptions)
-
getConfig
CompletableFuture<LlmGetConfigResponse> getConfig(LlmGetConfigParams params)
-
getConfig
CompletableFuture<LlmGetConfigResponse> getConfig(RequestOptions requestOptions)
-
-
-
-