Package dev.case.api.services.async
Interface LlmServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface LlmServiceAsync.WithRawResponseA view of LlmServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract LlmServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()Access 40+ language models through a unified API CompletableFuture<HttpResponseFor<LlmGetConfigResponse>>getConfig()Returns a raw HTTP response for get /llm/config, but is otherwise the same as LlmServiceAsync.getConfig.abstract CompletableFuture<HttpResponseFor<LlmGetConfigResponse>>getConfig(LlmGetConfigParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<LlmGetConfigResponse>>getConfig(LlmGetConfigParams params)CompletableFuture<HttpResponseFor<LlmGetConfigResponse>>getConfig(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract LlmServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Access 40+ language models through a unified API
-
getConfig
CompletableFuture<HttpResponseFor<LlmGetConfigResponse>> getConfig()
Returns a raw HTTP response for
get /llm/config, but is otherwise the same as LlmServiceAsync.getConfig.
-
getConfig
abstract CompletableFuture<HttpResponseFor<LlmGetConfigResponse>> getConfig(LlmGetConfigParams params, RequestOptions requestOptions)
-
getConfig
CompletableFuture<HttpResponseFor<LlmGetConfigResponse>> getConfig(LlmGetConfigParams params)
-
getConfig
CompletableFuture<HttpResponseFor<LlmGetConfigResponse>> getConfig(RequestOptions requestOptions)
-
-
-
-