Package dev.case.api.services.async
Class LlmServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.LlmServiceAsync
public final class LlmServiceAsyncImpl implements LlmServiceAsync
Access 40+ language models through a unified API
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLlmServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LlmServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LlmServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Access 40+ language models through a unified API CompletableFuture<LlmGetConfigResponse>getConfig(LlmGetConfigParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
LlmServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LlmServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Access 40+ language models through a unified API
-
getConfig
CompletableFuture<LlmGetConfigResponse> getConfig(LlmGetConfigParams params, RequestOptions requestOptions)
-
-
-
-