Package dev.case.api.services.async
Class LlmServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.LlmServiceAsync.WithRawResponse
public final class LlmServiceAsyncImpl.WithRawResponseImpl implements LlmServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LlmServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()CompletableFuture<HttpResponseFor<LlmGetConfigResponse>>getConfig(LlmGetConfigParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
LlmServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getConfig
CompletableFuture<HttpResponseFor<LlmGetConfigResponse>> getConfig(LlmGetConfigParams params, RequestOptions requestOptions)
-
-
-
-