Package dev.case.api.services.async
Interface MatterServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface MatterServiceAsync.WithRawResponseA view of MatterServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract MatterServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()Matter-native legal workspaces and orchestration primitives -
-
Method Detail
-
withOptions
abstract MatterServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Matter-native legal workspaces and orchestration primitives
-
-
-
-