Package dev.case.api.services.async
Class MatterServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.MatterServiceAsync
public final class MatterServiceAsyncImpl implements MatterServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMatterServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MatterServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MatterServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Matter-native legal workspaces and orchestration primitives -
-
Method Detail
-
withRawResponse
MatterServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MatterServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Matter-native legal workspaces and orchestration primitives
-
-
-
-