Package dev.case.api.services.async
Class MatterServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.MatterServiceAsync.WithRawResponse
public final class MatterServiceAsyncImpl.WithRawResponseImpl implements MatterServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MatterServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()Matter-native legal workspaces and orchestration primitives -
-
Method Detail
-
withOptions
MatterServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync.WithRawResponse v1()
Matter-native legal workspaces and orchestration primitives
-
-
-
-