Package dev.case.api.services.async
Interface MemoryServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface MemoryServiceAsync.WithRawResponseA view of MemoryServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract MemoryServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()Persistent memory for AI agents with semantic search and 12 generic indexed tag fields -
-
Method Detail
-
withOptions
abstract MemoryServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Persistent memory for AI agents with semantic search and 12 generic indexed tag fields
-
-
-
-