Package dev.case.api.services.async
Class MemoryServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.MemoryServiceAsync
public final class MemoryServiceAsyncImpl implements MemoryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MemoryServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MemoryServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Persistent memory for AI agents with semantic search and 12 generic indexed tag fields -
-
Method Detail
-
withRawResponse
MemoryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MemoryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Persistent memory for AI agents with semantic search and 12 generic indexed tag fields
-
-
-
-