Package dev.case.api.services.async
Class OcrServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.OcrServiceAsync.WithRawResponse
public final class OcrServiceAsyncImpl.WithRawResponseImpl implements OcrServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OcrServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()Extract text from PDFs, images, and scanned documents -
-
Method Detail
-
withOptions
OcrServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync.WithRawResponse v1()
Extract text from PDFs, images, and scanned documents
-
-
-
-