Package dev.case.api.services.async
Interface PrivilegeServiceAsync
-
- All Implemented Interfaces:
public interface PrivilegeServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePrivilegeServiceAsync.WithRawResponseA view of PrivilegeServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PrivilegeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PrivilegeServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()Privilege detection for e-discovery and litigation workflows -
-
Method Detail
-
withRawResponse
abstract PrivilegeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PrivilegeServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
Privilege detection for e-discovery and litigation workflows
-
-
-
-