Package dev.case.api.services.async
Interface PrivilegeServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface PrivilegeServiceAsync.WithRawResponseA view of PrivilegeServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract PrivilegeServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()Privilege detection for e-discovery and litigation workflows -
-
Method Detail
-
withOptions
abstract PrivilegeServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Privilege detection for e-discovery and litigation workflows
-
-
-
-