Package dev.case.api.services.async
Class PrivilegeServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.PrivilegeServiceAsync
public final class PrivilegeServiceAsyncImpl implements PrivilegeServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPrivilegeServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PrivilegeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PrivilegeServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Privilege detection for e-discovery and litigation workflows -
-
Method Detail
-
withRawResponse
PrivilegeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PrivilegeServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Privilege detection for e-discovery and litigation workflows
-
-
-
-