Package dev.case.api.services.async
Interface SearchServiceAsync
-
- All Implemented Interfaces:
public interface SearchServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSearchServiceAsync.WithRawResponseA view of SearchServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SearchServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SearchServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()Web search, AI answers, and deep research -
-
Method Detail
-
withRawResponse
abstract SearchServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SearchServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
Web search, AI answers, and deep research
-
-
-
-