Package dev.case.api.services.async
Interface SearchServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface SearchServiceAsync.WithRawResponseA view of SearchServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SearchServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
abstract SearchServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
-
-
-
-