Package dev.case.api.services.async
Class SearchServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SearchServiceAsync
public final class SearchServiceAsyncImpl implements SearchServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSearchServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SearchServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SearchServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Web search, AI answers, and deep research -
-
Method Detail
-
withRawResponse
SearchServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SearchServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Web search, AI answers, and deep research
-
-
-
-