Package dev.case.api.services.async
Class SearchServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SearchServiceAsync.WithRawResponse
public final class SearchServiceAsyncImpl.WithRawResponseImpl implements SearchServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SearchServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()Web search, AI answers, and deep research -
-
Method Detail
-
withOptions
SearchServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync.WithRawResponse v1()
Web search, AI answers, and deep research
-
-
-
-