Package dev.case.api.services.async
Class SkillServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SkillServiceAsync
public final class SkillServiceAsyncImpl implements SkillServiceAsync
Search and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SkillServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SkillServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomServiceAsynccustom()Search and read legal AI skills for agents CompletableFuture<SkillCreateResponse>create(SkillCreateParams params, RequestOptions requestOptions)CompletableFuture<SkillUpdateResponse>update(SkillUpdateParams params, RequestOptions requestOptions)CompletableFuture<SkillDeleteResponse>delete(SkillDeleteParams params, RequestOptions requestOptions)CompletableFuture<SkillReadResponse>read(SkillReadParams params, RequestOptions requestOptions)CompletableFuture<SkillResolveResponse>resolve(SkillResolveParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.SkillServiceAsync
create, delete, delete, delete, delete, delete, read, read, read, read, read, resolve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SkillServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SkillServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
custom
CustomServiceAsync custom()
Search and read legal AI skills for agents
-
create
CompletableFuture<SkillCreateResponse> create(SkillCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<SkillUpdateResponse> update(SkillUpdateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<SkillDeleteResponse> delete(SkillDeleteParams params, RequestOptions requestOptions)
-
read
CompletableFuture<SkillReadResponse> read(SkillReadParams params, RequestOptions requestOptions)
-
resolve
CompletableFuture<SkillResolveResponse> resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-