Package dev.case.api.services.async
Interface SuperdocServiceAsync
-
- All Implemented Interfaces:
public interface SuperdocServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSuperdocServiceAsync.WithRawResponseA view of SuperdocServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SuperdocServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SuperdocServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()Document conversion and template automation -
-
Method Detail
-
withRawResponse
abstract SuperdocServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SuperdocServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
Document conversion and template automation
-
-
-
-