Package dev.case.api.services.async
Class SuperdocServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SuperdocServiceAsync
public final class SuperdocServiceAsyncImpl implements SuperdocServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSuperdocServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SuperdocServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SuperdocServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Document conversion and template automation -
-
Method Detail
-
withRawResponse
SuperdocServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SuperdocServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Document conversion and template automation
-
-
-
-