Package dev.case.api.services.async
Interface SystemServiceAsync
-
- All Implemented Interfaces:
public interface SystemServiceAsyncPublic system metadata and discovery endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSystemServiceAsync.WithRawResponseA view of SystemServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SystemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SystemServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<SystemListServicesResponse>listServices()Returns the public Case.dev services catalog derived from docs.case.dev/services. abstract CompletableFuture<SystemListServicesResponse>listServices(SystemListServicesParams params, RequestOptions requestOptions)CompletableFuture<SystemListServicesResponse>listServices(SystemListServicesParams params)CompletableFuture<SystemListServicesResponse>listServices(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SystemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SystemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
CompletableFuture<SystemListServicesResponse> listServices()
Returns the public Case.dev services catalog derived from docs.case.dev/services. This endpoint is unauthenticated and intended for discovery surfaces such as the case.dev homepage.
-
listServices
abstract CompletableFuture<SystemListServicesResponse> listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
listServices
CompletableFuture<SystemListServicesResponse> listServices(SystemListServicesParams params)
-
listServices
CompletableFuture<SystemListServicesResponse> listServices(RequestOptions requestOptions)
-
-
-
-