Package dev.case.api.services.async
Interface SystemServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface SystemServiceAsync.WithRawResponseA view of SystemServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SystemServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<SystemListServicesResponse>>listServices()Returns a raw HTTP response for get /services, but is otherwise the same as SystemServiceAsync.listServices.abstract CompletableFuture<HttpResponseFor<SystemListServicesResponse>>listServices(SystemListServicesParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<SystemListServicesResponse>>listServices(SystemListServicesParams params)CompletableFuture<HttpResponseFor<SystemListServicesResponse>>listServices(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract SystemServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
CompletableFuture<HttpResponseFor<SystemListServicesResponse>> listServices()
Returns a raw HTTP response for
get /services, but is otherwise the same as SystemServiceAsync.listServices.
-
listServices
abstract CompletableFuture<HttpResponseFor<SystemListServicesResponse>> listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
listServices
CompletableFuture<HttpResponseFor<SystemListServicesResponse>> listServices(SystemListServicesParams params)
-
listServices
CompletableFuture<HttpResponseFor<SystemListServicesResponse>> listServices(RequestOptions requestOptions)
-
-
-
-