Package dev.case.api.services.async
Class SystemServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SystemServiceAsync
public final class SystemServiceAsyncImpl implements SystemServiceAsync
Public system metadata and discovery endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSystemServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SystemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SystemServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<SystemListServicesResponse>listServices(SystemListServicesParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SystemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SystemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
CompletableFuture<SystemListServicesResponse> listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
-
-
-