Package dev.case.api.services.async
Class SystemServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SystemServiceAsync.WithRawResponse
public final class SystemServiceAsyncImpl.WithRawResponseImpl implements SystemServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SystemServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<SystemListServicesResponse>>listServices(SystemListServicesParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
SystemServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
CompletableFuture<HttpResponseFor<SystemListServicesResponse>> listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
-
-
-