Package dev.case.api.services.async
Class TranslateServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.TranslateServiceAsync
public final class TranslateServiceAsyncImpl implements TranslateServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTranslateServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TranslateServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TranslateServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()-
-
Method Detail
-
withRawResponse
TranslateServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TranslateServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
-
-
-
-