Package dev.case.api.services.async
Class TranslateServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.TranslateServiceAsync.WithRawResponse
public final class TranslateServiceAsyncImpl.WithRawResponseImpl implements TranslateServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description TranslateServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
TranslateServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-