Package dev.case.api.services.async
Interface UsageServiceAsync
-
- All Implemented Interfaces:
public interface UsageServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceUsageServiceAsync.WithRawResponseA view of UsageServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract UsageServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract UsageServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()Usage reporting and webhook subscriptions -
-
Method Detail
-
withRawResponse
abstract UsageServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract UsageServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
Usage reporting and webhook subscriptions
-
-
-
-