Package dev.case.api.services.async
Class UsageServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.UsageServiceAsync
public final class UsageServiceAsyncImpl implements UsageServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description UsageServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. UsageServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsyncv1()Usage reporting and webhook subscriptions -
-
Method Detail
-
withRawResponse
UsageServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
UsageServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync v1()
Usage reporting and webhook subscriptions
-
-
-
-