Package dev.case.api.services.async
Class UsageServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.UsageServiceAsync.WithRawResponse
public final class UsageServiceAsyncImpl.WithRawResponseImpl implements UsageServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description UsageServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()Usage reporting and webhook subscriptions -
-
Method Detail
-
withOptions
UsageServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1ServiceAsync.WithRawResponse v1()
Usage reporting and webhook subscriptions
-
-
-
-