Package dev.case.api.services.async
Class VaultServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.VaultServiceAsync
public final class VaultServiceAsyncImpl implements VaultServiceAsync
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.VaultServiceAsync
confirmUpload, confirmUpload, confirmUpload, create, delete, delete, delete, delete, delete, ingest, ingest, ingest, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, search, search, search, update, update, update, update, update, upload, upload, upload -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
VaultServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VaultServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
events
EventServiceAsync events()
-
graphrag
GraphragServiceAsync graphrag()
Secure document storage with semantic search and GraphRAG
-
groups
GroupServiceAsync groups()
Secure document storage with semantic search and GraphRAG
-
multipart
MultipartServiceAsync multipart()
Secure document storage with semantic search and GraphRAG
-
objects
ObjectServiceAsync objects()
Secure document storage with semantic search and GraphRAG
-
memory
MemoryServiceAsync memory()
Secure document storage with semantic search and GraphRAG
-
create
CompletableFuture<VaultCreateResponse> create(VaultCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<VaultRetrieveResponse> retrieve(VaultRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<VaultUpdateResponse> update(VaultUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<VaultListResponse> list(VaultListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<VaultDeleteResponse> delete(VaultDeleteParams params, RequestOptions requestOptions)
-
confirmUpload
CompletableFuture<VaultConfirmUploadResponse> confirmUpload(VaultConfirmUploadParams params, RequestOptions requestOptions)
-
ingest
CompletableFuture<VaultIngestResponse> ingest(VaultIngestParams params, RequestOptions requestOptions)
-
search
CompletableFuture<VaultSearchResponse> search(VaultSearchParams params, RequestOptions requestOptions)
-
upload
CompletableFuture<VaultUploadResponse> upload(VaultUploadParams params, RequestOptions requestOptions)
-
-
-
-