Package dev.case.api.services.async
Interface VoiceServiceAsync
-
- All Implemented Interfaces:
public interface VoiceServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceVoiceServiceAsync.WithRawResponseA view of VoiceServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract VoiceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract VoiceServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract StreamingServiceAsyncstreaming()Audio transcription and text-to-speech abstract BoostListServiceAsyncboostList()Audio transcription and text-to-speech abstract TranscriptionServiceAsynctranscription()Audio transcription and text-to-speech abstract V1ServiceAsyncv1()Audio transcription and text-to-speech -
-
Method Detail
-
withRawResponse
abstract VoiceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract VoiceServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
abstract StreamingServiceAsync streaming()
Audio transcription and text-to-speech
-
boostList
abstract BoostListServiceAsync boostList()
Audio transcription and text-to-speech
-
transcription
abstract TranscriptionServiceAsync transcription()
Audio transcription and text-to-speech
-
v1
abstract V1ServiceAsync v1()
Audio transcription and text-to-speech
-
-
-
-