Package dev.case.api.services.async
Interface VoiceServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface VoiceServiceAsync.WithRawResponseA view of VoiceServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract VoiceServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract StreamingServiceAsync.WithRawResponsestreaming()Audio transcription and text-to-speech abstract BoostListServiceAsync.WithRawResponseboostList()Audio transcription and text-to-speech abstract TranscriptionServiceAsync.WithRawResponsetranscription()Audio transcription and text-to-speech abstract V1ServiceAsync.WithRawResponsev1()Audio transcription and text-to-speech -
-
Method Detail
-
withOptions
abstract VoiceServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
abstract StreamingServiceAsync.WithRawResponse streaming()
Audio transcription and text-to-speech
-
boostList
abstract BoostListServiceAsync.WithRawResponse boostList()
Audio transcription and text-to-speech
-
transcription
abstract TranscriptionServiceAsync.WithRawResponse transcription()
Audio transcription and text-to-speech
-
v1
abstract V1ServiceAsync.WithRawResponse v1()
Audio transcription and text-to-speech
-
-
-
-