Package dev.case.api.services.async
Class VoiceServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.VoiceServiceAsync
public final class VoiceServiceAsyncImpl implements VoiceServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVoiceServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description VoiceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. VoiceServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamingServiceAsyncstreaming()Audio transcription and text-to-speech BoostListServiceAsyncboostList()Audio transcription and text-to-speech TranscriptionServiceAsynctranscription()Audio transcription and text-to-speech V1ServiceAsyncv1()Audio transcription and text-to-speech -
-
Method Detail
-
withRawResponse
VoiceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VoiceServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
StreamingServiceAsync streaming()
Audio transcription and text-to-speech
-
boostList
BoostListServiceAsync boostList()
Audio transcription and text-to-speech
-
transcription
TranscriptionServiceAsync transcription()
Audio transcription and text-to-speech
-
v1
V1ServiceAsync v1()
Audio transcription and text-to-speech
-
-
-
-