Package dev.case.api.services.async
Class VoiceServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.VoiceServiceAsync.WithRawResponse
public final class VoiceServiceAsyncImpl.WithRawResponseImpl implements VoiceServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description VoiceServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamingServiceAsync.WithRawResponsestreaming()Audio transcription and text-to-speech BoostListServiceAsync.WithRawResponseboostList()Audio transcription and text-to-speech TranscriptionServiceAsync.WithRawResponsetranscription()Audio transcription and text-to-speech V1ServiceAsync.WithRawResponsev1()Audio transcription and text-to-speech -
-
Method Detail
-
withOptions
VoiceServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
StreamingServiceAsync.WithRawResponse streaming()
Audio transcription and text-to-speech
-
boostList
BoostListServiceAsync.WithRawResponse boostList()
Audio transcription and text-to-speech
-
transcription
TranscriptionServiceAsync.WithRawResponse transcription()
Audio transcription and text-to-speech
-
v1
V1ServiceAsync.WithRawResponse v1()
Audio transcription and text-to-speech
-
-
-
-