Package dev.case.api.services.async
Interface WebhookServiceAsync
-
- All Implemented Interfaces:
public interface WebhookServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWebhookServiceAsync.WithRawResponseA view of WebhookServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WebhookServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WebhookServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()-
-
Method Detail
-
withRawResponse
abstract WebhookServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WebhookServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
-
-
-
-