Package dev.case.api.services.async
Interface WorkerServiceAsync
-
- All Implemented Interfaces:
public interface WorkerServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWorkerServiceAsync.WithRawResponseA view of WorkerServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WorkerServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WorkerServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1ServiceAsyncv1()-
-
Method Detail
-
withRawResponse
abstract WorkerServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WorkerServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1ServiceAsync v1()
-
-
-
-