Package dev.case.api.services.async
Class WorkerServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.WorkerServiceAsync.WithRawResponse
public final class WorkerServiceAsyncImpl.WithRawResponseImpl implements WorkerServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description WorkerServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
WorkerServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-