Interface SkillServiceAsync
-
- All Implemented Interfaces:
public interface SkillServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSkillServiceAsync.WithRawResponseA view of SkillServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SkillServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SkillServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract NamespaceServiceAsyncnamespaces()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
abstract SkillServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SkillServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
namespaces
abstract NamespaceServiceAsync namespaces()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-