Interface SkillServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface SkillServiceAsync.WithRawResponseA view of SkillServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SkillServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract NamespaceServiceAsync.WithRawResponsenamespaces()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withOptions
abstract SkillServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
namespaces
abstract NamespaceServiceAsync.WithRawResponse namespaces()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-