Class SkillServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.SkillServiceAsync
public final class SkillServiceAsyncImpl implements SkillServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SkillServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SkillServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. NamespaceServiceAsyncnamespaces()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
SkillServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SkillServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
namespaces
NamespaceServiceAsync namespaces()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-