Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentServiceAsync.WithRawResponseagents()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract RunServiceAsync.WithRawResponserun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract ExecuteServiceAsync.WithRawResponseexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract ChatServiceAsync.WithRawResponsechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
abstract AgentServiceAsync.WithRawResponse agents()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
run
abstract RunServiceAsync.WithRawResponse run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
abstract ExecuteServiceAsync.WithRawResponse execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
abstract ChatServiceAsync.WithRawResponse chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-