Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentServiceAsyncagents()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows RunServiceAsyncrun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ExecuteServiceAsyncexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatServiceAsyncchat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
AgentServiceAsync agents()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
run
RunServiceAsync run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
ExecuteServiceAsync execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
ChatServiceAsync chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-