Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentServiceAsync.WithRawResponseagents()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows RunServiceAsync.WithRawResponserun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ExecuteServiceAsync.WithRawResponseexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatServiceAsync.WithRawResponsechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
AgentServiceAsync.WithRawResponse agents()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
run
RunServiceAsync.WithRawResponse run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
ExecuteServiceAsync.WithRawResponse execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
ChatServiceAsync.WithRawResponse chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-