Interface V2ServiceAsync

    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Method Summary

      Modifier and Type Method Description
      abstract V2ServiceAsync.WithRawResponse withRawResponse() Returns a view of this service that provides access to raw HTTP responses for each method.
      abstract V2ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier) Returns a view of this service with the given option modifications applied.
      abstract RunServiceAsync run() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      abstract ExecuteServiceAsync execute() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      abstract ChatServiceAsync chat() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait