Class V2ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.V2ServiceAsync.WithRawResponse
public final class V2ServiceAsyncImpl.WithRawResponseImpl implements V2ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V2ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RunServiceAsync.WithRawResponserun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ExecuteServiceAsync.WithRawResponseexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatServiceAsync.WithRawResponsechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withOptions
V2ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
run
RunServiceAsync.WithRawResponse run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
ExecuteServiceAsync.WithRawResponse execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
ChatServiceAsync.WithRawResponse chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-