Class NamespaceServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.skills.NamespaceServiceAsync
public final class NamespaceServiceAsyncImpl implements NamespaceServiceAsync
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNamespaceServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description NamespaceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. NamespaceServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(NamespaceCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(NamespaceRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>list(NamespaceListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(NamespaceDeleteParams params, RequestOptions requestOptions)CompletableFuture<Void>publish(NamespacePublishParams params, RequestOptions requestOptions)CompletableFuture<Void>pull(NamespacePullParams params, RequestOptions requestOptions)CompletableFuture<Void>rotateToken(NamespaceRotateTokenParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.agent.skills.NamespaceServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, publish, publish, publish, pull, pull, pull, pull, pull, retrieve, retrieve, retrieve, retrieve, retrieve, rotateToken, rotateToken, rotateToken, rotateToken, rotateToken -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
NamespaceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
NamespaceServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(NamespaceCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(NamespaceRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(NamespaceListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(NamespaceDeleteParams params, RequestOptions requestOptions)
-
publish
CompletableFuture<Void> publish(NamespacePublishParams params, RequestOptions requestOptions)
-
pull
CompletableFuture<Void> pull(NamespacePullParams params, RequestOptions requestOptions)
-
rotateToken
CompletableFuture<Void> rotateToken(NamespaceRotateTokenParams params, RequestOptions requestOptions)
-
-
-
-