Interface AgentServiceAsync
-
- All Implemented Interfaces:
public interface AgentServiceAsyncCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAgentServiceAsync.WithRawResponseA view of AgentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AgentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AgentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<AgentCreateResponse> create(AgentCreateParams params)
Creates a new agent definition with a scoped API key. The agent can then be used to create and execute runs.
-
create
abstract CompletableFuture<AgentCreateResponse> create(AgentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AgentRetrieveResponse> retrieve(String id)
Retrieves a single agent definition by ID.
-
retrieve
CompletableFuture<AgentRetrieveResponse> retrieve(String id, AgentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AgentRetrieveResponse> retrieve(String id, AgentRetrieveParams params)
-
retrieve
abstract CompletableFuture<AgentRetrieveResponse> retrieve(AgentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AgentRetrieveResponse> retrieve(AgentRetrieveParams params)
-
retrieve
CompletableFuture<AgentRetrieveResponse> retrieve(String id, RequestOptions requestOptions)
-
update
CompletableFuture<AgentUpdateResponse> update(String id)
Updates an agent definition. Only provided fields are changed.
-
update
CompletableFuture<AgentUpdateResponse> update(String id, AgentUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AgentUpdateResponse> update(String id, AgentUpdateParams params)
-
update
abstract CompletableFuture<AgentUpdateResponse> update(AgentUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AgentUpdateResponse> update(AgentUpdateParams params)
-
update
CompletableFuture<AgentUpdateResponse> update(String id, RequestOptions requestOptions)
-
list
CompletableFuture<AgentListResponse> list()
Lists all active agents for the authenticated organization.
-
list
abstract CompletableFuture<AgentListResponse> list(AgentListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AgentListResponse> list(AgentListParams params)
-
list
CompletableFuture<AgentListResponse> list(RequestOptions requestOptions)
-
delete
CompletableFuture<AgentDeleteResponse> delete(String id)
Soft-deletes an agent and revokes its scoped API key.
-
delete
CompletableFuture<AgentDeleteResponse> delete(String id, AgentDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<AgentDeleteResponse> delete(String id, AgentDeleteParams params)
-
delete
abstract CompletableFuture<AgentDeleteResponse> delete(AgentDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<AgentDeleteResponse> delete(AgentDeleteParams params)
-
delete
CompletableFuture<AgentDeleteResponse> delete(String id, RequestOptions requestOptions)
-
-
-
-