Class AgentServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v1.AgentServiceAsync
public final class AgentServiceAsyncImpl implements AgentServiceAsync
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AgentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AgentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AgentCreateResponse>create(AgentCreateParams params, RequestOptions requestOptions)CompletableFuture<AgentRetrieveResponse>retrieve(AgentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<AgentUpdateResponse>update(AgentUpdateParams params, RequestOptions requestOptions)CompletableFuture<AgentListResponse>list(AgentListParams params, RequestOptions requestOptions)CompletableFuture<AgentDeleteResponse>delete(AgentDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.agent.v1.AgentServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AgentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AgentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<AgentCreateResponse> create(AgentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AgentRetrieveResponse> retrieve(AgentRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AgentUpdateResponse> update(AgentUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AgentListResponse> list(AgentListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<AgentDeleteResponse> delete(AgentDeleteParams params, RequestOptions requestOptions)
-
-
-
-