Class AgentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v1.AgentServiceAsync.WithRawResponse
public final class AgentServiceAsyncImpl.WithRawResponseImpl implements AgentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AgentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<AgentCreateResponse>>create(AgentCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AgentRetrieveResponse>>retrieve(AgentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AgentUpdateResponse>>update(AgentUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AgentListResponse>>list(AgentListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AgentDeleteResponse>>delete(AgentDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.agent.v1.AgentServiceAsync.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AgentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<AgentCreateResponse>> create(AgentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<AgentRetrieveResponse>> retrieve(AgentRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<AgentUpdateResponse>> update(AgentUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<AgentListResponse>> list(AgentListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponseFor<AgentDeleteResponse>> delete(AgentDeleteParams params, RequestOptions requestOptions)
-
-
-
-