Class ChatServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v1.ChatServiceAsync.WithRawResponse
public final class ChatServiceAsyncImpl.WithRawResponseImpl implements ChatServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.agent.v1.ChatServiceAsync.WithRawResponse
cancel, cancel, cancel, cancel, cancel, create, create, create, delete, delete, delete, delete, delete, replyToQuestion, replyToQuestion, replyToQuestion, respondStreaming, respondStreaming, respondStreaming, respondStreaming, respondStreaming, sendMessage, sendMessage, sendMessage, sendMessage, sendMessage, streamStreaming, streamStreaming, streamStreaming, streamStreaming, streamStreaming -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ChatServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
FileServiceAsync.WithRawResponse files()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
create
CompletableFuture<HttpResponseFor<ChatCreateResponse>> create(ChatCreateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponseFor<ChatDeleteResponse>> delete(ChatDeleteParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<HttpResponseFor<ChatCancelResponse>> cancel(ChatCancelParams params, RequestOptions requestOptions)
-
replyToQuestion
CompletableFuture<HttpResponse> replyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)
-
respondStreaming
CompletableFuture<HttpResponseFor<StreamResponse<String>>> respondStreaming(ChatRespondParams params, RequestOptions requestOptions)
-
sendMessage
CompletableFuture<HttpResponse> sendMessage(ChatSendMessageParams params, RequestOptions requestOptions)
-
streamStreaming
CompletableFuture<HttpResponseFor<StreamResponse<String>>> streamStreaming(ChatStreamParams params, RequestOptions requestOptions)
-
-
-
-