Interface ExecuteServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ExecuteServiceAsync.WithRawResponseA view of ExecuteServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ExecuteServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ExecuteCreateResponse>>create(ExecuteCreateParams params)Returns a raw HTTP response for post /agent/v1/execute, but is otherwise the same as ExecuteServiceAsync.create.abstract CompletableFuture<HttpResponseFor<ExecuteCreateResponse>>create(ExecuteCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ExecuteServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<ExecuteCreateResponse>> create(ExecuteCreateParams params)
Returns a raw HTTP response for
post /agent/v1/execute, but is otherwise the same as ExecuteServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<ExecuteCreateResponse>> create(ExecuteCreateParams params, RequestOptions requestOptions)
-
-
-
-