Class ExecuteServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v1.ExecuteServiceAsync
public final class ExecuteServiceAsyncImpl implements ExecuteServiceAsync
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExecuteServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ExecuteServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ExecuteServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ExecuteCreateResponse>create(ExecuteCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ExecuteServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ExecuteServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ExecuteCreateResponse> create(ExecuteCreateParams params, RequestOptions requestOptions)
-
-
-
-