Class ExecuteServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v1.ExecuteServiceAsync.WithRawResponse
public final class ExecuteServiceAsyncImpl.WithRawResponseImpl implements ExecuteServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ExecuteServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ExecuteCreateResponse>>create(ExecuteCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ExecuteServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<ExecuteCreateResponse>> create(ExecuteCreateParams params, RequestOptions requestOptions)
-
-
-
-