Class RunServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v1.RunServiceAsync
public final class RunServiceAsyncImpl implements RunServiceAsync
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.agent.v1.RunServiceAsync
cancel, cancel, cancel, cancel, cancel, create, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, exec, exec, exec, exec, exec, getDetails, getDetails, getDetails, getDetails, getDetails, getStatus, getStatus, getStatus, getStatus, getStatus, list, list, list, watch, watch, watch -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RunServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RunServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<RunCreateResponse> create(RunCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RunListResponse> list(RunListParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<RunCancelResponse> cancel(RunCancelParams params, RequestOptions requestOptions)
-
eventsStreaming
AsyncStreamResponse<String> eventsStreaming(RunEventsParams params, RequestOptions requestOptions)
-
exec
CompletableFuture<RunExecResponse> exec(RunExecParams params, RequestOptions requestOptions)
-
getDetails
CompletableFuture<RunGetDetailsResponse> getDetails(RunGetDetailsParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<RunGetStatusResponse> getStatus(RunGetStatusParams params, RequestOptions requestOptions)
-
watch
CompletableFuture<RunWatchResponse> watch(RunWatchParams params, RequestOptions requestOptions)
-
-
-
-