Interface FileServiceAsync
-
- All Implemented Interfaces:
public interface FileServiceAsyncCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileServiceAsync.WithRawResponseA view of FileServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract FileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<FileListResponse> list(String id)
Lists files created by the agent in the sandbox workspace. Only available while the sandbox is running.
-
list
CompletableFuture<FileListResponse> list(String id, FileListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FileListResponse> list(String id, FileListParams params)
-
list
abstract CompletableFuture<FileListResponse> list(FileListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FileListResponse> list(FileListParams params)
-
list
CompletableFuture<FileListResponse> list(String id, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(String filePath, FileDownloadParams params)
Downloads a file from the sandbox workspace by path. Only available while the sandbox is running.
-
download
CompletableFuture<HttpResponse> download(String filePath, FileDownloadParams params, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(FileDownloadParams params)
-
download
abstract CompletableFuture<HttpResponse> download(FileDownloadParams params, RequestOptions requestOptions)
-
-
-
-