Class FileServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v1.chat.FileServiceAsync
public final class FileServiceAsyncImpl implements FileServiceAsync
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<FileListResponse>list(FileListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>download(FileDownloadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<FileListResponse> list(FileListParams params, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(FileDownloadParams params, RequestOptions requestOptions)
-
-
-
-