Package dev.case.api.services.async.agent.v1
See: Description
-
Interface Summary Interface Description WithRawResponse A view of AgentServiceAsync that provides access to raw HTTP responses for each method. AgentServiceAsync Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponse A view of ChatServiceAsync that provides access to raw HTTP responses for each method. ChatServiceAsync Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponse A view of ExecuteServiceAsync that provides access to raw HTTP responses for each method. ExecuteServiceAsync Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponse A view of RunServiceAsync that provides access to raw HTTP responses for each method. RunServiceAsync Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
Class Summary Class Description WithRawResponseImpl AgentServiceAsyncImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponseImpl ChatServiceAsyncImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponseImpl ExecuteServiceAsyncImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponseImpl RunServiceAsyncImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows