Class ChatServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v2.ChatServiceAsync
public final class ChatServiceAsyncImpl implements ChatServiceAsync
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.agent.v2.ChatServiceAsync
cancel, cancel, cancel, cancel, cancel, create, create, create, delete, delete, delete, delete, delete, replyToQuestion, replyToQuestion, replyToQuestion, respondStreaming, respondStreaming, respondStreaming, respondStreaming, respondStreaming, sendMessage, sendMessage, sendMessage, sendMessage, sendMessage, streamStreaming, streamStreaming, streamStreaming, streamStreaming, streamStreaming -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ChatServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ChatServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
FileServiceAsync files()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
create
CompletableFuture<ChatCreateResponse> create(ChatCreateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<ChatDeleteResponse> delete(ChatDeleteParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<ChatCancelResponse> cancel(ChatCancelParams params, RequestOptions requestOptions)
-
replyToQuestion
CompletableFuture<Void> replyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)
-
respondStreaming
AsyncStreamResponse<String> respondStreaming(ChatRespondParams params, RequestOptions requestOptions)
-
sendMessage
CompletableFuture<Void> sendMessage(ChatSendMessageParams params, RequestOptions requestOptions)
-
streamStreaming
AsyncStreamResponse<String> streamStreaming(ChatStreamParams params, RequestOptions requestOptions)
-
-
-
-