Interface ExecuteServiceAsync
-
- All Implemented Interfaces:
public interface ExecuteServiceAsyncCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExecuteServiceAsync.WithRawResponseA view of ExecuteServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExecuteServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ExecuteServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ExecuteCreateResponse>create(ExecuteCreateParams params)Creates an ephemeral agent and immediately executes a v2 run on the Daytona runtime. abstract CompletableFuture<ExecuteCreateResponse>create(ExecuteCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ExecuteServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExecuteServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ExecuteCreateResponse> create(ExecuteCreateParams params)
Creates an ephemeral agent and immediately executes a v2 run on the Daytona runtime.
-
create
abstract CompletableFuture<ExecuteCreateResponse> create(ExecuteCreateParams params, RequestOptions requestOptions)
-
-
-
-