Interface RunServiceAsync
-
- All Implemented Interfaces:
public interface RunServiceAsyncCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRunServiceAsync.WithRawResponseA view of RunServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract RunServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RunServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<RunCreateResponse> create(RunCreateParams params)
Creates a v2 run in queued state. Call POST /agent/v2/run/:id/exec to start execution on the Daytona runtime.
-
create
abstract CompletableFuture<RunCreateResponse> create(RunCreateParams params, RequestOptions requestOptions)
-
eventsStreaming
AsyncStreamResponse<String> eventsStreaming(String id)
Streams real-time v2 run events over SSE with replay support.
-
eventsStreaming
AsyncStreamResponse<String> eventsStreaming(String id, RunEventsParams params, RequestOptions requestOptions)
-
eventsStreaming
AsyncStreamResponse<String> eventsStreaming(String id, RunEventsParams params)
-
eventsStreaming
abstract AsyncStreamResponse<String> eventsStreaming(RunEventsParams params, RequestOptions requestOptions)
-
eventsStreaming
AsyncStreamResponse<String> eventsStreaming(RunEventsParams params)
-
eventsStreaming
AsyncStreamResponse<String> eventsStreaming(String id, RequestOptions requestOptions)
-
exec
CompletableFuture<RunExecResponse> exec(String id)
Starts execution of a queued v2 run. The agent runs in a durable workflow on a Daytona runtime.
-
exec
CompletableFuture<RunExecResponse> exec(String id, RunExecParams params, RequestOptions requestOptions)
-
exec
CompletableFuture<RunExecResponse> exec(String id, RunExecParams params)
-
exec
abstract CompletableFuture<RunExecResponse> exec(RunExecParams params, RequestOptions requestOptions)
-
exec
CompletableFuture<RunExecResponse> exec(RunExecParams params)
-
exec
CompletableFuture<RunExecResponse> exec(String id, RequestOptions requestOptions)
-
getDetails
CompletableFuture<RunGetDetailsResponse> getDetails(String id)
Full audit trail for a v2 run, with provider-neutral runtime metadata.
-
getDetails
CompletableFuture<RunGetDetailsResponse> getDetails(String id, RunGetDetailsParams params, RequestOptions requestOptions)
-
getDetails
CompletableFuture<RunGetDetailsResponse> getDetails(String id, RunGetDetailsParams params)
-
getDetails
abstract CompletableFuture<RunGetDetailsResponse> getDetails(RunGetDetailsParams params, RequestOptions requestOptions)
-
getDetails
CompletableFuture<RunGetDetailsResponse> getDetails(RunGetDetailsParams params)
-
getDetails
CompletableFuture<RunGetDetailsResponse> getDetails(String id, RequestOptions requestOptions)
-
getStatus
CompletableFuture<RunGetStatusResponse> getStatus(String id)
Lightweight status poll for a v2 run including neutral runtime metadata.
-
getStatus
CompletableFuture<RunGetStatusResponse> getStatus(String id, RunGetStatusParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<RunGetStatusResponse> getStatus(String id, RunGetStatusParams params)
-
getStatus
abstract CompletableFuture<RunGetStatusResponse> getStatus(RunGetStatusParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<RunGetStatusResponse> getStatus(RunGetStatusParams params)
-
getStatus
CompletableFuture<RunGetStatusResponse> getStatus(String id, RequestOptions requestOptions)
-
-
-
-