Class RunServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v2.RunServiceAsync.WithRawResponse
public final class RunServiceAsyncImpl.WithRawResponseImpl implements RunServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RunServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<RunCreateResponse>>create(RunCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<StreamResponse<String>>>eventsStreaming(RunEventsParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RunExecResponse>>exec(RunExecParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RunGetDetailsResponse>>getDetails(RunGetDetailsParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RunGetStatusResponse>>getStatus(RunGetStatusParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.agent.v2.RunServiceAsync.WithRawResponse
create, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, exec, exec, exec, exec, exec, getDetails, getDetails, getDetails, getDetails, getDetails, getStatus, getStatus, getStatus, getStatus, getStatus -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
RunServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<RunCreateResponse>> create(RunCreateParams params, RequestOptions requestOptions)
-
eventsStreaming
CompletableFuture<HttpResponseFor<StreamResponse<String>>> eventsStreaming(RunEventsParams params, RequestOptions requestOptions)
-
exec
CompletableFuture<HttpResponseFor<RunExecResponse>> exec(RunExecParams params, RequestOptions requestOptions)
-
getDetails
CompletableFuture<HttpResponseFor<RunGetDetailsResponse>> getDetails(RunGetDetailsParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<HttpResponseFor<RunGetStatusResponse>> getStatus(RunGetStatusParams params, RequestOptions requestOptions)
-
-
-
-