Class FileServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.v2.chat.FileServiceAsync.WithRawResponse
public final class FileServiceAsyncImpl.WithRawResponseImpl implements FileServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FileServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<FileListResponse>>list(FileListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>download(FileDownloadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
FileServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<FileListResponse>> list(FileListParams params, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(FileDownloadParams params, RequestOptions requestOptions)
-
-
-
-