Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract DeploymentServiceAsyncdeployments()Web application deployment management abstract ProjectServiceAsyncprojects()abstract WorkflowServiceAsyncworkflows()Web application deployment management -
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
deployments
abstract DeploymentServiceAsync deployments()
Web application deployment management
-
projects
abstract ProjectServiceAsync projects()
-
workflows
abstract WorkflowServiceAsync workflows()
Web application deployment management
-
-
-
-