Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract DeploymentServiceAsync.WithRawResponsedeployments()abstract ProjectServiceAsync.WithRawResponseprojects()abstract WorkflowServiceAsync.WithRawResponseworkflows()-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
deployments
abstract DeploymentServiceAsync.WithRawResponse deployments()
-
projects
abstract ProjectServiceAsync.WithRawResponse projects()
-
workflows
abstract WorkflowServiceAsync.WithRawResponse workflows()
-
-
-
-