Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.applications.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DeploymentServiceAsync.WithRawResponsedeployments()Web application deployment management ProjectServiceAsync.WithRawResponseprojects()WorkflowServiceAsync.WithRawResponseworkflows()Web application deployment management -
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
deployments
DeploymentServiceAsync.WithRawResponse deployments()
Web application deployment management
-
projects
ProjectServiceAsync.WithRawResponse projects()
-
workflows
WorkflowServiceAsync.WithRawResponse workflows()
Web application deployment management
-
-
-
-