Class DeploymentServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.applications.v1.DeploymentServiceAsync
public final class DeploymentServiceAsyncImpl implements DeploymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeploymentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.applications.v1.DeploymentServiceAsync
cancel, cancel, cancel, create, createFromFiles, createFromFiles, createFromFiles, getLogs, getLogs, getLogs, getStatus, getStatus, getStatus, getStatus, getStatus, list, retrieve, retrieve, retrieve, stream, stream, stream -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DeploymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DeploymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(DeploymentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(DeploymentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(DeploymentListParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<Void> cancel(DeploymentCancelParams params, RequestOptions requestOptions)
-
createFromFiles
CompletableFuture<Void> createFromFiles(DeploymentCreateFromFilesParams params, RequestOptions requestOptions)
-
getLogs
CompletableFuture<Void> getLogs(DeploymentGetLogsParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<Void> getStatus(DeploymentGetStatusParams params, RequestOptions requestOptions)
-
stream
CompletableFuture<Void> stream(DeploymentStreamParams params, RequestOptions requestOptions)
-
-
-
-