Class DeploymentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.applications.v1.DeploymentServiceAsync.WithRawResponse
public final class DeploymentServiceAsyncImpl.WithRawResponseImpl implements DeploymentServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.applications.v1.DeploymentServiceAsync.WithRawResponse
cancel, cancel, cancel, create, createFromFiles, createFromFiles, createFromFiles, getLogs, getLogs, getLogs, getStatus, getStatus, getStatus, getStatus, getStatus, list, retrieve, retrieve, retrieve, stream, stream, stream -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DeploymentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(DeploymentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponse> retrieve(DeploymentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(DeploymentListParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<HttpResponse> cancel(DeploymentCancelParams params, RequestOptions requestOptions)
-
createFromFiles
CompletableFuture<HttpResponse> createFromFiles(DeploymentCreateFromFilesParams params, RequestOptions requestOptions)
-
getLogs
CompletableFuture<HttpResponse> getLogs(DeploymentGetLogsParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<HttpResponse> getStatus(DeploymentGetStatusParams params, RequestOptions requestOptions)
-
stream
CompletableFuture<HttpResponse> stream(DeploymentStreamParams params, RequestOptions requestOptions)
-
-
-
-