Class ProjectServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.applications.v1.ProjectServiceAsync
public final class ProjectServiceAsyncImpl implements ProjectServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.applications.v1.ProjectServiceAsync
create, createDeployment, createDeployment, createDeployment, createDeployment, createDeployment, createDomain, createDomain, createDomain, createEnv, createEnv, createEnv, delete, delete, delete, delete, delete, deleteDomain, deleteDomain, deleteDomain, deleteEnv, deleteEnv, deleteEnv, getRuntimeLogs, getRuntimeLogs, getRuntimeLogs, getRuntimeLogs, getRuntimeLogs, list, list, list, listDeployments, listDeployments, listDeployments, listDeployments, listDeployments, listDomains, listDomains, listDomains, listDomains, listDomains, listEnv, listEnv, listEnv, listEnv, listEnv, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ProjectServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProjectServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(ProjectCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(ProjectRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProjectListResponse> list(ProjectListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(ProjectDeleteParams params, RequestOptions requestOptions)
-
createDeployment
CompletableFuture<Void> createDeployment(ProjectCreateDeploymentParams params, RequestOptions requestOptions)
-
createDomain
CompletableFuture<Void> createDomain(ProjectCreateDomainParams params, RequestOptions requestOptions)
-
createEnv
CompletableFuture<Void> createEnv(ProjectCreateEnvParams params, RequestOptions requestOptions)
-
deleteDomain
CompletableFuture<Void> deleteDomain(ProjectDeleteDomainParams params, RequestOptions requestOptions)
-
deleteEnv
CompletableFuture<Void> deleteEnv(ProjectDeleteEnvParams params, RequestOptions requestOptions)
-
getRuntimeLogs
CompletableFuture<Void> getRuntimeLogs(ProjectGetRuntimeLogsParams params, RequestOptions requestOptions)
-
listDeployments
CompletableFuture<Void> listDeployments(ProjectListDeploymentsParams params, RequestOptions requestOptions)
-
listDomains
CompletableFuture<Void> listDomains(ProjectListDomainsParams params, RequestOptions requestOptions)
-
listEnv
CompletableFuture<Void> listEnv(ProjectListEnvParams params, RequestOptions requestOptions)
-
-
-
-