Interface WorkflowServiceAsync
-
- All Implemented Interfaces:
public interface WorkflowServiceAsyncWeb application deployment management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWorkflowServiceAsync.WithRawResponseA view of WorkflowServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WorkflowServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WorkflowServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>getStatus(String id, WorkflowGetStatusParams params)Get current deployment workflow status and accumulated events CompletableFuture<Void>getStatus(String id, WorkflowGetStatusParams params, RequestOptions requestOptions)CompletableFuture<Void>getStatus(WorkflowGetStatusParams params)abstract CompletableFuture<Void>getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract WorkflowServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WorkflowServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStatus
CompletableFuture<Void> getStatus(String id, WorkflowGetStatusParams params)
Get current deployment workflow status and accumulated events
-
getStatus
CompletableFuture<Void> getStatus(String id, WorkflowGetStatusParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<Void> getStatus(WorkflowGetStatusParams params)
-
getStatus
abstract CompletableFuture<Void> getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)
-
-
-
-