Class WorkflowServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.applications.v1.WorkflowServiceAsync
public final class WorkflowServiceAsyncImpl implements WorkflowServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkflowServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WorkflowServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WorkflowServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
WorkflowServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WorkflowServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStatus
CompletableFuture<Void> getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)
-
-
-
-