Class WorkflowServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.applications.v1.WorkflowServiceAsync.WithRawResponse
public final class WorkflowServiceAsyncImpl.WithRawResponseImpl implements WorkflowServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description WorkflowServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
WorkflowServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStatus
CompletableFuture<HttpResponse> getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)
-
-
-
-