Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsyncServerless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract EnvironmentServiceAsyncenvironments()Serverless GPU and CPU infrastructure abstract InstanceTypeServiceAsyncinstanceTypes()Serverless GPU and CPU infrastructure abstract InstanceServiceAsyncinstances()Serverless GPU and CPU infrastructure abstract SecretServiceAsyncsecrets()Serverless GPU and CPU infrastructure CompletableFuture<Void>getPricing()Returns current pricing for GPU instances. abstract CompletableFuture<Void>getPricing(V1GetPricingParams params, RequestOptions requestOptions)CompletableFuture<Void>getPricing(V1GetPricingParams params)CompletableFuture<Void>getPricing(RequestOptions requestOptions)CompletableFuture<V1GetUsageResponse>getUsage()Returns detailed compute usage statistics and billing information for your organization. abstract CompletableFuture<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)CompletableFuture<V1GetUsageResponse>getUsage(V1GetUsageParams params)CompletableFuture<V1GetUsageResponse>getUsage(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
abstract EnvironmentServiceAsync environments()
Serverless GPU and CPU infrastructure
-
instanceTypes
abstract InstanceTypeServiceAsync instanceTypes()
Serverless GPU and CPU infrastructure
-
instances
abstract InstanceServiceAsync instances()
Serverless GPU and CPU infrastructure
-
secrets
abstract SecretServiceAsync secrets()
Serverless GPU and CPU infrastructure
-
getPricing
CompletableFuture<Void> getPricing()
Returns current pricing for GPU instances. Prices are fetched in real-time and include a 20% platform fee. For detailed instance types and availability, use GET /compute/v1/instance-types.
-
getPricing
abstract CompletableFuture<Void> getPricing(V1GetPricingParams params, RequestOptions requestOptions)
-
getPricing
CompletableFuture<Void> getPricing(V1GetPricingParams params)
-
getPricing
CompletableFuture<Void> getPricing(RequestOptions requestOptions)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage()
Returns detailed compute usage statistics and billing information for your organization. Includes GPU and CPU hours, total runs, costs, and breakdowns by environment. Use optional query parameters to filter by specific year and month.
-
getUsage
abstract CompletableFuture<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage(V1GetUsageParams params)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage(RequestOptions requestOptions)
-
-
-
-