Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.compute.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
Serverless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EnvironmentServiceAsyncenvironments()Serverless GPU and CPU infrastructure InstanceTypeServiceAsyncinstanceTypes()Serverless GPU and CPU infrastructure InstanceServiceAsyncinstances()Serverless GPU and CPU infrastructure SecretServiceAsyncsecrets()Serverless GPU and CPU infrastructure CompletableFuture<Void>getPricing(V1GetPricingParams params, RequestOptions requestOptions)CompletableFuture<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
EnvironmentServiceAsync environments()
Serverless GPU and CPU infrastructure
-
instanceTypes
InstanceTypeServiceAsync instanceTypes()
Serverless GPU and CPU infrastructure
-
instances
InstanceServiceAsync instances()
Serverless GPU and CPU infrastructure
-
secrets
SecretServiceAsync secrets()
Serverless GPU and CPU infrastructure
-
getPricing
CompletableFuture<Void> getPricing(V1GetPricingParams params, RequestOptions requestOptions)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
-
-
-