Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.compute.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EnvironmentServiceAsync.WithRawResponseenvironments()Serverless GPU and CPU infrastructure InstanceTypeServiceAsync.WithRawResponseinstanceTypes()Serverless GPU and CPU infrastructure InstanceServiceAsync.WithRawResponseinstances()Serverless GPU and CPU infrastructure SecretServiceAsync.WithRawResponsesecrets()Serverless GPU and CPU infrastructure CompletableFuture<HttpResponse>getPricing(V1GetPricingParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1GetUsageResponse>>getUsage(V1GetUsageParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
EnvironmentServiceAsync.WithRawResponse environments()
Serverless GPU and CPU infrastructure
-
instanceTypes
InstanceTypeServiceAsync.WithRawResponse instanceTypes()
Serverless GPU and CPU infrastructure
-
instances
InstanceServiceAsync.WithRawResponse instances()
Serverless GPU and CPU infrastructure
-
secrets
SecretServiceAsync.WithRawResponse secrets()
Serverless GPU and CPU infrastructure
-
getPricing
CompletableFuture<HttpResponse> getPricing(V1GetPricingParams params, RequestOptions requestOptions)
-
getUsage
CompletableFuture<HttpResponseFor<V1GetUsageResponse>> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
-
-
-