Class EnvironmentServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.compute.v1.EnvironmentServiceAsync
public final class EnvironmentServiceAsyncImpl implements EnvironmentServiceAsync
Serverless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EnvironmentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EnvironmentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<EnvironmentCreateResponse>create(EnvironmentCreateParams params, RequestOptions requestOptions)CompletableFuture<EnvironmentRetrieveResponse>retrieve(EnvironmentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<EnvironmentListResponse>list(EnvironmentListParams params, RequestOptions requestOptions)CompletableFuture<EnvironmentDeleteResponse>delete(EnvironmentDeleteParams params, RequestOptions requestOptions)CompletableFuture<EnvironmentSetDefaultResponse>setDefault(EnvironmentSetDefaultParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.compute.v1.EnvironmentServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, setDefault, setDefault, setDefault, setDefault, setDefault -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EnvironmentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EnvironmentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<EnvironmentCreateResponse> create(EnvironmentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<EnvironmentRetrieveResponse> retrieve(EnvironmentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EnvironmentListResponse> list(EnvironmentListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<EnvironmentDeleteResponse> delete(EnvironmentDeleteParams params, RequestOptions requestOptions)
-
setDefault
CompletableFuture<EnvironmentSetDefaultResponse> setDefault(EnvironmentSetDefaultParams params, RequestOptions requestOptions)
-
-
-
-