Class EnvironmentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.compute.v1.EnvironmentServiceAsync.WithRawResponse
public final class EnvironmentServiceAsyncImpl.WithRawResponseImpl implements EnvironmentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EnvironmentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<EnvironmentCreateResponse>>create(EnvironmentCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EnvironmentRetrieveResponse>>retrieve(EnvironmentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EnvironmentListResponse>>list(EnvironmentListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EnvironmentDeleteResponse>>delete(EnvironmentDeleteParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EnvironmentSetDefaultResponse>>setDefault(EnvironmentSetDefaultParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.compute.v1.EnvironmentServiceAsync.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, setDefault, setDefault, setDefault, setDefault, setDefault -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
EnvironmentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<EnvironmentCreateResponse>> create(EnvironmentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<EnvironmentRetrieveResponse>> retrieve(EnvironmentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<EnvironmentListResponse>> list(EnvironmentListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponseFor<EnvironmentDeleteResponse>> delete(EnvironmentDeleteParams params, RequestOptions requestOptions)
-
setDefault
CompletableFuture<HttpResponseFor<EnvironmentSetDefaultResponse>> setDefault(EnvironmentSetDefaultParams params, RequestOptions requestOptions)
-
-
-
-