Class InstanceServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.compute.v1.InstanceServiceAsync
public final class InstanceServiceAsyncImpl implements InstanceServiceAsync
Serverless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InstanceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InstanceServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InstanceCreateResponse>create(InstanceCreateParams params, RequestOptions requestOptions)CompletableFuture<InstanceRetrieveResponse>retrieve(InstanceRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InstanceListResponse>list(InstanceListParams params, RequestOptions requestOptions)CompletableFuture<InstanceDeleteResponse>delete(InstanceDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.compute.v1.InstanceServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InstanceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InstanceServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InstanceCreateResponse> create(InstanceCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InstanceRetrieveResponse> retrieve(InstanceRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InstanceListResponse> list(InstanceListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<InstanceDeleteResponse> delete(InstanceDeleteParams params, RequestOptions requestOptions)
-
-
-
-