Class SecretServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.compute.v1.SecretServiceAsync
public final class SecretServiceAsyncImpl implements SecretServiceAsync
Serverless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SecretServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SecretServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<SecretCreateResponse>create(SecretCreateParams params, RequestOptions requestOptions)CompletableFuture<SecretListResponse>list(SecretListParams params, RequestOptions requestOptions)CompletableFuture<SecretDeleteGroupResponse>deleteGroup(SecretDeleteGroupParams params, RequestOptions requestOptions)CompletableFuture<SecretRetrieveGroupResponse>retrieveGroup(SecretRetrieveGroupParams params, RequestOptions requestOptions)CompletableFuture<SecretUpdateGroupResponse>updateGroup(SecretUpdateGroupParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.compute.v1.SecretServiceAsync
create, deleteGroup, deleteGroup, deleteGroup, deleteGroup, deleteGroup, list, list, list, retrieveGroup, retrieveGroup, retrieveGroup, retrieveGroup, retrieveGroup, updateGroup, updateGroup, updateGroup -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SecretServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SecretServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<SecretCreateResponse> create(SecretCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<SecretListResponse> list(SecretListParams params, RequestOptions requestOptions)
-
deleteGroup
CompletableFuture<SecretDeleteGroupResponse> deleteGroup(SecretDeleteGroupParams params, RequestOptions requestOptions)
-
retrieveGroup
CompletableFuture<SecretRetrieveGroupResponse> retrieveGroup(SecretRetrieveGroupParams params, RequestOptions requestOptions)
-
updateGroup
CompletableFuture<SecretUpdateGroupResponse> updateGroup(SecretUpdateGroupParams params, RequestOptions requestOptions)
-
-
-
-