Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsyncServerless PostgreSQL databases with instant branching
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ProjectServiceAsyncprojects()Serverless PostgreSQL databases with instant branching CompletableFuture<V1GetUsageResponse>getUsage()Returns detailed database usage statistics and billing information for the current billing period. abstract CompletableFuture<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)CompletableFuture<V1GetUsageResponse>getUsage(V1GetUsageParams params)CompletableFuture<V1GetUsageResponse>getUsage(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
projects
abstract ProjectServiceAsync projects()
Serverless PostgreSQL databases with instant branching
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage()
Returns detailed database usage statistics and billing information for the current billing period. Includes compute hours, storage, data transfer, and branch counts with associated costs broken down by project.
-
getUsage
abstract CompletableFuture<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage(V1GetUsageParams params)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage(RequestOptions requestOptions)
-
-
-
-