Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ProjectServiceAsync.WithRawResponseprojects()Serverless PostgreSQL databases with instant branching CompletableFuture<HttpResponseFor<V1GetUsageResponse>>getUsage()Returns a raw HTTP response for get /database/v1/usage, but is otherwise the same as V1ServiceAsync.getUsage.abstract CompletableFuture<HttpResponseFor<V1GetUsageResponse>>getUsage(V1GetUsageParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1GetUsageResponse>>getUsage(V1GetUsageParams params)CompletableFuture<HttpResponseFor<V1GetUsageResponse>>getUsage(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
projects
abstract ProjectServiceAsync.WithRawResponse projects()
Serverless PostgreSQL databases with instant branching
-
getUsage
CompletableFuture<HttpResponseFor<V1GetUsageResponse>> getUsage()
Returns a raw HTTP response for
get /database/v1/usage, but is otherwise the same as V1ServiceAsync.getUsage.
-
getUsage
abstract CompletableFuture<HttpResponseFor<V1GetUsageResponse>> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
CompletableFuture<HttpResponseFor<V1GetUsageResponse>> getUsage(V1GetUsageParams params)
-
getUsage
CompletableFuture<HttpResponseFor<V1GetUsageResponse>> getUsage(RequestOptions requestOptions)
-
-
-
-