Interface ProjectServiceAsync
-
- All Implemented Interfaces:
public interface ProjectServiceAsyncServerless PostgreSQL databases with instant branching
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProjectServiceAsync.WithRawResponseA view of ProjectServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ProjectServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProjectServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ProjectCreateResponse> create(ProjectCreateParams params)
Creates a new serverless Postgres database project powered by Neon. Includes automatic scaling, connection pooling, and a default 'main' branch with 'neondb' database. Supports branching for isolated dev/staging environments. Perfect for case management applications, document workflows, and litigation support systems.
-
create
abstract CompletableFuture<ProjectCreateResponse> create(ProjectCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ProjectRetrieveResponse> retrieve(String id)
Retrieves detailed information about a specific database project including branches, databases, storage/compute metrics, connection host, and linked deployments. Fetches live usage statistics from Neon API.
-
retrieve
CompletableFuture<ProjectRetrieveResponse> retrieve(String id, ProjectRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ProjectRetrieveResponse> retrieve(String id, ProjectRetrieveParams params)
-
retrieve
abstract CompletableFuture<ProjectRetrieveResponse> retrieve(ProjectRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ProjectRetrieveResponse> retrieve(ProjectRetrieveParams params)
-
retrieve
CompletableFuture<ProjectRetrieveResponse> retrieve(String id, RequestOptions requestOptions)
-
list
CompletableFuture<ProjectListResponse> list()
Retrieves all serverless Postgres database projects for the authenticated organization. Includes storage and compute metrics, plus linked application deployments and Compute instances.
-
list
abstract CompletableFuture<ProjectListResponse> list(ProjectListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProjectListResponse> list(ProjectListParams params)
-
list
CompletableFuture<ProjectListResponse> list(RequestOptions requestOptions)
-
delete
CompletableFuture<ProjectDeleteResponse> delete(String id)
Permanently deletes a database project from Neon and marks it as deleted in Case.dev. This action cannot be undone and will destroy all data including branches and databases. Use with caution.
-
delete
CompletableFuture<ProjectDeleteResponse> delete(String id, ProjectDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<ProjectDeleteResponse> delete(String id, ProjectDeleteParams params)
-
delete
abstract CompletableFuture<ProjectDeleteResponse> delete(ProjectDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<ProjectDeleteResponse> delete(ProjectDeleteParams params)
-
delete
CompletableFuture<ProjectDeleteResponse> delete(String id, RequestOptions requestOptions)
-
createBranch
CompletableFuture<ProjectCreateBranchResponse> createBranch(String id, ProjectCreateBranchParams params)
Creates a new branch from the specified parent branch (or default 'main' branch). Branches provide instant point-in-time clones of your database for isolated development, staging, testing, or feature work. Perfect for testing schema changes, running migrations safely, or creating ephemeral preview environments.
-
createBranch
CompletableFuture<ProjectCreateBranchResponse> createBranch(String id, ProjectCreateBranchParams params, RequestOptions requestOptions)
-
createBranch
CompletableFuture<ProjectCreateBranchResponse> createBranch(ProjectCreateBranchParams params)
-
createBranch
abstract CompletableFuture<ProjectCreateBranchResponse> createBranch(ProjectCreateBranchParams params, RequestOptions requestOptions)
-
getConnection
CompletableFuture<ProjectGetConnectionResponse> getConnection(String id)
Retrieves the PostgreSQL connection URI for a database project. Supports selecting specific branches and pooled vs direct connections. Connection strings include credentials and should be stored securely. Use for configuring applications and deployment environments.
-
getConnection
CompletableFuture<ProjectGetConnectionResponse> getConnection(String id, ProjectGetConnectionParams params, RequestOptions requestOptions)
-
getConnection
CompletableFuture<ProjectGetConnectionResponse> getConnection(String id, ProjectGetConnectionParams params)
-
getConnection
abstract CompletableFuture<ProjectGetConnectionResponse> getConnection(ProjectGetConnectionParams params, RequestOptions requestOptions)
-
getConnection
CompletableFuture<ProjectGetConnectionResponse> getConnection(ProjectGetConnectionParams params)
-
getConnection
CompletableFuture<ProjectGetConnectionResponse> getConnection(String id, RequestOptions requestOptions)
-
listBranches
CompletableFuture<ProjectListBranchesResponse> listBranches(String id)
Retrieves all branches for a database project. Branches enable isolated development and testing environments with instant point-in-time cloning. Each branch includes the default branch and any custom branches created for staging, testing, or feature development.
-
listBranches
CompletableFuture<ProjectListBranchesResponse> listBranches(String id, ProjectListBranchesParams params, RequestOptions requestOptions)
-
listBranches
CompletableFuture<ProjectListBranchesResponse> listBranches(String id, ProjectListBranchesParams params)
-
listBranches
abstract CompletableFuture<ProjectListBranchesResponse> listBranches(ProjectListBranchesParams params, RequestOptions requestOptions)
-
listBranches
CompletableFuture<ProjectListBranchesResponse> listBranches(ProjectListBranchesParams params)
-
listBranches
CompletableFuture<ProjectListBranchesResponse> listBranches(String id, RequestOptions requestOptions)
-
-
-
-