Class ProjectServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.database.v1.ProjectServiceAsync
public final class ProjectServiceAsyncImpl implements ProjectServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.database.v1.ProjectServiceAsync
create, createBranch, createBranch, createBranch, delete, delete, delete, delete, delete, getConnection, getConnection, getConnection, getConnection, getConnection, list, list, list, listBranches, listBranches, listBranches, listBranches, listBranches, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ProjectServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProjectServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ProjectCreateResponse> create(ProjectCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ProjectRetrieveResponse> retrieve(ProjectRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProjectListResponse> list(ProjectListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<ProjectDeleteResponse> delete(ProjectDeleteParams params, RequestOptions requestOptions)
-
createBranch
CompletableFuture<ProjectCreateBranchResponse> createBranch(ProjectCreateBranchParams params, RequestOptions requestOptions)
-
getConnection
CompletableFuture<ProjectGetConnectionResponse> getConnection(ProjectGetConnectionParams params, RequestOptions requestOptions)
-
listBranches
CompletableFuture<ProjectListBranchesResponse> listBranches(ProjectListBranchesParams params, RequestOptions requestOptions)
-
-
-
-