Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract TemplateServiceAsynctemplates()CompletableFuture<HttpResponse>createDocument(V1CreateDocumentParams params)Convert Markdown, JSON, or text content to professionally formatted PDF, DOCX, or HTML documents. abstract CompletableFuture<HttpResponse>createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
templates
abstract TemplateServiceAsync templates()
-
createDocument
CompletableFuture<HttpResponse> createDocument(V1CreateDocumentParams params)
Convert Markdown, JSON, or text content to professionally formatted PDF, DOCX, or HTML documents. Supports template components with variable interpolation for creating consistent legal documents like contracts, briefs, and reports.
-
createDocument
abstract CompletableFuture<HttpResponse> createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)
-
-
-
-