Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract TemplateServiceAsync.WithRawResponsetemplates()Document formatting and template rendering (MD/JSON to PDF/DOCX) CompletableFuture<HttpResponse>createDocument(V1CreateDocumentParams params)Returns a raw HTTP response for post /format/v1/document, but is otherwise the same as V1ServiceAsync.createDocument.abstract CompletableFuture<HttpResponse>createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
templates
abstract TemplateServiceAsync.WithRawResponse templates()
Document formatting and template rendering (MD/JSON to PDF/DOCX)
-
createDocument
CompletableFuture<HttpResponse> createDocument(V1CreateDocumentParams params)
Returns a raw HTTP response for
post /format/v1/document, but is otherwise the same as V1ServiceAsync.createDocument.
-
createDocument
abstract CompletableFuture<HttpResponse> createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)
-
-
-
-