Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.format.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. TemplateServiceAsync.WithRawResponsetemplates()CompletableFuture<HttpResponse>createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
templates
TemplateServiceAsync.WithRawResponse templates()
-
createDocument
CompletableFuture<HttpResponse> createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)
-
-
-
-