Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.legal.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
Legal research tools including citation verification
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.legal.V1ServiceAsync
docket, draft, find, getCitations, getCitationsFromUrl, getFullText, listCourts, listCourts, listCourts, listJurisdictions, patentSearch, research, similar, trademarkSearch, trademarkSearch, trademarkSearch, verify -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
docket
CompletableFuture<V1DocketResponse> docket(V1DocketParams params, RequestOptions requestOptions)
-
draft
CompletableFuture<V1DraftResponse> draft(V1DraftParams params, RequestOptions requestOptions)
-
find
CompletableFuture<V1FindResponse> find(V1FindParams params, RequestOptions requestOptions)
-
getCitations
CompletableFuture<V1GetCitationsResponse> getCitations(V1GetCitationsParams params, RequestOptions requestOptions)
-
getCitationsFromUrl
CompletableFuture<V1GetCitationsFromUrlResponse> getCitationsFromUrl(V1GetCitationsFromUrlParams params, RequestOptions requestOptions)
-
getFullText
CompletableFuture<V1GetFullTextResponse> getFullText(V1GetFullTextParams params, RequestOptions requestOptions)
-
listCourts
CompletableFuture<V1ListCourtsResponse> listCourts(V1ListCourtsParams params, RequestOptions requestOptions)
-
listJurisdictions
CompletableFuture<V1ListJurisdictionsResponse> listJurisdictions(V1ListJurisdictionsParams params, RequestOptions requestOptions)
-
patentSearch
CompletableFuture<V1PatentSearchResponse> patentSearch(V1PatentSearchParams params, RequestOptions requestOptions)
-
research
CompletableFuture<V1ResearchResponse> research(V1ResearchParams params, RequestOptions requestOptions)
-
similar
CompletableFuture<V1SimilarResponse> similar(V1SimilarParams params, RequestOptions requestOptions)
-
trademarkSearch
CompletableFuture<V1TrademarkSearchResponse> trademarkSearch(V1TrademarkSearchParams params, RequestOptions requestOptions)
-
verify
CompletableFuture<V1VerifyResponse> verify(V1VerifyParams params, RequestOptions requestOptions)
-
-
-
-