Package dev.case.api.services.async.llm
Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.llm.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ChatServiceAsync.WithRawResponsechat()Access 40+ language models through a unified API CompletableFuture<HttpResponseFor<V1CreateEmbeddingResponse>>createEmbedding(V1CreateEmbeddingParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1ListModelsResponse>>listModels(V1ListModelsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
chat
ChatServiceAsync.WithRawResponse chat()
Access 40+ language models through a unified API
-
createEmbedding
CompletableFuture<HttpResponseFor<V1CreateEmbeddingResponse>> createEmbedding(V1CreateEmbeddingParams params, RequestOptions requestOptions)
-
listModels
CompletableFuture<HttpResponseFor<V1ListModelsResponse>> listModels(V1ListModelsParams params, RequestOptions requestOptions)
-
-
-
-