Interface ChatServiceAsync
-
- All Implemented Interfaces:
public interface ChatServiceAsyncAccess 40+ language models through a unified API
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceChatServiceAsync.WithRawResponseA view of ChatServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ChatServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ChatServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ChatCreateCompletionResponse>createCompletion(ChatCreateCompletionParams params)Create a completion for the provided prompt and parameters. abstract CompletableFuture<ChatCreateCompletionResponse>createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ChatServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ChatServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createCompletion
CompletableFuture<ChatCreateCompletionResponse> createCompletion(ChatCreateCompletionParams params)
Create a completion for the provided prompt and parameters. Compatible with OpenAI's chat completions API. Supports 40+ models including GPT-4, Claude, Gemini, and CaseMark legal AI models. Includes streaming support, token counting, and usage tracking.
-
createCompletion
abstract CompletableFuture<ChatCreateCompletionResponse> createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)
-
-
-
-