Class ChatServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.llm.v1.ChatServiceAsync
public final class ChatServiceAsyncImpl implements ChatServiceAsync
Access 40+ language models through a unified API
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ChatServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ChatServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ChatCreateCompletionResponse>createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ChatServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ChatServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createCompletion
CompletableFuture<ChatCreateCompletionResponse> createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)
-
-
-
-