Class ChatServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.llm.v1.ChatServiceAsync.WithRawResponse
public final class ChatServiceAsyncImpl.WithRawResponseImpl implements ChatServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ChatServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ChatCreateCompletionResponse>>createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ChatServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createCompletion
CompletableFuture<HttpResponseFor<ChatCreateCompletionResponse>> createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)
-
-
-
-