Package dev.case.api.services.async.mail
Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract InboxServiceAsyncinboxes()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
inboxes
abstract InboxServiceAsync inboxes()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-