Package dev.case.api.services.async.mail
Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.mail.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboxServiceAsync.WithRawResponseinboxes()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
inboxes
InboxServiceAsync.WithRawResponse inboxes()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-