Interface InboxServiceAsync
-
- All Implemented Interfaces:
public interface InboxServiceAsyncCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboxServiceAsync.WithRawResponseA view of InboxServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboxServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboxServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create()
Create an inbox owned by the authenticated organization.
-
create
abstract CompletableFuture<Void> create(InboxCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Void> create(InboxCreateParams params)
-
create
CompletableFuture<Void> create(RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String inboxId)
Get an inbox owned by the authenticated organization.
-
retrieve
CompletableFuture<Void> retrieve(String inboxId, InboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String inboxId, InboxRetrieveParams params)
-
retrieve
abstract CompletableFuture<Void> retrieve(InboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(InboxRetrieveParams params)
-
retrieve
CompletableFuture<Void> retrieve(String inboxId, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list()
List inboxes owned by the authenticated organization.
-
list
abstract CompletableFuture<Void> list(InboxListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(InboxListParams params)
-
list
CompletableFuture<Void> list(RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String inboxId)
Delete an inbox owned by the authenticated organization.
-
delete
CompletableFuture<Void> delete(String inboxId, InboxDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String inboxId, InboxDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(InboxDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(InboxDeleteParams params)
-
delete
CompletableFuture<Void> delete(String inboxId, RequestOptions requestOptions)
-
getAttachment
CompletableFuture<Void> getAttachment(String attachmentId, InboxGetAttachmentParams params)
Get attachment metadata for a message in an inbox owned by the authenticated organization.
-
getAttachment
CompletableFuture<Void> getAttachment(String attachmentId, InboxGetAttachmentParams params, RequestOptions requestOptions)
-
getAttachment
CompletableFuture<Void> getAttachment(InboxGetAttachmentParams params)
-
getAttachment
abstract CompletableFuture<Void> getAttachment(InboxGetAttachmentParams params, RequestOptions requestOptions)
-
getMessage
CompletableFuture<Void> getMessage(String messageId, InboxGetMessageParams params)
Get a message for an inbox owned by the authenticated organization.
-
getMessage
CompletableFuture<Void> getMessage(String messageId, InboxGetMessageParams params, RequestOptions requestOptions)
-
getMessage
CompletableFuture<Void> getMessage(InboxGetMessageParams params)
-
getMessage
abstract CompletableFuture<Void> getMessage(InboxGetMessageParams params, RequestOptions requestOptions)
-
getPolicy
CompletableFuture<Void> getPolicy(String inboxId)
Get the sender allowlist and send/reply/read access rules for an inbox owned by the authenticated organization.
-
getPolicy
CompletableFuture<Void> getPolicy(String inboxId, InboxGetPolicyParams params, RequestOptions requestOptions)
-
getPolicy
CompletableFuture<Void> getPolicy(String inboxId, InboxGetPolicyParams params)
-
getPolicy
abstract CompletableFuture<Void> getPolicy(InboxGetPolicyParams params, RequestOptions requestOptions)
-
getPolicy
CompletableFuture<Void> getPolicy(InboxGetPolicyParams params)
-
getPolicy
CompletableFuture<Void> getPolicy(String inboxId, RequestOptions requestOptions)
-
listMessages
CompletableFuture<Void> listMessages(String inboxId)
List messages for an inbox owned by the authenticated organization.
-
listMessages
CompletableFuture<Void> listMessages(String inboxId, InboxListMessagesParams params, RequestOptions requestOptions)
-
listMessages
CompletableFuture<Void> listMessages(String inboxId, InboxListMessagesParams params)
-
listMessages
abstract CompletableFuture<Void> listMessages(InboxListMessagesParams params, RequestOptions requestOptions)
-
listMessages
CompletableFuture<Void> listMessages(InboxListMessagesParams params)
-
listMessages
CompletableFuture<Void> listMessages(String inboxId, RequestOptions requestOptions)
-
reply
CompletableFuture<Void> reply(String messageId, InboxReplyParams params)
Reply to a message in an inbox owned by the authenticated organization.
-
reply
CompletableFuture<Void> reply(String messageId, InboxReplyParams params, RequestOptions requestOptions)
-
reply
CompletableFuture<Void> reply(InboxReplyParams params)
-
reply
abstract CompletableFuture<Void> reply(InboxReplyParams params, RequestOptions requestOptions)
-
send
CompletableFuture<Void> send(String inboxId)
Send a message from an inbox owned by the authenticated organization.
-
send
CompletableFuture<Void> send(String inboxId, InboxSendParams params, RequestOptions requestOptions)
-
send
CompletableFuture<Void> send(String inboxId, InboxSendParams params)
-
send
abstract CompletableFuture<Void> send(InboxSendParams params, RequestOptions requestOptions)
-
send
CompletableFuture<Void> send(InboxSendParams params)
-
send
CompletableFuture<Void> send(String inboxId, RequestOptions requestOptions)
-
setPolicy
CompletableFuture<Void> setPolicy(String inboxId)
Set the sender allowlist and send/reply/read access rules for an inbox owned by the authenticated organization.
-
setPolicy
CompletableFuture<Void> setPolicy(String inboxId, InboxSetPolicyParams params, RequestOptions requestOptions)
-
setPolicy
CompletableFuture<Void> setPolicy(String inboxId, InboxSetPolicyParams params)
-
setPolicy
abstract CompletableFuture<Void> setPolicy(InboxSetPolicyParams params, RequestOptions requestOptions)
-
setPolicy
CompletableFuture<Void> setPolicy(InboxSetPolicyParams params)
-
setPolicy
CompletableFuture<Void> setPolicy(String inboxId, RequestOptions requestOptions)
-
-
-
-