Class InboxServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.mail.v1.InboxServiceAsync
public final class InboxServiceAsyncImpl implements InboxServiceAsync
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.mail.v1.InboxServiceAsync
create, create, create, delete, delete, delete, delete, delete, getAttachment, getAttachment, getAttachment, getMessage, getMessage, getMessage, getPolicy, getPolicy, getPolicy, getPolicy, getPolicy, list, list, list, listMessages, listMessages, listMessages, listMessages, listMessages, reply, reply, reply, retrieve, retrieve, retrieve, retrieve, retrieve, send, send, send, send, send, setPolicy, setPolicy, setPolicy, setPolicy, setPolicy -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboxServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboxServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(InboxCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(InboxRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(InboxListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(InboxDeleteParams params, RequestOptions requestOptions)
-
getAttachment
CompletableFuture<Void> getAttachment(InboxGetAttachmentParams params, RequestOptions requestOptions)
-
getMessage
CompletableFuture<Void> getMessage(InboxGetMessageParams params, RequestOptions requestOptions)
-
getPolicy
CompletableFuture<Void> getPolicy(InboxGetPolicyParams params, RequestOptions requestOptions)
-
listMessages
CompletableFuture<Void> listMessages(InboxListMessagesParams params, RequestOptions requestOptions)
-
reply
CompletableFuture<Void> reply(InboxReplyParams params, RequestOptions requestOptions)
-
send
CompletableFuture<Void> send(InboxSendParams params, RequestOptions requestOptions)
-
setPolicy
CompletableFuture<Void> setPolicy(InboxSetPolicyParams params, RequestOptions requestOptions)
-
-
-
-