Class InboxServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.mail.v1.InboxServiceAsync.WithRawResponse
public final class InboxServiceAsyncImpl.WithRawResponseImpl implements InboxServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.mail.v1.InboxServiceAsync.WithRawResponse
create, create, create, delete, delete, delete, delete, delete, getAttachment, getAttachment, getAttachment, getMessage, getMessage, getMessage, getPolicy, getPolicy, getPolicy, getPolicy, getPolicy, list, list, list, listMessages, listMessages, listMessages, listMessages, listMessages, reply, reply, reply, retrieve, retrieve, retrieve, retrieve, retrieve, send, send, send, send, send, setPolicy, setPolicy, setPolicy, setPolicy, setPolicy -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboxServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(InboxCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponse> retrieve(InboxRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(InboxListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(InboxDeleteParams params, RequestOptions requestOptions)
-
getAttachment
CompletableFuture<HttpResponse> getAttachment(InboxGetAttachmentParams params, RequestOptions requestOptions)
-
getMessage
CompletableFuture<HttpResponse> getMessage(InboxGetMessageParams params, RequestOptions requestOptions)
-
getPolicy
CompletableFuture<HttpResponse> getPolicy(InboxGetPolicyParams params, RequestOptions requestOptions)
-
listMessages
CompletableFuture<HttpResponse> listMessages(InboxListMessagesParams params, RequestOptions requestOptions)
-
reply
CompletableFuture<HttpResponse> reply(InboxReplyParams params, RequestOptions requestOptions)
-
send
CompletableFuture<HttpResponse> send(InboxSendParams params, RequestOptions requestOptions)
-
setPolicy
CompletableFuture<HttpResponse> setPolicy(InboxSetPolicyParams params, RequestOptions requestOptions)
-
-
-
-