Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsyncMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentTypeServiceAsyncagentTypes()Matter-native legal workspaces and orchestration primitives abstract PartyServiceAsyncparties()Matter-native legal workspaces and orchestration primitives abstract TypeServiceAsynctypes()Matter-native legal workspaces and orchestration primitives abstract EventServiceAsyncevents()abstract LogServiceAsynclog()Matter-native legal workspaces and orchestration primitives abstract MatterPartyServiceAsyncmatterParties()Matter-native legal workspaces and orchestration primitives abstract ShareServiceAsyncshares()Matter-native legal workspaces and orchestration primitives abstract WorkItemServiceAsyncworkItems()Matter-native legal workspaces and orchestration primitives CompletableFuture<Void>create(V1CreateParams params)Create a new legal matter and optionally link an existing primary vault. abstract CompletableFuture<Void>create(V1CreateParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(String id)Get a single matter by ID. CompletableFuture<Void>retrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(String id, V1RetrieveParams params)abstract CompletableFuture<Void>retrieve(V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(V1RetrieveParams params)CompletableFuture<Void>retrieve(String id, RequestOptions requestOptions)CompletableFuture<Void>update(String id)Update mutable matter fields. CompletableFuture<Void>update(String id, V1UpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(String id, V1UpdateParams params)abstract CompletableFuture<Void>update(V1UpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(V1UpdateParams params)CompletableFuture<Void>update(String id, RequestOptions requestOptions)CompletableFuture<Void>list()List matters for the authenticated organization. abstract CompletableFuture<Void>list(V1ListParams params, RequestOptions requestOptions)CompletableFuture<Void>list(V1ListParams params)CompletableFuture<Void>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agentTypes
abstract AgentTypeServiceAsync agentTypes()
Matter-native legal workspaces and orchestration primitives
-
parties
abstract PartyServiceAsync parties()
Matter-native legal workspaces and orchestration primitives
-
types
abstract TypeServiceAsync types()
Matter-native legal workspaces and orchestration primitives
-
events
abstract EventServiceAsync events()
-
log
abstract LogServiceAsync log()
Matter-native legal workspaces and orchestration primitives
-
matterParties
abstract MatterPartyServiceAsync matterParties()
Matter-native legal workspaces and orchestration primitives
-
shares
abstract ShareServiceAsync shares()
Matter-native legal workspaces and orchestration primitives
-
workItems
abstract WorkItemServiceAsync workItems()
Matter-native legal workspaces and orchestration primitives
-
create
CompletableFuture<Void> create(V1CreateParams params)
Create a new legal matter and optionally link an existing primary vault.
-
create
abstract CompletableFuture<Void> create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String id)
Get a single matter by ID.
-
retrieve
CompletableFuture<Void> retrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String id, V1RetrieveParams params)
-
retrieve
abstract CompletableFuture<Void> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(V1RetrieveParams params)
-
retrieve
CompletableFuture<Void> retrieve(String id, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String id)
Update mutable matter fields.
-
update
CompletableFuture<Void> update(String id, V1UpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String id, V1UpdateParams params)
-
update
abstract CompletableFuture<Void> update(V1UpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(V1UpdateParams params)
-
update
CompletableFuture<Void> update(String id, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list()
List matters for the authenticated organization.
-
list
abstract CompletableFuture<Void> list(V1ListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(V1ListParams params)
-
list
CompletableFuture<Void> list(RequestOptions requestOptions)
-
-
-
-