Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentTypeServiceAsyncagentTypes()Matter-native legal workspaces and orchestration primitives PartyServiceAsyncparties()Matter-native legal workspaces and orchestration primitives TypeServiceAsynctypes()Matter-native legal workspaces and orchestration primitives EventServiceAsyncevents()LogServiceAsynclog()Matter-native legal workspaces and orchestration primitives MatterPartyServiceAsyncmatterParties()Matter-native legal workspaces and orchestration primitives ShareServiceAsyncshares()Matter-native legal workspaces and orchestration primitives WorkItemServiceAsyncworkItems()Matter-native legal workspaces and orchestration primitives CompletableFuture<Void>create(V1CreateParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>update(V1UpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(V1ListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.V1ServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agentTypes
AgentTypeServiceAsync agentTypes()
Matter-native legal workspaces and orchestration primitives
-
parties
PartyServiceAsync parties()
Matter-native legal workspaces and orchestration primitives
-
types
TypeServiceAsync types()
Matter-native legal workspaces and orchestration primitives
-
events
EventServiceAsync events()
-
log
LogServiceAsync log()
Matter-native legal workspaces and orchestration primitives
-
matterParties
MatterPartyServiceAsync matterParties()
Matter-native legal workspaces and orchestration primitives
-
shares
ShareServiceAsync shares()
Matter-native legal workspaces and orchestration primitives
-
workItems
WorkItemServiceAsync workItems()
Matter-native legal workspaces and orchestration primitives
-
create
CompletableFuture<Void> create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(V1UpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(V1ListParams params, RequestOptions requestOptions)
-
-
-
-