Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentTypeServiceAsync.WithRawResponseagentTypes()Matter-native legal workspaces and orchestration primitives PartyServiceAsync.WithRawResponseparties()Matter-native legal workspaces and orchestration primitives TypeServiceAsync.WithRawResponsetypes()Matter-native legal workspaces and orchestration primitives EventServiceAsync.WithRawResponseevents()LogServiceAsync.WithRawResponselog()Matter-native legal workspaces and orchestration primitives MatterPartyServiceAsync.WithRawResponsematterParties()Matter-native legal workspaces and orchestration primitives ShareServiceAsync.WithRawResponseshares()Matter-native legal workspaces and orchestration primitives WorkItemServiceAsync.WithRawResponseworkItems()Matter-native legal workspaces and orchestration primitives CompletableFuture<HttpResponse>create(V1CreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>retrieve(V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>update(V1UpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>list(V1ListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.V1ServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agentTypes
AgentTypeServiceAsync.WithRawResponse agentTypes()
Matter-native legal workspaces and orchestration primitives
-
parties
PartyServiceAsync.WithRawResponse parties()
Matter-native legal workspaces and orchestration primitives
-
types
TypeServiceAsync.WithRawResponse types()
Matter-native legal workspaces and orchestration primitives
-
events
EventServiceAsync.WithRawResponse events()
-
log
LogServiceAsync.WithRawResponse log()
Matter-native legal workspaces and orchestration primitives
-
matterParties
MatterPartyServiceAsync.WithRawResponse matterParties()
Matter-native legal workspaces and orchestration primitives
-
shares
ShareServiceAsync.WithRawResponse shares()
Matter-native legal workspaces and orchestration primitives
-
workItems
WorkItemServiceAsync.WithRawResponse workItems()
Matter-native legal workspaces and orchestration primitives
-
create
CompletableFuture<HttpResponse> create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponse> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponse> update(V1UpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(V1ListParams params, RequestOptions requestOptions)
-
-
-
-