Interface LogServiceAsync
-
- All Implemented Interfaces:
public interface LogServiceAsyncMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLogServiceAsync.WithRawResponseA view of LogServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract LogServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract LogServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(String id, LogCreateParams params)
Append a manual operational note or event to a matter log.
-
create
CompletableFuture<Void> create(String id, LogCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Void> create(LogCreateParams params)
-
create
abstract CompletableFuture<Void> create(LogCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id)
List the operational history for a matter.
-
list
CompletableFuture<Void> list(String id, LogListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id, LogListParams params)
-
list
abstract CompletableFuture<Void> list(LogListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(LogListParams params)
-
list
CompletableFuture<Void> list(String id, RequestOptions requestOptions)
-
export
CompletableFuture<LogExportResponse> export(String id)
Bulk export matter log entries for audits, visibility, and eval pipelines. Supports json, csv, tsv, and jsonl. Limited to 10,000 entries per request.
-
export
CompletableFuture<LogExportResponse> export(String id, LogExportParams params, RequestOptions requestOptions)
-
export
CompletableFuture<LogExportResponse> export(String id, LogExportParams params)
-
export
abstract CompletableFuture<LogExportResponse> export(LogExportParams params, RequestOptions requestOptions)
-
export
CompletableFuture<LogExportResponse> export(LogExportParams params)
-
export
CompletableFuture<LogExportResponse> export(String id, RequestOptions requestOptions)
-
-
-
-