Class LogServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.v1.LogServiceAsync
public final class LogServiceAsyncImpl implements LogServiceAsync
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LogServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LogServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(LogCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(LogListParams params, RequestOptions requestOptions)CompletableFuture<LogExportResponse>export(LogExportParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.v1.LogServiceAsync
create, create, create, export, export, export, export, export, list, list, list, list, list -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
LogServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LogServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(LogCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(LogListParams params, RequestOptions requestOptions)
-
export
CompletableFuture<LogExportResponse> export(LogExportParams params, RequestOptions requestOptions)
-
-
-
-