Class LogServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.v1.LogServiceAsync.WithRawResponse
public final class LogServiceAsyncImpl.WithRawResponseImpl implements LogServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LogServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>create(LogCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>list(LogListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<LogExportResponse>>export(LogExportParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.v1.LogServiceAsync.WithRawResponse
create, create, create, export, export, export, export, export, list, list, list, list, list -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
LogServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(LogCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(LogListParams params, RequestOptions requestOptions)
-
export
CompletableFuture<HttpResponseFor<LogExportResponse>> export(LogExportParams params, RequestOptions requestOptions)
-
-
-
-