Interface MatterPartyServiceAsync
-
- All Implemented Interfaces:
public interface MatterPartyServiceAsyncMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMatterPartyServiceAsync.WithRawResponseA view of MatterPartyServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract MatterPartyServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MatterPartyServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(String id, MatterPartyCreateParams params)
Attach a reusable party to a matter with a matter-specific role.
-
create
CompletableFuture<Void> create(String id, MatterPartyCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Void> create(MatterPartyCreateParams params)
-
create
abstract CompletableFuture<Void> create(MatterPartyCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id)
List parties attached to a matter.
-
list
CompletableFuture<Void> list(String id, MatterPartyListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id, MatterPartyListParams params)
-
list
abstract CompletableFuture<Void> list(MatterPartyListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(MatterPartyListParams params)
-
list
CompletableFuture<Void> list(String id, RequestOptions requestOptions)
-
-
-
-