Interface PartyServiceAsync
-
- All Implemented Interfaces:
public interface PartyServiceAsyncMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePartyServiceAsync.WithRawResponseA view of PartyServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract PartyServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PartyServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(PartyCreateParams params)
Create a reusable legal party for the authenticated organization.
-
create
abstract CompletableFuture<Void> create(PartyCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String partyId)
Get a reusable legal party by ID.
-
retrieve
CompletableFuture<Void> retrieve(String partyId, PartyRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String partyId, PartyRetrieveParams params)
-
retrieve
abstract CompletableFuture<Void> retrieve(PartyRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(PartyRetrieveParams params)
-
retrieve
CompletableFuture<Void> retrieve(String partyId, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String partyId)
Update a reusable legal party.
-
update
CompletableFuture<Void> update(String partyId, PartyUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String partyId, PartyUpdateParams params)
-
update
abstract CompletableFuture<Void> update(PartyUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(PartyUpdateParams params)
-
update
CompletableFuture<Void> update(String partyId, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list()
List reusable legal parties for the authenticated organization.
-
list
abstract CompletableFuture<Void> list(PartyListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(PartyListParams params)
-
list
CompletableFuture<Void> list(RequestOptions requestOptions)
-
-
-
-