Class PartyServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.v1.PartyServiceAsync
public final class PartyServiceAsyncImpl implements PartyServiceAsync
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPartyServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PartyServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PartyServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(PartyCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(PartyRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>update(PartyUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(PartyListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.v1.PartyServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PartyServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PartyServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(PartyCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(PartyRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(PartyUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(PartyListParams params, RequestOptions requestOptions)
-
-
-
-