Class PartyServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.v1.PartyServiceAsync.WithRawResponse
public final class PartyServiceAsyncImpl.WithRawResponseImpl implements PartyServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PartyServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>create(PartyCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>retrieve(PartyRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>update(PartyUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>list(PartyListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.v1.PartyServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
PartyServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(PartyCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponse> retrieve(PartyRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponse> update(PartyUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(PartyListParams params, RequestOptions requestOptions)
-
-
-
-