Interface ShareServiceAsync
-
- All Implemented Interfaces:
public interface ShareServiceAsyncMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceShareServiceAsync.WithRawResponseA view of ShareServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ShareServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ShareServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(String id, ShareCreateParams params)
Grant another organization scoped access to this matter and its primary vault.
-
create
CompletableFuture<Void> create(String id, ShareCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Void> create(ShareCreateParams params)
-
create
abstract CompletableFuture<Void> create(ShareCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id)
List cross-org shares for a matter. Owner only.
-
list
CompletableFuture<Void> list(String id, ShareListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id, ShareListParams params)
-
list
abstract CompletableFuture<Void> list(ShareListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(ShareListParams params)
-
list
CompletableFuture<Void> list(String id, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String shareId, ShareDeleteParams params)
Revoke a matter share and its linked vault share.
-
delete
CompletableFuture<Void> delete(String shareId, ShareDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(ShareDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(ShareDeleteParams params, RequestOptions requestOptions)
-
-
-
-