Class ShareServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.v1.ShareServiceAsync
public final class ShareServiceAsyncImpl implements ShareServiceAsync
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classShareServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ShareServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ShareServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(ShareCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(ShareListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(ShareDeleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ShareServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ShareServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(ShareCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(ShareListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(ShareDeleteParams params, RequestOptions requestOptions)
-
-
-
-