Class ShareServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.v1.ShareServiceAsync.WithRawResponse
public final class ShareServiceAsyncImpl.WithRawResponseImpl implements ShareServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ShareServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>create(ShareCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>list(ShareListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>delete(ShareDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.v1.ShareServiceAsync.WithRawResponse
create, create, create, delete, delete, delete, list, list, list, list, list -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ShareServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(ShareCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(ShareListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(ShareDeleteParams params, RequestOptions requestOptions)
-
-
-
-