Interface WorkItemServiceAsync
-
- All Implemented Interfaces:
public interface WorkItemServiceAsyncMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWorkItemServiceAsync.WithRawResponseA view of WorkItemServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract WorkItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WorkItemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(String id, WorkItemCreateParams params)
Create an active work item on a matter.
-
create
CompletableFuture<Void> create(String id, WorkItemCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Void> create(WorkItemCreateParams params)
-
create
abstract CompletableFuture<Void> create(WorkItemCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String workItemId, WorkItemRetrieveParams params)
Get a single work item for a matter.
-
retrieve
CompletableFuture<Void> retrieve(String workItemId, WorkItemRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(WorkItemRetrieveParams params)
-
retrieve
abstract CompletableFuture<Void> retrieve(WorkItemRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String workItemId, WorkItemUpdateParams params)
Update a matter work item.
-
update
CompletableFuture<Void> update(String workItemId, WorkItemUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(WorkItemUpdateParams params)
-
update
abstract CompletableFuture<Void> update(WorkItemUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id)
List active work items for a matter.
-
list
CompletableFuture<Void> list(String id, WorkItemListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(String id, WorkItemListParams params)
-
list
abstract CompletableFuture<Void> list(WorkItemListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(WorkItemListParams params)
-
list
CompletableFuture<Void> list(String id, RequestOptions requestOptions)
-
decide
CompletableFuture<Void> decide(String workItemId, WorkItemDecideParams params)
Approve, revise, block, or reassign a work item. Used by humans or agents to move work items through their lifecycle.
-
decide
CompletableFuture<Void> decide(String workItemId, WorkItemDecideParams params, RequestOptions requestOptions)
-
decide
CompletableFuture<Void> decide(WorkItemDecideParams params)
-
decide
abstract CompletableFuture<Void> decide(WorkItemDecideParams params, RequestOptions requestOptions)
-
listExecutions
CompletableFuture<Void> listExecutions(String workItemId, WorkItemListExecutionsParams params)
List execution attempts for a work item, including agent and run linkage.
-
listExecutions
CompletableFuture<Void> listExecutions(String workItemId, WorkItemListExecutionsParams params, RequestOptions requestOptions)
-
listExecutions
CompletableFuture<Void> listExecutions(WorkItemListExecutionsParams params)
-
listExecutions
abstract CompletableFuture<Void> listExecutions(WorkItemListExecutionsParams params, RequestOptions requestOptions)
-
-
-
-