Class WorkItemServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.matters.v1.WorkItemServiceAsync
public final class WorkItemServiceAsyncImpl implements WorkItemServiceAsync
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WorkItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WorkItemServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(WorkItemCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(WorkItemRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>update(WorkItemUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(WorkItemListParams params, RequestOptions requestOptions)CompletableFuture<Void>decide(WorkItemDecideParams params, RequestOptions requestOptions)CompletableFuture<Void>listExecutions(WorkItemListExecutionsParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.matters.v1.WorkItemServiceAsync
create, create, create, decide, decide, decide, list, list, list, list, list, listExecutions, listExecutions, listExecutions, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
WorkItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WorkItemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(WorkItemCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(WorkItemRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(WorkItemUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(WorkItemListParams params, RequestOptions requestOptions)
-
decide
CompletableFuture<Void> decide(WorkItemDecideParams params, RequestOptions requestOptions)
-
listExecutions
CompletableFuture<Void> listExecutions(WorkItemListExecutionsParams params, RequestOptions requestOptions)
-
-
-
-