Package dev.case.api.services.async.ocr
Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.ocr.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
Extract text from PDFs, images, and scanned documents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<V1RetrieveResponse>retrieve(V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>download(V1DownloadParams params, RequestOptions requestOptions)CompletableFuture<V1ProcessResponse>process(V1ProcessParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.ocr.V1ServiceAsync
download, download, download, process, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<V1RetrieveResponse> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(V1DownloadParams params, RequestOptions requestOptions)
-
process
CompletableFuture<V1ProcessResponse> process(V1ProcessParams params, RequestOptions requestOptions)
-
-
-
-