Package dev.case.api.services.async.ocr
Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.ocr.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<V1RetrieveResponse>>retrieve(V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>download(V1DownloadParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1ProcessResponse>>process(V1ProcessParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.ocr.V1ServiceAsync.WithRawResponse
download, download, download, process, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<V1RetrieveResponse>> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(V1DownloadParams params, RequestOptions requestOptions)
-
process
CompletableFuture<HttpResponseFor<V1ProcessResponse>> process(V1ProcessParams params, RequestOptions requestOptions)
-
-
-
-