Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.operator.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(V1CreateParams params, RequestOptions requestOptions)CompletableFuture<Void>createChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)CompletableFuture<Void>createResponse(V1CreateResponseParams params, RequestOptions requestOptions)CompletableFuture<Void>getStatus(V1GetStatusParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.operator.V1ServiceAsync
create, createChatCompletion, createChatCompletion, createChatCompletion, createResponse, createResponse, createResponse, getStatus, getStatus, getStatus -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(V1CreateParams params, RequestOptions requestOptions)
-
createChatCompletion
CompletableFuture<Void> createChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)
-
createResponse
CompletableFuture<Void> createResponse(V1CreateResponseParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<Void> getStatus(V1GetStatusParams params, RequestOptions requestOptions)
-
-
-
-