Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.operator.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>create(V1CreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>createChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>createResponse(V1CreateResponseParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>getStatus(V1GetStatusParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.operator.V1ServiceAsync.WithRawResponse
create, createChatCompletion, createChatCompletion, createChatCompletion, createResponse, createResponse, createResponse, getStatus, getStatus, getStatus -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(V1CreateParams params, RequestOptions requestOptions)
-
createChatCompletion
CompletableFuture<HttpResponse> createChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)
-
createResponse
CompletableFuture<HttpResponse> createResponse(V1CreateResponseParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<HttpResponse> getStatus(V1GetStatusParams params, RequestOptions requestOptions)
-
-
-
-