Package dev.case.api.services.async
See: Description
-
Interface Summary Interface Description WithRawResponse A view of AgentServiceAsync that provides access to raw HTTP responses for each method. AgentServiceAsync WithRawResponse A view of ApplicationServiceAsync that provides access to raw HTTP responses for each method. ApplicationServiceAsync WithRawResponse A view of ComputeServiceAsync that provides access to raw HTTP responses for each method. ComputeServiceAsync WithRawResponse A view of DatabaseServiceAsync that provides access to raw HTTP responses for each method. DatabaseServiceAsync WithRawResponse A view of FormatServiceAsync that provides access to raw HTTP responses for each method. FormatServiceAsync WithRawResponse A view of LegalServiceAsync that provides access to raw HTTP responses for each method. LegalServiceAsync WithRawResponse A view of LlmServiceAsync that provides access to raw HTTP responses for each method. LlmServiceAsync Access 40+ language models through a unified API WithRawResponse A view of MemoryServiceAsync that provides access to raw HTTP responses for each method. MemoryServiceAsync WithRawResponse A view of OcrServiceAsync that provides access to raw HTTP responses for each method. OcrServiceAsync WithRawResponse A view of PrivilegeServiceAsync that provides access to raw HTTP responses for each method. PrivilegeServiceAsync WithRawResponse A view of SearchServiceAsync that provides access to raw HTTP responses for each method. SearchServiceAsync WithRawResponse A view of SkillServiceAsync that provides access to raw HTTP responses for each method. SkillServiceAsync Search and read legal AI skills for agents WithRawResponse A view of SuperdocServiceAsync that provides access to raw HTTP responses for each method. SuperdocServiceAsync WithRawResponse A view of SystemServiceAsync that provides access to raw HTTP responses for each method. SystemServiceAsync Public system metadata and discovery endpoints WithRawResponse A view of TranslateServiceAsync that provides access to raw HTTP responses for each method. TranslateServiceAsync WithRawResponse A view of VaultServiceAsync that provides access to raw HTTP responses for each method. VaultServiceAsync Secure document storage with semantic search and GraphRAG WithRawResponse A view of VoiceServiceAsync that provides access to raw HTTP responses for each method. VoiceServiceAsync -
Class Summary Class Description WithRawResponseImpl AgentServiceAsyncImpl WithRawResponseImpl ApplicationServiceAsyncImpl WithRawResponseImpl ComputeServiceAsyncImpl WithRawResponseImpl DatabaseServiceAsyncImpl WithRawResponseImpl FormatServiceAsyncImpl WithRawResponseImpl LegalServiceAsyncImpl WithRawResponseImpl LlmServiceAsyncImpl Access 40+ language models through a unified API WithRawResponseImpl MemoryServiceAsyncImpl WithRawResponseImpl OcrServiceAsyncImpl WithRawResponseImpl PrivilegeServiceAsyncImpl WithRawResponseImpl SearchServiceAsyncImpl WithRawResponseImpl SkillServiceAsyncImpl Search and read legal AI skills for agents WithRawResponseImpl SuperdocServiceAsyncImpl WithRawResponseImpl SystemServiceAsyncImpl Public system metadata and discovery endpoints WithRawResponseImpl TranslateServiceAsyncImpl WithRawResponseImpl VaultServiceAsyncImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl VoiceServiceAsyncImpl