Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<V1DetectResponse>>detect()Returns a raw HTTP response for post /privilege/v1/detect, but is otherwise the same as V1ServiceAsync.detect.abstract CompletableFuture<HttpResponseFor<V1DetectResponse>>detect(V1DetectParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1DetectResponse>>detect(V1DetectParams params)CompletableFuture<HttpResponseFor<V1DetectResponse>>detect(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
detect
CompletableFuture<HttpResponseFor<V1DetectResponse>> detect()
Returns a raw HTTP response for
post /privilege/v1/detect, but is otherwise the same as V1ServiceAsync.detect.
-
detect
abstract CompletableFuture<HttpResponseFor<V1DetectResponse>> detect(V1DetectParams params, RequestOptions requestOptions)
-
detect
CompletableFuture<HttpResponseFor<V1DetectResponse>> detect(V1DetectParams params)
-
detect
CompletableFuture<HttpResponseFor<V1DetectResponse>> detect(RequestOptions requestOptions)
-
-
-
-