Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.search.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
Web search, AI answers, and deep research
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<V1AnswerResponse>answer(V1AnswerParams params, RequestOptions requestOptions)CompletableFuture<V1ContentsResponse>contents(V1ContentsParams params, RequestOptions requestOptions)CompletableFuture<V1ResearchResponse>research(V1ResearchParams params, RequestOptions requestOptions)CompletableFuture<V1RetrieveResearchResponse>retrieveResearch(V1RetrieveResearchParams params, RequestOptions requestOptions)CompletableFuture<V1SearchResponse>search(V1SearchParams params, RequestOptions requestOptions)CompletableFuture<V1SimilarResponse>similar(V1SimilarParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.search.V1ServiceAsync
answer, contents, research, retrieveResearch, retrieveResearch, retrieveResearch, retrieveResearch, retrieveResearch, search, similar -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
answer
CompletableFuture<V1AnswerResponse> answer(V1AnswerParams params, RequestOptions requestOptions)
-
contents
CompletableFuture<V1ContentsResponse> contents(V1ContentsParams params, RequestOptions requestOptions)
-
research
CompletableFuture<V1ResearchResponse> research(V1ResearchParams params, RequestOptions requestOptions)
-
retrieveResearch
CompletableFuture<V1RetrieveResearchResponse> retrieveResearch(V1RetrieveResearchParams params, RequestOptions requestOptions)
-
search
CompletableFuture<V1SearchResponse> search(V1SearchParams params, RequestOptions requestOptions)
-
similar
CompletableFuture<V1SimilarResponse> similar(V1SimilarParams params, RequestOptions requestOptions)
-
-
-
-