Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.search.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<V1AnswerResponse>>answer(V1AnswerParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1ContentsResponse>>contents(V1ContentsParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1ResearchResponse>>research(V1ResearchParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1RetrieveResearchResponse>>retrieveResearch(V1RetrieveResearchParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1SearchResponse>>search(V1SearchParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1SimilarResponse>>similar(V1SimilarParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.search.V1ServiceAsync.WithRawResponse
answer, contents, research, retrieveResearch, retrieveResearch, retrieveResearch, retrieveResearch, retrieveResearch, search, similar -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
answer
CompletableFuture<HttpResponseFor<V1AnswerResponse>> answer(V1AnswerParams params, RequestOptions requestOptions)
-
contents
CompletableFuture<HttpResponseFor<V1ContentsResponse>> contents(V1ContentsParams params, RequestOptions requestOptions)
-
research
CompletableFuture<HttpResponseFor<V1ResearchResponse>> research(V1ResearchParams params, RequestOptions requestOptions)
-
retrieveResearch
CompletableFuture<HttpResponseFor<V1RetrieveResearchResponse>> retrieveResearch(V1RetrieveResearchParams params, RequestOptions requestOptions)
-
search
CompletableFuture<HttpResponseFor<V1SearchResponse>> search(V1SearchParams params, RequestOptions requestOptions)
-
similar
CompletableFuture<HttpResponseFor<V1SimilarResponse>> similar(V1SimilarParams params, RequestOptions requestOptions)
-
-
-
-