Interface CustomServiceAsync
-
- All Implemented Interfaces:
public interface CustomServiceAsyncSearch and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomServiceAsync.WithRawResponseA view of CustomServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CustomServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CustomServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CustomListResponse>list()List all custom skills for the authenticated organization. abstract CompletableFuture<CustomListResponse>list(CustomListParams params, RequestOptions requestOptions)CompletableFuture<CustomListResponse>list(CustomListParams params)CompletableFuture<CustomListResponse>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CustomServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CustomServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<CustomListResponse> list()
List all custom skills for the authenticated organization. Supports cursor-based pagination.
-
list
abstract CompletableFuture<CustomListResponse> list(CustomListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CustomListResponse> list(CustomListParams params)
-
list
CompletableFuture<CustomListResponse> list(RequestOptions requestOptions)
-
-
-
-