Interface CustomServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface CustomServiceAsync.WithRawResponseA view of CustomServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CustomServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CustomListResponse>>list()Returns a raw HTTP response for get /skills/custom, but is otherwise the same as CustomServiceAsync.list.abstract CompletableFuture<HttpResponseFor<CustomListResponse>>list(CustomListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CustomListResponse>>list(CustomListParams params)CompletableFuture<HttpResponseFor<CustomListResponse>>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CustomServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<CustomListResponse>> list()
Returns a raw HTTP response for
get /skills/custom, but is otherwise the same as CustomServiceAsync.list.
-
list
abstract CompletableFuture<HttpResponseFor<CustomListResponse>> list(CustomListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<CustomListResponse>> list(CustomListParams params)
-
list
CompletableFuture<HttpResponseFor<CustomListResponse>> list(RequestOptions requestOptions)
-
-
-
-