Class CustomServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.skills.CustomServiceAsync
public final class CustomServiceAsyncImpl implements CustomServiceAsync
Search and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CustomServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CustomServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CustomListResponse>list(CustomListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CustomServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CustomServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<CustomListResponse> list(CustomListParams params, RequestOptions requestOptions)
-
-
-
-