Class CustomServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.skills.CustomServiceAsync.WithRawResponse
public final class CustomServiceAsyncImpl.WithRawResponseImpl implements CustomServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CustomServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CustomListResponse>>list(CustomListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CustomServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<CustomListResponse>> list(CustomListParams params, RequestOptions requestOptions)
-
-
-
-