Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsyncDocument conversion and template automation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>annotate(V1AnnotateParams params)Populate fields inside a DOCX template using SuperDoc annotations. abstract CompletableFuture<HttpResponse>annotate(V1AnnotateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>convert(V1ConvertParams params)Convert documents between formats using SuperDoc. abstract CompletableFuture<HttpResponse>convert(V1ConvertParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
annotate
CompletableFuture<HttpResponse> annotate(V1AnnotateParams params)
Populate fields inside a DOCX template using SuperDoc annotations. Supports text, images, dates, and numbers. Can target individual fields by ID or multiple fields by group.
-
annotate
abstract CompletableFuture<HttpResponse> annotate(V1AnnotateParams params, RequestOptions requestOptions)
-
convert
CompletableFuture<HttpResponse> convert(V1ConvertParams params)
Convert documents between formats using SuperDoc. Supports DOCX to PDF, Markdown to DOCX, and HTML to DOCX conversions.
-
convert
abstract CompletableFuture<HttpResponse> convert(V1ConvertParams params, RequestOptions requestOptions)
-
-
-
-