Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>annotate(V1AnnotateParams params)Returns a raw HTTP response for post /superdoc/v1/annotate, but is otherwise the same as V1ServiceAsync.annotate.abstract CompletableFuture<HttpResponse>annotate(V1AnnotateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>convert(V1ConvertParams params)Returns a raw HTTP response for post /superdoc/v1/convert, but is otherwise the same as V1ServiceAsync.convert.abstract CompletableFuture<HttpResponse>convert(V1ConvertParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
annotate
CompletableFuture<HttpResponse> annotate(V1AnnotateParams params)
Returns a raw HTTP response for
post /superdoc/v1/annotate, but is otherwise the same as V1ServiceAsync.annotate.
-
annotate
abstract CompletableFuture<HttpResponse> annotate(V1AnnotateParams params, RequestOptions requestOptions)
-
convert
CompletableFuture<HttpResponse> convert(V1ConvertParams params)
Returns a raw HTTP response for
post /superdoc/v1/convert, but is otherwise the same as V1ServiceAsync.convert.
-
convert
abstract CompletableFuture<HttpResponse> convert(V1ConvertParams params, RequestOptions requestOptions)
-
-
-
-