Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.superdoc.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
Document conversion and template automation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>annotate(V1AnnotateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>convert(V1ConvertParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
annotate
CompletableFuture<HttpResponse> annotate(V1AnnotateParams params, RequestOptions requestOptions)
-
convert
CompletableFuture<HttpResponse> convert(V1ConvertParams params, RequestOptions requestOptions)
-
-
-
-