Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
detect
CompletableFuture<V1DetectResponse> detect(V1DetectParams params)
Detect the language of text. Returns the most likely language code and confidence score. Supports batch detection for multiple texts.
-
detect
abstract CompletableFuture<V1DetectResponse> detect(V1DetectParams params, RequestOptions requestOptions)
-
listLanguages
CompletableFuture<V1ListLanguagesResponse> listLanguages()
Get the list of languages supported for translation. Optionally specify a target language to get translated language names.
-
listLanguages
abstract CompletableFuture<V1ListLanguagesResponse> listLanguages(V1ListLanguagesParams params, RequestOptions requestOptions)
-
listLanguages
CompletableFuture<V1ListLanguagesResponse> listLanguages(V1ListLanguagesParams params)
-
listLanguages
CompletableFuture<V1ListLanguagesResponse> listLanguages(RequestOptions requestOptions)
-
translate
CompletableFuture<V1TranslateResponse> translate(V1TranslateParams params)
Translate text between languages using Google Cloud Translation API. Supports 100+ languages, automatic language detection, HTML preservation, and batch translation.
-
translate
abstract CompletableFuture<V1TranslateResponse> translate(V1TranslateParams params, RequestOptions requestOptions)
-
-
-
-