Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.translate.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<V1DetectResponse>>detect(V1DetectParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1ListLanguagesResponse>>listLanguages(V1ListLanguagesParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1TranslateResponse>>translate(V1TranslateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
detect
CompletableFuture<HttpResponseFor<V1DetectResponse>> detect(V1DetectParams params, RequestOptions requestOptions)
-
listLanguages
CompletableFuture<HttpResponseFor<V1ListLanguagesResponse>> listLanguages(V1ListLanguagesParams params, RequestOptions requestOptions)
-
translate
CompletableFuture<HttpResponseFor<V1TranslateResponse>> translate(V1TranslateParams params, RequestOptions requestOptions)
-
-
-
-