Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsyncUsage reporting and webhook subscriptions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SubscriptionServiceAsyncsubscriptions()Usage reporting and webhook subscriptions CompletableFuture<Void>retrieve()Returns customer-facing usage metrics and costs for the requested period. abstract CompletableFuture<Void>retrieve(V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(V1RetrieveParams params)CompletableFuture<Void>retrieve(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
abstract SubscriptionServiceAsync subscriptions()
Usage reporting and webhook subscriptions
-
retrieve
CompletableFuture<Void> retrieve()
Returns customer-facing usage metrics and costs for the requested period. Supports summary totals and daily buckets for timestamped usage sources. Vault storage is intentionally omitted from totals because it is not yet periodized for arbitrary windows.
-
retrieve
abstract CompletableFuture<Void> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(V1RetrieveParams params)
-
retrieve
CompletableFuture<Void> retrieve(RequestOptions requestOptions)
-
-
-
-