Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SubscriptionServiceAsync.WithRawResponsesubscriptions()Usage reporting and webhook subscriptions CompletableFuture<HttpResponse>retrieve()Returns a raw HTTP response for get /usage/v1, but is otherwise the same as V1ServiceAsync.retrieve.abstract CompletableFuture<HttpResponse>retrieve(V1RetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>retrieve(V1RetrieveParams params)CompletableFuture<HttpResponse>retrieve(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
abstract SubscriptionServiceAsync.WithRawResponse subscriptions()
Usage reporting and webhook subscriptions
-
retrieve
CompletableFuture<HttpResponse> retrieve()
Returns a raw HTTP response for
get /usage/v1, but is otherwise the same as V1ServiceAsync.retrieve.
-
retrieve
abstract CompletableFuture<HttpResponse> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponse> retrieve(V1RetrieveParams params)
-
retrieve
CompletableFuture<HttpResponse> retrieve(RequestOptions requestOptions)
-
-
-
-