Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.usage.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
Usage reporting and webhook subscriptions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SubscriptionServiceAsyncsubscriptions()Usage reporting and webhook subscriptions CompletableFuture<Void>retrieve(V1RetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
SubscriptionServiceAsync subscriptions()
Usage reporting and webhook subscriptions
-
retrieve
CompletableFuture<Void> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
-
-
-