Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.usage.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SubscriptionServiceAsync.WithRawResponsesubscriptions()Usage reporting and webhook subscriptions CompletableFuture<HttpResponse>retrieve(V1RetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
SubscriptionServiceAsync.WithRawResponse subscriptions()
Usage reporting and webhook subscriptions
-
retrieve
CompletableFuture<HttpResponse> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
-
-
-