Class SubscriptionServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.usage.v1.SubscriptionServiceAsync
public final class SubscriptionServiceAsyncImpl implements SubscriptionServiceAsync
Usage reporting and webhook subscriptions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SubscriptionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SubscriptionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(SubscriptionCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(SubscriptionUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(SubscriptionListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(SubscriptionDeleteParams params, RequestOptions requestOptions)CompletableFuture<Void>test(SubscriptionTestParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.usage.v1.SubscriptionServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, test, test, test, test, test, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SubscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SubscriptionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(SubscriptionCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(SubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(SubscriptionListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(SubscriptionDeleteParams params, RequestOptions requestOptions)
-
test
CompletableFuture<Void> test(SubscriptionTestParams params, RequestOptions requestOptions)
-
-
-
-