Class EventServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.EventServiceAsync
public final class EventServiceAsyncImpl implements EventServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SubscriptionServiceAsyncsubscriptions()Secure document storage with semantic search and GraphRAG -
-
Method Detail
-
withRawResponse
EventServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
SubscriptionServiceAsync subscriptions()
Secure document storage with semantic search and GraphRAG
-
-
-
-