Class EventServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.EventServiceAsync.WithRawResponse
public final class EventServiceAsyncImpl.WithRawResponseImpl implements EventServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SubscriptionServiceAsync.WithRawResponsesubscriptions()Secure document storage with semantic search and GraphRAG -
-
Method Detail
-
withOptions
EventServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
SubscriptionServiceAsync.WithRawResponse subscriptions()
Secure document storage with semantic search and GraphRAG
-
-
-
-