Class GraphragServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.GraphragServiceAsync
public final class GraphragServiceAsyncImpl implements GraphragServiceAsync
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description GraphragServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. GraphragServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<GraphragGetStatsResponse>getStats(GraphragGetStatsParams params, RequestOptions requestOptions)CompletableFuture<GraphragInitResponse>init(GraphragInitParams params, RequestOptions requestOptions)CompletableFuture<GraphragProcessObjectResponse>processObject(GraphragProcessObjectParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.vault.GraphragServiceAsync
getStats, getStats, getStats, getStats, getStats, init, init, init, init, init, processObject, processObject, processObject -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
GraphragServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
GraphragServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStats
CompletableFuture<GraphragGetStatsResponse> getStats(GraphragGetStatsParams params, RequestOptions requestOptions)
-
init
CompletableFuture<GraphragInitResponse> init(GraphragInitParams params, RequestOptions requestOptions)
-
processObject
CompletableFuture<GraphragProcessObjectResponse> processObject(GraphragProcessObjectParams params, RequestOptions requestOptions)
-
-
-
-