Class GraphragServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.GraphragServiceAsync.WithRawResponse
public final class GraphragServiceAsyncImpl.WithRawResponseImpl implements GraphragServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description GraphragServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<GraphragGetStatsResponse>>getStats(GraphragGetStatsParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<GraphragInitResponse>>init(GraphragInitParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<GraphragProcessObjectResponse>>processObject(GraphragProcessObjectParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.vault.GraphragServiceAsync.WithRawResponse
getStats, getStats, getStats, getStats, getStats, init, init, init, init, init, processObject, processObject, processObject -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
GraphragServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStats
CompletableFuture<HttpResponseFor<GraphragGetStatsResponse>> getStats(GraphragGetStatsParams params, RequestOptions requestOptions)
-
init
CompletableFuture<HttpResponseFor<GraphragInitResponse>> init(GraphragInitParams params, RequestOptions requestOptions)
-
processObject
CompletableFuture<HttpResponseFor<GraphragProcessObjectResponse>> processObject(GraphragProcessObjectParams params, RequestOptions requestOptions)
-
-
-
-