Interface GroupServiceAsync
-
- All Implemented Interfaces:
public interface GroupServiceAsyncSecure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceGroupServiceAsync.WithRawResponseA view of GroupServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract GroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract GroupServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(GroupCreateParams params)Creates a vault group for organizing vaults and applying group-scoped access controls. abstract CompletableFuture<Void>create(GroupCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(String groupId)Updates a vault group for the authenticated organization. CompletableFuture<Void>update(String groupId, GroupUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(String groupId, GroupUpdateParams params)abstract CompletableFuture<Void>update(GroupUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(GroupUpdateParams params)CompletableFuture<Void>update(String groupId, RequestOptions requestOptions)CompletableFuture<Void>list()Lists vault groups visible to the authenticated organization. abstract CompletableFuture<Void>list(GroupListParams params, RequestOptions requestOptions)CompletableFuture<Void>list(GroupListParams params)CompletableFuture<Void>list(RequestOptions requestOptions)CompletableFuture<Void>delete(String groupId)Soft-deletes a vault group that no longer has any active vaults assigned. CompletableFuture<Void>delete(String groupId, GroupDeleteParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(String groupId, GroupDeleteParams params)abstract CompletableFuture<Void>delete(GroupDeleteParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(GroupDeleteParams params)CompletableFuture<Void>delete(String groupId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract GroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract GroupServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(GroupCreateParams params)
Creates a vault group for organizing vaults and applying group-scoped access controls. Group-scoped API keys cannot create or manage vault groups.
-
create
abstract CompletableFuture<Void> create(GroupCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String groupId)
Updates a vault group for the authenticated organization. Only provided fields are changed, and setting description to null removes the current description.
-
update
CompletableFuture<Void> update(String groupId, GroupUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String groupId, GroupUpdateParams params)
-
update
abstract CompletableFuture<Void> update(GroupUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(GroupUpdateParams params)
-
update
CompletableFuture<Void> update(String groupId, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list()
Lists vault groups visible to the authenticated organization. Group-scoped API keys only receive groups within their allowed scope.
-
list
abstract CompletableFuture<Void> list(GroupListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(GroupListParams params)
-
list
CompletableFuture<Void> list(RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String groupId)
Soft-deletes a vault group that no longer has any active vaults assigned. This operation is blocked when the group still contains vaults.
-
delete
CompletableFuture<Void> delete(String groupId, GroupDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String groupId, GroupDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(GroupDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(GroupDeleteParams params)
-
delete
CompletableFuture<Void> delete(String groupId, RequestOptions requestOptions)
-
-
-
-