Class GroupServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.GroupServiceAsync
public final class GroupServiceAsyncImpl implements GroupServiceAsync
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroupServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description GroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. GroupServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(GroupCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(GroupUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(GroupListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(GroupDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.vault.GroupServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
GroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
GroupServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(GroupCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(GroupUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(GroupListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(GroupDeleteParams params, RequestOptions requestOptions)
-
-
-
-