Class GroupServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.GroupServiceAsync.WithRawResponse
public final class GroupServiceAsyncImpl.WithRawResponseImpl implements GroupServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description GroupServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>create(GroupCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>update(GroupUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>list(GroupListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>delete(GroupDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.vault.GroupServiceAsync.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
GroupServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(GroupCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponse> update(GroupUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(GroupListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(GroupDeleteParams params, RequestOptions requestOptions)
-
-
-
-