Interface MemoryServiceAsync
-
- All Implemented Interfaces:
public interface MemoryServiceAsyncSecure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMemoryServiceAsync.WithRawResponseA view of MemoryServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract MemoryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MemoryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<MemoryCreateResponse> create(String id, MemoryCreateParams params)
Append a new file-backed memory entry to a vault.
-
create
CompletableFuture<MemoryCreateResponse> create(String id, MemoryCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<MemoryCreateResponse> create(MemoryCreateParams params)
-
create
abstract CompletableFuture<MemoryCreateResponse> create(MemoryCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(String entryId, MemoryUpdateParams params)
Rewrite a file-backed vault memory entry with updated content, source, or tags.
-
update
CompletableFuture<Void> update(String entryId, MemoryUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(MemoryUpdateParams params)
-
update
abstract CompletableFuture<Void> update(MemoryUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<MemoryListResponse> list(String id)
Retrieve file-backed memory entries stored in a vault.
-
list
CompletableFuture<MemoryListResponse> list(String id, MemoryListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<MemoryListResponse> list(String id, MemoryListParams params)
-
list
abstract CompletableFuture<MemoryListResponse> list(MemoryListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<MemoryListResponse> list(MemoryListParams params)
-
list
CompletableFuture<MemoryListResponse> list(String id, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String entryId, MemoryDeleteParams params)
Remove a file-backed memory entry from a vault.
-
delete
CompletableFuture<Void> delete(String entryId, MemoryDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(MemoryDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(MemoryDeleteParams params, RequestOptions requestOptions)
-
search
CompletableFuture<MemorySearchResponse> search(String id, MemorySearchParams params)
Search file-backed vault memory using simple full-text matching over content and tags.
-
search
CompletableFuture<MemorySearchResponse> search(String id, MemorySearchParams params, RequestOptions requestOptions)
-
search
CompletableFuture<MemorySearchResponse> search(MemorySearchParams params)
-
search
abstract CompletableFuture<MemorySearchResponse> search(MemorySearchParams params, RequestOptions requestOptions)
-
-
-
-