Class MemoryServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.MemoryServiceAsync
public final class MemoryServiceAsyncImpl implements MemoryServiceAsync
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MemoryServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MemoryServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<MemoryCreateResponse>create(MemoryCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>update(MemoryUpdateParams params, RequestOptions requestOptions)CompletableFuture<MemoryListResponse>list(MemoryListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(MemoryDeleteParams params, RequestOptions requestOptions)CompletableFuture<MemorySearchResponse>search(MemorySearchParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.vault.MemoryServiceAsync
create, create, create, delete, delete, delete, list, list, list, list, list, search, search, search, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
MemoryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MemoryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<MemoryCreateResponse> create(MemoryCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(MemoryUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<MemoryListResponse> list(MemoryListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(MemoryDeleteParams params, RequestOptions requestOptions)
-
search
CompletableFuture<MemorySearchResponse> search(MemorySearchParams params, RequestOptions requestOptions)
-
-
-
-