Class MemoryServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.MemoryServiceAsync.WithRawResponse
public final class MemoryServiceAsyncImpl.WithRawResponseImpl implements MemoryServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MemoryServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<MemoryCreateResponse>>create(MemoryCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>update(MemoryUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<MemoryListResponse>>list(MemoryListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>delete(MemoryDeleteParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<MemorySearchResponse>>search(MemorySearchParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.vault.MemoryServiceAsync.WithRawResponse
create, create, create, delete, delete, delete, list, list, list, list, list, search, search, search, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
MemoryServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<MemoryCreateResponse>> create(MemoryCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponse> update(MemoryUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<MemoryListResponse>> list(MemoryListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(MemoryDeleteParams params, RequestOptions requestOptions)
-
search
CompletableFuture<HttpResponseFor<MemorySearchResponse>> search(MemorySearchParams params, RequestOptions requestOptions)
-
-
-
-