Class MultipartServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.MultipartServiceAsync
public final class MultipartServiceAsyncImpl implements MultipartServiceAsync
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMultipartServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MultipartServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MultipartServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>abort(MultipartAbortParams params, RequestOptions requestOptions)CompletableFuture<MultipartGetPartUrlsResponse>getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MultipartServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MultipartServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
abort
CompletableFuture<Void> abort(MultipartAbortParams params, RequestOptions requestOptions)
-
getPartUrls
CompletableFuture<MultipartGetPartUrlsResponse> getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)
-
-
-
-