Class MultipartServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.MultipartServiceAsync.WithRawResponse
public final class MultipartServiceAsyncImpl.WithRawResponseImpl implements MultipartServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MultipartServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>abort(MultipartAbortParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<MultipartGetPartUrlsResponse>>getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
MultipartServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
abort
CompletableFuture<HttpResponse> abort(MultipartAbortParams params, RequestOptions requestOptions)
-
getPartUrls
CompletableFuture<HttpResponseFor<MultipartGetPartUrlsResponse>> getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)
-
-
-
-