Class ObjectServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.ObjectServiceAsync.WithRawResponse
public final class ObjectServiceAsyncImpl.WithRawResponseImpl implements ObjectServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.vault.ObjectServiceAsync.WithRawResponse
createPresignedUrl, createPresignedUrl, createPresignedUrl, delete, delete, delete, download, download, download, getChunks, getChunks, getChunks, getOcrWords, getOcrWords, getOcrWords, getPages, getPages, getPages, getSummarizeJob, getSummarizeJob, getSummarizeJob, getText, getText, getText, list, list, list, list, list, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ObjectServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<ObjectRetrieveResponse>> retrieve(ObjectRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<ObjectUpdateResponse>> update(ObjectUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<ObjectListResponse>> list(ObjectListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponseFor<ObjectDeleteResponse>> delete(ObjectDeleteParams params, RequestOptions requestOptions)
-
createPresignedUrl
CompletableFuture<HttpResponseFor<ObjectCreatePresignedUrlResponse>> createPresignedUrl(ObjectCreatePresignedUrlParams params, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(ObjectDownloadParams params, RequestOptions requestOptions)
-
getChunks
CompletableFuture<HttpResponseFor<ObjectGetChunksResponse>> getChunks(ObjectGetChunksParams params, RequestOptions requestOptions)
-
getOcrWords
CompletableFuture<HttpResponseFor<ObjectGetOcrWordsResponse>> getOcrWords(ObjectGetOcrWordsParams params, RequestOptions requestOptions)
-
getPages
CompletableFuture<HttpResponseFor<ObjectGetPagesResponse>> getPages(ObjectGetPagesParams params, RequestOptions requestOptions)
-
getSummarizeJob
CompletableFuture<HttpResponseFor<ObjectGetSummarizeJobResponse>> getSummarizeJob(ObjectGetSummarizeJobParams params, RequestOptions requestOptions)
-
getText
CompletableFuture<HttpResponseFor<ObjectGetTextResponse>> getText(ObjectGetTextParams params, RequestOptions requestOptions)
-
-
-
-