Package dev.case.api.services.async.vault
See: Description
-
Interface Summary Interface Description WithRawResponse A view of EventServiceAsync that provides access to raw HTTP responses for each method. EventServiceAsync WithRawResponse A view of GraphragServiceAsync that provides access to raw HTTP responses for each method. GraphragServiceAsync Secure document storage with semantic search and GraphRAG WithRawResponse A view of GroupServiceAsync that provides access to raw HTTP responses for each method. GroupServiceAsync Secure document storage with semantic search and GraphRAG WithRawResponse A view of MemoryServiceAsync that provides access to raw HTTP responses for each method. MemoryServiceAsync Secure document storage with semantic search and GraphRAG WithRawResponse A view of MultipartServiceAsync that provides access to raw HTTP responses for each method. MultipartServiceAsync Secure document storage with semantic search and GraphRAG WithRawResponse A view of ObjectServiceAsync that provides access to raw HTTP responses for each method. ObjectServiceAsync Secure document storage with semantic search and GraphRAG -
Class Summary Class Description WithRawResponseImpl EventServiceAsyncImpl WithRawResponseImpl GraphragServiceAsyncImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl GroupServiceAsyncImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl MemoryServiceAsyncImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl MultipartServiceAsyncImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl ObjectServiceAsyncImpl Secure document storage with semantic search and GraphRAG