Interface BoostListServiceAsync
-
- All Implemented Interfaces:
public interface BoostListServiceAsyncAudio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBoostListServiceAsync.WithRawResponseA view of BoostListServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BoostListServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BoostListServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<BoostListExtractResponse>extract()Extracts a categorized word boost list from vault documents or raw text using LLM entity extraction. abstract CompletableFuture<BoostListExtractResponse>extract(BoostListExtractParams params, RequestOptions requestOptions)CompletableFuture<BoostListExtractResponse>extract(BoostListExtractParams params)CompletableFuture<BoostListExtractResponse>extract(RequestOptions requestOptions)CompletableFuture<BoostListGenerateResponse>generate(BoostListGenerateParams params)Generates a categorized word boost list from a completed transcription job. abstract CompletableFuture<BoostListGenerateResponse>generate(BoostListGenerateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BoostListServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BoostListServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extract
CompletableFuture<BoostListExtractResponse> extract()
Extracts a categorized word boost list from vault documents or raw text using LLM entity extraction. The resulting list can be passed as
word_boostto the transcription endpoint for improved accuracy.
-
extract
abstract CompletableFuture<BoostListExtractResponse> extract(BoostListExtractParams params, RequestOptions requestOptions)
-
extract
CompletableFuture<BoostListExtractResponse> extract(BoostListExtractParams params)
-
extract
CompletableFuture<BoostListExtractResponse> extract(RequestOptions requestOptions)
-
generate
CompletableFuture<BoostListGenerateResponse> generate(BoostListGenerateParams params)
Generates a categorized word boost list from a completed transcription job. Extracts entities from the pass-1 transcript for use as
word_boostin a second transcription pass.
-
generate
abstract CompletableFuture<BoostListGenerateResponse> generate(BoostListGenerateParams params, RequestOptions requestOptions)
-
-
-
-