Class BoostListServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.BoostListServiceAsync
public final class BoostListServiceAsyncImpl implements BoostListServiceAsync
Audio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBoostListServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BoostListServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BoostListServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<BoostListExtractResponse>extract(BoostListExtractParams params, RequestOptions requestOptions)CompletableFuture<BoostListGenerateResponse>generate(BoostListGenerateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BoostListServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BoostListServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extract
CompletableFuture<BoostListExtractResponse> extract(BoostListExtractParams params, RequestOptions requestOptions)
-
generate
CompletableFuture<BoostListGenerateResponse> generate(BoostListGenerateParams params, RequestOptions requestOptions)
-
-
-
-