Class BoostListServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.BoostListServiceAsync.WithRawResponse
public final class BoostListServiceAsyncImpl.WithRawResponseImpl implements BoostListServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BoostListServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<BoostListExtractResponse>>extract(BoostListExtractParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BoostListGenerateResponse>>generate(BoostListGenerateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
BoostListServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extract
CompletableFuture<HttpResponseFor<BoostListExtractResponse>> extract(BoostListExtractParams params, RequestOptions requestOptions)
-
generate
CompletableFuture<HttpResponseFor<BoostListGenerateResponse>> generate(BoostListGenerateParams params, RequestOptions requestOptions)
-
-
-
-