Interface StreamingServiceAsync
-
- All Implemented Interfaces:
public interface StreamingServiceAsyncAudio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceStreamingServiceAsync.WithRawResponseA view of StreamingServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract StreamingServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract StreamingServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<StreamingGetUrlResponse>getUrl()Returns the WebSocket URL and connection details for real-time audio transcription. abstract CompletableFuture<StreamingGetUrlResponse>getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)CompletableFuture<StreamingGetUrlResponse>getUrl(StreamingGetUrlParams params)CompletableFuture<StreamingGetUrlResponse>getUrl(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract StreamingServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract StreamingServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
CompletableFuture<StreamingGetUrlResponse> getUrl()
Returns the WebSocket URL and connection details for real-time audio transcription. The returned URL can be used to establish a WebSocket connection for streaming audio data and receiving transcribed text in real-time.
Audio Requirements:
Sample Rate: 16kHz
Encoding: PCM 16-bit little-endian
Channels: Mono (1 channel)
Pricing:
$0.01 per minute ($
0.60 per hour)
-
getUrl
abstract CompletableFuture<StreamingGetUrlResponse> getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
getUrl
CompletableFuture<StreamingGetUrlResponse> getUrl(StreamingGetUrlParams params)
-
getUrl
CompletableFuture<StreamingGetUrlResponse> getUrl(RequestOptions requestOptions)
-
-
-
-