Interface StreamingServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface StreamingServiceAsync.WithRawResponseA view of StreamingServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract StreamingServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>>getUrl()Returns a raw HTTP response for get /voice/streaming/url, but is otherwise the same as StreamingServiceAsync.getUrl.abstract CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>>getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>>getUrl(StreamingGetUrlParams params)CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>>getUrl(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract StreamingServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>> getUrl()
Returns a raw HTTP response for
get /voice/streaming/url, but is otherwise the same as StreamingServiceAsync.getUrl.
-
getUrl
abstract CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>> getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
getUrl
CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>> getUrl(StreamingGetUrlParams params)
-
getUrl
CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>> getUrl(RequestOptions requestOptions)
-
-
-
-