Class StreamingServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.StreamingServiceAsync
public final class StreamingServiceAsyncImpl implements StreamingServiceAsync
Audio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamingServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description StreamingServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. StreamingServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<StreamingGetUrlResponse>getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
StreamingServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
StreamingServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
CompletableFuture<StreamingGetUrlResponse> getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
-
-
-