Class StreamingServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.StreamingServiceAsync.WithRawResponse
public final class StreamingServiceAsyncImpl.WithRawResponseImpl implements StreamingServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description StreamingServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>>getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
StreamingServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
CompletableFuture<HttpResponseFor<StreamingGetUrlResponse>> getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
-
-
-