Class TranscriptionServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.TranscriptionServiceAsync
public final class TranscriptionServiceAsyncImpl implements TranscriptionServiceAsync
Audio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTranscriptionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TranscriptionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TranscriptionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<TranscriptionCreateResponse>create(TranscriptionCreateParams params, RequestOptions requestOptions)CompletableFuture<TranscriptionRetrieveResponse>retrieve(TranscriptionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(TranscriptionDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.voice.TranscriptionServiceAsync
create, create, create, delete, delete, delete, delete, delete, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
TranscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TranscriptionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<TranscriptionCreateResponse> create(TranscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<TranscriptionRetrieveResponse> retrieve(TranscriptionRetrieveParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(TranscriptionDeleteParams params, RequestOptions requestOptions)
-
-
-
-