Class TranscriptionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.TranscriptionServiceAsync.WithRawResponse
public final class TranscriptionServiceAsyncImpl.WithRawResponseImpl implements TranscriptionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description TranscriptionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<TranscriptionCreateResponse>>create(TranscriptionCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<TranscriptionRetrieveResponse>>retrieve(TranscriptionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>delete(TranscriptionDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.voice.TranscriptionServiceAsync.WithRawResponse
create, create, create, delete, delete, delete, delete, delete, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
TranscriptionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<TranscriptionCreateResponse>> create(TranscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<TranscriptionRetrieveResponse>> retrieve(TranscriptionRetrieveParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(TranscriptionDeleteParams params, RequestOptions requestOptions)
-
-
-
-