Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsyncAudio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SpeakServiceAsyncspeak()Audio transcription and text-to-speech CompletableFuture<V1ListVoicesResponse>listVoices()Retrieve a list of available voices for text-to-speech synthesis. abstract CompletableFuture<V1ListVoicesResponse>listVoices(V1ListVoicesParams params, RequestOptions requestOptions)CompletableFuture<V1ListVoicesResponse>listVoices(V1ListVoicesParams params)CompletableFuture<V1ListVoicesResponse>listVoices(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
speak
abstract SpeakServiceAsync speak()
Audio transcription and text-to-speech
-
listVoices
CompletableFuture<V1ListVoicesResponse> listVoices()
Retrieve a list of available voices for text-to-speech synthesis. This endpoint provides access to a comprehensive catalog of voices with various characteristics, languages, and styles suitable for legal document narration, client presentations, and accessibility purposes.
-
listVoices
abstract CompletableFuture<V1ListVoicesResponse> listVoices(V1ListVoicesParams params, RequestOptions requestOptions)
-
listVoices
CompletableFuture<V1ListVoicesResponse> listVoices(V1ListVoicesParams params)
-
listVoices
CompletableFuture<V1ListVoicesResponse> listVoices(RequestOptions requestOptions)
-
-
-
-