Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SpeakServiceAsync.WithRawResponsespeak()Audio transcription and text-to-speech CompletableFuture<HttpResponseFor<V1ListVoicesResponse>>listVoices()Returns a raw HTTP response for get /voice/v1/voices, but is otherwise the same as V1ServiceAsync.listVoices.abstract CompletableFuture<HttpResponseFor<V1ListVoicesResponse>>listVoices(V1ListVoicesParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<V1ListVoicesResponse>>listVoices(V1ListVoicesParams params)CompletableFuture<HttpResponseFor<V1ListVoicesResponse>>listVoices(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
speak
abstract SpeakServiceAsync.WithRawResponse speak()
Audio transcription and text-to-speech
-
listVoices
CompletableFuture<HttpResponseFor<V1ListVoicesResponse>> listVoices()
Returns a raw HTTP response for
get /voice/v1/voices, but is otherwise the same as V1ServiceAsync.listVoices.
-
listVoices
abstract CompletableFuture<HttpResponseFor<V1ListVoicesResponse>> listVoices(V1ListVoicesParams params, RequestOptions requestOptions)
-
listVoices
CompletableFuture<HttpResponseFor<V1ListVoicesResponse>> listVoices(V1ListVoicesParams params)
-
listVoices
CompletableFuture<HttpResponseFor<V1ListVoicesResponse>> listVoices(RequestOptions requestOptions)
-
-
-
-