Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SpeakServiceAsync.WithRawResponsespeak()Audio transcription and text-to-speech CompletableFuture<HttpResponseFor<V1ListVoicesResponse>>listVoices(V1ListVoicesParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
speak
SpeakServiceAsync.WithRawResponse speak()
Audio transcription and text-to-speech
-
listVoices
CompletableFuture<HttpResponseFor<V1ListVoicesResponse>> listVoices(V1ListVoicesParams params, RequestOptions requestOptions)
-
-
-
-