Class SpeakServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.voice.v1.SpeakServiceAsync
public final class SpeakServiceAsyncImpl implements SpeakServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSpeakServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SpeakServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SpeakServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>create(SpeakCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SpeakServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SpeakServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponse> create(SpeakCreateParams params, RequestOptions requestOptions)
-
-
-
-