Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract EndpointServiceAsync.WithRawResponseendpoints()Webhook endpoint management abstract DeliveryServiceAsync.WithRawResponsedeliveries()Webhook endpoint management abstract EventTypeServiceAsync.WithRawResponseeventTypes()Webhook endpoint management -
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
endpoints
abstract EndpointServiceAsync.WithRawResponse endpoints()
Webhook endpoint management
-
deliveries
abstract DeliveryServiceAsync.WithRawResponse deliveries()
Webhook endpoint management
-
eventTypes
abstract EventTypeServiceAsync.WithRawResponse eventTypes()
Webhook endpoint management
-
-
-
-