Class V1ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.webhooks.V1ServiceAsync
public final class V1ServiceAsyncImpl implements V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EndpointServiceAsyncendpoints()Webhook endpoint management DeliveryServiceAsyncdeliveries()Webhook endpoint management EventTypeServiceAsynceventTypes()Webhook endpoint management -
-
Method Detail
-
withRawResponse
V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
endpoints
EndpointServiceAsync endpoints()
Webhook endpoint management
-
deliveries
DeliveryServiceAsync deliveries()
Webhook endpoint management
-
eventTypes
EventTypeServiceAsync eventTypes()
Webhook endpoint management
-
-
-
-