Class V1ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.webhooks.V1ServiceAsync.WithRawResponse
public final class V1ServiceAsyncImpl.WithRawResponseImpl implements V1ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EndpointServiceAsync.WithRawResponseendpoints()Webhook endpoint management DeliveryServiceAsync.WithRawResponsedeliveries()Webhook endpoint management EventTypeServiceAsync.WithRawResponseeventTypes()Webhook endpoint management -
-
Method Detail
-
withOptions
V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
endpoints
EndpointServiceAsync.WithRawResponse endpoints()
Webhook endpoint management
-
deliveries
DeliveryServiceAsync.WithRawResponse deliveries()
Webhook endpoint management
-
eventTypes
EventTypeServiceAsync.WithRawResponse eventTypes()
Webhook endpoint management
-
-
-
-