Class DeliveryServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.webhooks.v1.DeliveryServiceAsync
public final class DeliveryServiceAsyncImpl implements DeliveryServiceAsync
Webhook endpoint management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeliveryServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DeliveryServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DeliveryServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>retrieve(DeliveryRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>list(DeliveryListParams params, RequestOptions requestOptions)CompletableFuture<Void>replay(DeliveryReplayParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.webhooks.v1.DeliveryServiceAsync
list, list, list, replay, replay, replay, replay, replay, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DeliveryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DeliveryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<Void> retrieve(DeliveryRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(DeliveryListParams params, RequestOptions requestOptions)
-
replay
CompletableFuture<Void> replay(DeliveryReplayParams params, RequestOptions requestOptions)
-
-
-
-