Class DeliveryServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.webhooks.v1.DeliveryServiceAsync.WithRawResponse
public final class DeliveryServiceAsyncImpl.WithRawResponseImpl implements DeliveryServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DeliveryServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>retrieve(DeliveryRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>list(DeliveryListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>replay(DeliveryReplayParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.webhooks.v1.DeliveryServiceAsync.WithRawResponse
list, list, list, replay, replay, replay, replay, replay, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DeliveryServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponse> retrieve(DeliveryRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponse> list(DeliveryListParams params, RequestOptions requestOptions)
-
replay
CompletableFuture<HttpResponse> replay(DeliveryReplayParams params, RequestOptions requestOptions)
-
-
-
-