Class EndpointServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.webhooks.v1.EndpointServiceAsync
public final class EndpointServiceAsyncImpl implements EndpointServiceAsync
Webhook endpoint management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EndpointServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EndpointServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>create(EndpointCreateParams params, RequestOptions requestOptions)CompletableFuture<Void>retrieve(EndpointRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Void>update(EndpointUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>list(EndpointListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(EndpointDeleteParams params, RequestOptions requestOptions)CompletableFuture<Void>rotateSecret(EndpointRotateSecretParams params, RequestOptions requestOptions)CompletableFuture<Void>test(EndpointTestParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.async.webhooks.v1.EndpointServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, rotateSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, test, test, test, test, test, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EndpointServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EndpointServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(EndpointCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(EndpointRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Void> update(EndpointUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(EndpointListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(EndpointDeleteParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<Void> rotateSecret(EndpointRotateSecretParams params, RequestOptions requestOptions)
-
test
CompletableFuture<Void> test(EndpointTestParams params, RequestOptions requestOptions)
-
-
-
-