Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create()
Creates a Daytona-backed worker runtime. The worker exposes its native runtime API through /worker/v1/:id/* without reshaping payloads or events.
-
create
abstract CompletableFuture<Void> create(V1CreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Void> create(V1CreateParams params)
-
create
CompletableFuture<Void> create(RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String id)
Get worker
-
retrieve
CompletableFuture<Void> retrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String id, V1RetrieveParams params)
-
retrieve
abstract CompletableFuture<Void> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(V1RetrieveParams params)
-
retrieve
CompletableFuture<Void> retrieve(String id, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id)
End worker
-
delete
CompletableFuture<Void> delete(String id, V1DeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id, V1DeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(V1DeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(V1DeleteParams params)
-
delete
CompletableFuture<Void> delete(String id, RequestOptions requestOptions)
-
boot
CompletableFuture<Void> boot(String id)
Starts or resumes the worker sandbox and OpenCode server. Native /worker/v1/:id/* proxy routes require this lifecycle primitive to have completed first.
-
boot
CompletableFuture<Void> boot(String id, V1BootParams params, RequestOptions requestOptions)
-
boot
CompletableFuture<Void> boot(String id, V1BootParams params)
-
boot
abstract CompletableFuture<Void> boot(V1BootParams params, RequestOptions requestOptions)
-
boot
CompletableFuture<Void> boot(V1BootParams params)
-
boot
CompletableFuture<Void> boot(String id, RequestOptions requestOptions)
-
proxyDelete
CompletableFuture<Void> proxyDelete(String workerPath, V1ProxyDeleteParams params)
Forwards a DELETE request to the worker runtime without translating response shapes.
-
proxyDelete
CompletableFuture<Void> proxyDelete(String workerPath, V1ProxyDeleteParams params, RequestOptions requestOptions)
-
proxyDelete
CompletableFuture<Void> proxyDelete(V1ProxyDeleteParams params)
-
proxyDelete
abstract CompletableFuture<Void> proxyDelete(V1ProxyDeleteParams params, RequestOptions requestOptions)
-
proxyGet
CompletableFuture<Void> proxyGet(String workerPath, V1ProxyGetParams params)
Forwards a GET request to the worker runtime without translating response or SSE event shapes.
-
proxyGet
CompletableFuture<Void> proxyGet(String workerPath, V1ProxyGetParams params, RequestOptions requestOptions)
-
proxyGet
CompletableFuture<Void> proxyGet(V1ProxyGetParams params)
-
proxyGet
abstract CompletableFuture<Void> proxyGet(V1ProxyGetParams params, RequestOptions requestOptions)
-
proxyPatch
CompletableFuture<Void> proxyPatch(String workerPath, V1ProxyPatchParams params)
Forwards a PATCH request to the worker runtime without translating request or response shapes.
-
proxyPatch
CompletableFuture<Void> proxyPatch(String workerPath, V1ProxyPatchParams params, RequestOptions requestOptions)
-
proxyPatch
CompletableFuture<Void> proxyPatch(V1ProxyPatchParams params)
-
proxyPatch
abstract CompletableFuture<Void> proxyPatch(V1ProxyPatchParams params, RequestOptions requestOptions)
-
proxyPost
CompletableFuture<Void> proxyPost(String workerPath, V1ProxyPostParams params)
Forwards a POST request to the worker runtime without translating request, response, or SSE event shapes.
-
proxyPost
CompletableFuture<Void> proxyPost(String workerPath, V1ProxyPostParams params, RequestOptions requestOptions)
-
proxyPost
CompletableFuture<Void> proxyPost(V1ProxyPostParams params)
-
proxyPost
abstract CompletableFuture<Void> proxyPost(V1ProxyPostParams params, RequestOptions requestOptions)
-
proxyPut
CompletableFuture<Void> proxyPut(String workerPath, V1ProxyPutParams params)
Forwards a PUT request to the worker runtime without translating request or response shapes.
-
proxyPut
CompletableFuture<Void> proxyPut(String workerPath, V1ProxyPutParams params, RequestOptions requestOptions)
-
proxyPut
CompletableFuture<Void> proxyPut(V1ProxyPutParams params)
-
proxyPut
abstract CompletableFuture<Void> proxyPut(V1ProxyPutParams params, RequestOptions requestOptions)
-
-
-
-