Package dev.case.api.services.blocking
Interface AgentService
-
- All Implemented Interfaces:
public interface AgentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAgentService.WithRawResponseA view of AgentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AgentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AgentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SkillServiceskills()abstract V1Servicev1()-
-
Method Detail
-
withRawResponse
abstract AgentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AgentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
skills
abstract SkillService skills()
-
-
-
-