Package dev.case.api.services.blocking
Interface AgentService.WithRawResponse
-
- All Implemented Interfaces:
public interface AgentService.WithRawResponseA view of AgentService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AgentService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
abstract AgentService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
-
-
-
-