Package dev.case.api.services.blocking
Class AgentServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.AgentService
public final class AgentServiceImpl implements AgentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AgentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AgentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()V2Servicev2()-
-
Method Detail
-
withRawResponse
AgentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AgentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-