Package dev.case.api.services.blocking
Interface ApplicationService
-
- All Implemented Interfaces:
public interface ApplicationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceApplicationService.WithRawResponseA view of ApplicationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ApplicationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ApplicationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()-
-
Method Detail
-
withRawResponse
abstract ApplicationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ApplicationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-