Package dev.case.api.services.blocking
Class ApplicationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.ApplicationService.WithRawResponse
public final class ApplicationServiceImpl.WithRawResponseImpl implements ApplicationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ApplicationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
ApplicationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-