Package dev.case.api.services.blocking
Interface ComputeService
-
- All Implemented Interfaces:
public interface ComputeService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceComputeService.WithRawResponseA view of ComputeService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ComputeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ComputeServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Serverless GPU and CPU infrastructure -
-
Method Detail
-
withRawResponse
abstract ComputeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ComputeService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-