Package dev.case.api.services.blocking
Class ComputeServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.ComputeService.WithRawResponse
public final class ComputeServiceImpl.WithRawResponseImpl implements ComputeService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ComputeService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()Serverless GPU and CPU infrastructure -
-
Method Detail
-
withOptions
ComputeService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1Service.WithRawResponse v1()
Serverless GPU and CPU infrastructure
-
-
-
-