Package dev.case.api.services.blocking
Interface DatabaseService.WithRawResponse
-
- All Implemented Interfaces:
public interface DatabaseService.WithRawResponseA view of DatabaseService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract DatabaseService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()Serverless PostgreSQL databases with instant branching -
-
Method Detail
-
withOptions
abstract DatabaseService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
Serverless PostgreSQL databases with instant branching
-
-
-
-