Package dev.case.api.services.blocking
Interface FormatService
-
- All Implemented Interfaces:
public interface FormatService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFormatService.WithRawResponseA view of FormatService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FormatService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FormatServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Document formatting and template rendering (MD/JSON to PDF/DOCX) -
-
Method Detail
-
withRawResponse
abstract FormatService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FormatService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-