Package dev.case.api.services.blocking
Interface FormatService.WithRawResponse
-
- All Implemented Interfaces:
public interface FormatService.WithRawResponseA view of FormatService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract FormatService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()Document formatting and template rendering (MD/JSON to PDF/DOCX) -
-
Method Detail
-
withOptions
abstract FormatService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
Document formatting and template rendering (MD/JSON to PDF/DOCX)
-
-
-
-