Package dev.case.api.services.blocking
Class FormatServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.FormatService
public final class FormatServiceImpl implements FormatService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFormatServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FormatService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FormatServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()Document formatting and template rendering (MD/JSON to PDF/DOCX) -
-
Method Detail
-
withRawResponse
FormatService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FormatService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-