Package dev.case.api.services.blocking
Class FormatServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.FormatService.WithRawResponse
public final class FormatServiceImpl.WithRawResponseImpl implements FormatService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FormatService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()Document formatting and template rendering (MD/JSON to PDF/DOCX) -
-
Method Detail
-
withOptions
FormatService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1Service.WithRawResponse v1()
Document formatting and template rendering (MD/JSON to PDF/DOCX)
-
-
-
-