Package dev.case.api.services.blocking
Interface LegalService.WithRawResponse
-
- All Implemented Interfaces:
public interface LegalService.WithRawResponseA view of LegalService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract LegalService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()Legal research tools including citation verification -
-
Method Detail
-
withOptions
abstract LegalService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
Legal research tools including citation verification
-
-
-
-