Package dev.case.api.services.blocking
Class LegalServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.LegalService.WithRawResponse
public final class LegalServiceImpl.WithRawResponseImpl implements LegalService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LegalService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
LegalService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-