Package dev.case.api.services.blocking
Interface LlmService.WithRawResponse
-
- All Implemented Interfaces:
public interface LlmService.WithRawResponseA view of LlmService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract LlmService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()Access 40+ language models through a unified API HttpResponseFor<LlmGetConfigResponse>getConfig()Returns a raw HTTP response for get /llm/config, but is otherwise the same as LlmService.getConfig.abstract HttpResponseFor<LlmGetConfigResponse>getConfig(LlmGetConfigParams params, RequestOptions requestOptions)HttpResponseFor<LlmGetConfigResponse>getConfig(LlmGetConfigParams params)HttpResponseFor<LlmGetConfigResponse>getConfig(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract LlmService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
Access 40+ language models through a unified API
-
getConfig
@MustBeClosed() HttpResponseFor<LlmGetConfigResponse> getConfig()
Returns a raw HTTP response for
get /llm/config, but is otherwise the same as LlmService.getConfig.
-
getConfig
@MustBeClosed() abstract HttpResponseFor<LlmGetConfigResponse> getConfig(LlmGetConfigParams params, RequestOptions requestOptions)
-
getConfig
@MustBeClosed() HttpResponseFor<LlmGetConfigResponse> getConfig(LlmGetConfigParams params)
-
getConfig
@MustBeClosed() HttpResponseFor<LlmGetConfigResponse> getConfig(RequestOptions requestOptions)
-
-
-
-