Package dev.case.api.services.blocking
Class LlmServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.LlmService
public final class LlmServiceImpl implements LlmService
Access 40+ language models through a unified API
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLlmServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LlmService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LlmServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()Access 40+ language models through a unified API LlmGetConfigResponsegetConfig(LlmGetConfigParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
LlmService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LlmService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getConfig
LlmGetConfigResponse getConfig(LlmGetConfigParams params, RequestOptions requestOptions)
-
-
-
-