Package dev.case.api.services.blocking
Class LlmServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.LlmService.WithRawResponse
public final class LlmServiceImpl.WithRawResponseImpl implements LlmService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LlmService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()Access 40+ language models through a unified API HttpResponseFor<LlmGetConfigResponse>getConfig(LlmGetConfigParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
LlmService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1Service.WithRawResponse v1()
Access 40+ language models through a unified API
-
getConfig
HttpResponseFor<LlmGetConfigResponse> getConfig(LlmGetConfigParams params, RequestOptions requestOptions)
-
-
-
-