Package dev.case.api.services.blocking
Interface MailService
-
- All Implemented Interfaces:
public interface MailService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMailService.WithRawResponseA view of MailService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MailService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MailServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()-
-
Method Detail
-
withRawResponse
abstract MailService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MailService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-