Package dev.case.api.services.blocking
Class MailServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.MailService
public final class MailServiceImpl implements MailService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMailServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MailService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MailServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()-
-
Method Detail
-
withRawResponse
MailService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MailService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-