Package dev.case.api.services.blocking
Class MailServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.MailService.WithRawResponse
public final class MailServiceImpl.WithRawResponseImpl implements MailService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MailService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
MailService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-