Package dev.case.api.services.blocking
Interface MatterService
-
- All Implemented Interfaces:
public interface MatterService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMatterService.WithRawResponseA view of MatterService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MatterService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MatterServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Matter-native legal workspaces and orchestration primitives -
-
Method Detail
-
withRawResponse
abstract MatterService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MatterService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-