Package dev.case.api.services.blocking
Class MatterServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.MatterService
public final class MatterServiceImpl implements MatterService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMatterServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MatterService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MatterServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()Matter-native legal workspaces and orchestration primitives -
-
Method Detail
-
withRawResponse
MatterService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MatterService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-