Package dev.case.api.services.blocking
Interface MemoryService
-
- All Implemented Interfaces:
public interface MemoryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMemoryService.WithRawResponseA view of MemoryService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MemoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MemoryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Persistent memory for AI agents with semantic search and 12 generic indexed tag fields -
-
Method Detail
-
withRawResponse
abstract MemoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MemoryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-