Package dev.case.api.services.blocking
Interface MemoryService.WithRawResponse
-
- All Implemented Interfaces:
public interface MemoryService.WithRawResponseA view of MemoryService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract MemoryService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()Persistent memory for AI agents with semantic search and 12 generic indexed tag fields -
-
Method Detail
-
withOptions
abstract MemoryService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
Persistent memory for AI agents with semantic search and 12 generic indexed tag fields
-
-
-
-