Package dev.case.api.services.blocking
Class MemoryServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.MemoryService
public final class MemoryServiceImpl implements MemoryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MemoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MemoryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()Persistent memory for AI agents with semantic search and 12 generic indexed tag fields -
-
Method Detail
-
withRawResponse
MemoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MemoryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-