Package dev.case.api.services.blocking
Interface OcrService
-
- All Implemented Interfaces:
public interface OcrService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOcrService.WithRawResponseA view of OcrService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OcrService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract OcrServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Extract text from PDFs, images, and scanned documents -
-
Method Detail
-
withRawResponse
abstract OcrService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract OcrService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-