Class OcrServiceImpl

  • All Implemented Interfaces:
    dev.case.api.services.blocking.OcrService

    
    public final class OcrServiceImpl
     implements OcrService
                        
    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Method Summary

      Modifier and Type Method Description
      OcrService.WithRawResponse withRawResponse() Returns a view of this service that provides access to raw HTTP responses for each method.
      OcrService withOptions(Consumer<ClientOptions.Builder> modifier) Returns a view of this service with the given option modifications applied.
      V1Service v1() Extract text from PDFs, images, and scanned documents
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait