Package dev.case.api.services.blocking
Class OcrServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.OcrService.WithRawResponse
public final class OcrServiceImpl.WithRawResponseImpl implements OcrService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OcrService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()Extract text from PDFs, images, and scanned documents -
-
Method Detail
-
withOptions
OcrService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1Service.WithRawResponse v1()
Extract text from PDFs, images, and scanned documents
-
-
-
-