Package dev.case.api.services.blocking
Interface PrivilegeService
-
- All Implemented Interfaces:
public interface PrivilegeService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePrivilegeService.WithRawResponseA view of PrivilegeService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PrivilegeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PrivilegeServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Privilege detection for e-discovery and litigation workflows -
-
Method Detail
-
withRawResponse
abstract PrivilegeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PrivilegeService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-