Package dev.case.api.services.blocking
Interface PrivilegeService.WithRawResponse
-
- All Implemented Interfaces:
public interface PrivilegeService.WithRawResponseA view of PrivilegeService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract PrivilegeService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()Privilege detection for e-discovery and litigation workflows -
-
Method Detail
-
withOptions
abstract PrivilegeService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
Privilege detection for e-discovery and litigation workflows
-
-
-
-