Package dev.case.api.services.blocking
Class PrivilegeServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.PrivilegeService
public final class PrivilegeServiceImpl implements PrivilegeService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPrivilegeServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PrivilegeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PrivilegeServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()Privilege detection for e-discovery and litigation workflows -
-
Method Detail
-
withRawResponse
PrivilegeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PrivilegeService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-