Package dev.case.api.services.blocking
Class PrivilegeServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.PrivilegeService.WithRawResponse
public final class PrivilegeServiceImpl.WithRawResponseImpl implements PrivilegeService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PrivilegeService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()Privilege detection for e-discovery and litigation workflows -
-
Method Detail
-
withOptions
PrivilegeService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1Service.WithRawResponse v1()
Privilege detection for e-discovery and litigation workflows
-
-
-
-