Package dev.case.api.services.blocking
Interface SearchService
-
- All Implemented Interfaces:
public interface SearchService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSearchService.WithRawResponseA view of SearchService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SearchService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SearchServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Web search, AI answers, and deep research -
-
Method Detail
-
withRawResponse
abstract SearchService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SearchService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-