Package dev.case.api.services.blocking
Class SearchServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SearchService.WithRawResponse
public final class SearchServiceImpl.WithRawResponseImpl implements SearchService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SearchService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()Web search, AI answers, and deep research -
-
Method Detail
-
withOptions
SearchService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1Service.WithRawResponse v1()
Web search, AI answers, and deep research
-
-
-
-