Package dev.case.api.services.blocking
Class SkillServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SkillService
public final class SkillServiceImpl implements SkillService
Search and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SkillService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SkillServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomServicecustom()Search and read legal AI skills for agents SkillCreateResponsecreate(SkillCreateParams params, RequestOptions requestOptions)SkillUpdateResponseupdate(SkillUpdateParams params, RequestOptions requestOptions)SkillDeleteResponsedelete(SkillDeleteParams params, RequestOptions requestOptions)SkillReadResponseread(SkillReadParams params, RequestOptions requestOptions)SkillResolveResponseresolve(SkillResolveParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.SkillService
create, delete, delete, delete, delete, delete, read, read, read, read, read, resolve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SkillService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SkillService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
custom
CustomService custom()
Search and read legal AI skills for agents
-
create
SkillCreateResponse create(SkillCreateParams params, RequestOptions requestOptions)
-
update
SkillUpdateResponse update(SkillUpdateParams params, RequestOptions requestOptions)
-
delete
SkillDeleteResponse delete(SkillDeleteParams params, RequestOptions requestOptions)
-
read
SkillReadResponse read(SkillReadParams params, RequestOptions requestOptions)
-
resolve
SkillResolveResponse resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-