Package dev.case.api.services.blocking
Class SkillServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SkillService.WithRawResponse
public final class SkillServiceImpl.WithRawResponseImpl implements SkillService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SkillService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomService.WithRawResponsecustom()Search and read legal AI skills for agents HttpResponseFor<SkillCreateResponse>create(SkillCreateParams params, RequestOptions requestOptions)HttpResponseFor<SkillUpdateResponse>update(SkillUpdateParams params, RequestOptions requestOptions)HttpResponseFor<SkillDeleteResponse>delete(SkillDeleteParams params, RequestOptions requestOptions)HttpResponseFor<SkillReadResponse>read(SkillReadParams params, RequestOptions requestOptions)HttpResponseFor<SkillResolveResponse>resolve(SkillResolveParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.SkillService.WithRawResponse
create, delete, delete, delete, delete, delete, read, read, read, read, read, resolve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
SkillService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
custom
CustomService.WithRawResponse custom()
Search and read legal AI skills for agents
-
create
HttpResponseFor<SkillCreateResponse> create(SkillCreateParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<SkillUpdateResponse> update(SkillUpdateParams params, RequestOptions requestOptions)
-
delete
HttpResponseFor<SkillDeleteResponse> delete(SkillDeleteParams params, RequestOptions requestOptions)
-
read
HttpResponseFor<SkillReadResponse> read(SkillReadParams params, RequestOptions requestOptions)
-
resolve
HttpResponseFor<SkillResolveResponse> resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-