Package dev.case.api.services.blocking
Interface SuperdocService.WithRawResponse
-
- All Implemented Interfaces:
public interface SuperdocService.WithRawResponseA view of SuperdocService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SuperdocService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Service.WithRawResponsev1()Document conversion and template automation -
-
Method Detail
-
withOptions
abstract SuperdocService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
abstract V1Service.WithRawResponse v1()
Document conversion and template automation
-
-
-
-