Package dev.case.api.services.blocking
Class SuperdocServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SuperdocService.WithRawResponse
public final class SuperdocServiceImpl.WithRawResponseImpl implements SuperdocService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SuperdocService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
SuperdocService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-