Package dev.case.api.services.blocking
Interface SystemService
-
- All Implemented Interfaces:
public interface SystemServicePublic system metadata and discovery endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSystemService.WithRawResponseA view of SystemService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SystemService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SystemServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SystemListServicesResponselistServices()Returns the public Case.dev services catalog derived from docs.case.dev/services. abstract SystemListServicesResponselistServices(SystemListServicesParams params, RequestOptions requestOptions)SystemListServicesResponselistServices(SystemListServicesParams params)SystemListServicesResponselistServices(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SystemService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SystemService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
SystemListServicesResponse listServices()
Returns the public Case.dev services catalog derived from docs.case.dev/services. This endpoint is unauthenticated and intended for discovery surfaces such as the case.dev homepage.
-
listServices
abstract SystemListServicesResponse listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
listServices
SystemListServicesResponse listServices(SystemListServicesParams params)
-
listServices
SystemListServicesResponse listServices(RequestOptions requestOptions)
-
-
-
-