Package dev.case.api.services.blocking
Interface SystemService.WithRawResponse
-
- All Implemented Interfaces:
public interface SystemService.WithRawResponseA view of SystemService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SystemService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<SystemListServicesResponse>listServices()Returns a raw HTTP response for get /services, but is otherwise the same as SystemService.listServices.abstract HttpResponseFor<SystemListServicesResponse>listServices(SystemListServicesParams params, RequestOptions requestOptions)HttpResponseFor<SystemListServicesResponse>listServices(SystemListServicesParams params)HttpResponseFor<SystemListServicesResponse>listServices(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract SystemService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
@MustBeClosed() HttpResponseFor<SystemListServicesResponse> listServices()
Returns a raw HTTP response for
get /services, but is otherwise the same as SystemService.listServices.
-
listServices
@MustBeClosed() abstract HttpResponseFor<SystemListServicesResponse> listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
listServices
@MustBeClosed() HttpResponseFor<SystemListServicesResponse> listServices(SystemListServicesParams params)
-
listServices
@MustBeClosed() HttpResponseFor<SystemListServicesResponse> listServices(RequestOptions requestOptions)
-
-
-
-