Package dev.case.api.services.blocking
Class SystemServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SystemService
public final class SystemServiceImpl implements SystemService
Public system metadata and discovery endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSystemServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SystemService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SystemServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SystemListServicesResponselistServices(SystemListServicesParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SystemService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SystemService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
SystemListServicesResponse listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
-
-
-