Package dev.case.api.services.blocking
Class SystemServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SystemService.WithRawResponse
public final class SystemServiceImpl.WithRawResponseImpl implements SystemService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SystemService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<SystemListServicesResponse>listServices(SystemListServicesParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
SystemService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listServices
HttpResponseFor<SystemListServicesResponse> listServices(SystemListServicesParams params, RequestOptions requestOptions)
-
-
-
-