Package dev.case.api.services.blocking
Interface TranslateService
-
- All Implemented Interfaces:
public interface TranslateService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTranslateService.WithRawResponseA view of TranslateService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract TranslateService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract TranslateServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()-
-
Method Detail
-
withRawResponse
abstract TranslateService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract TranslateService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-