Package dev.case.api.services.blocking
Class TranslateServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.TranslateService
public final class TranslateServiceImpl implements TranslateService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTranslateServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TranslateService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TranslateServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()-
-
Method Detail
-
withRawResponse
TranslateService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TranslateService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-