Package dev.case.api.services.blocking
Class TranslateServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.TranslateService.WithRawResponse
public final class TranslateServiceImpl.WithRawResponseImpl implements TranslateService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description TranslateService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
TranslateService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-