Package dev.case.api.services.blocking
Interface UsageService
-
- All Implemented Interfaces:
public interface UsageService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceUsageService.WithRawResponseA view of UsageService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract UsageService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract UsageServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()Usage reporting and webhook subscriptions -
-
Method Detail
-
withRawResponse
abstract UsageService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract UsageService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-