Package dev.case.api.services.blocking
Class UsageServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.UsageService.WithRawResponse
public final class UsageServiceImpl.WithRawResponseImpl implements UsageService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description UsageService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()Usage reporting and webhook subscriptions -
-
Method Detail
-
withOptions
UsageService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
v1
V1Service.WithRawResponse v1()
Usage reporting and webhook subscriptions
-
-
-
-