Package dev.case.api.services.blocking
Class VaultServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.VaultService
public final class VaultServiceImpl implements VaultService
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description VaultService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. VaultServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EventServiceevents()GraphragServicegraphrag()Secure document storage with semantic search and GraphRAG GroupServicegroups()Secure document storage with semantic search and GraphRAG MultipartServicemultipart()Secure document storage with semantic search and GraphRAG ObjectServiceobjects()Secure document storage with semantic search and GraphRAG MemoryServicememory()Secure document storage with semantic search and GraphRAG VaultCreateResponsecreate(VaultCreateParams params, RequestOptions requestOptions)VaultRetrieveResponseretrieve(VaultRetrieveParams params, RequestOptions requestOptions)VaultUpdateResponseupdate(VaultUpdateParams params, RequestOptions requestOptions)VaultListResponselist(VaultListParams params, RequestOptions requestOptions)VaultDeleteResponsedelete(VaultDeleteParams params, RequestOptions requestOptions)VaultConfirmUploadResponseconfirmUpload(VaultConfirmUploadParams params, RequestOptions requestOptions)VaultIngestResponseingest(VaultIngestParams params, RequestOptions requestOptions)VaultSearchResponsesearch(VaultSearchParams params, RequestOptions requestOptions)VaultUploadResponseupload(VaultUploadParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.VaultService
confirmUpload, confirmUpload, confirmUpload, create, delete, delete, delete, delete, delete, ingest, ingest, ingest, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, search, search, search, update, update, update, update, update, upload, upload, upload -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
VaultService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VaultService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
events
EventService events()
-
graphrag
GraphragService graphrag()
Secure document storage with semantic search and GraphRAG
-
groups
GroupService groups()
Secure document storage with semantic search and GraphRAG
-
multipart
MultipartService multipart()
Secure document storage with semantic search and GraphRAG
-
objects
ObjectService objects()
Secure document storage with semantic search and GraphRAG
-
memory
MemoryService memory()
Secure document storage with semantic search and GraphRAG
-
create
VaultCreateResponse create(VaultCreateParams params, RequestOptions requestOptions)
-
retrieve
VaultRetrieveResponse retrieve(VaultRetrieveParams params, RequestOptions requestOptions)
-
update
VaultUpdateResponse update(VaultUpdateParams params, RequestOptions requestOptions)
-
list
VaultListResponse list(VaultListParams params, RequestOptions requestOptions)
-
delete
VaultDeleteResponse delete(VaultDeleteParams params, RequestOptions requestOptions)
-
confirmUpload
VaultConfirmUploadResponse confirmUpload(VaultConfirmUploadParams params, RequestOptions requestOptions)
-
ingest
VaultIngestResponse ingest(VaultIngestParams params, RequestOptions requestOptions)
-
search
VaultSearchResponse search(VaultSearchParams params, RequestOptions requestOptions)
-
upload
VaultUploadResponse upload(VaultUploadParams params, RequestOptions requestOptions)
-
-
-
-