Package dev.case.api.services.blocking
Interface VoiceService
-
- All Implemented Interfaces:
public interface VoiceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceVoiceService.WithRawResponseA view of VoiceService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract VoiceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract VoiceServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract StreamingServicestreaming()Audio transcription and text-to-speech abstract TranscriptionServicetranscription()Audio transcription and text-to-speech abstract V1Servicev1()Audio transcription and text-to-speech -
-
Method Detail
-
withRawResponse
abstract VoiceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract VoiceService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
abstract StreamingService streaming()
Audio transcription and text-to-speech
-
transcription
abstract TranscriptionService transcription()
Audio transcription and text-to-speech
-
-
-
-