Package dev.case.api.services.blocking
Interface VoiceService.WithRawResponse
-
- All Implemented Interfaces:
public interface VoiceService.WithRawResponseA view of VoiceService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract VoiceService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract StreamingService.WithRawResponsestreaming()Audio transcription and text-to-speech abstract BoostListService.WithRawResponseboostList()Audio transcription and text-to-speech abstract TranscriptionService.WithRawResponsetranscription()Audio transcription and text-to-speech abstract V1Service.WithRawResponsev1()Audio transcription and text-to-speech -
-
Method Detail
-
withOptions
abstract VoiceService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
abstract StreamingService.WithRawResponse streaming()
Audio transcription and text-to-speech
-
boostList
abstract BoostListService.WithRawResponse boostList()
Audio transcription and text-to-speech
-
transcription
abstract TranscriptionService.WithRawResponse transcription()
Audio transcription and text-to-speech
-
v1
abstract V1Service.WithRawResponse v1()
Audio transcription and text-to-speech
-
-
-
-