Package dev.case.api.services.blocking
Class VoiceServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.VoiceService
public final class VoiceServiceImpl implements VoiceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVoiceServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description VoiceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. VoiceServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamingServicestreaming()Audio transcription and text-to-speech BoostListServiceboostList()Audio transcription and text-to-speech TranscriptionServicetranscription()Audio transcription and text-to-speech V1Servicev1()Audio transcription and text-to-speech -
-
Method Detail
-
withRawResponse
VoiceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VoiceService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
StreamingService streaming()
Audio transcription and text-to-speech
-
boostList
BoostListService boostList()
Audio transcription and text-to-speech
-
transcription
TranscriptionService transcription()
Audio transcription and text-to-speech
-
-
-
-