Package dev.case.api.services.blocking
Class VoiceServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.VoiceService.WithRawResponse
public final class VoiceServiceImpl.WithRawResponseImpl implements VoiceService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description VoiceService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamingService.WithRawResponsestreaming()Audio transcription and text-to-speech BoostListService.WithRawResponseboostList()Audio transcription and text-to-speech TranscriptionService.WithRawResponsetranscription()Audio transcription and text-to-speech V1Service.WithRawResponsev1()Audio transcription and text-to-speech -
-
Method Detail
-
withOptions
VoiceService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
StreamingService.WithRawResponse streaming()
Audio transcription and text-to-speech
-
boostList
BoostListService.WithRawResponse boostList()
Audio transcription and text-to-speech
-
transcription
TranscriptionService.WithRawResponse transcription()
Audio transcription and text-to-speech
-
v1
V1Service.WithRawResponse v1()
Audio transcription and text-to-speech
-
-
-
-