Package dev.case.api.services.blocking
Interface WorkerService
-
- All Implemented Interfaces:
public interface WorkerService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWorkerService.WithRawResponseA view of WorkerService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WorkerService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WorkerServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract V1Servicev1()-
-
Method Detail
-
withRawResponse
abstract WorkerService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WorkerService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-