Package dev.case.api.services.blocking
Class WorkerServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.WorkerService
public final class WorkerServiceImpl implements WorkerService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkerServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WorkerService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WorkerServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()-
-
Method Detail
-
withRawResponse
WorkerService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WorkerService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-