Package dev.case.api.services.blocking
Class WorkerServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.WorkerService.WithRawResponse
public final class WorkerServiceImpl.WithRawResponseImpl implements WorkerService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description WorkerService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
WorkerService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-