Interface SkillService
-
- All Implemented Interfaces:
public interface SkillService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSkillService.WithRawResponseA view of SkillService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SkillService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SkillServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract NamespaceServicenamespaces()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
abstract SkillService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SkillService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
namespaces
abstract NamespaceService namespaces()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-