Class SkillServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.SkillService
public final class SkillServiceImpl implements SkillService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SkillService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SkillServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. NamespaceServicenamespaces()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
SkillService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SkillService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
namespaces
NamespaceService namespaces()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-