Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentService.WithRawResponseagents()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract RunService.WithRawResponserun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract ExecuteService.WithRawResponseexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract ChatService.WithRawResponsechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
abstract AgentService.WithRawResponse agents()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
run
abstract RunService.WithRawResponse run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
abstract ExecuteService.WithRawResponse execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
abstract ChatService.WithRawResponse chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-