Class V1ServiceImpl

  • All Implemented Interfaces:
    dev.case.api.services.blocking.agent.V1Service

    
    public final class V1ServiceImpl
     implements V1Service
                        
    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Method Summary

      Modifier and Type Method Description
      V1Service.WithRawResponse withRawResponse() Returns a view of this service that provides access to raw HTTP responses for each method.
      V1Service withOptions(Consumer<ClientOptions.Builder> modifier) Returns a view of this service with the given option modifications applied.
      AgentService agents() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      RunService run() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      ExecuteService execute() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      ChatService chat() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

    • Method Detail

      • agents

         AgentService agents()

        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows

      • run

         RunService run()

        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows

      • execute

         ExecuteService execute()

        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows

      • chat

         ChatService chat()

        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows