Class V2ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.V2Service
public final class V2ServiceImpl implements V2Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V2Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V2ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RunServicerun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ExecuteServiceexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatServicechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
V2Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V2Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
run
RunService run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
ExecuteService execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
ChatService chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-