Class V2ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.V2Service.WithRawResponse
public final class V2ServiceImpl.WithRawResponseImpl implements V2Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V2Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RunService.WithRawResponserun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ExecuteService.WithRawResponseexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatService.WithRawResponsechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withOptions
V2Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
run
RunService.WithRawResponse run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
ExecuteService.WithRawResponse execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
ChatService.WithRawResponse chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-