Class NamespaceServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.skills.NamespaceService
public final class NamespaceServiceImpl implements NamespaceService
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNamespaceServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description NamespaceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. NamespaceServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(NamespaceCreateParams params, RequestOptions requestOptions)Unitretrieve(NamespaceRetrieveParams params, RequestOptions requestOptions)Unitlist(NamespaceListParams params, RequestOptions requestOptions)Unitdelete(NamespaceDeleteParams params, RequestOptions requestOptions)Unitpublish(NamespacePublishParams params, RequestOptions requestOptions)Unitpull(NamespacePullParams params, RequestOptions requestOptions)UnitrotateToken(NamespaceRotateTokenParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.agent.skills.NamespaceService
create, delete, delete, delete, delete, delete, list, list, list, publish, publish, publish, pull, pull, pull, pull, pull, retrieve, retrieve, retrieve, retrieve, retrieve, rotateToken, rotateToken, rotateToken, rotateToken, rotateToken -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
NamespaceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
NamespaceService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(NamespaceCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(NamespaceRetrieveParams params, RequestOptions requestOptions)
-
list
Unit list(NamespaceListParams params, RequestOptions requestOptions)
-
delete
Unit delete(NamespaceDeleteParams params, RequestOptions requestOptions)
-
publish
Unit publish(NamespacePublishParams params, RequestOptions requestOptions)
-
pull
Unit pull(NamespacePullParams params, RequestOptions requestOptions)
-
rotateToken
Unit rotateToken(NamespaceRotateTokenParams params, RequestOptions requestOptions)
-
-
-
-