Interface AgentService
-
- All Implemented Interfaces:
public interface AgentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAgentService.WithRawResponseA view of AgentService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AgentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AgentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
AgentCreateResponse create(AgentCreateParams params)
Creates a new agent definition with a scoped API key. The agent can then be used to create and execute runs.
-
create
abstract AgentCreateResponse create(AgentCreateParams params, RequestOptions requestOptions)
-
retrieve
AgentRetrieveResponse retrieve(String id)
Retrieves a single agent definition by ID.
-
retrieve
AgentRetrieveResponse retrieve(String id, AgentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AgentRetrieveResponse retrieve(String id, AgentRetrieveParams params)
-
retrieve
abstract AgentRetrieveResponse retrieve(AgentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AgentRetrieveResponse retrieve(AgentRetrieveParams params)
-
retrieve
AgentRetrieveResponse retrieve(String id, RequestOptions requestOptions)
-
update
AgentUpdateResponse update(String id)
Updates an agent definition. Only provided fields are changed.
-
update
AgentUpdateResponse update(String id, AgentUpdateParams params, RequestOptions requestOptions)
-
update
AgentUpdateResponse update(String id, AgentUpdateParams params)
-
update
abstract AgentUpdateResponse update(AgentUpdateParams params, RequestOptions requestOptions)
-
update
AgentUpdateResponse update(AgentUpdateParams params)
-
update
AgentUpdateResponse update(String id, RequestOptions requestOptions)
-
list
AgentListResponse list()
Lists all active agents for the authenticated organization.
-
list
abstract AgentListResponse list(AgentListParams params, RequestOptions requestOptions)
-
list
AgentListResponse list(AgentListParams params)
-
list
AgentListResponse list(RequestOptions requestOptions)
-
delete
AgentDeleteResponse delete(String id)
Soft-deletes an agent and revokes its scoped API key.
-
delete
AgentDeleteResponse delete(String id, AgentDeleteParams params, RequestOptions requestOptions)
-
delete
AgentDeleteResponse delete(String id, AgentDeleteParams params)
-
delete
abstract AgentDeleteResponse delete(AgentDeleteParams params, RequestOptions requestOptions)
-
delete
AgentDeleteResponse delete(AgentDeleteParams params)
-
delete
AgentDeleteResponse delete(String id, RequestOptions requestOptions)
-
-
-
-