Class AgentServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v1.AgentService
public final class AgentServiceImpl implements AgentService
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AgentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AgentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentCreateResponsecreate(AgentCreateParams params, RequestOptions requestOptions)AgentRetrieveResponseretrieve(AgentRetrieveParams params, RequestOptions requestOptions)AgentUpdateResponseupdate(AgentUpdateParams params, RequestOptions requestOptions)AgentListResponselist(AgentListParams params, RequestOptions requestOptions)AgentDeleteResponsedelete(AgentDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.agent.v1.AgentService
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AgentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AgentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
AgentCreateResponse create(AgentCreateParams params, RequestOptions requestOptions)
-
retrieve
AgentRetrieveResponse retrieve(AgentRetrieveParams params, RequestOptions requestOptions)
-
update
AgentUpdateResponse update(AgentUpdateParams params, RequestOptions requestOptions)
-
list
AgentListResponse list(AgentListParams params, RequestOptions requestOptions)
-
delete
AgentDeleteResponse delete(AgentDeleteParams params, RequestOptions requestOptions)
-
-
-
-