Class AgentServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v1.AgentService.WithRawResponse
public final class AgentServiceImpl.WithRawResponseImpl implements AgentService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AgentService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<AgentCreateResponse>create(AgentCreateParams params, RequestOptions requestOptions)HttpResponseFor<AgentRetrieveResponse>retrieve(AgentRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<AgentUpdateResponse>update(AgentUpdateParams params, RequestOptions requestOptions)HttpResponseFor<AgentListResponse>list(AgentListParams params, RequestOptions requestOptions)HttpResponseFor<AgentDeleteResponse>delete(AgentDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.agent.v1.AgentService.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AgentService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<AgentCreateResponse> create(AgentCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<AgentRetrieveResponse> retrieve(AgentRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<AgentUpdateResponse> update(AgentUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<AgentListResponse> list(AgentListParams params, RequestOptions requestOptions)
-
delete
HttpResponseFor<AgentDeleteResponse> delete(AgentDeleteParams params, RequestOptions requestOptions)
-
-
-
-