Interface ChatService.WithRawResponse
-
- All Implemented Interfaces:
public interface ChatService.WithRawResponseA view of ChatService that provides access to raw HTTP responses for each method.
-
-
Method Summary
-
-
Method Detail
-
withOptions
abstract ChatService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
abstract FileService.WithRawResponse files()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
create
@MustBeClosed() HttpResponseFor<ChatCreateResponse> create()
Returns a raw HTTP response for
post /agent/v1/chat, but is otherwise the same as ChatService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<ChatCreateResponse> create(ChatCreateParams params, RequestOptions requestOptions)
-
create
@MustBeClosed() HttpResponseFor<ChatCreateResponse> create(ChatCreateParams params)
-
create
@MustBeClosed() HttpResponseFor<ChatCreateResponse> create(RequestOptions requestOptions)
-
delete
@MustBeClosed() HttpResponseFor<ChatDeleteResponse> delete(String id)
Returns a raw HTTP response for
delete /agent/v1/chat/{id}, but is otherwise the same as ChatService.delete.
-
delete
@MustBeClosed() HttpResponseFor<ChatDeleteResponse> delete(String id, ChatDeleteParams params, RequestOptions requestOptions)
-
delete
@MustBeClosed() HttpResponseFor<ChatDeleteResponse> delete(String id, ChatDeleteParams params)
-
delete
@MustBeClosed() abstract HttpResponseFor<ChatDeleteResponse> delete(ChatDeleteParams params, RequestOptions requestOptions)
-
delete
@MustBeClosed() HttpResponseFor<ChatDeleteResponse> delete(ChatDeleteParams params)
-
delete
@MustBeClosed() HttpResponseFor<ChatDeleteResponse> delete(String id, RequestOptions requestOptions)
-
cancel
@MustBeClosed() HttpResponseFor<ChatCancelResponse> cancel(String id)
Returns a raw HTTP response for
post /agent/v1/chat/{id}/cancel, but is otherwise the same as ChatService.cancel.
-
cancel
@MustBeClosed() HttpResponseFor<ChatCancelResponse> cancel(String id, ChatCancelParams params, RequestOptions requestOptions)
-
cancel
@MustBeClosed() HttpResponseFor<ChatCancelResponse> cancel(String id, ChatCancelParams params)
-
cancel
@MustBeClosed() abstract HttpResponseFor<ChatCancelResponse> cancel(ChatCancelParams params, RequestOptions requestOptions)
-
cancel
@MustBeClosed() HttpResponseFor<ChatCancelResponse> cancel(ChatCancelParams params)
-
cancel
@MustBeClosed() HttpResponseFor<ChatCancelResponse> cancel(String id, RequestOptions requestOptions)
-
replyToQuestion
@MustBeClosed() HttpResponse replyToQuestion(String requestId, ChatReplyToQuestionParams params)
Returns a raw HTTP response for
post /agent/v1/chat/{id}/question/{requestID}/reply, but is otherwise the same as ChatService.replyToQuestion.
-
replyToQuestion
@MustBeClosed() HttpResponse replyToQuestion(String requestId, ChatReplyToQuestionParams params, RequestOptions requestOptions)
-
replyToQuestion
@MustBeClosed() HttpResponse replyToQuestion(ChatReplyToQuestionParams params)
-
replyToQuestion
@MustBeClosed() abstract HttpResponse replyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)
-
respondStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> respondStreaming(String id)
Returns a raw HTTP response for
post /agent/v1/chat/{id}/respond, but is otherwise the same as ChatService.respondStreaming.
-
respondStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> respondStreaming(String id, ChatRespondParams params, RequestOptions requestOptions)
-
respondStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> respondStreaming(String id, ChatRespondParams params)
-
respondStreaming
@MustBeClosed() abstract HttpResponseFor<StreamResponse<String>> respondStreaming(ChatRespondParams params, RequestOptions requestOptions)
-
respondStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> respondStreaming(ChatRespondParams params)
-
respondStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> respondStreaming(String id, RequestOptions requestOptions)
-
sendMessage
@MustBeClosed() HttpResponse sendMessage(String id)
Returns a raw HTTP response for
post /agent/v1/chat/{id}/message, but is otherwise the same as ChatService.sendMessage.
-
sendMessage
@MustBeClosed() HttpResponse sendMessage(String id, ChatSendMessageParams params, RequestOptions requestOptions)
-
sendMessage
@MustBeClosed() HttpResponse sendMessage(String id, ChatSendMessageParams params)
-
sendMessage
@MustBeClosed() abstract HttpResponse sendMessage(ChatSendMessageParams params, RequestOptions requestOptions)
-
sendMessage
@MustBeClosed() HttpResponse sendMessage(ChatSendMessageParams params)
-
sendMessage
@MustBeClosed() HttpResponse sendMessage(String id, RequestOptions requestOptions)
-
streamStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> streamStreaming(String id)
Returns a raw HTTP response for
get /agent/v1/chat/{id}/stream, but is otherwise the same as ChatService.streamStreaming.
-
streamStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> streamStreaming(String id, ChatStreamParams params, RequestOptions requestOptions)
-
streamStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> streamStreaming(String id, ChatStreamParams params)
-
streamStreaming
@MustBeClosed() abstract HttpResponseFor<StreamResponse<String>> streamStreaming(ChatStreamParams params, RequestOptions requestOptions)
-
streamStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> streamStreaming(ChatStreamParams params)
-
streamStreaming
@MustBeClosed() HttpResponseFor<StreamResponse<String>> streamStreaming(String id, RequestOptions requestOptions)
-
-
-
-