Class ChatServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v1.ChatService
public final class ChatServiceImpl implements ChatService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.blocking.agent.v1.ChatService
cancel, cancel, cancel, cancel, cancel, create, create, create, delete, delete, delete, delete, delete, replyToQuestion, replyToQuestion, replyToQuestion, respondStreaming, respondStreaming, respondStreaming, sendMessage, sendMessage, sendMessage, streamStreaming, streamStreaming, streamStreaming, streamStreaming, streamStreaming, uiStreamStreaming, uiStreamStreaming, uiStreamStreaming -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ChatService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ChatService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
ChatCreateResponse create(ChatCreateParams params, RequestOptions requestOptions)
-
delete
ChatDeleteResponse delete(ChatDeleteParams params, RequestOptions requestOptions)
-
cancel
ChatCancelResponse cancel(ChatCancelParams params, RequestOptions requestOptions)
-
replyToQuestion
Unit replyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)
-
respondStreaming
StreamResponse<String> respondStreaming(ChatRespondParams params, RequestOptions requestOptions)
-
sendMessage
Unit sendMessage(ChatSendMessageParams params, RequestOptions requestOptions)
-
streamStreaming
StreamResponse<String> streamStreaming(ChatStreamParams params, RequestOptions requestOptions)
-
uiStreamStreaming
StreamResponse<String> uiStreamStreaming(ChatUiStreamParams params, RequestOptions requestOptions)
-
-
-
-