Class ChatServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v1.ChatService.WithRawResponse
public final class ChatServiceImpl.WithRawResponseImpl implements ChatService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ChatService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<ChatCreateResponse>create(ChatCreateParams params, RequestOptions requestOptions)HttpResponseFor<ChatDeleteResponse>delete(ChatDeleteParams params, RequestOptions requestOptions)HttpResponseFor<ChatCancelResponse>cancel(ChatCancelParams params, RequestOptions requestOptions)HttpResponsereplyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)HttpResponseFor<StreamResponse<String>>respondStreaming(ChatRespondParams params, RequestOptions requestOptions)HttpResponsesendMessage(ChatSendMessageParams params, RequestOptions requestOptions)HttpResponseFor<StreamResponse<String>>streamStreaming(ChatStreamParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.agent.v1.ChatService.WithRawResponse
cancel, cancel, cancel, cancel, cancel, create, create, create, delete, delete, delete, delete, delete, replyToQuestion, replyToQuestion, replyToQuestion, respondStreaming, respondStreaming, respondStreaming, respondStreaming, respondStreaming, sendMessage, sendMessage, sendMessage, sendMessage, sendMessage, streamStreaming, streamStreaming, streamStreaming, streamStreaming, streamStreaming -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ChatService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<ChatCreateResponse> create(ChatCreateParams params, RequestOptions requestOptions)
-
delete
HttpResponseFor<ChatDeleteResponse> delete(ChatDeleteParams params, RequestOptions requestOptions)
-
cancel
HttpResponseFor<ChatCancelResponse> cancel(ChatCancelParams params, RequestOptions requestOptions)
-
replyToQuestion
HttpResponse replyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)
-
respondStreaming
HttpResponseFor<StreamResponse<String>> respondStreaming(ChatRespondParams params, RequestOptions requestOptions)
-
sendMessage
HttpResponse sendMessage(ChatSendMessageParams params, RequestOptions requestOptions)
-
streamStreaming
HttpResponseFor<StreamResponse<String>> streamStreaming(ChatStreamParams params, RequestOptions requestOptions)
-
-
-
-