Interface ExecuteService.WithRawResponse
-
- All Implemented Interfaces:
public interface ExecuteService.WithRawResponseA view of ExecuteService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ExecuteService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<ExecuteCreateResponse>create(ExecuteCreateParams params)Returns a raw HTTP response for post /agent/v1/execute, but is otherwise the same as ExecuteService.create.abstract HttpResponseFor<ExecuteCreateResponse>create(ExecuteCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ExecuteService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<ExecuteCreateResponse> create(ExecuteCreateParams params)
Returns a raw HTTP response for
post /agent/v1/execute, but is otherwise the same as ExecuteService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<ExecuteCreateResponse> create(ExecuteCreateParams params, RequestOptions requestOptions)
-
-
-
-