Class ExecuteServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v1.ExecuteService
public final class ExecuteServiceImpl implements ExecuteService
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExecuteServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ExecuteService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ExecuteServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ExecuteCreateResponsecreate(ExecuteCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ExecuteService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ExecuteService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
ExecuteCreateResponse create(ExecuteCreateParams params, RequestOptions requestOptions)
-
-
-
-