Class RunServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v1.RunService
public final class RunServiceImpl implements RunService
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RunService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RunServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RunCreateResponsecreate(RunCreateParams params, RequestOptions requestOptions)RunListResponselist(RunListParams params, RequestOptions requestOptions)RunCancelResponsecancel(RunCancelParams params, RequestOptions requestOptions)StreamResponse<String>eventsStreaming(RunEventsParams params, RequestOptions requestOptions)RunExecResponseexec(RunExecParams params, RequestOptions requestOptions)RunGetDetailsResponsegetDetails(RunGetDetailsParams params, RequestOptions requestOptions)RunGetStatusResponsegetStatus(RunGetStatusParams params, RequestOptions requestOptions)RunWatchResponsewatch(RunWatchParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.agent.v1.RunService
cancel, cancel, cancel, cancel, cancel, create, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, exec, exec, exec, exec, exec, getDetails, getDetails, getDetails, getDetails, getDetails, getStatus, getStatus, getStatus, getStatus, getStatus, list, list, list, watch, watch, watch -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RunService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RunService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
RunCreateResponse create(RunCreateParams params, RequestOptions requestOptions)
-
list
RunListResponse list(RunListParams params, RequestOptions requestOptions)
-
cancel
RunCancelResponse cancel(RunCancelParams params, RequestOptions requestOptions)
-
eventsStreaming
StreamResponse<String> eventsStreaming(RunEventsParams params, RequestOptions requestOptions)
-
exec
RunExecResponse exec(RunExecParams params, RequestOptions requestOptions)
-
getDetails
RunGetDetailsResponse getDetails(RunGetDetailsParams params, RequestOptions requestOptions)
-
getStatus
RunGetStatusResponse getStatus(RunGetStatusParams params, RequestOptions requestOptions)
-
watch
RunWatchResponse watch(RunWatchParams params, RequestOptions requestOptions)
-
-
-
-