Interface FileService
-
- All Implemented Interfaces:
public interface FileServiceCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileService.WithRawResponseA view of FileService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FileServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileListResponselist(String id)Lists files created by the agent in the sandbox workspace. FileListResponselist(String id, FileListParams params, RequestOptions requestOptions)FileListResponselist(String id, FileListParams params)abstract FileListResponselist(FileListParams params, RequestOptions requestOptions)FileListResponselist(FileListParams params)FileListResponselist(String id, RequestOptions requestOptions)HttpResponsedownload(String filePath, FileDownloadParams params)Downloads a file from the sandbox workspace by path. HttpResponsedownload(String filePath, FileDownloadParams params, RequestOptions requestOptions)HttpResponsedownload(FileDownloadParams params)abstract HttpResponsedownload(FileDownloadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FileService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
FileListResponse list(String id)
Lists files created by the agent in the sandbox workspace. Only available while the sandbox is running.
-
list
FileListResponse list(String id, FileListParams params, RequestOptions requestOptions)
-
list
FileListResponse list(String id, FileListParams params)
-
list
abstract FileListResponse list(FileListParams params, RequestOptions requestOptions)
-
list
FileListResponse list(FileListParams params)
-
list
FileListResponse list(String id, RequestOptions requestOptions)
-
download
@MustBeClosed() HttpResponse download(String filePath, FileDownloadParams params)
Downloads a file from the sandbox workspace by path. Only available while the sandbox is running.
-
download
@MustBeClosed() HttpResponse download(String filePath, FileDownloadParams params, RequestOptions requestOptions)
-
download
@MustBeClosed() HttpResponse download(FileDownloadParams params)
-
download
@MustBeClosed() abstract HttpResponse download(FileDownloadParams params, RequestOptions requestOptions)
-
-
-
-