Class ChatServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v2.ChatService
public final class ChatServiceImpl implements ChatService
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ChatService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ChatServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileServicefiles()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatCreateResponsecreate(ChatCreateParams params, RequestOptions requestOptions)ChatDeleteResponsedelete(ChatDeleteParams params, RequestOptions requestOptions)ChatCancelResponsecancel(ChatCancelParams params, RequestOptions requestOptions)UnitreplyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)StreamResponse<String>respondStreaming(ChatRespondParams params, RequestOptions requestOptions)UnitsendMessage(ChatSendMessageParams params, RequestOptions requestOptions)StreamResponse<String>streamStreaming(ChatStreamParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.agent.v2.ChatService
cancel, cancel, cancel, cancel, cancel, create, create, create, delete, delete, delete, delete, delete, replyToQuestion, replyToQuestion, replyToQuestion, respondStreaming, respondStreaming, respondStreaming, respondStreaming, respondStreaming, sendMessage, sendMessage, sendMessage, sendMessage, sendMessage, streamStreaming, streamStreaming, streamStreaming, streamStreaming, streamStreaming -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ChatService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ChatService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
FileService files()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
create
ChatCreateResponse create(ChatCreateParams params, RequestOptions requestOptions)
-
delete
ChatDeleteResponse delete(ChatDeleteParams params, RequestOptions requestOptions)
-
cancel
ChatCancelResponse cancel(ChatCancelParams params, RequestOptions requestOptions)
-
replyToQuestion
Unit replyToQuestion(ChatReplyToQuestionParams params, RequestOptions requestOptions)
-
respondStreaming
StreamResponse<String> respondStreaming(ChatRespondParams params, RequestOptions requestOptions)
-
sendMessage
Unit sendMessage(ChatSendMessageParams params, RequestOptions requestOptions)
-
streamStreaming
StreamResponse<String> streamStreaming(ChatStreamParams params, RequestOptions requestOptions)
-
-
-
-