Interface RunService
-
- All Implemented Interfaces:
public interface RunServiceCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRunService.WithRawResponseA view of RunService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract RunService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RunService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
RunCreateResponse create(RunCreateParams params)
Creates a v2 run in queued state. Call POST /agent/v2/run/:id/exec to start execution on the Daytona runtime.
-
create
abstract RunCreateResponse create(RunCreateParams params, RequestOptions requestOptions)
-
eventsStreaming
@MustBeClosed() StreamResponse<String> eventsStreaming(String id)
Streams real-time v2 run events over SSE with replay support.
-
eventsStreaming
@MustBeClosed() StreamResponse<String> eventsStreaming(String id, RunEventsParams params, RequestOptions requestOptions)
-
eventsStreaming
@MustBeClosed() StreamResponse<String> eventsStreaming(String id, RunEventsParams params)
-
eventsStreaming
@MustBeClosed() abstract StreamResponse<String> eventsStreaming(RunEventsParams params, RequestOptions requestOptions)
-
eventsStreaming
@MustBeClosed() StreamResponse<String> eventsStreaming(RunEventsParams params)
-
eventsStreaming
@MustBeClosed() StreamResponse<String> eventsStreaming(String id, RequestOptions requestOptions)
-
exec
RunExecResponse exec(String id)
Starts execution of a queued v2 run. The agent runs in a durable workflow on a Daytona runtime.
-
exec
RunExecResponse exec(String id, RunExecParams params, RequestOptions requestOptions)
-
exec
RunExecResponse exec(String id, RunExecParams params)
-
exec
abstract RunExecResponse exec(RunExecParams params, RequestOptions requestOptions)
-
exec
RunExecResponse exec(RunExecParams params)
-
exec
RunExecResponse exec(String id, RequestOptions requestOptions)
-
getDetails
RunGetDetailsResponse getDetails(String id)
Full audit trail for a v2 run, with provider-neutral runtime metadata.
-
getDetails
RunGetDetailsResponse getDetails(String id, RunGetDetailsParams params, RequestOptions requestOptions)
-
getDetails
RunGetDetailsResponse getDetails(String id, RunGetDetailsParams params)
-
getDetails
abstract RunGetDetailsResponse getDetails(RunGetDetailsParams params, RequestOptions requestOptions)
-
getDetails
RunGetDetailsResponse getDetails(RunGetDetailsParams params)
-
getDetails
RunGetDetailsResponse getDetails(String id, RequestOptions requestOptions)
-
getStatus
RunGetStatusResponse getStatus(String id)
Lightweight status poll for a v2 run including neutral runtime metadata.
-
getStatus
RunGetStatusResponse getStatus(String id, RunGetStatusParams params, RequestOptions requestOptions)
-
getStatus
RunGetStatusResponse getStatus(String id, RunGetStatusParams params)
-
getStatus
abstract RunGetStatusResponse getStatus(RunGetStatusParams params, RequestOptions requestOptions)
-
getStatus
RunGetStatusResponse getStatus(RunGetStatusParams params)
-
getStatus
RunGetStatusResponse getStatus(String id, RequestOptions requestOptions)
-
-
-
-