Class RunServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v2.RunService.WithRawResponse
public final class RunServiceImpl.WithRawResponseImpl implements RunService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RunService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<RunCreateResponse>create(RunCreateParams params, RequestOptions requestOptions)HttpResponseFor<StreamResponse<String>>eventsStreaming(RunEventsParams params, RequestOptions requestOptions)HttpResponseFor<RunExecResponse>exec(RunExecParams params, RequestOptions requestOptions)HttpResponseFor<RunGetDetailsResponse>getDetails(RunGetDetailsParams params, RequestOptions requestOptions)HttpResponseFor<RunGetStatusResponse>getStatus(RunGetStatusParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.agent.v2.RunService.WithRawResponse
create, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, eventsStreaming, exec, exec, exec, exec, exec, getDetails, getDetails, getDetails, getDetails, getDetails, getStatus, getStatus, getStatus, getStatus, getStatus -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
RunService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<RunCreateResponse> create(RunCreateParams params, RequestOptions requestOptions)
-
eventsStreaming
HttpResponseFor<StreamResponse<String>> eventsStreaming(RunEventsParams params, RequestOptions requestOptions)
-
exec
HttpResponseFor<RunExecResponse> exec(RunExecParams params, RequestOptions requestOptions)
-
getDetails
HttpResponseFor<RunGetDetailsResponse> getDetails(RunGetDetailsParams params, RequestOptions requestOptions)
-
getStatus
HttpResponseFor<RunGetStatusResponse> getStatus(RunGetStatusParams params, RequestOptions requestOptions)
-
-
-
-