Class FileServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v2.chat.FileService
public final class FileServiceImpl implements FileService
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileListResponselist(FileListParams params, RequestOptions requestOptions)HttpResponsedownload(FileDownloadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FileService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
FileListResponse list(FileListParams params, RequestOptions requestOptions)
-
download
HttpResponse download(FileDownloadParams params, RequestOptions requestOptions)
-
-
-
-