Class FileServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.v2.chat.FileService.WithRawResponse
public final class FileServiceImpl.WithRawResponseImpl implements FileService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FileService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<FileListResponse>list(FileListParams params, RequestOptions requestOptions)HttpResponsedownload(FileDownloadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
FileService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<FileListResponse> list(FileListParams params, RequestOptions requestOptions)
-
download
HttpResponse download(FileDownloadParams params, RequestOptions requestOptions)
-
-
-
-