Package dev.case.api.services.blocking.agent.v2
See: Description
-
Interface Summary Interface Description WithRawResponse A view of ChatService that provides access to raw HTTP responses for each method. ChatService Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponse A view of ExecuteService that provides access to raw HTTP responses for each method. ExecuteService Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponse A view of RunService that provides access to raw HTTP responses for each method. RunService Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
Class Summary Class Description WithRawResponseImpl ChatServiceImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponseImpl ExecuteServiceImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows WithRawResponseImpl RunServiceImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows