Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract DeploymentService.WithRawResponsedeployments()abstract ProjectService.WithRawResponseprojects()abstract WorkflowService.WithRawResponseworkflows()-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
deployments
abstract DeploymentService.WithRawResponse deployments()
-
projects
abstract ProjectService.WithRawResponse projects()
-
workflows
abstract WorkflowService.WithRawResponse workflows()
-
-
-
-