Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.applications.V1Service
public final class V1ServiceImpl implements V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DeploymentServicedeployments()Web application deployment management ProjectServiceprojects()WorkflowServiceworkflows()Web application deployment management -
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
deployments
DeploymentService deployments()
Web application deployment management
-
projects
ProjectService projects()
-
workflows
WorkflowService workflows()
Web application deployment management
-
-
-
-