Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.applications.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DeploymentService.WithRawResponsedeployments()Web application deployment management ProjectService.WithRawResponseprojects()WorkflowService.WithRawResponseworkflows()Web application deployment management -
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
deployments
DeploymentService.WithRawResponse deployments()
Web application deployment management
-
projects
ProjectService.WithRawResponse projects()
-
workflows
WorkflowService.WithRawResponse workflows()
Web application deployment management
-
-
-
-