Class DeploymentServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.applications.v1.DeploymentService
public final class DeploymentServiceImpl implements DeploymentService
Web application deployment management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeploymentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DeploymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DeploymentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(DeploymentCreateParams params, RequestOptions requestOptions)Unitretrieve(DeploymentRetrieveParams params, RequestOptions requestOptions)Unitlist(DeploymentListParams params, RequestOptions requestOptions)Unitcancel(DeploymentCancelParams params, RequestOptions requestOptions)UnitcreateFromFiles(DeploymentCreateFromFilesParams params, RequestOptions requestOptions)UnitgetLogs(DeploymentGetLogsParams params, RequestOptions requestOptions)UnitgetStatus(DeploymentGetStatusParams params, RequestOptions requestOptions)Unitstream(DeploymentStreamParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.applications.v1.DeploymentService
cancel, cancel, cancel, create, createFromFiles, createFromFiles, createFromFiles, getLogs, getLogs, getLogs, getStatus, getStatus, getStatus, getStatus, getStatus, list, retrieve, retrieve, retrieve, stream, stream, stream -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DeploymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DeploymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(DeploymentCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(DeploymentRetrieveParams params, RequestOptions requestOptions)
-
list
Unit list(DeploymentListParams params, RequestOptions requestOptions)
-
cancel
Unit cancel(DeploymentCancelParams params, RequestOptions requestOptions)
-
createFromFiles
Unit createFromFiles(DeploymentCreateFromFilesParams params, RequestOptions requestOptions)
-
getLogs
Unit getLogs(DeploymentGetLogsParams params, RequestOptions requestOptions)
-
getStatus
Unit getStatus(DeploymentGetStatusParams params, RequestOptions requestOptions)
-
stream
Unit stream(DeploymentStreamParams params, RequestOptions requestOptions)
-
-
-
-