Interface ProjectService
-
- All Implemented Interfaces:
public interface ProjectService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProjectService.WithRawResponseA view of ProjectService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ProjectService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProjectService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(ProjectCreateParams params)
Create a new web application project
-
create
abstract Unit create(ProjectCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String id, ProjectRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String id, ProjectRetrieveParams params)
-
retrieve
abstract Unit retrieve(ProjectRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(ProjectRetrieveParams params)
-
retrieve
Unit retrieve(String id, RequestOptions requestOptions)
-
list
ProjectListResponse list()
List all web application projects
-
list
abstract ProjectListResponse list(ProjectListParams params, RequestOptions requestOptions)
-
list
ProjectListResponse list(ProjectListParams params)
-
list
ProjectListResponse list(RequestOptions requestOptions)
-
delete
Unit delete(String id, ProjectDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String id, ProjectDeleteParams params)
-
delete
abstract Unit delete(ProjectDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(ProjectDeleteParams params)
-
delete
Unit delete(String id, RequestOptions requestOptions)
-
createDeployment
Unit createDeployment(String id)
Trigger a new deployment for a project.
-
createDeployment
Unit createDeployment(String id, ProjectCreateDeploymentParams params, RequestOptions requestOptions)
-
createDeployment
Unit createDeployment(String id, ProjectCreateDeploymentParams params)
-
createDeployment
abstract Unit createDeployment(ProjectCreateDeploymentParams params, RequestOptions requestOptions)
-
createDeployment
Unit createDeployment(ProjectCreateDeploymentParams params)
-
createDeployment
Unit createDeployment(String id, RequestOptions requestOptions)
-
createDomain
Unit createDomain(String id, ProjectCreateDomainParams params)
Add a custom domain to a project
-
createDomain
Unit createDomain(String id, ProjectCreateDomainParams params, RequestOptions requestOptions)
-
createDomain
Unit createDomain(ProjectCreateDomainParams params)
-
createDomain
abstract Unit createDomain(ProjectCreateDomainParams params, RequestOptions requestOptions)
-
createEnv
Unit createEnv(String id, ProjectCreateEnvParams params)
Create a new environment variable for a project
-
createEnv
Unit createEnv(String id, ProjectCreateEnvParams params, RequestOptions requestOptions)
-
createEnv
Unit createEnv(ProjectCreateEnvParams params)
-
createEnv
abstract Unit createEnv(ProjectCreateEnvParams params, RequestOptions requestOptions)
-
deleteDomain
Unit deleteDomain(String domain, ProjectDeleteDomainParams params)
Remove a domain from a project
-
deleteDomain
Unit deleteDomain(String domain, ProjectDeleteDomainParams params, RequestOptions requestOptions)
-
deleteDomain
Unit deleteDomain(ProjectDeleteDomainParams params)
-
deleteDomain
abstract Unit deleteDomain(ProjectDeleteDomainParams params, RequestOptions requestOptions)
-
deleteEnv
Unit deleteEnv(String envId, ProjectDeleteEnvParams params)
Delete an environment variable from a project
-
deleteEnv
Unit deleteEnv(String envId, ProjectDeleteEnvParams params, RequestOptions requestOptions)
-
deleteEnv
Unit deleteEnv(ProjectDeleteEnvParams params)
-
deleteEnv
abstract Unit deleteEnv(ProjectDeleteEnvParams params, RequestOptions requestOptions)
-
getRuntimeLogs
Unit getRuntimeLogs(String id)
Get runtime/function logs for a project
-
getRuntimeLogs
Unit getRuntimeLogs(String id, ProjectGetRuntimeLogsParams params, RequestOptions requestOptions)
-
getRuntimeLogs
Unit getRuntimeLogs(String id, ProjectGetRuntimeLogsParams params)
-
getRuntimeLogs
abstract Unit getRuntimeLogs(ProjectGetRuntimeLogsParams params, RequestOptions requestOptions)
-
getRuntimeLogs
Unit getRuntimeLogs(ProjectGetRuntimeLogsParams params)
-
getRuntimeLogs
Unit getRuntimeLogs(String id, RequestOptions requestOptions)
-
listDeployments
Unit listDeployments(String id)
List deployments for a specific project
-
listDeployments
Unit listDeployments(String id, ProjectListDeploymentsParams params, RequestOptions requestOptions)
-
listDeployments
Unit listDeployments(String id, ProjectListDeploymentsParams params)
-
listDeployments
abstract Unit listDeployments(ProjectListDeploymentsParams params, RequestOptions requestOptions)
-
listDeployments
Unit listDeployments(ProjectListDeploymentsParams params)
-
listDeployments
Unit listDeployments(String id, RequestOptions requestOptions)
-
listDomains
Unit listDomains(String id)
List all domains configured for a project
-
listDomains
Unit listDomains(String id, ProjectListDomainsParams params, RequestOptions requestOptions)
-
listDomains
Unit listDomains(String id, ProjectListDomainsParams params)
-
listDomains
abstract Unit listDomains(ProjectListDomainsParams params, RequestOptions requestOptions)
-
listDomains
Unit listDomains(ProjectListDomainsParams params)
-
listDomains
Unit listDomains(String id, RequestOptions requestOptions)
-
listEnv
Unit listEnv(String id)
List all environment variables for a project (values are hidden unless decrypt=true)
-
listEnv
Unit listEnv(String id, ProjectListEnvParams params, RequestOptions requestOptions)
-
listEnv
Unit listEnv(String id, ProjectListEnvParams params)
-
listEnv
abstract Unit listEnv(ProjectListEnvParams params, RequestOptions requestOptions)
-
listEnv
Unit listEnv(ProjectListEnvParams params)
-
listEnv
Unit listEnv(String id, RequestOptions requestOptions)
-
-
-
-