Class ProjectServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.applications.v1.ProjectService
public final class ProjectServiceImpl implements ProjectService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.blocking.applications.v1.ProjectService
create, createDeployment, createDeployment, createDeployment, createDeployment, createDeployment, createDomain, createDomain, createDomain, createEnv, createEnv, createEnv, delete, delete, delete, delete, delete, deleteDomain, deleteDomain, deleteDomain, deleteEnv, deleteEnv, deleteEnv, getRuntimeLogs, getRuntimeLogs, getRuntimeLogs, getRuntimeLogs, getRuntimeLogs, list, list, list, listDeployments, listDeployments, listDeployments, listDeployments, listDeployments, listDomains, listDomains, listDomains, listDomains, listDomains, listEnv, listEnv, listEnv, listEnv, listEnv, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ProjectService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProjectService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(ProjectCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(ProjectRetrieveParams params, RequestOptions requestOptions)
-
list
ProjectListResponse list(ProjectListParams params, RequestOptions requestOptions)
-
delete
Unit delete(ProjectDeleteParams params, RequestOptions requestOptions)
-
createDeployment
Unit createDeployment(ProjectCreateDeploymentParams params, RequestOptions requestOptions)
-
createDomain
Unit createDomain(ProjectCreateDomainParams params, RequestOptions requestOptions)
-
createEnv
Unit createEnv(ProjectCreateEnvParams params, RequestOptions requestOptions)
-
deleteDomain
Unit deleteDomain(ProjectDeleteDomainParams params, RequestOptions requestOptions)
-
deleteEnv
Unit deleteEnv(ProjectDeleteEnvParams params, RequestOptions requestOptions)
-
getRuntimeLogs
Unit getRuntimeLogs(ProjectGetRuntimeLogsParams params, RequestOptions requestOptions)
-
listDeployments
Unit listDeployments(ProjectListDeploymentsParams params, RequestOptions requestOptions)
-
listDomains
Unit listDomains(ProjectListDomainsParams params, RequestOptions requestOptions)
-
listEnv
Unit listEnv(ProjectListEnvParams params, RequestOptions requestOptions)
-
-
-
-