Interface WorkflowService
-
- All Implemented Interfaces:
public interface WorkflowServiceWeb application deployment management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWorkflowService.WithRawResponseA view of WorkflowService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WorkflowService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WorkflowServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UnitgetStatus(String id, WorkflowGetStatusParams params)Get current deployment workflow status and accumulated events UnitgetStatus(String id, WorkflowGetStatusParams params, RequestOptions requestOptions)UnitgetStatus(WorkflowGetStatusParams params)abstract UnitgetStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract WorkflowService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WorkflowService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStatus
Unit getStatus(String id, WorkflowGetStatusParams params)
Get current deployment workflow status and accumulated events
-
getStatus
Unit getStatus(String id, WorkflowGetStatusParams params, RequestOptions requestOptions)
-
getStatus
Unit getStatus(WorkflowGetStatusParams params)
-
getStatus
abstract Unit getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)
-
-
-
-