Interface WorkflowService.WithRawResponse
-
- All Implemented Interfaces:
public interface WorkflowService.WithRawResponseA view of WorkflowService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract WorkflowService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsegetStatus(String id, WorkflowGetStatusParams params)Returns a raw HTTP response for get /applications/v1/workflows/{id}/status, but is otherwise the same as WorkflowService.getStatus.HttpResponsegetStatus(String id, WorkflowGetStatusParams params, RequestOptions requestOptions)HttpResponsegetStatus(WorkflowGetStatusParams params)abstract HttpResponsegetStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract WorkflowService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStatus
@MustBeClosed() HttpResponse getStatus(String id, WorkflowGetStatusParams params)
Returns a raw HTTP response for
get /applications/v1/workflows/{id}/status, but is otherwise the same as WorkflowService.getStatus.
-
getStatus
@MustBeClosed() HttpResponse getStatus(String id, WorkflowGetStatusParams params, RequestOptions requestOptions)
-
getStatus
@MustBeClosed() HttpResponse getStatus(WorkflowGetStatusParams params)
-
getStatus
@MustBeClosed() abstract HttpResponse getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)
-
-
-
-