Class WorkflowServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.applications.v1.WorkflowService
public final class WorkflowServiceImpl implements WorkflowService
Web application deployment management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkflowServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WorkflowService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WorkflowServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UnitgetStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
WorkflowService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WorkflowService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStatus
Unit getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)
-
-
-
-