Class WorkflowServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.applications.v1.WorkflowService.WithRawResponse
public final class WorkflowServiceImpl.WithRawResponseImpl implements WorkflowService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description WorkflowService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsegetStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
WorkflowService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStatus
HttpResponse getStatus(WorkflowGetStatusParams params, RequestOptions requestOptions)
-
-
-
-