Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract EnvironmentService.WithRawResponseenvironments()Serverless GPU and CPU infrastructure abstract InstanceTypeService.WithRawResponseinstanceTypes()Serverless GPU and CPU infrastructure abstract InstanceService.WithRawResponseinstances()Serverless GPU and CPU infrastructure abstract SecretService.WithRawResponsesecrets()Serverless GPU and CPU infrastructure HttpResponsegetPricing()Returns a raw HTTP response for get /compute/v1/pricing, but is otherwise the same as V1Service.getPricing.abstract HttpResponsegetPricing(V1GetPricingParams params, RequestOptions requestOptions)HttpResponsegetPricing(V1GetPricingParams params)HttpResponsegetPricing(RequestOptions requestOptions)HttpResponseFor<V1GetUsageResponse>getUsage()Returns a raw HTTP response for get /compute/v1/usage, but is otherwise the same as V1Service.getUsage.abstract HttpResponseFor<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)HttpResponseFor<V1GetUsageResponse>getUsage(V1GetUsageParams params)HttpResponseFor<V1GetUsageResponse>getUsage(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
abstract EnvironmentService.WithRawResponse environments()
Serverless GPU and CPU infrastructure
-
instanceTypes
abstract InstanceTypeService.WithRawResponse instanceTypes()
Serverless GPU and CPU infrastructure
-
instances
abstract InstanceService.WithRawResponse instances()
Serverless GPU and CPU infrastructure
-
secrets
abstract SecretService.WithRawResponse secrets()
Serverless GPU and CPU infrastructure
-
getPricing
@MustBeClosed() HttpResponse getPricing()
Returns a raw HTTP response for
get /compute/v1/pricing, but is otherwise the same as V1Service.getPricing.
-
getPricing
@MustBeClosed() abstract HttpResponse getPricing(V1GetPricingParams params, RequestOptions requestOptions)
-
getPricing
@MustBeClosed() HttpResponse getPricing(V1GetPricingParams params)
-
getPricing
@MustBeClosed() HttpResponse getPricing(RequestOptions requestOptions)
-
getUsage
@MustBeClosed() HttpResponseFor<V1GetUsageResponse> getUsage()
Returns a raw HTTP response for
get /compute/v1/usage, but is otherwise the same as V1Service.getUsage.
-
getUsage
@MustBeClosed() abstract HttpResponseFor<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
@MustBeClosed() HttpResponseFor<V1GetUsageResponse> getUsage(V1GetUsageParams params)
-
getUsage
@MustBeClosed() HttpResponseFor<V1GetUsageResponse> getUsage(RequestOptions requestOptions)
-
-
-
-