Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.compute.V1Service
public final class V1ServiceImpl implements V1Service
Serverless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EnvironmentServiceenvironments()Serverless GPU and CPU infrastructure InstanceTypeServiceinstanceTypes()Serverless GPU and CPU infrastructure InstanceServiceinstances()Serverless GPU and CPU infrastructure SecretServicesecrets()Serverless GPU and CPU infrastructure UnitgetPricing(V1GetPricingParams params, RequestOptions requestOptions)V1GetUsageResponsegetUsage(V1GetUsageParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
EnvironmentService environments()
Serverless GPU and CPU infrastructure
-
instanceTypes
InstanceTypeService instanceTypes()
Serverless GPU and CPU infrastructure
-
instances
InstanceService instances()
Serverless GPU and CPU infrastructure
-
secrets
SecretService secrets()
Serverless GPU and CPU infrastructure
-
getPricing
Unit getPricing(V1GetPricingParams params, RequestOptions requestOptions)
-
getUsage
V1GetUsageResponse getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
-
-
-