Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.compute.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EnvironmentService.WithRawResponseenvironments()Serverless GPU and CPU infrastructure InstanceTypeService.WithRawResponseinstanceTypes()Serverless GPU and CPU infrastructure InstanceService.WithRawResponseinstances()Serverless GPU and CPU infrastructure SecretService.WithRawResponsesecrets()Serverless GPU and CPU infrastructure HttpResponsegetPricing(V1GetPricingParams params, RequestOptions requestOptions)HttpResponseFor<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
EnvironmentService.WithRawResponse environments()
Serverless GPU and CPU infrastructure
-
instanceTypes
InstanceTypeService.WithRawResponse instanceTypes()
Serverless GPU and CPU infrastructure
-
instances
InstanceService.WithRawResponse instances()
Serverless GPU and CPU infrastructure
-
secrets
SecretService.WithRawResponse secrets()
Serverless GPU and CPU infrastructure
-
getPricing
HttpResponse getPricing(V1GetPricingParams params, RequestOptions requestOptions)
-
getUsage
HttpResponseFor<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
-
-
-