Class EnvironmentServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.compute.v1.EnvironmentService
public final class EnvironmentServiceImpl implements EnvironmentService
Serverless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EnvironmentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EnvironmentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EnvironmentCreateResponsecreate(EnvironmentCreateParams params, RequestOptions requestOptions)EnvironmentRetrieveResponseretrieve(EnvironmentRetrieveParams params, RequestOptions requestOptions)EnvironmentListResponselist(EnvironmentListParams params, RequestOptions requestOptions)EnvironmentDeleteResponsedelete(EnvironmentDeleteParams params, RequestOptions requestOptions)EnvironmentSetDefaultResponsesetDefault(EnvironmentSetDefaultParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.compute.v1.EnvironmentService
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, setDefault, setDefault, setDefault, setDefault, setDefault -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EnvironmentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EnvironmentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
EnvironmentCreateResponse create(EnvironmentCreateParams params, RequestOptions requestOptions)
-
retrieve
EnvironmentRetrieveResponse retrieve(EnvironmentRetrieveParams params, RequestOptions requestOptions)
-
list
EnvironmentListResponse list(EnvironmentListParams params, RequestOptions requestOptions)
-
delete
EnvironmentDeleteResponse delete(EnvironmentDeleteParams params, RequestOptions requestOptions)
-
setDefault
EnvironmentSetDefaultResponse setDefault(EnvironmentSetDefaultParams params, RequestOptions requestOptions)
-
-
-
-