Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceServerless PostgreSQL databases with instant branching
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ProjectServiceprojects()Serverless PostgreSQL databases with instant branching V1GetUsageResponsegetUsage()Returns detailed database usage statistics and billing information for the current billing period. abstract V1GetUsageResponsegetUsage(V1GetUsageParams params, RequestOptions requestOptions)V1GetUsageResponsegetUsage(V1GetUsageParams params)V1GetUsageResponsegetUsage(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
projects
abstract ProjectService projects()
Serverless PostgreSQL databases with instant branching
-
getUsage
V1GetUsageResponse getUsage()
Returns detailed database usage statistics and billing information for the current billing period. Includes compute hours, storage, data transfer, and branch counts with associated costs broken down by project.
-
getUsage
abstract V1GetUsageResponse getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
V1GetUsageResponse getUsage(V1GetUsageParams params)
-
getUsage
V1GetUsageResponse getUsage(RequestOptions requestOptions)
-
-
-
-