Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ProjectService.WithRawResponseprojects()Serverless PostgreSQL databases with instant branching HttpResponseFor<V1GetUsageResponse>getUsage()Returns a raw HTTP response for get /database/v1/usage, but is otherwise the same as V1Service.getUsage.abstract HttpResponseFor<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)HttpResponseFor<V1GetUsageResponse>getUsage(V1GetUsageParams params)HttpResponseFor<V1GetUsageResponse>getUsage(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
projects
abstract ProjectService.WithRawResponse projects()
Serverless PostgreSQL databases with instant branching
-
getUsage
@MustBeClosed() HttpResponseFor<V1GetUsageResponse> getUsage()
Returns a raw HTTP response for
get /database/v1/usage, but is otherwise the same as V1Service.getUsage.
-
getUsage
@MustBeClosed() abstract HttpResponseFor<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
@MustBeClosed() HttpResponseFor<V1GetUsageResponse> getUsage(V1GetUsageParams params)
-
getUsage
@MustBeClosed() HttpResponseFor<V1GetUsageResponse> getUsage(RequestOptions requestOptions)
-
-
-
-