Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.database.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ProjectService.WithRawResponseprojects()Serverless PostgreSQL databases with instant branching HttpResponseFor<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
projects
ProjectService.WithRawResponse projects()
Serverless PostgreSQL databases with instant branching
-
getUsage
HttpResponseFor<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
-
-
-