Class ProjectServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.database.v1.ProjectService
public final class ProjectServiceImpl implements ProjectService
Serverless PostgreSQL databases with instant branching
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ProjectService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ProjectServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ProjectCreateResponsecreate(ProjectCreateParams params, RequestOptions requestOptions)ProjectRetrieveResponseretrieve(ProjectRetrieveParams params, RequestOptions requestOptions)ProjectListResponselist(ProjectListParams params, RequestOptions requestOptions)ProjectDeleteResponsedelete(ProjectDeleteParams params, RequestOptions requestOptions)ProjectCreateBranchResponsecreateBranch(ProjectCreateBranchParams params, RequestOptions requestOptions)ProjectGetConnectionResponsegetConnection(ProjectGetConnectionParams params, RequestOptions requestOptions)ProjectListBranchesResponselistBranches(ProjectListBranchesParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.database.v1.ProjectService
create, createBranch, createBranch, createBranch, delete, delete, delete, delete, delete, getConnection, getConnection, getConnection, getConnection, getConnection, list, list, list, listBranches, listBranches, listBranches, listBranches, listBranches, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ProjectService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProjectService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
ProjectCreateResponse create(ProjectCreateParams params, RequestOptions requestOptions)
-
retrieve
ProjectRetrieveResponse retrieve(ProjectRetrieveParams params, RequestOptions requestOptions)
-
list
ProjectListResponse list(ProjectListParams params, RequestOptions requestOptions)
-
delete
ProjectDeleteResponse delete(ProjectDeleteParams params, RequestOptions requestOptions)
-
createBranch
ProjectCreateBranchResponse createBranch(ProjectCreateBranchParams params, RequestOptions requestOptions)
-
getConnection
ProjectGetConnectionResponse getConnection(ProjectGetConnectionParams params, RequestOptions requestOptions)
-
listBranches
ProjectListBranchesResponse listBranches(ProjectListBranchesParams params, RequestOptions requestOptions)
-
-
-
-