Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceDocument formatting and template rendering (MD/JSON to PDF/DOCX)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract TemplateServicetemplates()Document formatting and template rendering (MD/JSON to PDF/DOCX) HttpResponsecreateDocument(V1CreateDocumentParams params)Convert Markdown, JSON, or text content to professionally formatted PDF, DOCX, or HTML documents. abstract HttpResponsecreateDocument(V1CreateDocumentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
templates
abstract TemplateService templates()
Document formatting and template rendering (MD/JSON to PDF/DOCX)
-
createDocument
@MustBeClosed() HttpResponse createDocument(V1CreateDocumentParams params)
Convert Markdown, JSON, or text content to professionally formatted PDF, DOCX, or HTML documents. Supports template components with variable interpolation for creating consistent legal documents like contracts, briefs, and reports.
-
createDocument
@MustBeClosed() abstract HttpResponse createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)
-
-
-
-