Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract TemplateService.WithRawResponsetemplates()Document formatting and template rendering (MD/JSON to PDF/DOCX) HttpResponsecreateDocument(V1CreateDocumentParams params)Returns a raw HTTP response for post /format/v1/document, but is otherwise the same as V1Service.createDocument.abstract HttpResponsecreateDocument(V1CreateDocumentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
templates
abstract TemplateService.WithRawResponse templates()
Document formatting and template rendering (MD/JSON to PDF/DOCX)
-
createDocument
@MustBeClosed() HttpResponse createDocument(V1CreateDocumentParams params)
Returns a raw HTTP response for
post /format/v1/document, but is otherwise the same as V1Service.createDocument.
-
createDocument
@MustBeClosed() abstract HttpResponse createDocument(V1CreateDocumentParams params, RequestOptions requestOptions)
-
-
-
-