Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.llm.V1Service
public final class V1ServiceImpl implements V1Service
Access 40+ language models through a unified API
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ChatServicechat()Access 40+ language models through a unified API V1CreateEmbeddingResponsecreateEmbedding(V1CreateEmbeddingParams params, RequestOptions requestOptions)V1ListModelsResponselistModels(V1ListModelsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
chat
ChatService chat()
Access 40+ language models through a unified API
-
createEmbedding
V1CreateEmbeddingResponse createEmbedding(V1CreateEmbeddingParams params, RequestOptions requestOptions)
-
listModels
V1ListModelsResponse listModels(V1ListModelsParams params, RequestOptions requestOptions)
-
-
-
-