Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.llm.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ChatService.WithRawResponsechat()Access 40+ language models through a unified API HttpResponseFor<V1CreateEmbeddingResponse>createEmbedding(V1CreateEmbeddingParams params, RequestOptions requestOptions)HttpResponseFor<V1ListModelsResponse>listModels(V1ListModelsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
chat
ChatService.WithRawResponse chat()
Access 40+ language models through a unified API
-
createEmbedding
HttpResponseFor<V1CreateEmbeddingResponse> createEmbedding(V1CreateEmbeddingParams params, RequestOptions requestOptions)
-
listModels
HttpResponseFor<V1ListModelsResponse> listModels(V1ListModelsParams params, RequestOptions requestOptions)
-
-
-
-