Class ChatServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.llm.v1.ChatService
public final class ChatServiceImpl implements ChatService
Access 40+ language models through a unified API
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ChatService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ChatServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ChatCreateCompletionResponsecreateCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ChatService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ChatService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createCompletion
ChatCreateCompletionResponse createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)
-
-
-
-