Class ChatServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.llm.v1.ChatService.WithRawResponse
public final class ChatServiceImpl.WithRawResponseImpl implements ChatService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ChatService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<ChatCreateCompletionResponse>createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ChatService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createCompletion
HttpResponseFor<ChatCreateCompletionResponse> createCompletion(ChatCreateCompletionParams params, RequestOptions requestOptions)
-
-
-
-