Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.mail.V1Service
public final class V1ServiceImpl implements V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboxServiceinboxes()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
inboxes
InboxService inboxes()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-