Interface InboxService
-
- All Implemented Interfaces:
public interface InboxServiceCreate, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboxService.WithRawResponseA view of InboxService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboxService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboxServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate()Create an inbox owned by the authenticated organization. abstract Unitcreate(InboxCreateParams params, RequestOptions requestOptions)Unitcreate(InboxCreateParams params)Unitcreate(RequestOptions requestOptions)Unitretrieve(String inboxId)Get an inbox owned by the authenticated organization. Unitretrieve(String inboxId, InboxRetrieveParams params, RequestOptions requestOptions)Unitretrieve(String inboxId, InboxRetrieveParams params)abstract Unitretrieve(InboxRetrieveParams params, RequestOptions requestOptions)Unitretrieve(InboxRetrieveParams params)Unitretrieve(String inboxId, RequestOptions requestOptions)Unitlist()List inboxes owned by the authenticated organization. abstract Unitlist(InboxListParams params, RequestOptions requestOptions)Unitlist(InboxListParams params)Unitlist(RequestOptions requestOptions)Unitdelete(String inboxId)Delete an inbox owned by the authenticated organization. Unitdelete(String inboxId, InboxDeleteParams params, RequestOptions requestOptions)Unitdelete(String inboxId, InboxDeleteParams params)abstract Unitdelete(InboxDeleteParams params, RequestOptions requestOptions)Unitdelete(InboxDeleteParams params)Unitdelete(String inboxId, RequestOptions requestOptions)UnitgetAttachment(String attachmentId, InboxGetAttachmentParams params)Get attachment metadata for a message in an inbox owned by the authenticated organization. UnitgetAttachment(String attachmentId, InboxGetAttachmentParams params, RequestOptions requestOptions)UnitgetAttachment(InboxGetAttachmentParams params)abstract UnitgetAttachment(InboxGetAttachmentParams params, RequestOptions requestOptions)UnitgetMessage(String messageId, InboxGetMessageParams params)Get a message for an inbox owned by the authenticated organization. UnitgetMessage(String messageId, InboxGetMessageParams params, RequestOptions requestOptions)UnitgetMessage(InboxGetMessageParams params)abstract UnitgetMessage(InboxGetMessageParams params, RequestOptions requestOptions)UnitgetPolicy(String inboxId)Get the sender allowlist and send/reply/read access rules for an inbox owned by the authenticated organization. UnitgetPolicy(String inboxId, InboxGetPolicyParams params, RequestOptions requestOptions)UnitgetPolicy(String inboxId, InboxGetPolicyParams params)abstract UnitgetPolicy(InboxGetPolicyParams params, RequestOptions requestOptions)UnitgetPolicy(InboxGetPolicyParams params)UnitgetPolicy(String inboxId, RequestOptions requestOptions)UnitlistMessages(String inboxId)List messages for an inbox owned by the authenticated organization. UnitlistMessages(String inboxId, InboxListMessagesParams params, RequestOptions requestOptions)UnitlistMessages(String inboxId, InboxListMessagesParams params)abstract UnitlistMessages(InboxListMessagesParams params, RequestOptions requestOptions)UnitlistMessages(InboxListMessagesParams params)UnitlistMessages(String inboxId, RequestOptions requestOptions)Unitreply(String messageId, InboxReplyParams params)Reply to a message in an inbox owned by the authenticated organization. Unitreply(String messageId, InboxReplyParams params, RequestOptions requestOptions)Unitreply(InboxReplyParams params)abstract Unitreply(InboxReplyParams params, RequestOptions requestOptions)Unitsend(String inboxId)Send a message from an inbox owned by the authenticated organization. Unitsend(String inboxId, InboxSendParams params, RequestOptions requestOptions)Unitsend(String inboxId, InboxSendParams params)abstract Unitsend(InboxSendParams params, RequestOptions requestOptions)Unitsend(InboxSendParams params)Unitsend(String inboxId, RequestOptions requestOptions)UnitsetPolicy(String inboxId)Set the sender allowlist and send/reply/read access rules for an inbox owned by the authenticated organization. UnitsetPolicy(String inboxId, InboxSetPolicyParams params, RequestOptions requestOptions)UnitsetPolicy(String inboxId, InboxSetPolicyParams params)abstract UnitsetPolicy(InboxSetPolicyParams params, RequestOptions requestOptions)UnitsetPolicy(InboxSetPolicyParams params)UnitsetPolicy(String inboxId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboxService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboxService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
abstract Unit create(InboxCreateParams params, RequestOptions requestOptions)
-
create
Unit create(InboxCreateParams params)
-
create
Unit create(RequestOptions requestOptions)
-
retrieve
Unit retrieve(String inboxId, InboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String inboxId, InboxRetrieveParams params)
-
retrieve
abstract Unit retrieve(InboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(InboxRetrieveParams params)
-
retrieve
Unit retrieve(String inboxId, RequestOptions requestOptions)
-
list
abstract Unit list(InboxListParams params, RequestOptions requestOptions)
-
list
Unit list(InboxListParams params)
-
list
Unit list(RequestOptions requestOptions)
-
delete
Unit delete(String inboxId, InboxDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String inboxId, InboxDeleteParams params)
-
delete
abstract Unit delete(InboxDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(InboxDeleteParams params)
-
delete
Unit delete(String inboxId, RequestOptions requestOptions)
-
getAttachment
Unit getAttachment(String attachmentId, InboxGetAttachmentParams params)
Get attachment metadata for a message in an inbox owned by the authenticated organization.
-
getAttachment
Unit getAttachment(String attachmentId, InboxGetAttachmentParams params, RequestOptions requestOptions)
-
getAttachment
Unit getAttachment(InboxGetAttachmentParams params)
-
getAttachment
abstract Unit getAttachment(InboxGetAttachmentParams params, RequestOptions requestOptions)
-
getMessage
Unit getMessage(String messageId, InboxGetMessageParams params)
Get a message for an inbox owned by the authenticated organization.
-
getMessage
Unit getMessage(String messageId, InboxGetMessageParams params, RequestOptions requestOptions)
-
getMessage
Unit getMessage(InboxGetMessageParams params)
-
getMessage
abstract Unit getMessage(InboxGetMessageParams params, RequestOptions requestOptions)
-
getPolicy
Unit getPolicy(String inboxId)
Get the sender allowlist and send/reply/read access rules for an inbox owned by the authenticated organization.
-
getPolicy
Unit getPolicy(String inboxId, InboxGetPolicyParams params, RequestOptions requestOptions)
-
getPolicy
Unit getPolicy(String inboxId, InboxGetPolicyParams params)
-
getPolicy
abstract Unit getPolicy(InboxGetPolicyParams params, RequestOptions requestOptions)
-
getPolicy
Unit getPolicy(InboxGetPolicyParams params)
-
getPolicy
Unit getPolicy(String inboxId, RequestOptions requestOptions)
-
listMessages
Unit listMessages(String inboxId)
List messages for an inbox owned by the authenticated organization.
-
listMessages
Unit listMessages(String inboxId, InboxListMessagesParams params, RequestOptions requestOptions)
-
listMessages
Unit listMessages(String inboxId, InboxListMessagesParams params)
-
listMessages
abstract Unit listMessages(InboxListMessagesParams params, RequestOptions requestOptions)
-
listMessages
Unit listMessages(InboxListMessagesParams params)
-
listMessages
Unit listMessages(String inboxId, RequestOptions requestOptions)
-
reply
Unit reply(String messageId, InboxReplyParams params)
Reply to a message in an inbox owned by the authenticated organization.
-
reply
Unit reply(String messageId, InboxReplyParams params, RequestOptions requestOptions)
-
reply
Unit reply(InboxReplyParams params)
-
reply
abstract Unit reply(InboxReplyParams params, RequestOptions requestOptions)
-
send
Unit send(String inboxId)
Send a message from an inbox owned by the authenticated organization.
-
send
Unit send(String inboxId, InboxSendParams params, RequestOptions requestOptions)
-
send
Unit send(String inboxId, InboxSendParams params)
-
send
abstract Unit send(InboxSendParams params, RequestOptions requestOptions)
-
send
Unit send(InboxSendParams params)
-
send
Unit send(String inboxId, RequestOptions requestOptions)
-
setPolicy
Unit setPolicy(String inboxId)
Set the sender allowlist and send/reply/read access rules for an inbox owned by the authenticated organization.
-
setPolicy
Unit setPolicy(String inboxId, InboxSetPolicyParams params, RequestOptions requestOptions)
-
setPolicy
Unit setPolicy(String inboxId, InboxSetPolicyParams params)
-
setPolicy
abstract Unit setPolicy(InboxSetPolicyParams params, RequestOptions requestOptions)
-
setPolicy
Unit setPolicy(InboxSetPolicyParams params)
-
setPolicy
Unit setPolicy(String inboxId, RequestOptions requestOptions)
-
-
-
-