Package dev.case.api.services.blocking.mail.v1
See: Description
-
Interface Summary Interface Description WithRawResponse A view of InboxService that provides access to raw HTTP responses for each method. InboxService Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
Class Summary Class Description WithRawResponseImpl InboxServiceImpl Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows