Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentTypeServiceagentTypes()Matter-native legal workspaces and orchestration primitives abstract PartyServiceparties()Matter-native legal workspaces and orchestration primitives abstract TypeServicetypes()Matter-native legal workspaces and orchestration primitives abstract EventServiceevents()abstract LogServicelog()Matter-native legal workspaces and orchestration primitives abstract MatterPartyServicematterParties()Matter-native legal workspaces and orchestration primitives abstract ShareServiceshares()Matter-native legal workspaces and orchestration primitives abstract WorkItemServiceworkItems()Matter-native legal workspaces and orchestration primitives Unitcreate(V1CreateParams params)Create a new legal matter and optionally link an existing primary vault. abstract Unitcreate(V1CreateParams params, RequestOptions requestOptions)Unitretrieve(String id)Get a single matter by ID. Unitretrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)Unitretrieve(String id, V1RetrieveParams params)abstract Unitretrieve(V1RetrieveParams params, RequestOptions requestOptions)Unitretrieve(V1RetrieveParams params)Unitretrieve(String id, RequestOptions requestOptions)Unitupdate(String id)Update mutable matter fields. Unitupdate(String id, V1UpdateParams params, RequestOptions requestOptions)Unitupdate(String id, V1UpdateParams params)abstract Unitupdate(V1UpdateParams params, RequestOptions requestOptions)Unitupdate(V1UpdateParams params)Unitupdate(String id, RequestOptions requestOptions)Unitlist()List matters for the authenticated organization. abstract Unitlist(V1ListParams params, RequestOptions requestOptions)Unitlist(V1ListParams params)Unitlist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agentTypes
abstract AgentTypeService agentTypes()
Matter-native legal workspaces and orchestration primitives
-
parties
abstract PartyService parties()
Matter-native legal workspaces and orchestration primitives
-
types
abstract TypeService types()
Matter-native legal workspaces and orchestration primitives
-
events
abstract EventService events()
-
log
abstract LogService log()
Matter-native legal workspaces and orchestration primitives
-
matterParties
abstract MatterPartyService matterParties()
Matter-native legal workspaces and orchestration primitives
-
shares
abstract ShareService shares()
Matter-native legal workspaces and orchestration primitives
-
workItems
abstract WorkItemService workItems()
Matter-native legal workspaces and orchestration primitives
-
create
Unit create(V1CreateParams params)
Create a new legal matter and optionally link an existing primary vault.
-
create
abstract Unit create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String id, V1RetrieveParams params)
-
retrieve
abstract Unit retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(V1RetrieveParams params)
-
retrieve
Unit retrieve(String id, RequestOptions requestOptions)
-
update
Unit update(String id, V1UpdateParams params, RequestOptions requestOptions)
-
update
Unit update(String id, V1UpdateParams params)
-
update
abstract Unit update(V1UpdateParams params, RequestOptions requestOptions)
-
update
Unit update(V1UpdateParams params)
-
update
Unit update(String id, RequestOptions requestOptions)
-
list
abstract Unit list(V1ListParams params, RequestOptions requestOptions)
-
list
Unit list(V1ListParams params)
-
list
Unit list(RequestOptions requestOptions)
-
-
-
-