Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentTypeService.WithRawResponseagentTypes()Matter-native legal workspaces and orchestration primitives abstract PartyService.WithRawResponseparties()Matter-native legal workspaces and orchestration primitives abstract TypeService.WithRawResponsetypes()Matter-native legal workspaces and orchestration primitives abstract EventService.WithRawResponseevents()abstract LogService.WithRawResponselog()Matter-native legal workspaces and orchestration primitives abstract MatterPartyService.WithRawResponsematterParties()Matter-native legal workspaces and orchestration primitives abstract ShareService.WithRawResponseshares()Matter-native legal workspaces and orchestration primitives abstract WorkItemService.WithRawResponseworkItems()Matter-native legal workspaces and orchestration primitives HttpResponsecreate(V1CreateParams params)Returns a raw HTTP response for post /matters/v1, but is otherwise the same as V1Service.create.abstract HttpResponsecreate(V1CreateParams params, RequestOptions requestOptions)HttpResponseretrieve(String id)Returns a raw HTTP response for get /matters/v1/{id}, but is otherwise the same as V1Service.retrieve.HttpResponseretrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)HttpResponseretrieve(String id, V1RetrieveParams params)abstract HttpResponseretrieve(V1RetrieveParams params, RequestOptions requestOptions)HttpResponseretrieve(V1RetrieveParams params)HttpResponseretrieve(String id, RequestOptions requestOptions)HttpResponseupdate(String id)Returns a raw HTTP response for patch /matters/v1/{id}, but is otherwise the same as V1Service.update.HttpResponseupdate(String id, V1UpdateParams params, RequestOptions requestOptions)HttpResponseupdate(String id, V1UpdateParams params)abstract HttpResponseupdate(V1UpdateParams params, RequestOptions requestOptions)HttpResponseupdate(V1UpdateParams params)HttpResponseupdate(String id, RequestOptions requestOptions)HttpResponselist()Returns a raw HTTP response for get /matters/v1, but is otherwise the same as V1Service.list.abstract HttpResponselist(V1ListParams params, RequestOptions requestOptions)HttpResponselist(V1ListParams params)HttpResponselist(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agentTypes
abstract AgentTypeService.WithRawResponse agentTypes()
Matter-native legal workspaces and orchestration primitives
-
parties
abstract PartyService.WithRawResponse parties()
Matter-native legal workspaces and orchestration primitives
-
types
abstract TypeService.WithRawResponse types()
Matter-native legal workspaces and orchestration primitives
-
events
abstract EventService.WithRawResponse events()
-
log
abstract LogService.WithRawResponse log()
Matter-native legal workspaces and orchestration primitives
-
matterParties
abstract MatterPartyService.WithRawResponse matterParties()
Matter-native legal workspaces and orchestration primitives
-
shares
abstract ShareService.WithRawResponse shares()
Matter-native legal workspaces and orchestration primitives
-
workItems
abstract WorkItemService.WithRawResponse workItems()
Matter-native legal workspaces and orchestration primitives
-
create
@MustBeClosed() HttpResponse create(V1CreateParams params)
Returns a raw HTTP response for
post /matters/v1, but is otherwise the same as V1Service.create.
-
create
@MustBeClosed() abstract HttpResponse create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponse retrieve(String id)
Returns a raw HTTP response for
get /matters/v1/{id}, but is otherwise the same as V1Service.retrieve.
-
retrieve
@MustBeClosed() HttpResponse retrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponse retrieve(String id, V1RetrieveParams params)
-
retrieve
@MustBeClosed() abstract HttpResponse retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponse retrieve(V1RetrieveParams params)
-
retrieve
@MustBeClosed() HttpResponse retrieve(String id, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponse update(String id)
Returns a raw HTTP response for
patch /matters/v1/{id}, but is otherwise the same as V1Service.update.
-
update
@MustBeClosed() HttpResponse update(String id, V1UpdateParams params, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponse update(String id, V1UpdateParams params)
-
update
@MustBeClosed() abstract HttpResponse update(V1UpdateParams params, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponse update(V1UpdateParams params)
-
update
@MustBeClosed() HttpResponse update(String id, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponse list()
Returns a raw HTTP response for
get /matters/v1, but is otherwise the same as V1Service.list.
-
list
@MustBeClosed() abstract HttpResponse list(V1ListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponse list(V1ListParams params)
-
list
@MustBeClosed() HttpResponse list(RequestOptions requestOptions)
-
-
-
-