Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.V1Service
public final class V1ServiceImpl implements V1Service
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentTypeServiceagentTypes()Matter-native legal workspaces and orchestration primitives PartyServiceparties()Matter-native legal workspaces and orchestration primitives TypeServicetypes()Matter-native legal workspaces and orchestration primitives EventServiceevents()LogServicelog()Matter-native legal workspaces and orchestration primitives MatterPartyServicematterParties()Matter-native legal workspaces and orchestration primitives ShareServiceshares()Matter-native legal workspaces and orchestration primitives WorkItemServiceworkItems()Matter-native legal workspaces and orchestration primitives Unitcreate(V1CreateParams params, RequestOptions requestOptions)Unitretrieve(V1RetrieveParams params, RequestOptions requestOptions)Unitupdate(V1UpdateParams params, RequestOptions requestOptions)Unitlist(V1ListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.matters.V1Service
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agentTypes
AgentTypeService agentTypes()
Matter-native legal workspaces and orchestration primitives
-
parties
PartyService parties()
Matter-native legal workspaces and orchestration primitives
-
types
TypeService types()
Matter-native legal workspaces and orchestration primitives
-
events
EventService events()
-
log
LogService log()
Matter-native legal workspaces and orchestration primitives
-
matterParties
MatterPartyService matterParties()
Matter-native legal workspaces and orchestration primitives
-
shares
ShareService shares()
Matter-native legal workspaces and orchestration primitives
-
workItems
WorkItemService workItems()
Matter-native legal workspaces and orchestration primitives
-
create
Unit create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
update
Unit update(V1UpdateParams params, RequestOptions requestOptions)
-
list
Unit list(V1ListParams params, RequestOptions requestOptions)
-
-
-
-