Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentTypeService.WithRawResponseagentTypes()Matter-native legal workspaces and orchestration primitives PartyService.WithRawResponseparties()Matter-native legal workspaces and orchestration primitives TypeService.WithRawResponsetypes()Matter-native legal workspaces and orchestration primitives EventService.WithRawResponseevents()LogService.WithRawResponselog()Matter-native legal workspaces and orchestration primitives MatterPartyService.WithRawResponsematterParties()Matter-native legal workspaces and orchestration primitives ShareService.WithRawResponseshares()Matter-native legal workspaces and orchestration primitives WorkItemService.WithRawResponseworkItems()Matter-native legal workspaces and orchestration primitives HttpResponsecreate(V1CreateParams params, RequestOptions requestOptions)HttpResponseretrieve(V1RetrieveParams params, RequestOptions requestOptions)HttpResponseupdate(V1UpdateParams params, RequestOptions requestOptions)HttpResponselist(V1ListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.matters.V1Service.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agentTypes
AgentTypeService.WithRawResponse agentTypes()
Matter-native legal workspaces and orchestration primitives
-
parties
PartyService.WithRawResponse parties()
Matter-native legal workspaces and orchestration primitives
-
types
TypeService.WithRawResponse types()
Matter-native legal workspaces and orchestration primitives
-
events
EventService.WithRawResponse events()
-
log
LogService.WithRawResponse log()
Matter-native legal workspaces and orchestration primitives
-
matterParties
MatterPartyService.WithRawResponse matterParties()
Matter-native legal workspaces and orchestration primitives
-
shares
ShareService.WithRawResponse shares()
Matter-native legal workspaces and orchestration primitives
-
workItems
WorkItemService.WithRawResponse workItems()
Matter-native legal workspaces and orchestration primitives
-
create
HttpResponse create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponse retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponse update(V1UpdateParams params, RequestOptions requestOptions)
-
list
HttpResponse list(V1ListParams params, RequestOptions requestOptions)
-
-
-
-