Interface LogService
-
- All Implemented Interfaces:
public interface LogServiceMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLogService.WithRawResponseA view of LogService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract LogService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract LogServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(String id, LogCreateParams params)Append a manual operational note or event to a matter log. Unitcreate(String id, LogCreateParams params, RequestOptions requestOptions)Unitcreate(LogCreateParams params)abstract Unitcreate(LogCreateParams params, RequestOptions requestOptions)Unitlist(String id)List the operational history for a matter. Unitlist(String id, LogListParams params, RequestOptions requestOptions)Unitlist(String id, LogListParams params)abstract Unitlist(LogListParams params, RequestOptions requestOptions)Unitlist(LogListParams params)Unitlist(String id, RequestOptions requestOptions)LogExportResponseexport(String id)Bulk export matter log entries for audits, visibility, and eval pipelines. LogExportResponseexport(String id, LogExportParams params, RequestOptions requestOptions)LogExportResponseexport(String id, LogExportParams params)abstract LogExportResponseexport(LogExportParams params, RequestOptions requestOptions)LogExportResponseexport(LogExportParams params)LogExportResponseexport(String id, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract LogService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract LogService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(String id, LogCreateParams params)
Append a manual operational note or event to a matter log.
-
create
Unit create(String id, LogCreateParams params, RequestOptions requestOptions)
-
create
Unit create(LogCreateParams params)
-
create
abstract Unit create(LogCreateParams params, RequestOptions requestOptions)
-
list
Unit list(String id, LogListParams params, RequestOptions requestOptions)
-
list
Unit list(String id, LogListParams params)
-
list
abstract Unit list(LogListParams params, RequestOptions requestOptions)
-
list
Unit list(LogListParams params)
-
list
Unit list(String id, RequestOptions requestOptions)
-
export
LogExportResponse export(String id)
Bulk export matter log entries for audits, visibility, and eval pipelines. Supports json, csv, tsv, and jsonl. Limited to 10,000 entries per request.
-
export
LogExportResponse export(String id, LogExportParams params, RequestOptions requestOptions)
-
export
LogExportResponse export(String id, LogExportParams params)
-
export
abstract LogExportResponse export(LogExportParams params, RequestOptions requestOptions)
-
export
LogExportResponse export(LogExportParams params)
-
export
LogExportResponse export(String id, RequestOptions requestOptions)
-
-
-
-