Class LogServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.v1.LogService
public final class LogServiceImpl implements LogService
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LogService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LogServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(LogCreateParams params, RequestOptions requestOptions)Unitlist(LogListParams params, RequestOptions requestOptions)LogExportResponseexport(LogExportParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.matters.v1.LogService
create, create, create, export, export, export, export, export, list, list, list, list, list -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
LogService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LogService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(LogCreateParams params, RequestOptions requestOptions)
-
list
Unit list(LogListParams params, RequestOptions requestOptions)
-
export
LogExportResponse export(LogExportParams params, RequestOptions requestOptions)
-
-
-
-