Class LogServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.v1.LogService.WithRawResponse
public final class LogServiceImpl.WithRawResponseImpl implements LogService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LogService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(LogCreateParams params, RequestOptions requestOptions)HttpResponselist(LogListParams params, RequestOptions requestOptions)HttpResponseFor<LogExportResponse>export(LogExportParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.matters.v1.LogService.WithRawResponse
create, create, create, export, export, export, export, export, list, list, list, list, list -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
LogService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponse create(LogCreateParams params, RequestOptions requestOptions)
-
list
HttpResponse list(LogListParams params, RequestOptions requestOptions)
-
export
HttpResponseFor<LogExportResponse> export(LogExportParams params, RequestOptions requestOptions)
-
-
-
-