Interface MatterPartyService
-
- All Implemented Interfaces:
public interface MatterPartyServiceMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMatterPartyService.WithRawResponseA view of MatterPartyService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MatterPartyService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MatterPartyServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(String id, MatterPartyCreateParams params)Attach a reusable party to a matter with a matter-specific role. Unitcreate(String id, MatterPartyCreateParams params, RequestOptions requestOptions)Unitcreate(MatterPartyCreateParams params)abstract Unitcreate(MatterPartyCreateParams params, RequestOptions requestOptions)Unitlist(String id)List parties attached to a matter. Unitlist(String id, MatterPartyListParams params, RequestOptions requestOptions)Unitlist(String id, MatterPartyListParams params)abstract Unitlist(MatterPartyListParams params, RequestOptions requestOptions)Unitlist(MatterPartyListParams params)Unitlist(String id, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract MatterPartyService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MatterPartyService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(String id, MatterPartyCreateParams params)
Attach a reusable party to a matter with a matter-specific role.
-
create
Unit create(String id, MatterPartyCreateParams params, RequestOptions requestOptions)
-
create
Unit create(MatterPartyCreateParams params)
-
create
abstract Unit create(MatterPartyCreateParams params, RequestOptions requestOptions)
-
list
Unit list(String id, MatterPartyListParams params, RequestOptions requestOptions)
-
list
Unit list(String id, MatterPartyListParams params)
-
list
abstract Unit list(MatterPartyListParams params, RequestOptions requestOptions)
-
list
Unit list(MatterPartyListParams params)
-
list
Unit list(String id, RequestOptions requestOptions)
-
-
-
-