Class MatterPartyServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.v1.MatterPartyService.WithRawResponse
public final class MatterPartyServiceImpl.WithRawResponseImpl implements MatterPartyService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MatterPartyService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(MatterPartyCreateParams params, RequestOptions requestOptions)HttpResponselist(MatterPartyListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
MatterPartyService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponse create(MatterPartyCreateParams params, RequestOptions requestOptions)
-
list
HttpResponse list(MatterPartyListParams params, RequestOptions requestOptions)
-
-
-
-