Interface PartyService
-
- All Implemented Interfaces:
public interface PartyServiceMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePartyService.WithRawResponseA view of PartyService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PartyService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PartyServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(PartyCreateParams params)Create a reusable legal party for the authenticated organization. abstract Unitcreate(PartyCreateParams params, RequestOptions requestOptions)Unitretrieve(String partyId)Get a reusable legal party by ID. Unitretrieve(String partyId, PartyRetrieveParams params, RequestOptions requestOptions)Unitretrieve(String partyId, PartyRetrieveParams params)abstract Unitretrieve(PartyRetrieveParams params, RequestOptions requestOptions)Unitretrieve(PartyRetrieveParams params)Unitretrieve(String partyId, RequestOptions requestOptions)Unitupdate(String partyId)Update a reusable legal party. Unitupdate(String partyId, PartyUpdateParams params, RequestOptions requestOptions)Unitupdate(String partyId, PartyUpdateParams params)abstract Unitupdate(PartyUpdateParams params, RequestOptions requestOptions)Unitupdate(PartyUpdateParams params)Unitupdate(String partyId, RequestOptions requestOptions)Unitlist()List reusable legal parties for the authenticated organization. abstract Unitlist(PartyListParams params, RequestOptions requestOptions)Unitlist(PartyListParams params)Unitlist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PartyService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PartyService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(PartyCreateParams params)
Create a reusable legal party for the authenticated organization.
-
create
abstract Unit create(PartyCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String partyId, PartyRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String partyId, PartyRetrieveParams params)
-
retrieve
abstract Unit retrieve(PartyRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(PartyRetrieveParams params)
-
retrieve
Unit retrieve(String partyId, RequestOptions requestOptions)
-
update
Unit update(String partyId, PartyUpdateParams params, RequestOptions requestOptions)
-
update
Unit update(String partyId, PartyUpdateParams params)
-
update
abstract Unit update(PartyUpdateParams params, RequestOptions requestOptions)
-
update
Unit update(PartyUpdateParams params)
-
update
Unit update(String partyId, RequestOptions requestOptions)
-
list
abstract Unit list(PartyListParams params, RequestOptions requestOptions)
-
list
Unit list(PartyListParams params)
-
list
Unit list(RequestOptions requestOptions)
-
-
-
-