Interface PartyService.WithRawResponse
-
- All Implemented Interfaces:
public interface PartyService.WithRawResponseA view of PartyService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract PartyService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(PartyCreateParams params)Returns a raw HTTP response for post /matters/v1/parties, but is otherwise the same as PartyService.create.abstract HttpResponsecreate(PartyCreateParams params, RequestOptions requestOptions)HttpResponseretrieve(String partyId)Returns a raw HTTP response for get /matters/v1/parties/{partyId}, but is otherwise the same as PartyService.retrieve.HttpResponseretrieve(String partyId, PartyRetrieveParams params, RequestOptions requestOptions)HttpResponseretrieve(String partyId, PartyRetrieveParams params)abstract HttpResponseretrieve(PartyRetrieveParams params, RequestOptions requestOptions)HttpResponseretrieve(PartyRetrieveParams params)HttpResponseretrieve(String partyId, RequestOptions requestOptions)HttpResponseupdate(String partyId)Returns a raw HTTP response for patch /matters/v1/parties/{partyId}, but is otherwise the same as PartyService.update.HttpResponseupdate(String partyId, PartyUpdateParams params, RequestOptions requestOptions)HttpResponseupdate(String partyId, PartyUpdateParams params)abstract HttpResponseupdate(PartyUpdateParams params, RequestOptions requestOptions)HttpResponseupdate(PartyUpdateParams params)HttpResponseupdate(String partyId, RequestOptions requestOptions)HttpResponselist()Returns a raw HTTP response for get /matters/v1/parties, but is otherwise the same as PartyService.list.abstract HttpResponselist(PartyListParams params, RequestOptions requestOptions)HttpResponselist(PartyListParams params)HttpResponselist(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract PartyService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponse create(PartyCreateParams params)
Returns a raw HTTP response for
post /matters/v1/parties, but is otherwise the same as PartyService.create.
-
create
@MustBeClosed() abstract HttpResponse create(PartyCreateParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponse retrieve(String partyId)
Returns a raw HTTP response for
get /matters/v1/parties/{partyId}, but is otherwise the same as PartyService.retrieve.
-
retrieve
@MustBeClosed() HttpResponse retrieve(String partyId, PartyRetrieveParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponse retrieve(String partyId, PartyRetrieveParams params)
-
retrieve
@MustBeClosed() abstract HttpResponse retrieve(PartyRetrieveParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponse retrieve(PartyRetrieveParams params)
-
retrieve
@MustBeClosed() HttpResponse retrieve(String partyId, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponse update(String partyId)
Returns a raw HTTP response for
patch /matters/v1/parties/{partyId}, but is otherwise the same as PartyService.update.
-
update
@MustBeClosed() HttpResponse update(String partyId, PartyUpdateParams params, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponse update(String partyId, PartyUpdateParams params)
-
update
@MustBeClosed() abstract HttpResponse update(PartyUpdateParams params, RequestOptions requestOptions)
-
update
@MustBeClosed() HttpResponse update(PartyUpdateParams params)
-
update
@MustBeClosed() HttpResponse update(String partyId, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponse list()
Returns a raw HTTP response for
get /matters/v1/parties, but is otherwise the same as PartyService.list.
-
list
@MustBeClosed() abstract HttpResponse list(PartyListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponse list(PartyListParams params)
-
list
@MustBeClosed() HttpResponse list(RequestOptions requestOptions)
-
-
-
-