Class PartyServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.v1.PartyService
public final class PartyServiceImpl implements PartyService
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPartyServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PartyService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PartyServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(PartyCreateParams params, RequestOptions requestOptions)Unitretrieve(PartyRetrieveParams params, RequestOptions requestOptions)Unitupdate(PartyUpdateParams params, RequestOptions requestOptions)Unitlist(PartyListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.matters.v1.PartyService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PartyService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PartyService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(PartyCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(PartyRetrieveParams params, RequestOptions requestOptions)
-
update
Unit update(PartyUpdateParams params, RequestOptions requestOptions)
-
list
Unit list(PartyListParams params, RequestOptions requestOptions)
-
-
-
-