Class PartyServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.v1.PartyService.WithRawResponse
public final class PartyServiceImpl.WithRawResponseImpl implements PartyService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PartyService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(PartyCreateParams params, RequestOptions requestOptions)HttpResponseretrieve(PartyRetrieveParams params, RequestOptions requestOptions)HttpResponseupdate(PartyUpdateParams params, RequestOptions requestOptions)HttpResponselist(PartyListParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.matters.v1.PartyService.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
PartyService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponse create(PartyCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponse retrieve(PartyRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponse update(PartyUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponse list(PartyListParams params, RequestOptions requestOptions)
-
-
-
-