Interface ShareService
-
- All Implemented Interfaces:
public interface ShareServiceMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceShareService.WithRawResponseA view of ShareService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ShareService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ShareServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(String id, ShareCreateParams params)Grant another organization scoped access to this matter and its primary vault. Unitcreate(String id, ShareCreateParams params, RequestOptions requestOptions)Unitcreate(ShareCreateParams params)abstract Unitcreate(ShareCreateParams params, RequestOptions requestOptions)Unitlist(String id)List cross-org shares for a matter. Unitlist(String id, ShareListParams params, RequestOptions requestOptions)Unitlist(String id, ShareListParams params)abstract Unitlist(ShareListParams params, RequestOptions requestOptions)Unitlist(ShareListParams params)Unitlist(String id, RequestOptions requestOptions)Unitdelete(String shareId, ShareDeleteParams params)Revoke a matter share and its linked vault share. Unitdelete(String shareId, ShareDeleteParams params, RequestOptions requestOptions)Unitdelete(ShareDeleteParams params)abstract Unitdelete(ShareDeleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ShareService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ShareService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(String id, ShareCreateParams params)
Grant another organization scoped access to this matter and its primary vault.
-
create
Unit create(String id, ShareCreateParams params, RequestOptions requestOptions)
-
create
Unit create(ShareCreateParams params)
-
create
abstract Unit create(ShareCreateParams params, RequestOptions requestOptions)
-
list
Unit list(String id, ShareListParams params, RequestOptions requestOptions)
-
list
Unit list(String id, ShareListParams params)
-
list
abstract Unit list(ShareListParams params, RequestOptions requestOptions)
-
list
Unit list(ShareListParams params)
-
list
Unit list(String id, RequestOptions requestOptions)
-
delete
Unit delete(String shareId, ShareDeleteParams params)
Revoke a matter share and its linked vault share.
-
delete
Unit delete(String shareId, ShareDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(ShareDeleteParams params)
-
delete
abstract Unit delete(ShareDeleteParams params, RequestOptions requestOptions)
-
-
-
-