Interface ShareService.WithRawResponse
-
- All Implemented Interfaces:
public interface ShareService.WithRawResponseA view of ShareService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ShareService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(String id, ShareCreateParams params)Returns a raw HTTP response for post /matters/v1/{id}/shares, but is otherwise the same as ShareService.create.HttpResponsecreate(String id, ShareCreateParams params, RequestOptions requestOptions)HttpResponsecreate(ShareCreateParams params)abstract HttpResponsecreate(ShareCreateParams params, RequestOptions requestOptions)HttpResponselist(String id)Returns a raw HTTP response for get /matters/v1/{id}/shares, but is otherwise the same as ShareService.list.HttpResponselist(String id, ShareListParams params, RequestOptions requestOptions)HttpResponselist(String id, ShareListParams params)abstract HttpResponselist(ShareListParams params, RequestOptions requestOptions)HttpResponselist(ShareListParams params)HttpResponselist(String id, RequestOptions requestOptions)HttpResponsedelete(String shareId, ShareDeleteParams params)Returns a raw HTTP response for delete /matters/v1/{id}/shares/{shareId}, but is otherwise the same as ShareService.delete.HttpResponsedelete(String shareId, ShareDeleteParams params, RequestOptions requestOptions)HttpResponsedelete(ShareDeleteParams params)abstract HttpResponsedelete(ShareDeleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ShareService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponse create(String id, ShareCreateParams params)
Returns a raw HTTP response for
post /matters/v1/{id}/shares, but is otherwise the same as ShareService.create.
-
create
@MustBeClosed() HttpResponse create(String id, ShareCreateParams params, RequestOptions requestOptions)
-
create
@MustBeClosed() HttpResponse create(ShareCreateParams params)
-
create
@MustBeClosed() abstract HttpResponse create(ShareCreateParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponse list(String id)
Returns a raw HTTP response for
get /matters/v1/{id}/shares, but is otherwise the same as ShareService.list.
-
list
@MustBeClosed() HttpResponse list(String id, ShareListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponse list(String id, ShareListParams params)
-
list
@MustBeClosed() abstract HttpResponse list(ShareListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponse list(ShareListParams params)
-
list
@MustBeClosed() HttpResponse list(String id, RequestOptions requestOptions)
-
delete
@MustBeClosed() HttpResponse delete(String shareId, ShareDeleteParams params)
Returns a raw HTTP response for
delete /matters/v1/{id}/shares/{shareId}, but is otherwise the same as ShareService.delete.
-
delete
@MustBeClosed() HttpResponse delete(String shareId, ShareDeleteParams params, RequestOptions requestOptions)
-
delete
@MustBeClosed() HttpResponse delete(ShareDeleteParams params)
-
delete
@MustBeClosed() abstract HttpResponse delete(ShareDeleteParams params, RequestOptions requestOptions)
-
-
-
-