Class ShareServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.matters.v1.ShareService
public final class ShareServiceImpl implements ShareService
Matter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classShareServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ShareService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ShareServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(ShareCreateParams params, RequestOptions requestOptions)Unitlist(ShareListParams params, RequestOptions requestOptions)Unitdelete(ShareDeleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ShareService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ShareService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(ShareCreateParams params, RequestOptions requestOptions)
-
list
Unit list(ShareListParams params, RequestOptions requestOptions)
-
delete
Unit delete(ShareDeleteParams params, RequestOptions requestOptions)
-
-
-
-