Interface WorkItemService
-
- All Implemented Interfaces:
public interface WorkItemServiceMatter-native legal workspaces and orchestration primitives
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWorkItemService.WithRawResponseA view of WorkItemService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WorkItemService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WorkItemServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(String id, WorkItemCreateParams params)Create an active work item on a matter. Unitcreate(String id, WorkItemCreateParams params, RequestOptions requestOptions)Unitcreate(WorkItemCreateParams params)abstract Unitcreate(WorkItemCreateParams params, RequestOptions requestOptions)Unitretrieve(String workItemId, WorkItemRetrieveParams params)Get a single work item for a matter. Unitretrieve(String workItemId, WorkItemRetrieveParams params, RequestOptions requestOptions)Unitretrieve(WorkItemRetrieveParams params)abstract Unitretrieve(WorkItemRetrieveParams params, RequestOptions requestOptions)Unitupdate(String workItemId, WorkItemUpdateParams params)Update a matter work item. Unitupdate(String workItemId, WorkItemUpdateParams params, RequestOptions requestOptions)Unitupdate(WorkItemUpdateParams params)abstract Unitupdate(WorkItemUpdateParams params, RequestOptions requestOptions)Unitlist(String id)List active work items for a matter. Unitlist(String id, WorkItemListParams params, RequestOptions requestOptions)Unitlist(String id, WorkItemListParams params)abstract Unitlist(WorkItemListParams params, RequestOptions requestOptions)Unitlist(WorkItemListParams params)Unitlist(String id, RequestOptions requestOptions)Unitdecide(String workItemId, WorkItemDecideParams params)Allow a human to act as the orchestrator for a work item. Unitdecide(String workItemId, WorkItemDecideParams params, RequestOptions requestOptions)Unitdecide(WorkItemDecideParams params)abstract Unitdecide(WorkItemDecideParams params, RequestOptions requestOptions)UnitlistExecutions(String workItemId, WorkItemListExecutionsParams params)List execution attempts for a work item, including agent and run linkage. UnitlistExecutions(String workItemId, WorkItemListExecutionsParams params, RequestOptions requestOptions)UnitlistExecutions(WorkItemListExecutionsParams params)abstract UnitlistExecutions(WorkItemListExecutionsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract WorkItemService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WorkItemService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(String id, WorkItemCreateParams params)
Create an active work item on a matter.
-
create
Unit create(String id, WorkItemCreateParams params, RequestOptions requestOptions)
-
create
Unit create(WorkItemCreateParams params)
-
create
abstract Unit create(WorkItemCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String workItemId, WorkItemRetrieveParams params)
Get a single work item for a matter.
-
retrieve
Unit retrieve(String workItemId, WorkItemRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(WorkItemRetrieveParams params)
-
retrieve
abstract Unit retrieve(WorkItemRetrieveParams params, RequestOptions requestOptions)
-
update
Unit update(String workItemId, WorkItemUpdateParams params)
Update a matter work item.
-
update
Unit update(String workItemId, WorkItemUpdateParams params, RequestOptions requestOptions)
-
update
Unit update(WorkItemUpdateParams params)
-
update
abstract Unit update(WorkItemUpdateParams params, RequestOptions requestOptions)
-
list
Unit list(String id, WorkItemListParams params, RequestOptions requestOptions)
-
list
Unit list(String id, WorkItemListParams params)
-
list
abstract Unit list(WorkItemListParams params, RequestOptions requestOptions)
-
list
Unit list(WorkItemListParams params)
-
list
Unit list(String id, RequestOptions requestOptions)
-
decide
Unit decide(String workItemId, WorkItemDecideParams params)
Allow a human to act as the orchestrator for a work item.
-
decide
Unit decide(String workItemId, WorkItemDecideParams params, RequestOptions requestOptions)
-
decide
Unit decide(WorkItemDecideParams params)
-
decide
abstract Unit decide(WorkItemDecideParams params, RequestOptions requestOptions)
-
listExecutions
Unit listExecutions(String workItemId, WorkItemListExecutionsParams params)
List execution attempts for a work item, including agent and run linkage.
-
listExecutions
Unit listExecutions(String workItemId, WorkItemListExecutionsParams params, RequestOptions requestOptions)
-
listExecutions
Unit listExecutions(WorkItemListExecutionsParams params)
-
listExecutions
abstract Unit listExecutions(WorkItemListExecutionsParams params, RequestOptions requestOptions)
-
-
-
-