Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.memory.V1Service
public final class V1ServiceImpl implements V1Service
Persistent memory for AI agents with semantic search and 12 generic indexed tag fields
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1CreateResponsecreate(V1CreateParams params, RequestOptions requestOptions)V1RetrieveResponseretrieve(V1RetrieveParams params, RequestOptions requestOptions)V1ListResponselist(V1ListParams params, RequestOptions requestOptions)V1DeleteResponsedelete(V1DeleteParams params, RequestOptions requestOptions)V1DeleteAllResponsedeleteAll(V1DeleteAllParams params, RequestOptions requestOptions)V1SearchResponsesearch(V1SearchParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.memory.V1Service
create, delete, delete, delete, delete, delete, deleteAll, deleteAll, deleteAll, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, search -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
V1CreateResponse create(V1CreateParams params, RequestOptions requestOptions)
-
retrieve
V1RetrieveResponse retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
list
V1ListResponse list(V1ListParams params, RequestOptions requestOptions)
-
delete
V1DeleteResponse delete(V1DeleteParams params, RequestOptions requestOptions)
-
deleteAll
V1DeleteAllResponse deleteAll(V1DeleteAllParams params, RequestOptions requestOptions)
-
search
V1SearchResponse search(V1SearchParams params, RequestOptions requestOptions)
-
-
-
-