Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceExtract text from PDFs, images, and scanned documents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1RetrieveResponseretrieve(String id)Retrieve the status and results of an OCR job. V1RetrieveResponseretrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)V1RetrieveResponseretrieve(String id, V1RetrieveParams params)abstract V1RetrieveResponseretrieve(V1RetrieveParams params, RequestOptions requestOptions)V1RetrieveResponseretrieve(V1RetrieveParams params)V1RetrieveResponseretrieve(String id, RequestOptions requestOptions)HttpResponsedownload(V1DownloadParams.Type type, V1DownloadParams params)Download OCR processing results in various formats. HttpResponsedownload(V1DownloadParams.Type type, V1DownloadParams params, RequestOptions requestOptions)HttpResponsedownload(V1DownloadParams params)abstract HttpResponsedownload(V1DownloadParams params, RequestOptions requestOptions)V1ProcessResponseprocess(V1ProcessParams params)Submit a document for OCR processing to extract text, detect tables, forms, and other features. abstract V1ProcessResponseprocess(V1ProcessParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
V1RetrieveResponse retrieve(String id)
Retrieve the status and results of an OCR job. Returns job progress, extracted text, and metadata when processing is complete.
-
retrieve
V1RetrieveResponse retrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
V1RetrieveResponse retrieve(String id, V1RetrieveParams params)
-
retrieve
abstract V1RetrieveResponse retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
V1RetrieveResponse retrieve(V1RetrieveParams params)
-
retrieve
V1RetrieveResponse retrieve(String id, RequestOptions requestOptions)
-
download
@MustBeClosed() HttpResponse download(V1DownloadParams.Type type, V1DownloadParams params)
Download OCR processing results in various formats. Returns the processed document as text extraction, structured JSON with coordinates, searchable PDF with text layer, or the original uploaded document.
-
download
@MustBeClosed() HttpResponse download(V1DownloadParams.Type type, V1DownloadParams params, RequestOptions requestOptions)
-
download
@MustBeClosed() HttpResponse download(V1DownloadParams params)
-
download
@MustBeClosed() abstract HttpResponse download(V1DownloadParams params, RequestOptions requestOptions)
-
process
V1ProcessResponse process(V1ProcessParams params)
Submit a document for OCR processing to extract text, detect tables, forms, and other features. Supports PDFs, images, and scanned documents. Returns a job ID that can be used to track processing status.
-
process
abstract V1ProcessResponse process(V1ProcessParams params, RequestOptions requestOptions)
-
-
-
-