Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.ocr.V1Service
public final class V1ServiceImpl implements V1Service
Extract text from PDFs, images, and scanned documents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1RetrieveResponseretrieve(V1RetrieveParams params, RequestOptions requestOptions)HttpResponsedownload(V1DownloadParams params, RequestOptions requestOptions)V1ProcessResponseprocess(V1ProcessParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
V1RetrieveResponse retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
download
HttpResponse download(V1DownloadParams params, RequestOptions requestOptions)
-
process
V1ProcessResponse process(V1ProcessParams params, RequestOptions requestOptions)
-
-
-
-