Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.ocr.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<V1RetrieveResponse>retrieve(V1RetrieveParams params, RequestOptions requestOptions)HttpResponsedownload(V1DownloadParams params, RequestOptions requestOptions)HttpResponseFor<V1ProcessResponse>process(V1ProcessParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.ocr.V1Service.WithRawResponse
download, download, download, process, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<V1RetrieveResponse> retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
download
HttpResponse download(V1DownloadParams params, RequestOptions requestOptions)
-
process
HttpResponseFor<V1ProcessResponse> process(V1ProcessParams params, RequestOptions requestOptions)
-
-
-
-