Interface V1Service
-
- All Implemented Interfaces:
public interface V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(V1CreateParams params)Provision a new operator instance for the organization. abstract Unitcreate(V1CreateParams params, RequestOptions requestOptions)UnitcreateChatCompletion()Proxy a chat completion request to the organization's operator instance. abstract UnitcreateChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)UnitcreateChatCompletion(V1CreateChatCompletionParams params)UnitcreateChatCompletion(RequestOptions requestOptions)UnitcreateResponse()Proxy a response request to the organization's operator instance. abstract UnitcreateResponse(V1CreateResponseParams params, RequestOptions requestOptions)UnitcreateResponse(V1CreateResponseParams params)UnitcreateResponse(RequestOptions requestOptions)UnitgetStatus()Get the status of the organization's operator instance. abstract UnitgetStatus(V1GetStatusParams params, RequestOptions requestOptions)UnitgetStatus(V1GetStatusParams params)UnitgetStatus(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(V1CreateParams params)
Provision a new operator instance for the organization.
-
create
abstract Unit create(V1CreateParams params, RequestOptions requestOptions)
-
createChatCompletion
Unit createChatCompletion()
Proxy a chat completion request to the organization's operator instance.
-
createChatCompletion
abstract Unit createChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)
-
createChatCompletion
Unit createChatCompletion(V1CreateChatCompletionParams params)
-
createChatCompletion
Unit createChatCompletion(RequestOptions requestOptions)
-
createResponse
Unit createResponse()
Proxy a response request to the organization's operator instance.
-
createResponse
abstract Unit createResponse(V1CreateResponseParams params, RequestOptions requestOptions)
-
createResponse
Unit createResponse(V1CreateResponseParams params)
-
createResponse
Unit createResponse(RequestOptions requestOptions)
-
getStatus
abstract Unit getStatus(V1GetStatusParams params, RequestOptions requestOptions)
-
getStatus
Unit getStatus(V1GetStatusParams params)
-
getStatus
Unit getStatus(RequestOptions requestOptions)
-
-
-
-