Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.operator.V1Service
public final class V1ServiceImpl implements V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(V1CreateParams params, RequestOptions requestOptions)UnitcreateChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)UnitcreateResponse(V1CreateResponseParams params, RequestOptions requestOptions)UnitgetStatus(V1GetStatusParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.operator.V1Service
create, createChatCompletion, createChatCompletion, createChatCompletion, createResponse, createResponse, createResponse, getStatus, getStatus, getStatus -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(V1CreateParams params, RequestOptions requestOptions)
-
createChatCompletion
Unit createChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)
-
createResponse
Unit createResponse(V1CreateResponseParams params, RequestOptions requestOptions)
-
getStatus
Unit getStatus(V1GetStatusParams params, RequestOptions requestOptions)
-
-
-
-