Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.operator.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(V1CreateParams params, RequestOptions requestOptions)HttpResponsecreateChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)HttpResponsecreateResponse(V1CreateResponseParams params, RequestOptions requestOptions)HttpResponsegetStatus(V1GetStatusParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.operator.V1Service.WithRawResponse
create, createChatCompletion, createChatCompletion, createChatCompletion, createResponse, createResponse, createResponse, getStatus, getStatus, getStatus -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponse create(V1CreateParams params, RequestOptions requestOptions)
-
createChatCompletion
HttpResponse createChatCompletion(V1CreateChatCompletionParams params, RequestOptions requestOptions)
-
createResponse
HttpResponse createResponse(V1CreateResponseParams params, RequestOptions requestOptions)
-
getStatus
HttpResponse getStatus(V1GetStatusParams params, RequestOptions requestOptions)
-
-
-
-