Package dev.case.api.services.blocking
See: Description
-
Interface Summary Interface Description WithRawResponse A view of AgentService that provides access to raw HTTP responses for each method. AgentService WithRawResponse A view of ApplicationService that provides access to raw HTTP responses for each method. ApplicationService WithRawResponse A view of ComputeService that provides access to raw HTTP responses for each method. ComputeService WithRawResponse A view of DatabaseService that provides access to raw HTTP responses for each method. DatabaseService WithRawResponse A view of FormatService that provides access to raw HTTP responses for each method. FormatService WithRawResponse A view of LegalService that provides access to raw HTTP responses for each method. LegalService WithRawResponse A view of LlmService that provides access to raw HTTP responses for each method. LlmService Access 40+ language models through a unified API WithRawResponse A view of MemoryService that provides access to raw HTTP responses for each method. MemoryService WithRawResponse A view of OcrService that provides access to raw HTTP responses for each method. OcrService WithRawResponse A view of PrivilegeService that provides access to raw HTTP responses for each method. PrivilegeService WithRawResponse A view of SearchService that provides access to raw HTTP responses for each method. SearchService WithRawResponse A view of SkillService that provides access to raw HTTP responses for each method. SkillService Search and read legal AI skills for agents WithRawResponse A view of SuperdocService that provides access to raw HTTP responses for each method. SuperdocService WithRawResponse A view of SystemService that provides access to raw HTTP responses for each method. SystemService Public system metadata and discovery endpoints WithRawResponse A view of TranslateService that provides access to raw HTTP responses for each method. TranslateService WithRawResponse A view of VaultService that provides access to raw HTTP responses for each method. VaultService Secure document storage with semantic search and GraphRAG WithRawResponse A view of VoiceService that provides access to raw HTTP responses for each method. VoiceService -
Class Summary Class Description WithRawResponseImpl AgentServiceImpl WithRawResponseImpl ApplicationServiceImpl WithRawResponseImpl ComputeServiceImpl WithRawResponseImpl DatabaseServiceImpl WithRawResponseImpl FormatServiceImpl WithRawResponseImpl LegalServiceImpl WithRawResponseImpl LlmServiceImpl Access 40+ language models through a unified API WithRawResponseImpl MemoryServiceImpl WithRawResponseImpl OcrServiceImpl WithRawResponseImpl PrivilegeServiceImpl WithRawResponseImpl SearchServiceImpl WithRawResponseImpl SkillServiceImpl Search and read legal AI skills for agents WithRawResponseImpl SuperdocServiceImpl WithRawResponseImpl SystemServiceImpl Public system metadata and discovery endpoints WithRawResponseImpl TranslateServiceImpl WithRawResponseImpl VaultServiceImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl VoiceServiceImpl