Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<V1DetectResponse>detect()Returns a raw HTTP response for post /privilege/v1/detect, but is otherwise the same as V1Service.detect.abstract HttpResponseFor<V1DetectResponse>detect(V1DetectParams params, RequestOptions requestOptions)HttpResponseFor<V1DetectResponse>detect(V1DetectParams params)HttpResponseFor<V1DetectResponse>detect(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
detect
@MustBeClosed() HttpResponseFor<V1DetectResponse> detect()
Returns a raw HTTP response for
post /privilege/v1/detect, but is otherwise the same as V1Service.detect.
-
detect
@MustBeClosed() abstract HttpResponseFor<V1DetectResponse> detect(V1DetectParams params, RequestOptions requestOptions)
-
detect
@MustBeClosed() HttpResponseFor<V1DetectResponse> detect(V1DetectParams params)
-
detect
@MustBeClosed() HttpResponseFor<V1DetectResponse> detect(RequestOptions requestOptions)
-
-
-
-