Interface CustomService
-
- All Implemented Interfaces:
public interface CustomServiceSearch and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomService.WithRawResponseA view of CustomService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CustomService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CustomServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomListResponselist()List all custom skills for the authenticated organization. abstract CustomListResponselist(CustomListParams params, RequestOptions requestOptions)CustomListResponselist(CustomListParams params)CustomListResponselist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CustomService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CustomService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CustomListResponse list()
List all custom skills for the authenticated organization. Supports cursor-based pagination.
-
list
abstract CustomListResponse list(CustomListParams params, RequestOptions requestOptions)
-
list
CustomListResponse list(CustomListParams params)
-
list
CustomListResponse list(RequestOptions requestOptions)
-
-
-
-