Interface CustomService.WithRawResponse
-
- All Implemented Interfaces:
public interface CustomService.WithRawResponseA view of CustomService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CustomService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CustomListResponse>list()Returns a raw HTTP response for get /skills/custom, but is otherwise the same as CustomService.list.abstract HttpResponseFor<CustomListResponse>list(CustomListParams params, RequestOptions requestOptions)HttpResponseFor<CustomListResponse>list(CustomListParams params)HttpResponseFor<CustomListResponse>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CustomService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
@MustBeClosed() HttpResponseFor<CustomListResponse> list()
Returns a raw HTTP response for
get /skills/custom, but is otherwise the same as CustomService.list.
-
list
@MustBeClosed() abstract HttpResponseFor<CustomListResponse> list(CustomListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<CustomListResponse> list(CustomListParams params)
-
list
@MustBeClosed() HttpResponseFor<CustomListResponse> list(RequestOptions requestOptions)
-
-
-
-