Class CustomServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.skills.CustomService
public final class CustomServiceImpl implements CustomService
Search and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CustomService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CustomServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomListResponselist(CustomListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CustomService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CustomService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CustomListResponse list(CustomListParams params, RequestOptions requestOptions)
-
-
-
-