Class CustomServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.skills.CustomService.WithRawResponse
public final class CustomServiceImpl.WithRawResponseImpl implements CustomService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CustomService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CustomListResponse>list(CustomListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CustomService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<CustomListResponse> list(CustomListParams params, RequestOptions requestOptions)
-
-
-
-