Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceDocument conversion and template automation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseannotate(V1AnnotateParams params)Populate fields inside a DOCX template using SuperDoc annotations. abstract HttpResponseannotate(V1AnnotateParams params, RequestOptions requestOptions)HttpResponseconvert(V1ConvertParams params)Convert documents between formats using SuperDoc. abstract HttpResponseconvert(V1ConvertParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
annotate
@MustBeClosed() HttpResponse annotate(V1AnnotateParams params)
Populate fields inside a DOCX template using SuperDoc annotations. Supports text, images, dates, and numbers. Can target individual fields by ID or multiple fields by group.
-
annotate
@MustBeClosed() abstract HttpResponse annotate(V1AnnotateParams params, RequestOptions requestOptions)
-
convert
@MustBeClosed() HttpResponse convert(V1ConvertParams params)
Convert documents between formats using SuperDoc. Supports DOCX to PDF, Markdown to DOCX, and HTML to DOCX conversions.
-
convert
@MustBeClosed() abstract HttpResponse convert(V1ConvertParams params, RequestOptions requestOptions)
-
-
-
-