Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseannotate(V1AnnotateParams params)Returns a raw HTTP response for post /superdoc/v1/annotate, but is otherwise the same as V1Service.annotate.abstract HttpResponseannotate(V1AnnotateParams params, RequestOptions requestOptions)HttpResponseconvert(V1ConvertParams params)Returns a raw HTTP response for post /superdoc/v1/convert, but is otherwise the same as V1Service.convert.abstract HttpResponseconvert(V1ConvertParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
annotate
@MustBeClosed() HttpResponse annotate(V1AnnotateParams params)
Returns a raw HTTP response for
post /superdoc/v1/annotate, but is otherwise the same as V1Service.annotate.
-
annotate
@MustBeClosed() abstract HttpResponse annotate(V1AnnotateParams params, RequestOptions requestOptions)
-
convert
@MustBeClosed() HttpResponse convert(V1ConvertParams params)
Returns a raw HTTP response for
post /superdoc/v1/convert, but is otherwise the same as V1Service.convert.
-
convert
@MustBeClosed() abstract HttpResponse convert(V1ConvertParams params, RequestOptions requestOptions)
-
-
-
-