Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.superdoc.V1Service
public final class V1ServiceImpl implements V1Service
Document conversion and template automation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseannotate(V1AnnotateParams params, RequestOptions requestOptions)HttpResponseconvert(V1ConvertParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
annotate
HttpResponse annotate(V1AnnotateParams params, RequestOptions requestOptions)
-
convert
HttpResponse convert(V1ConvertParams params, RequestOptions requestOptions)
-
-
-
-