Interface V1Service
-
- All Implemented Interfaces:
public interface V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1DetectResponsedetect(V1DetectParams params)Detect the language of text. abstract V1DetectResponsedetect(V1DetectParams params, RequestOptions requestOptions)V1ListLanguagesResponselistLanguages()Get the list of languages supported for translation. abstract V1ListLanguagesResponselistLanguages(V1ListLanguagesParams params, RequestOptions requestOptions)V1ListLanguagesResponselistLanguages(V1ListLanguagesParams params)V1ListLanguagesResponselistLanguages(RequestOptions requestOptions)V1TranslateResponsetranslate(V1TranslateParams params)Translate text between languages using Google Cloud Translation API. abstract V1TranslateResponsetranslate(V1TranslateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
detect
V1DetectResponse detect(V1DetectParams params)
Detect the language of text. Returns the most likely language code and confidence score. Supports batch detection for multiple texts.
-
detect
abstract V1DetectResponse detect(V1DetectParams params, RequestOptions requestOptions)
-
listLanguages
V1ListLanguagesResponse listLanguages()
Get the list of languages supported for translation. Optionally specify a target language to get translated language names.
-
listLanguages
abstract V1ListLanguagesResponse listLanguages(V1ListLanguagesParams params, RequestOptions requestOptions)
-
listLanguages
V1ListLanguagesResponse listLanguages(V1ListLanguagesParams params)
-
listLanguages
V1ListLanguagesResponse listLanguages(RequestOptions requestOptions)
-
translate
V1TranslateResponse translate(V1TranslateParams params)
Translate text between languages using Google Cloud Translation API. Supports 100+ languages, automatic language detection, HTML preservation, and batch translation.
-
translate
abstract V1TranslateResponse translate(V1TranslateParams params, RequestOptions requestOptions)
-
-
-
-