Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceUsage reporting and webhook subscriptions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SubscriptionServicesubscriptions()Usage reporting and webhook subscriptions Unitretrieve()Returns customer-facing usage metrics and costs for the requested period. abstract Unitretrieve(V1RetrieveParams params, RequestOptions requestOptions)Unitretrieve(V1RetrieveParams params)Unitretrieve(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
abstract SubscriptionService subscriptions()
Usage reporting and webhook subscriptions
-
retrieve
Unit retrieve()
Returns customer-facing usage metrics and costs for the requested period. Supports summary totals and daily buckets for timestamped usage sources. Vault storage is intentionally omitted from totals because it is not yet periodized for arbitrary windows.
-
retrieve
abstract Unit retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(V1RetrieveParams params)
-
retrieve
Unit retrieve(RequestOptions requestOptions)
-
-
-
-