Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.usage.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SubscriptionService.WithRawResponsesubscriptions()Usage reporting and webhook subscriptions HttpResponseretrieve(V1RetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
SubscriptionService.WithRawResponse subscriptions()
Usage reporting and webhook subscriptions
-
retrieve
HttpResponse retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
-
-
-