Class SubscriptionServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.usage.v1.SubscriptionService
public final class SubscriptionServiceImpl implements SubscriptionService
Usage reporting and webhook subscriptions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SubscriptionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SubscriptionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(SubscriptionCreateParams params, RequestOptions requestOptions)Unitupdate(SubscriptionUpdateParams params, RequestOptions requestOptions)Unitlist(SubscriptionListParams params, RequestOptions requestOptions)Unitdelete(SubscriptionDeleteParams params, RequestOptions requestOptions)Unittest(SubscriptionTestParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.usage.v1.SubscriptionService
create, delete, delete, delete, delete, delete, list, list, list, test, test, test, test, test, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SubscriptionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(SubscriptionCreateParams params, RequestOptions requestOptions)
-
update
Unit update(SubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
Unit list(SubscriptionListParams params, RequestOptions requestOptions)
-
delete
Unit delete(SubscriptionDeleteParams params, RequestOptions requestOptions)
-
test
Unit test(SubscriptionTestParams params, RequestOptions requestOptions)
-
-
-
-