Class SubscriptionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.usage.v1.SubscriptionService.WithRawResponse
public final class SubscriptionServiceImpl.WithRawResponseImpl implements SubscriptionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SubscriptionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(SubscriptionCreateParams params, RequestOptions requestOptions)HttpResponseupdate(SubscriptionUpdateParams params, RequestOptions requestOptions)HttpResponselist(SubscriptionListParams params, RequestOptions requestOptions)HttpResponsedelete(SubscriptionDeleteParams params, RequestOptions requestOptions)HttpResponsetest(SubscriptionTestParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.usage.v1.SubscriptionService.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, test, test, test, test, test, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
SubscriptionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponse create(SubscriptionCreateParams params, RequestOptions requestOptions)
-
update
HttpResponse update(SubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponse list(SubscriptionListParams params, RequestOptions requestOptions)
-
delete
HttpResponse delete(SubscriptionDeleteParams params, RequestOptions requestOptions)
-
test
HttpResponse test(SubscriptionTestParams params, RequestOptions requestOptions)
-
-
-
-