Interface EventService.WithRawResponse
-
- All Implemented Interfaces:
public interface EventService.WithRawResponseA view of EventService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract EventService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SubscriptionService.WithRawResponsesubscriptions()Secure document storage with semantic search and GraphRAG -
-
Method Detail
-
withOptions
abstract EventService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
abstract SubscriptionService.WithRawResponse subscriptions()
Secure document storage with semantic search and GraphRAG
-
-
-
-