Class EventServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.EventService
public final class EventServiceImpl implements EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SubscriptionServicesubscriptions()Secure document storage with semantic search and GraphRAG -
-
Method Detail
-
withRawResponse
EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
SubscriptionService subscriptions()
Secure document storage with semantic search and GraphRAG
-
-
-
-