Class EventServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.EventService.WithRawResponse
public final class EventServiceImpl.WithRawResponseImpl implements EventService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SubscriptionService.WithRawResponsesubscriptions()Secure document storage with semantic search and GraphRAG -
-
Method Detail
-
withOptions
EventService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
subscriptions
SubscriptionService.WithRawResponse subscriptions()
Secure document storage with semantic search and GraphRAG
-
-
-
-