Class GraphragServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.GraphragService
public final class GraphragServiceImpl implements GraphragService
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description GraphragService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. GraphragServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. GraphragGetStatsResponsegetStats(GraphragGetStatsParams params, RequestOptions requestOptions)GraphragInitResponseinit(GraphragInitParams params, RequestOptions requestOptions)GraphragProcessObjectResponseprocessObject(GraphragProcessObjectParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.vault.GraphragService
getStats, getStats, getStats, getStats, getStats, init, init, init, init, init, processObject, processObject, processObject -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
GraphragService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
GraphragService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStats
GraphragGetStatsResponse getStats(GraphragGetStatsParams params, RequestOptions requestOptions)
-
init
GraphragInitResponse init(GraphragInitParams params, RequestOptions requestOptions)
-
processObject
GraphragProcessObjectResponse processObject(GraphragProcessObjectParams params, RequestOptions requestOptions)
-
-
-
-