Class GraphragServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.GraphragService.WithRawResponse
public final class GraphragServiceImpl.WithRawResponseImpl implements GraphragService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description GraphragService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<GraphragGetStatsResponse>getStats(GraphragGetStatsParams params, RequestOptions requestOptions)HttpResponseFor<GraphragInitResponse>init(GraphragInitParams params, RequestOptions requestOptions)HttpResponseFor<GraphragProcessObjectResponse>processObject(GraphragProcessObjectParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.vault.GraphragService.WithRawResponse
getStats, getStats, getStats, getStats, getStats, init, init, init, init, init, processObject, processObject, processObject -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
GraphragService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getStats
HttpResponseFor<GraphragGetStatsResponse> getStats(GraphragGetStatsParams params, RequestOptions requestOptions)
-
init
HttpResponseFor<GraphragInitResponse> init(GraphragInitParams params, RequestOptions requestOptions)
-
processObject
HttpResponseFor<GraphragProcessObjectResponse> processObject(GraphragProcessObjectParams params, RequestOptions requestOptions)
-
-
-
-