Interface GroupService
-
- All Implemented Interfaces:
public interface GroupServiceSecure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceGroupService.WithRawResponseA view of GroupService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract GroupService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract GroupServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(GroupCreateParams params)Creates a vault group for organizing vaults and applying group-scoped access controls. abstract Unitcreate(GroupCreateParams params, RequestOptions requestOptions)Unitupdate(String groupId)Updates a vault group for the authenticated organization. Unitupdate(String groupId, GroupUpdateParams params, RequestOptions requestOptions)Unitupdate(String groupId, GroupUpdateParams params)abstract Unitupdate(GroupUpdateParams params, RequestOptions requestOptions)Unitupdate(GroupUpdateParams params)Unitupdate(String groupId, RequestOptions requestOptions)Unitlist()Lists vault groups visible to the authenticated organization. abstract Unitlist(GroupListParams params, RequestOptions requestOptions)Unitlist(GroupListParams params)Unitlist(RequestOptions requestOptions)Unitdelete(String groupId)Soft-deletes a vault group that no longer has any active vaults assigned. Unitdelete(String groupId, GroupDeleteParams params, RequestOptions requestOptions)Unitdelete(String groupId, GroupDeleteParams params)abstract Unitdelete(GroupDeleteParams params, RequestOptions requestOptions)Unitdelete(GroupDeleteParams params)Unitdelete(String groupId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract GroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract GroupService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(GroupCreateParams params)
Creates a vault group for organizing vaults and applying group-scoped access controls. Group-scoped API keys cannot create or manage vault groups.
-
create
abstract Unit create(GroupCreateParams params, RequestOptions requestOptions)
-
update
Unit update(String groupId)
Updates a vault group for the authenticated organization. Only provided fields are changed, and setting description to null removes the current description.
-
update
Unit update(String groupId, GroupUpdateParams params, RequestOptions requestOptions)
-
update
Unit update(String groupId, GroupUpdateParams params)
-
update
abstract Unit update(GroupUpdateParams params, RequestOptions requestOptions)
-
update
Unit update(GroupUpdateParams params)
-
update
Unit update(String groupId, RequestOptions requestOptions)
-
list
Unit list()
Lists vault groups visible to the authenticated organization. Group-scoped API keys only receive groups within their allowed scope.
-
list
abstract Unit list(GroupListParams params, RequestOptions requestOptions)
-
list
Unit list(GroupListParams params)
-
list
Unit list(RequestOptions requestOptions)
-
delete
Unit delete(String groupId)
Soft-deletes a vault group that no longer has any active vaults assigned. This operation is blocked when the group still contains vaults.
-
delete
Unit delete(String groupId, GroupDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String groupId, GroupDeleteParams params)
-
delete
abstract Unit delete(GroupDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(GroupDeleteParams params)
-
delete
Unit delete(String groupId, RequestOptions requestOptions)
-
-
-
-