Class GroupServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.GroupService
public final class GroupServiceImpl implements GroupService
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroupServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description GroupService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. GroupServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(GroupCreateParams params, RequestOptions requestOptions)Unitupdate(GroupUpdateParams params, RequestOptions requestOptions)Unitlist(GroupListParams params, RequestOptions requestOptions)Unitdelete(GroupDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.vault.GroupService
create, delete, delete, delete, delete, delete, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
GroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
GroupService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(GroupCreateParams params, RequestOptions requestOptions)
-
update
Unit update(GroupUpdateParams params, RequestOptions requestOptions)
-
list
Unit list(GroupListParams params, RequestOptions requestOptions)
-
delete
Unit delete(GroupDeleteParams params, RequestOptions requestOptions)
-
-
-
-