Interface MemoryService
-
- All Implemented Interfaces:
public interface MemoryServiceSecure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMemoryService.WithRawResponseA view of MemoryService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MemoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MemoryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. MemoryCreateResponsecreate(String id, MemoryCreateParams params)Append a new file-backed memory entry to a vault. MemoryCreateResponsecreate(String id, MemoryCreateParams params, RequestOptions requestOptions)MemoryCreateResponsecreate(MemoryCreateParams params)abstract MemoryCreateResponsecreate(MemoryCreateParams params, RequestOptions requestOptions)Unitupdate(String entryId, MemoryUpdateParams params)Rewrite a file-backed vault memory entry with updated content, source, or tags. Unitupdate(String entryId, MemoryUpdateParams params, RequestOptions requestOptions)Unitupdate(MemoryUpdateParams params)abstract Unitupdate(MemoryUpdateParams params, RequestOptions requestOptions)MemoryListResponselist(String id)Retrieve file-backed memory entries stored in a vault. MemoryListResponselist(String id, MemoryListParams params, RequestOptions requestOptions)MemoryListResponselist(String id, MemoryListParams params)abstract MemoryListResponselist(MemoryListParams params, RequestOptions requestOptions)MemoryListResponselist(MemoryListParams params)MemoryListResponselist(String id, RequestOptions requestOptions)Unitdelete(String entryId, MemoryDeleteParams params)Remove a file-backed memory entry from a vault. Unitdelete(String entryId, MemoryDeleteParams params, RequestOptions requestOptions)Unitdelete(MemoryDeleteParams params)abstract Unitdelete(MemoryDeleteParams params, RequestOptions requestOptions)MemorySearchResponsesearch(String id, MemorySearchParams params)Search file-backed vault memory using simple full-text matching over content and tags. MemorySearchResponsesearch(String id, MemorySearchParams params, RequestOptions requestOptions)MemorySearchResponsesearch(MemorySearchParams params)abstract MemorySearchResponsesearch(MemorySearchParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract MemoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MemoryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
MemoryCreateResponse create(String id, MemoryCreateParams params)
Append a new file-backed memory entry to a vault.
-
create
MemoryCreateResponse create(String id, MemoryCreateParams params, RequestOptions requestOptions)
-
create
MemoryCreateResponse create(MemoryCreateParams params)
-
create
abstract MemoryCreateResponse create(MemoryCreateParams params, RequestOptions requestOptions)
-
update
Unit update(String entryId, MemoryUpdateParams params)
Rewrite a file-backed vault memory entry with updated content, source, or tags.
-
update
Unit update(String entryId, MemoryUpdateParams params, RequestOptions requestOptions)
-
update
Unit update(MemoryUpdateParams params)
-
update
abstract Unit update(MemoryUpdateParams params, RequestOptions requestOptions)
-
list
MemoryListResponse list(String id)
Retrieve file-backed memory entries stored in a vault.
-
list
MemoryListResponse list(String id, MemoryListParams params, RequestOptions requestOptions)
-
list
MemoryListResponse list(String id, MemoryListParams params)
-
list
abstract MemoryListResponse list(MemoryListParams params, RequestOptions requestOptions)
-
list
MemoryListResponse list(MemoryListParams params)
-
list
MemoryListResponse list(String id, RequestOptions requestOptions)
-
delete
Unit delete(String entryId, MemoryDeleteParams params)
Remove a file-backed memory entry from a vault.
-
delete
Unit delete(String entryId, MemoryDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(MemoryDeleteParams params)
-
delete
abstract Unit delete(MemoryDeleteParams params, RequestOptions requestOptions)
-
search
MemorySearchResponse search(String id, MemorySearchParams params)
Search file-backed vault memory using simple full-text matching over content and tags.
-
search
MemorySearchResponse search(String id, MemorySearchParams params, RequestOptions requestOptions)
-
search
MemorySearchResponse search(MemorySearchParams params)
-
search
abstract MemorySearchResponse search(MemorySearchParams params, RequestOptions requestOptions)
-
-
-
-