Class MemoryServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.MemoryService
public final class MemoryServiceImpl implements MemoryService
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MemoryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MemoryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. MemoryCreateResponsecreate(MemoryCreateParams params, RequestOptions requestOptions)Unitupdate(MemoryUpdateParams params, RequestOptions requestOptions)MemoryListResponselist(MemoryListParams params, RequestOptions requestOptions)Unitdelete(MemoryDeleteParams params, RequestOptions requestOptions)MemorySearchResponsesearch(MemorySearchParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.vault.MemoryService
create, create, create, delete, delete, delete, list, list, list, list, list, search, search, search, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
MemoryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MemoryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
MemoryCreateResponse create(MemoryCreateParams params, RequestOptions requestOptions)
-
update
Unit update(MemoryUpdateParams params, RequestOptions requestOptions)
-
list
MemoryListResponse list(MemoryListParams params, RequestOptions requestOptions)
-
delete
Unit delete(MemoryDeleteParams params, RequestOptions requestOptions)
-
search
MemorySearchResponse search(MemorySearchParams params, RequestOptions requestOptions)
-
-
-
-