Class MemoryServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.MemoryService.WithRawResponse
public final class MemoryServiceImpl.WithRawResponseImpl implements MemoryService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MemoryService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<MemoryCreateResponse>create(MemoryCreateParams params, RequestOptions requestOptions)HttpResponseupdate(MemoryUpdateParams params, RequestOptions requestOptions)HttpResponseFor<MemoryListResponse>list(MemoryListParams params, RequestOptions requestOptions)HttpResponsedelete(MemoryDeleteParams params, RequestOptions requestOptions)HttpResponseFor<MemorySearchResponse>search(MemorySearchParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.vault.MemoryService.WithRawResponse
create, create, create, delete, delete, delete, list, list, list, list, list, search, search, search, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
MemoryService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<MemoryCreateResponse> create(MemoryCreateParams params, RequestOptions requestOptions)
-
update
HttpResponse update(MemoryUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<MemoryListResponse> list(MemoryListParams params, RequestOptions requestOptions)
-
delete
HttpResponse delete(MemoryDeleteParams params, RequestOptions requestOptions)
-
search
HttpResponseFor<MemorySearchResponse> search(MemorySearchParams params, RequestOptions requestOptions)
-
-
-
-