Interface MultipartService
-
- All Implemented Interfaces:
public interface MultipartServiceSecure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMultipartService.WithRawResponseA view of MultipartService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MultipartService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MultipartServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitabort(String id, MultipartAbortParams params)Abort a multipart upload and discard uploaded parts (live). Unitabort(String id, MultipartAbortParams params, RequestOptions requestOptions)Unitabort(MultipartAbortParams params)abstract Unitabort(MultipartAbortParams params, RequestOptions requestOptions)MultipartGetPartUrlsResponsegetPartUrls(String id, MultipartGetPartUrlsParams params)Generate presigned URLs for individual multipart upload parts (live). MultipartGetPartUrlsResponsegetPartUrls(String id, MultipartGetPartUrlsParams params, RequestOptions requestOptions)MultipartGetPartUrlsResponsegetPartUrls(MultipartGetPartUrlsParams params)abstract MultipartGetPartUrlsResponsegetPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract MultipartService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MultipartService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
abort
Unit abort(String id, MultipartAbortParams params)
Abort a multipart upload and discard uploaded parts (live).
-
abort
Unit abort(String id, MultipartAbortParams params, RequestOptions requestOptions)
-
abort
Unit abort(MultipartAbortParams params)
-
abort
abstract Unit abort(MultipartAbortParams params, RequestOptions requestOptions)
-
getPartUrls
MultipartGetPartUrlsResponse getPartUrls(String id, MultipartGetPartUrlsParams params)
Generate presigned URLs for individual multipart upload parts (live).
-
getPartUrls
MultipartGetPartUrlsResponse getPartUrls(String id, MultipartGetPartUrlsParams params, RequestOptions requestOptions)
-
getPartUrls
MultipartGetPartUrlsResponse getPartUrls(MultipartGetPartUrlsParams params)
-
getPartUrls
abstract MultipartGetPartUrlsResponse getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)
-
-
-
-