Class MultipartServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.MultipartService
public final class MultipartServiceImpl implements MultipartService
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMultipartServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MultipartService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MultipartServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitabort(MultipartAbortParams params, RequestOptions requestOptions)MultipartGetPartUrlsResponsegetPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MultipartService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MultipartService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
abort
Unit abort(MultipartAbortParams params, RequestOptions requestOptions)
-
getPartUrls
MultipartGetPartUrlsResponse getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)
-
-
-
-