Class MultipartServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.MultipartService.WithRawResponse
public final class MultipartServiceImpl.WithRawResponseImpl implements MultipartService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MultipartService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseabort(MultipartAbortParams params, RequestOptions requestOptions)HttpResponseFor<MultipartGetPartUrlsResponse>getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
MultipartService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
abort
HttpResponse abort(MultipartAbortParams params, RequestOptions requestOptions)
-
getPartUrls
HttpResponseFor<MultipartGetPartUrlsResponse> getPartUrls(MultipartGetPartUrlsParams params, RequestOptions requestOptions)
-
-
-
-