Class ObjectServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.vault.ObjectService
public final class ObjectServiceImpl implements ObjectService
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.blocking.vault.ObjectService
createPresignedUrl, createPresignedUrl, createPresignedUrl, delete, delete, delete, download, download, download, getChunks, getChunks, getChunks, getOcrWords, getOcrWords, getOcrWords, getPages, getPages, getPages, getSummarizeJob, getSummarizeJob, getSummarizeJob, getText, getText, getText, list, list, list, list, list, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ObjectService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ObjectService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
ObjectRetrieveResponse retrieve(ObjectRetrieveParams params, RequestOptions requestOptions)
-
update
ObjectUpdateResponse update(ObjectUpdateParams params, RequestOptions requestOptions)
-
list
ObjectListResponse list(ObjectListParams params, RequestOptions requestOptions)
-
delete
ObjectDeleteResponse delete(ObjectDeleteParams params, RequestOptions requestOptions)
-
createPresignedUrl
ObjectCreatePresignedUrlResponse createPresignedUrl(ObjectCreatePresignedUrlParams params, RequestOptions requestOptions)
-
download
HttpResponse download(ObjectDownloadParams params, RequestOptions requestOptions)
-
getChunks
ObjectGetChunksResponse getChunks(ObjectGetChunksParams params, RequestOptions requestOptions)
-
getOcrWords
ObjectGetOcrWordsResponse getOcrWords(ObjectGetOcrWordsParams params, RequestOptions requestOptions)
-
getPages
ObjectGetPagesResponse getPages(ObjectGetPagesParams params, RequestOptions requestOptions)
-
getSummarizeJob
ObjectGetSummarizeJobResponse getSummarizeJob(ObjectGetSummarizeJobParams params, RequestOptions requestOptions)
-
getText
ObjectGetTextResponse getText(ObjectGetTextParams params, RequestOptions requestOptions)
-
-
-
-