Package dev.case.api.services.blocking.vault
See: Description
-
Interface Summary Interface Description WithRawResponse A view of EventService that provides access to raw HTTP responses for each method. EventService WithRawResponse A view of GraphragService that provides access to raw HTTP responses for each method. GraphragService Secure document storage with semantic search and GraphRAG WithRawResponse A view of GroupService that provides access to raw HTTP responses for each method. GroupService Secure document storage with semantic search and GraphRAG WithRawResponse A view of MemoryService that provides access to raw HTTP responses for each method. MemoryService Secure document storage with semantic search and GraphRAG WithRawResponse A view of MultipartService that provides access to raw HTTP responses for each method. MultipartService Secure document storage with semantic search and GraphRAG WithRawResponse A view of ObjectService that provides access to raw HTTP responses for each method. ObjectService Secure document storage with semantic search and GraphRAG -
Class Summary Class Description WithRawResponseImpl EventServiceImpl WithRawResponseImpl GraphragServiceImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl GroupServiceImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl MemoryServiceImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl MultipartServiceImpl Secure document storage with semantic search and GraphRAG WithRawResponseImpl ObjectServiceImpl Secure document storage with semantic search and GraphRAG