Interface BoostListService
-
- All Implemented Interfaces:
public interface BoostListServiceAudio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBoostListService.WithRawResponseA view of BoostListService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BoostListService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BoostListServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. BoostListExtractResponseextract()Extracts a categorized word boost list from vault documents or raw text using LLM entity extraction. abstract BoostListExtractResponseextract(BoostListExtractParams params, RequestOptions requestOptions)BoostListExtractResponseextract(BoostListExtractParams params)BoostListExtractResponseextract(RequestOptions requestOptions)BoostListGenerateResponsegenerate(BoostListGenerateParams params)Generates a categorized word boost list from a completed transcription job. abstract BoostListGenerateResponsegenerate(BoostListGenerateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BoostListService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BoostListService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extract
BoostListExtractResponse extract()
Extracts a categorized word boost list from vault documents or raw text using LLM entity extraction. The resulting list can be passed as
word_boostto the transcription endpoint for improved accuracy.
-
extract
abstract BoostListExtractResponse extract(BoostListExtractParams params, RequestOptions requestOptions)
-
extract
BoostListExtractResponse extract(BoostListExtractParams params)
-
extract
BoostListExtractResponse extract(RequestOptions requestOptions)
-
generate
BoostListGenerateResponse generate(BoostListGenerateParams params)
Generates a categorized word boost list from a completed transcription job. Extracts entities from the pass-1 transcript for use as
word_boostin a second transcription pass.
-
generate
abstract BoostListGenerateResponse generate(BoostListGenerateParams params, RequestOptions requestOptions)
-
-
-
-