Interface BoostListService.WithRawResponse
-
- All Implemented Interfaces:
public interface BoostListService.WithRawResponseA view of BoostListService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract BoostListService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<BoostListExtractResponse>extract()Returns a raw HTTP response for post /voice/boost-list/extract, but is otherwise the same as BoostListService.extract.abstract HttpResponseFor<BoostListExtractResponse>extract(BoostListExtractParams params, RequestOptions requestOptions)HttpResponseFor<BoostListExtractResponse>extract(BoostListExtractParams params)HttpResponseFor<BoostListExtractResponse>extract(RequestOptions requestOptions)HttpResponseFor<BoostListGenerateResponse>generate(BoostListGenerateParams params)Returns a raw HTTP response for post /voice/boost-list/generate, but is otherwise the same as BoostListService.generate.abstract HttpResponseFor<BoostListGenerateResponse>generate(BoostListGenerateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract BoostListService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extract
@MustBeClosed() HttpResponseFor<BoostListExtractResponse> extract()
Returns a raw HTTP response for
post /voice/boost-list/extract, but is otherwise the same as BoostListService.extract.
-
extract
@MustBeClosed() abstract HttpResponseFor<BoostListExtractResponse> extract(BoostListExtractParams params, RequestOptions requestOptions)
-
extract
@MustBeClosed() HttpResponseFor<BoostListExtractResponse> extract(BoostListExtractParams params)
-
extract
@MustBeClosed() HttpResponseFor<BoostListExtractResponse> extract(RequestOptions requestOptions)
-
generate
@MustBeClosed() HttpResponseFor<BoostListGenerateResponse> generate(BoostListGenerateParams params)
Returns a raw HTTP response for
post /voice/boost-list/generate, but is otherwise the same as BoostListService.generate.
-
generate
@MustBeClosed() abstract HttpResponseFor<BoostListGenerateResponse> generate(BoostListGenerateParams params, RequestOptions requestOptions)
-
-
-
-