Class BoostListServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.BoostListService
public final class BoostListServiceImpl implements BoostListService
Audio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBoostListServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BoostListService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BoostListServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. BoostListExtractResponseextract(BoostListExtractParams params, RequestOptions requestOptions)BoostListGenerateResponsegenerate(BoostListGenerateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BoostListService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BoostListService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extract
BoostListExtractResponse extract(BoostListExtractParams params, RequestOptions requestOptions)
-
generate
BoostListGenerateResponse generate(BoostListGenerateParams params, RequestOptions requestOptions)
-
-
-
-