Class BoostListServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.BoostListService.WithRawResponse
public final class BoostListServiceImpl.WithRawResponseImpl implements BoostListService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BoostListService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<BoostListExtractResponse>extract(BoostListExtractParams params, RequestOptions requestOptions)HttpResponseFor<BoostListGenerateResponse>generate(BoostListGenerateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
BoostListService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extract
HttpResponseFor<BoostListExtractResponse> extract(BoostListExtractParams params, RequestOptions requestOptions)
-
generate
HttpResponseFor<BoostListGenerateResponse> generate(BoostListGenerateParams params, RequestOptions requestOptions)
-
-
-
-