Interface StreamingService
-
- All Implemented Interfaces:
public interface StreamingService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceStreamingService.WithRawResponseA view of StreamingService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract StreamingService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract StreamingServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamingGetUrlResponsegetUrl()Returns the WebSocket URL and connection details for real-time audio transcription. abstract StreamingGetUrlResponsegetUrl(StreamingGetUrlParams params, RequestOptions requestOptions)StreamingGetUrlResponsegetUrl(StreamingGetUrlParams params)StreamingGetUrlResponsegetUrl(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract StreamingService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract StreamingService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
StreamingGetUrlResponse getUrl()
Returns the WebSocket URL and connection details for real-time audio transcription. The returned URL can be used to establish a WebSocket connection for streaming audio data and receiving transcribed text in real-time.
Audio Requirements:
Sample Rate: 16kHz
Encoding: PCM 16-bit little-endian
Channels: Mono (1 channel)
Pricing:
$0.01 per minute ($
0.60 per hour)
-
getUrl
abstract StreamingGetUrlResponse getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
getUrl
StreamingGetUrlResponse getUrl(StreamingGetUrlParams params)
-
getUrl
StreamingGetUrlResponse getUrl(RequestOptions requestOptions)
-
-
-
-