Interface StreamingService.WithRawResponse
-
- All Implemented Interfaces:
public interface StreamingService.WithRawResponseA view of StreamingService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract StreamingService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<StreamingGetUrlResponse>getUrl()Returns a raw HTTP response for get /voice/streaming/url, but is otherwise the same as StreamingService.getUrl.abstract HttpResponseFor<StreamingGetUrlResponse>getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)HttpResponseFor<StreamingGetUrlResponse>getUrl(StreamingGetUrlParams params)HttpResponseFor<StreamingGetUrlResponse>getUrl(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract StreamingService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
@MustBeClosed() HttpResponseFor<StreamingGetUrlResponse> getUrl()
Returns a raw HTTP response for
get /voice/streaming/url, but is otherwise the same as StreamingService.getUrl.
-
getUrl
@MustBeClosed() abstract HttpResponseFor<StreamingGetUrlResponse> getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
getUrl
@MustBeClosed() HttpResponseFor<StreamingGetUrlResponse> getUrl(StreamingGetUrlParams params)
-
getUrl
@MustBeClosed() HttpResponseFor<StreamingGetUrlResponse> getUrl(RequestOptions requestOptions)
-
-
-
-