Class StreamingServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.StreamingService
public final class StreamingServiceImpl implements StreamingService
Audio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamingServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description StreamingService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. StreamingServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamingGetUrlResponsegetUrl(StreamingGetUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
StreamingService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
StreamingService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
StreamingGetUrlResponse getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
-
-
-