Class StreamingServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.StreamingService.WithRawResponse
public final class StreamingServiceImpl.WithRawResponseImpl implements StreamingService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description StreamingService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<StreamingGetUrlResponse>getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
StreamingService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
getUrl
HttpResponseFor<StreamingGetUrlResponse> getUrl(StreamingGetUrlParams params, RequestOptions requestOptions)
-
-
-
-