Class TranscriptionServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.TranscriptionService
public final class TranscriptionServiceImpl implements TranscriptionService
Audio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTranscriptionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TranscriptionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TranscriptionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. TranscriptionCreateResponsecreate(TranscriptionCreateParams params, RequestOptions requestOptions)TranscriptionRetrieveResponseretrieve(TranscriptionRetrieveParams params, RequestOptions requestOptions)Unitdelete(TranscriptionDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.voice.TranscriptionService
create, create, create, delete, delete, delete, delete, delete, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
TranscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TranscriptionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
TranscriptionCreateResponse create(TranscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
TranscriptionRetrieveResponse retrieve(TranscriptionRetrieveParams params, RequestOptions requestOptions)
-
delete
Unit delete(TranscriptionDeleteParams params, RequestOptions requestOptions)
-
-
-
-