Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceAudio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SpeakServicespeak()Audio transcription and text-to-speech V1ListVoicesResponselistVoices()Retrieve a list of available voices for text-to-speech synthesis. abstract V1ListVoicesResponselistVoices(V1ListVoicesParams params, RequestOptions requestOptions)V1ListVoicesResponselistVoices(V1ListVoicesParams params)V1ListVoicesResponselistVoices(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
speak
abstract SpeakService speak()
Audio transcription and text-to-speech
-
listVoices
V1ListVoicesResponse listVoices()
Retrieve a list of available voices for text-to-speech synthesis. This endpoint provides access to a comprehensive catalog of voices with various characteristics, languages, and styles suitable for legal document narration, client presentations, and accessibility purposes.
-
listVoices
abstract V1ListVoicesResponse listVoices(V1ListVoicesParams params, RequestOptions requestOptions)
-
listVoices
V1ListVoicesResponse listVoices(V1ListVoicesParams params)
-
listVoices
V1ListVoicesResponse listVoices(RequestOptions requestOptions)
-
-
-
-