Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract SpeakService.WithRawResponsespeak()Audio transcription and text-to-speech HttpResponseFor<V1ListVoicesResponse>listVoices()Returns a raw HTTP response for get /voice/v1/voices, but is otherwise the same as V1Service.listVoices.abstract HttpResponseFor<V1ListVoicesResponse>listVoices(V1ListVoicesParams params, RequestOptions requestOptions)HttpResponseFor<V1ListVoicesResponse>listVoices(V1ListVoicesParams params)HttpResponseFor<V1ListVoicesResponse>listVoices(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
speak
abstract SpeakService.WithRawResponse speak()
Audio transcription and text-to-speech
-
listVoices
@MustBeClosed() HttpResponseFor<V1ListVoicesResponse> listVoices()
Returns a raw HTTP response for
get /voice/v1/voices, but is otherwise the same as V1Service.listVoices.
-
listVoices
@MustBeClosed() abstract HttpResponseFor<V1ListVoicesResponse> listVoices(V1ListVoicesParams params, RequestOptions requestOptions)
-
listVoices
@MustBeClosed() HttpResponseFor<V1ListVoicesResponse> listVoices(V1ListVoicesParams params)
-
listVoices
@MustBeClosed() HttpResponseFor<V1ListVoicesResponse> listVoices(RequestOptions requestOptions)
-
-
-
-