Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SpeakService.WithRawResponsespeak()Audio transcription and text-to-speech HttpResponseFor<V1ListVoicesResponse>listVoices(V1ListVoicesParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
speak
SpeakService.WithRawResponse speak()
Audio transcription and text-to-speech
-
listVoices
HttpResponseFor<V1ListVoicesResponse> listVoices(V1ListVoicesParams params, RequestOptions requestOptions)
-
-
-
-