Interface SpeakService
-
- All Implemented Interfaces:
public interface SpeakService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSpeakService.WithRawResponseA view of SpeakService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SpeakService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SpeakServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(SpeakCreateParams params)Convert text to natural-sounding audio using ElevenLabs voices. abstract HttpResponsecreate(SpeakCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SpeakService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SpeakService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponse create(SpeakCreateParams params)
Convert text to natural-sounding audio using ElevenLabs voices. Ideal for creating audio summaries of legal documents, client presentations, or accessibility features. Supports multiple languages and voice customization.
-
create
@MustBeClosed() abstract HttpResponse create(SpeakCreateParams params, RequestOptions requestOptions)
-
-
-
-