Class SpeakServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.v1.SpeakService
public final class SpeakServiceImpl implements SpeakService
Audio transcription and text-to-speech
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSpeakServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SpeakService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SpeakServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(SpeakCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SpeakService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SpeakService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponse create(SpeakCreateParams params, RequestOptions requestOptions)
-
-
-
-