Class SpeakServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.voice.v1.SpeakService.WithRawResponse
public final class SpeakServiceImpl.WithRawResponseImpl implements SpeakService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SpeakService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsecreate(SpeakCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
SpeakService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponse create(SpeakCreateParams params, RequestOptions requestOptions)
-
-
-
-