Interface V1Service
-
- All Implemented Interfaces:
public interface V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract EndpointServiceendpoints()Webhook endpoint management abstract DeliveryServicedeliveries()Webhook endpoint management abstract EventTypeServiceeventTypes()Webhook endpoint management -
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
endpoints
abstract EndpointService endpoints()
Webhook endpoint management
-
deliveries
abstract DeliveryService deliveries()
Webhook endpoint management
-
eventTypes
abstract EventTypeService eventTypes()
Webhook endpoint management
-
-
-
-