Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract EndpointService.WithRawResponseendpoints()Webhook endpoint management abstract DeliveryService.WithRawResponsedeliveries()Webhook endpoint management abstract EventTypeService.WithRawResponseeventTypes()Webhook endpoint management -
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
endpoints
abstract EndpointService.WithRawResponse endpoints()
Webhook endpoint management
-
deliveries
abstract DeliveryService.WithRawResponse deliveries()
Webhook endpoint management
-
eventTypes
abstract EventTypeService.WithRawResponse eventTypes()
Webhook endpoint management
-
-
-
-