Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.webhooks.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EndpointService.WithRawResponseendpoints()Webhook endpoint management DeliveryService.WithRawResponsedeliveries()Webhook endpoint management EventTypeService.WithRawResponseeventTypes()Webhook endpoint management -
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
endpoints
EndpointService.WithRawResponse endpoints()
Webhook endpoint management
-
deliveries
DeliveryService.WithRawResponse deliveries()
Webhook endpoint management
-
eventTypes
EventTypeService.WithRawResponse eventTypes()
Webhook endpoint management
-
-
-
-