Class DeliveryServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.webhooks.v1.DeliveryService
public final class DeliveryServiceImpl implements DeliveryService
Webhook endpoint management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeliveryServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DeliveryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DeliveryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitretrieve(DeliveryRetrieveParams params, RequestOptions requestOptions)Unitlist(DeliveryListParams params, RequestOptions requestOptions)Unitreplay(DeliveryReplayParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.webhooks.v1.DeliveryService
list, list, list, replay, replay, replay, replay, replay, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DeliveryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DeliveryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
Unit retrieve(DeliveryRetrieveParams params, RequestOptions requestOptions)
-
list
Unit list(DeliveryListParams params, RequestOptions requestOptions)
-
replay
Unit replay(DeliveryReplayParams params, RequestOptions requestOptions)
-
-
-
-