Class EndpointServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.webhooks.v1.EndpointService
public final class EndpointServiceImpl implements EndpointService
Webhook endpoint management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EndpointService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EndpointServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(EndpointCreateParams params, RequestOptions requestOptions)Unitretrieve(EndpointRetrieveParams params, RequestOptions requestOptions)Unitupdate(EndpointUpdateParams params, RequestOptions requestOptions)Unitlist(EndpointListParams params, RequestOptions requestOptions)Unitdelete(EndpointDeleteParams params, RequestOptions requestOptions)UnitrotateSecret(EndpointRotateSecretParams params, RequestOptions requestOptions)Unittest(EndpointTestParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.webhooks.v1.EndpointService
create, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, rotateSecret, rotateSecret, rotateSecret, rotateSecret, rotateSecret, test, test, test, test, test, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EndpointService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EndpointService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(EndpointCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(EndpointRetrieveParams params, RequestOptions requestOptions)
-
update
Unit update(EndpointUpdateParams params, RequestOptions requestOptions)
-
list
Unit list(EndpointListParams params, RequestOptions requestOptions)
-
delete
Unit delete(EndpointDeleteParams params, RequestOptions requestOptions)
-
rotateSecret
Unit rotateSecret(EndpointRotateSecretParams params, RequestOptions requestOptions)
-
test
Unit test(EndpointTestParams params, RequestOptions requestOptions)
-
-
-
-