Interface V1Service
-
- All Implemented Interfaces:
public interface V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate()Creates a Daytona-backed worker runtime. abstract Unitcreate(V1CreateParams params, RequestOptions requestOptions)Unitcreate(V1CreateParams params)Unitcreate(RequestOptions requestOptions)Unitretrieve(String id)Get worker Unitretrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)Unitretrieve(String id, V1RetrieveParams params)abstract Unitretrieve(V1RetrieveParams params, RequestOptions requestOptions)Unitretrieve(V1RetrieveParams params)Unitretrieve(String id, RequestOptions requestOptions)Unitdelete(String id)End worker Unitdelete(String id, V1DeleteParams params, RequestOptions requestOptions)Unitdelete(String id, V1DeleteParams params)abstract Unitdelete(V1DeleteParams params, RequestOptions requestOptions)Unitdelete(V1DeleteParams params)Unitdelete(String id, RequestOptions requestOptions)UnitproxyDelete(String workerPath, V1ProxyDeleteParams params)Forwards a DELETE request to the worker runtime without translating response shapes. UnitproxyDelete(String workerPath, V1ProxyDeleteParams params, RequestOptions requestOptions)UnitproxyDelete(V1ProxyDeleteParams params)abstract UnitproxyDelete(V1ProxyDeleteParams params, RequestOptions requestOptions)UnitproxyGet(String workerPath, V1ProxyGetParams params)Forwards a GET request to the worker runtime without translating response or SSE event shapes. UnitproxyGet(String workerPath, V1ProxyGetParams params, RequestOptions requestOptions)UnitproxyGet(V1ProxyGetParams params)abstract UnitproxyGet(V1ProxyGetParams params, RequestOptions requestOptions)UnitproxyPatch(String workerPath, V1ProxyPatchParams params)Forwards a PATCH request to the worker runtime without translating request or response shapes. UnitproxyPatch(String workerPath, V1ProxyPatchParams params, RequestOptions requestOptions)UnitproxyPatch(V1ProxyPatchParams params)abstract UnitproxyPatch(V1ProxyPatchParams params, RequestOptions requestOptions)UnitproxyPost(String workerPath, V1ProxyPostParams params)Forwards a POST request to the worker runtime without translating request, response, or SSE event shapes. UnitproxyPost(String workerPath, V1ProxyPostParams params, RequestOptions requestOptions)UnitproxyPost(V1ProxyPostParams params)abstract UnitproxyPost(V1ProxyPostParams params, RequestOptions requestOptions)UnitproxyPut(String workerPath, V1ProxyPutParams params)Forwards a PUT request to the worker runtime without translating request or response shapes. UnitproxyPut(String workerPath, V1ProxyPutParams params, RequestOptions requestOptions)UnitproxyPut(V1ProxyPutParams params)abstract UnitproxyPut(V1ProxyPutParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create()
Creates a Daytona-backed worker runtime. The worker exposes its native runtime API through /worker/v1/:id/* without reshaping payloads or events.
-
create
abstract Unit create(V1CreateParams params, RequestOptions requestOptions)
-
create
Unit create(V1CreateParams params)
-
create
Unit create(RequestOptions requestOptions)
-
retrieve
Unit retrieve(String id, V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String id, V1RetrieveParams params)
-
retrieve
abstract Unit retrieve(V1RetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(V1RetrieveParams params)
-
retrieve
Unit retrieve(String id, RequestOptions requestOptions)
-
delete
Unit delete(String id, V1DeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String id, V1DeleteParams params)
-
delete
abstract Unit delete(V1DeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(V1DeleteParams params)
-
delete
Unit delete(String id, RequestOptions requestOptions)
-
proxyDelete
Unit proxyDelete(String workerPath, V1ProxyDeleteParams params)
Forwards a DELETE request to the worker runtime without translating response shapes.
-
proxyDelete
Unit proxyDelete(String workerPath, V1ProxyDeleteParams params, RequestOptions requestOptions)
-
proxyDelete
Unit proxyDelete(V1ProxyDeleteParams params)
-
proxyDelete
abstract Unit proxyDelete(V1ProxyDeleteParams params, RequestOptions requestOptions)
-
proxyGet
Unit proxyGet(String workerPath, V1ProxyGetParams params)
Forwards a GET request to the worker runtime without translating response or SSE event shapes.
-
proxyGet
Unit proxyGet(String workerPath, V1ProxyGetParams params, RequestOptions requestOptions)
-
proxyGet
Unit proxyGet(V1ProxyGetParams params)
-
proxyGet
abstract Unit proxyGet(V1ProxyGetParams params, RequestOptions requestOptions)
-
proxyPatch
Unit proxyPatch(String workerPath, V1ProxyPatchParams params)
Forwards a PATCH request to the worker runtime without translating request or response shapes.
-
proxyPatch
Unit proxyPatch(String workerPath, V1ProxyPatchParams params, RequestOptions requestOptions)
-
proxyPatch
Unit proxyPatch(V1ProxyPatchParams params)
-
proxyPatch
abstract Unit proxyPatch(V1ProxyPatchParams params, RequestOptions requestOptions)
-
proxyPost
Unit proxyPost(String workerPath, V1ProxyPostParams params)
Forwards a POST request to the worker runtime without translating request, response, or SSE event shapes.
-
proxyPost
Unit proxyPost(String workerPath, V1ProxyPostParams params, RequestOptions requestOptions)
-
proxyPost
Unit proxyPost(V1ProxyPostParams params)
-
proxyPost
abstract Unit proxyPost(V1ProxyPostParams params, RequestOptions requestOptions)
-
proxyPut
Unit proxyPut(String workerPath, V1ProxyPutParams params)
Forwards a PUT request to the worker runtime without translating request or response shapes.
-
proxyPut
Unit proxyPut(String workerPath, V1ProxyPutParams params, RequestOptions requestOptions)
-
proxyPut
Unit proxyPut(V1ProxyPutParams params)
-
proxyPut
abstract Unit proxyPut(V1ProxyPutParams params, RequestOptions requestOptions)
-
-
-
-