A  B  C  D  E  F  G  H  I  J  K  L  M  N  O  P  Q  R  S  T  U  V  W  Y  _ 

M

markText() - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse
The text of the trademark
markText(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Sets Builder.markText to an arbitrary JSON value.
markText(java.util.Optional) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Alias for calling Builder.markText with markText.orElse(null).
markText(java.lang.String) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
The text of the trademark
markType() - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse
Type of mark (e.g.
markType(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Sets Builder.markType to an arbitrary JSON value.
markType(java.util.Optional) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Alias for calling Builder.markType with markType.orElse(null).
markType(java.lang.String) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Type of mark (e.g.
maxCharacters() - function in dev.case.api.models.legal.v1.V1GetFullTextParams
Maximum characters to return (default: 10000, max: 50000)
maxCharacters() - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Body
Maximum characters to return (default: 10000, max: 50000)
maxCharacters(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Body.Builder
Sets Builder.maxCharacters to an arbitrary JSON value.
maxCharacters(java.lang.Long) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Body.Builder
Maximum characters to return (default: 10000, max: 50000)
maxCharacters(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Builder
Sets Builder.maxCharacters to an arbitrary JSON value.
maxCharacters(java.lang.Long) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Builder
Maximum characters to return (default: 10000, max: 50000)
maxIdleConnections(java.util.Optional) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
Alias for calling Builder.maxIdleConnections with maxIdleConnections.orElse(null).
maxIdleConnections(java.lang.Integer) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
Alias for Builder.maxIdleConnections.
maxIdleConnections(java.lang.Integer) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
The maximum number of idle connections kept by the underlying OkHttp connection pool.
maxIdleConnections(java.util.Optional) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
Alias for calling Builder.maxIdleConnections with maxIdleConnections.orElse(null).
maxIdleConnections(java.lang.Integer) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
Alias for Builder.maxIdleConnections.
maxIdleConnections(java.lang.Integer) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
The maximum number of idle connections kept by the underlying OkHttp connection pool.
maxIdleConnections(java.lang.Integer) - function in dev.case.api.client.okhttp.OkHttpClient.Builder
Sets the maximum number of idle connections kept by the underlying ConnectionPool.
maxRetries(java.lang.Integer) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
maxRetries(java.lang.Integer) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
maxRetries() - function in dev.case.api.core.ClientOptions
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
maxRetries(java.lang.Integer) - function in dev.case.api.core.ClientOptions.Builder
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
maxRetries(java.lang.Integer) - function in dev.case.api.core.http.RetryingHttpClient.Builder
 
maxTokens() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams
Maximum number of tokens to generate
maxTokens() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body
Maximum number of tokens to generate
maxTokens(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
Sets Builder.maxTokens to an arbitrary JSON value.
maxTokens(java.lang.Long) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
Maximum number of tokens to generate
maxTokens(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
Sets Builder.maxTokens to an arbitrary JSON value.
maxTokens(java.lang.Long) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
Maximum number of tokens to generate
maxTokens() - function in dev.case.api.models.search.v1.V1AnswerParams
Maximum tokens for LLM response
maxTokens() - function in dev.case.api.models.search.v1.V1AnswerParams.Body
Maximum tokens for LLM response
maxTokens(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1AnswerParams.Body.Builder
Sets Builder.maxTokens to an arbitrary JSON value.
maxTokens(java.lang.Long) - function in dev.case.api.models.search.v1.V1AnswerParams.Body.Builder
Maximum tokens for LLM response
maxTokens(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1AnswerParams.Builder
Sets Builder.maxTokens to an arbitrary JSON value.
maxTokens(java.lang.Long) - function in dev.case.api.models.search.v1.V1AnswerParams.Builder
Maximum tokens for LLM response
MD - enum entry in dev.case.api.models.format.v1.V1CreateDocumentParams.InputFormat.Known
 
MD - enum entry in dev.case.api.models.format.v1.V1CreateDocumentParams.InputFormat.Value
 
MD - enum entry in dev.case.api.models.superdoc.v1.V1ConvertParams.From.Known
 
MD - enum entry in dev.case.api.models.superdoc.v1.V1ConvertParams.From.Value
 
memory() - function in dev.case.api.client.CasedevClient
 
memory() - function in dev.case.api.client.CasedevClient.WithRawResponse
 
memory() - function in dev.case.api.client.CasedevClientAsync
 
memory() - function in dev.case.api.client.CasedevClientAsync.WithRawResponse
 
memory() - function in dev.case.api.client.CasedevClientAsyncImpl
 
memory() - function in dev.case.api.client.CasedevClientAsyncImpl.WithRawResponseImpl
 
memory() - function in dev.case.api.client.CasedevClientImpl
 
memory() - function in dev.case.api.client.CasedevClientImpl.WithRawResponseImpl
 
memory() - function in dev.case.api.models.memory.v1.V1CreateResponse.Result
Extracted memory text
memory(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1CreateResponse.Result.Builder
Sets Builder.memory to an arbitrary JSON value.
memory(java.lang.String) - function in dev.case.api.models.memory.v1.V1CreateResponse.Result.Builder
Extracted memory text
memory() - function in dev.case.api.models.memory.v1.V1ListResponse.Result
 
memory(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1ListResponse.Result.Builder
Sets Builder.memory to an arbitrary JSON value.
memory(java.lang.String) - function in dev.case.api.models.memory.v1.V1ListResponse.Result.Builder
 
memory() - function in dev.case.api.models.memory.v1.V1RetrieveResponse
Memory content
memory(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1RetrieveResponse.Builder
Sets Builder.memory to an arbitrary JSON value.
memory(java.lang.String) - function in dev.case.api.models.memory.v1.V1RetrieveResponse.Builder
Memory content
memory() - function in dev.case.api.models.memory.v1.V1SearchResponse.Result
Memory content
memory(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1SearchResponse.Result.Builder
Sets Builder.memory to an arbitrary JSON value.
memory(java.lang.String) - function in dev.case.api.models.memory.v1.V1SearchResponse.Result.Builder
Memory content
memoryGib() - function in dev.case.api.models.compute.v1.instancetypes.InstanceTypeListResponse.InstanceType.Specs
RAM in GiB
memoryGib(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.instancetypes.InstanceTypeListResponse.InstanceType.Specs.Builder
Sets Builder.memoryGib to an arbitrary JSON value.
memoryGib(java.lang.Long) - function in dev.case.api.models.compute.v1.instancetypes.InstanceTypeListResponse.InstanceType.Specs.Builder
RAM in GiB
memoryMiB() - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Sandbox
Memory in MiB
memoryMiB(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Sandbox.Builder
Sets Builder.memoryMiB to an arbitrary JSON value.
memoryMiB(java.lang.Long) - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Sandbox.Builder
Memory in MiB
MemoryService - class in dev.case.api.services.blocking
 
MemoryService.WithRawResponse - class in dev.case.api.services.blocking.MemoryService
A view of MemoryService that provides access to raw HTTP responses for each method.
MemoryServiceAsync - class in dev.case.api.services.async
 
MemoryServiceAsync.WithRawResponse - class in dev.case.api.services.async.MemoryServiceAsync
A view of MemoryServiceAsync that provides access to raw HTTP responses for each method.
MemoryServiceAsyncImpl - class in dev.case.api.services.async
 
MemoryServiceAsyncImpl.WithRawResponseImpl - class in dev.case.api.services.async.MemoryServiceAsyncImpl
 
MemoryServiceImpl - class in dev.case.api.services.blocking
 
MemoryServiceImpl.WithRawResponseImpl - class in dev.case.api.services.blocking.MemoryServiceImpl
 
message() - function in dev.case.api.models.agent.v1.run.RunCancelResponse
Present if run was already finished
message(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.run.RunCancelResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.agent.v1.run.RunCancelResponse.Builder
Present if run was already finished
message() - function in dev.case.api.models.agent.v1.run.RunExecResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.run.RunExecResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.agent.v1.run.RunExecResponse.Builder
 
message() - function in dev.case.api.models.compute.v1.environments.EnvironmentDeleteResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.environments.EnvironmentDeleteResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.compute.v1.environments.EnvironmentDeleteResponse.Builder
 
message() - function in dev.case.api.models.compute.v1.instances.InstanceCreateResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.instances.InstanceCreateResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.compute.v1.instances.InstanceCreateResponse.Builder
 
message() - function in dev.case.api.models.compute.v1.instances.InstanceDeleteResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.instances.InstanceDeleteResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.compute.v1.instances.InstanceDeleteResponse.Builder
 
message() - function in dev.case.api.models.compute.v1.secrets.SecretDeleteGroupResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.secrets.SecretDeleteGroupResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.compute.v1.secrets.SecretDeleteGroupResponse.Builder
 
message() - function in dev.case.api.models.compute.v1.secrets.SecretUpdateGroupResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.secrets.SecretUpdateGroupResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.compute.v1.secrets.SecretUpdateGroupResponse.Builder
 
message() - function in dev.case.api.models.database.v1.projects.ProjectDeleteResponse
Confirmation message
message(dev.case.api.core.JsonField) - function in dev.case.api.models.database.v1.projects.ProjectDeleteResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.database.v1.projects.ProjectDeleteResponse.Builder
Confirmation message
message() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice.Builder
Sets Builder.message to an arbitrary JSON value.
message(dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice.Message) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice.Builder
 
message() - function in dev.case.api.models.memory.v1.V1DeleteResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1DeleteResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.memory.v1.V1DeleteResponse.Builder
 
message() - function in dev.case.api.models.vault.VaultIngestResponse
Human-readable status message
message(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultIngestResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.vault.VaultIngestResponse.Builder
Human-readable status message
message() - function in dev.case.api.models.vault.graphrag.GraphragInitResponse
 
message(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.graphrag.GraphragInitResponse.Builder
Sets Builder.message to an arbitrary JSON value.
message(java.lang.String) - function in dev.case.api.models.vault.graphrag.GraphragInitResponse.Builder
 
messages() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams
List of messages comprising the conversation
messages() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body
List of messages comprising the conversation
messages(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
Sets Builder.messages to an arbitrary JSON value.
messages(java.util.List) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
List of messages comprising the conversation
messages(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
Sets Builder.messages to an arbitrary JSON value.
messages(java.util.List) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
List of messages comprising the conversation
messages() - function in dev.case.api.models.memory.v1.V1CreateParams
Conversation messages to extract memories from
messages() - function in dev.case.api.models.memory.v1.V1CreateParams.Body
Conversation messages to extract memories from
messages(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1CreateParams.Body.Builder
Sets Builder.messages to an arbitrary JSON value.
messages(java.util.List) - function in dev.case.api.models.memory.v1.V1CreateParams.Body.Builder
Conversation messages to extract memories from
messages(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1CreateParams.Builder
Sets Builder.messages to an arbitrary JSON value.
messages(java.util.List) - function in dev.case.api.models.memory.v1.V1CreateParams.Builder
Conversation messages to extract memories from
metadata() - function in dev.case.api.models.memory.v1.V1CreateParams
Additional metadata (not indexed)
metadata() - function in dev.case.api.models.memory.v1.V1CreateParams.Body
Additional metadata (not indexed)
metadata(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1CreateParams.Body.Builder
Sets Builder.metadata to an arbitrary JSON value.
metadata(dev.case.api.models.memory.v1.V1CreateParams.Metadata) - function in dev.case.api.models.memory.v1.V1CreateParams.Body.Builder
Additional metadata (not indexed)
metadata(dev.case.api.core.JsonField) - function in dev.case.api.models.memory.v1.V1CreateParams.Builder
Sets Builder.metadata to an arbitrary JSON value.
metadata(dev.case.api.models.memory.v1.V1CreateParams.Metadata) - function in dev.case.api.models.memory.v1.V1CreateParams.Builder
Additional metadata (not indexed)
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.memory.v1.V1ListResponse.Result.Builder
 
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.memory.v1.V1RetrieveResponse.Builder
Memory metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.memory.v1.V1SearchResponse.Result.Builder
Additional metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.ocr.v1.V1RetrieveResponse.Builder
Additional processing metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.search.v1.V1ContentsResponse.Result.Builder
Additional metadata about the content
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.VaultCreateParams.Body.Builder
Optional metadata to attach to the vault (e.g.
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.VaultCreateParams.Builder
Optional metadata to attach to the vault (e.g.
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.VaultRetrieveResponse.Builder
Additional vault metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.VaultUpdateResponse.Builder
Additional vault metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.VaultUploadParams.Body.Builder
Additional metadata to associate with the file
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.VaultUploadParams.Builder
Additional metadata to associate with the file
metadata() - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse
 
metadata(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse.Builder
Sets Builder.metadata to an arbitrary JSON value.
metadata(dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse.Metadata) - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse.Builder
 
metadata() - function in dev.case.api.models.vault.objects.ObjectGetTextResponse
 
metadata(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectGetTextResponse.Builder
Sets Builder.metadata to an arbitrary JSON value.
metadata(dev.case.api.models.vault.objects.ObjectGetTextResponse.Metadata) - function in dev.case.api.models.vault.objects.ObjectGetTextResponse.Builder
 
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.objects.ObjectListResponse.Object.Builder
Custom metadata associated with the document
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.objects.ObjectRetrieveResponse.Builder
Additional metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Body.Builder
Additional metadata to merge with existing metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Builder
Additional metadata to merge with existing metadata
metadata(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.objects.ObjectUpdateResponse.Builder
Full metadata object
method() - function in dev.case.api.core.http.HttpRequest
 
method(dev.case.api.core.http.HttpMethod) - function in dev.case.api.core.http.HttpRequest.Builder
 
method() - function in dev.case.api.models.vault.VaultRetrieveResponse.ChunkStrategy
Chunking method (e.g.
method(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultRetrieveResponse.ChunkStrategy.Builder
Sets Builder.method to an arbitrary JSON value.
method(java.lang.String) - function in dev.case.api.models.vault.VaultRetrieveResponse.ChunkStrategy.Builder
Chunking method (e.g.
method() - function in dev.case.api.models.vault.VaultSearchParams
Search method: 'global' for comprehensive questions, 'entity' for specific entities, 'fast' for quick similarity search, 'hybrid' for combined approach
method() - function in dev.case.api.models.vault.VaultSearchParams.Body
Search method: 'global' for comprehensive questions, 'entity' for specific entities, 'fast' for quick similarity search, 'hybrid' for combined approach
method(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultSearchParams.Body.Builder
Sets Builder.method to an arbitrary JSON value.
method(dev.case.api.models.vault.VaultSearchParams.Method) - function in dev.case.api.models.vault.VaultSearchParams.Body.Builder
Search method: 'global' for comprehensive questions, 'entity' for specific entities, 'fast' for quick similarity search, 'hybrid' for combined approach
method(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultSearchParams.Builder
Sets Builder.method to an arbitrary JSON value.
method(dev.case.api.models.vault.VaultSearchParams.Method) - function in dev.case.api.models.vault.VaultSearchParams.Builder
Search method: 'global' for comprehensive questions, 'entity' for specific entities, 'fast' for quick similarity search, 'hybrid' for combined approach
method() - function in dev.case.api.models.vault.VaultSearchResponse
Search method used
method(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultSearchResponse.Builder
Sets Builder.method to an arbitrary JSON value.
method(java.lang.String) - function in dev.case.api.models.vault.VaultSearchResponse.Builder
Search method used
method() - function in dev.case.api.models.vault.VaultUploadResponse.Instructions
 
method(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultUploadResponse.Instructions.Builder
Sets Builder.method to an arbitrary JSON value.
method(java.lang.String) - function in dev.case.api.models.vault.VaultUploadResponse.Instructions.Builder
 
minChunkSize() - function in dev.case.api.models.vault.VaultRetrieveResponse.ChunkStrategy
Minimum chunk size in tokens
minChunkSize(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultRetrieveResponse.ChunkStrategy.Builder
Sets Builder.minChunkSize to an arbitrary JSON value.
minChunkSize(java.lang.Long) - function in dev.case.api.models.vault.VaultRetrieveResponse.ChunkStrategy.Builder
Minimum chunk size in tokens
model() - function in dev.case.api.models.agent.v1.agents.AgentCreateParams
LLM model identifier (e.g.
model() - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Body
LLM model identifier (e.g.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Body.Builder
LLM model identifier (e.g.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Builder
LLM model identifier (e.g.
model() - function in dev.case.api.models.agent.v1.agents.AgentCreateResponse
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentCreateResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentCreateResponse.Builder
 
model() - function in dev.case.api.models.agent.v1.agents.AgentListResponse.Agent
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentListResponse.Agent.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentListResponse.Agent.Builder
 
model() - function in dev.case.api.models.agent.v1.agents.AgentRetrieveResponse
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentRetrieveResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentRetrieveResponse.Builder
 
model() - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams
 
model() - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams.Body
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams.Body.Builder
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams.Builder
 
model() - function in dev.case.api.models.agent.v1.agents.AgentUpdateResponse
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.agents.AgentUpdateResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.agents.AgentUpdateResponse.Builder
 
model() - function in dev.case.api.models.agent.v1.run.RunCreateParams
Override the agent default model for this run
model() - function in dev.case.api.models.agent.v1.run.RunCreateParams.Body
Override the agent default model for this run
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.run.RunCreateParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.util.Optional) - function in dev.case.api.models.agent.v1.run.RunCreateParams.Body.Builder
Alias for calling Builder.model with model.orElse(null).
model(java.lang.String) - function in dev.case.api.models.agent.v1.run.RunCreateParams.Body.Builder
Override the agent default model for this run
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.run.RunCreateParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.util.Optional) - function in dev.case.api.models.agent.v1.run.RunCreateParams.Builder
Alias for calling Builder.model with model.orElse(null).
model(java.lang.String) - function in dev.case.api.models.agent.v1.run.RunCreateParams.Builder
Override the agent default model for this run
model() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.util.Optional) - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Builder
Alias for calling Builder.model with model.orElse(null).
model(java.lang.String) - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Builder
 
model() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Usage
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Usage.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Usage.Builder
 
model() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams
Embedding model to use (e.g.
model() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.Body
Embedding model to use (e.g.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.Body.Builder
Embedding model to use (e.g.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.Builder
Embedding model to use (e.g.
model() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingResponse
 
model(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.V1CreateEmbeddingResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.llm.v1.V1CreateEmbeddingResponse.Builder
 
model() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams
Model to use for completion.
model() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body
Model to use for completion.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
Model to use for completion.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
Model to use for completion.
model() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse
Model used for completion
model(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Builder
Model used for completion
model() - function in dev.case.api.models.privilege.v1.V1DetectParams
LLM model to use for analysis
model() - function in dev.case.api.models.privilege.v1.V1DetectParams.Body
LLM model to use for analysis
model(dev.case.api.core.JsonField) - function in dev.case.api.models.privilege.v1.V1DetectParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.privilege.v1.V1DetectParams.Body.Builder
LLM model to use for analysis
model(dev.case.api.core.JsonField) - function in dev.case.api.models.privilege.v1.V1DetectParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.privilege.v1.V1DetectParams.Builder
LLM model to use for analysis
model() - function in dev.case.api.models.search.v1.V1AnswerParams
LLM model to use when useCustomLLM is true
model() - function in dev.case.api.models.search.v1.V1AnswerParams.Body
LLM model to use when useCustomLLM is true
model(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1AnswerParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.search.v1.V1AnswerParams.Body.Builder
LLM model to use when useCustomLLM is true
model(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1AnswerParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.search.v1.V1AnswerParams.Builder
LLM model to use when useCustomLLM is true
model() - function in dev.case.api.models.search.v1.V1AnswerResponse
Model used for answer generation
model(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1AnswerResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.search.v1.V1AnswerResponse.Builder
Model used for answer generation
model() - function in dev.case.api.models.search.v1.V1ResearchParams
Research quality level - fast (quick), normal (balanced), pro (comprehensive)
model() - function in dev.case.api.models.search.v1.V1ResearchParams.Body
Research quality level - fast (quick), normal (balanced), pro (comprehensive)
model(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1ResearchParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(dev.case.api.models.search.v1.V1ResearchParams.Model) - function in dev.case.api.models.search.v1.V1ResearchParams.Body.Builder
Research quality level - fast (quick), normal (balanced), pro (comprehensive)
model(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1ResearchParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(dev.case.api.models.search.v1.V1ResearchParams.Model) - function in dev.case.api.models.search.v1.V1ResearchParams.Builder
Research quality level - fast (quick), normal (balanced), pro (comprehensive)
model() - function in dev.case.api.models.search.v1.V1ResearchResponse
Model used for research
model(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1ResearchResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.search.v1.V1ResearchResponse.Builder
Model used for research
model() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse
Research model used
model(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Builder
Sets Builder.model to an arbitrary JSON value.
model(dev.case.api.models.search.v1.V1RetrieveResearchResponse.Model) - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Builder
Research model used
model() - function in dev.case.api.models.translate.v1.V1ListLanguagesParams
Translation model to check language support for
model(dev.case.api.models.translate.v1.V1ListLanguagesParams.Model) - function in dev.case.api.models.translate.v1.V1ListLanguagesParams.Builder
Translation model to check language support for
model(java.util.Optional) - function in dev.case.api.models.translate.v1.V1ListLanguagesParams.Builder
Alias for calling Builder.model with model.orElse(null).
model() - function in dev.case.api.models.translate.v1.V1TranslateParams
Translation model.
model() - function in dev.case.api.models.translate.v1.V1TranslateParams.Body
Translation model.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.translate.v1.V1TranslateParams.Body.Builder
Sets Builder.model to an arbitrary JSON value.
model(dev.case.api.models.translate.v1.V1TranslateParams.Model) - function in dev.case.api.models.translate.v1.V1TranslateParams.Body.Builder
Translation model.
model(dev.case.api.core.JsonField) - function in dev.case.api.models.translate.v1.V1TranslateParams.Builder
Sets Builder.model to an arbitrary JSON value.
model(dev.case.api.models.translate.v1.V1TranslateParams.Model) - function in dev.case.api.models.translate.v1.V1TranslateParams.Builder
Translation model.
model() - function in dev.case.api.models.translate.v1.V1TranslateResponse.Data.Translation
Model used for translation
model(dev.case.api.core.JsonField) - function in dev.case.api.models.translate.v1.V1TranslateResponse.Data.Translation.Builder
Sets Builder.model to an arbitrary JSON value.
model(java.lang.String) - function in dev.case.api.models.translate.v1.V1TranslateResponse.Data.Translation.Builder
Model used for translation
modelId() - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams
ElevenLabs model ID
modelId() - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.Body
ElevenLabs model ID
modelId(dev.case.api.core.JsonField) - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.Body.Builder
Sets Builder.modelId to an arbitrary JSON value.
modelId(dev.case.api.models.voice.v1.speak.SpeakCreateParams.ModelId) - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.Body.Builder
ElevenLabs model ID
modelId(dev.case.api.core.JsonField) - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.Builder
Sets Builder.modelId to an arbitrary JSON value.
modelId(dev.case.api.models.voice.v1.speak.SpeakCreateParams.ModelId) - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.Builder
ElevenLabs model ID
models() - function in dev.case.api.models.llm.LlmGetConfigResponse
 
models(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.LlmGetConfigResponse.Builder
Sets Builder.models to an arbitrary JSON value.
models(java.util.List) - function in dev.case.api.models.llm.LlmGetConfigResponse.Builder
 
modelType() - function in dev.case.api.models.llm.LlmGetConfigResponse.Model
Type of model (e.g.
modelType(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.LlmGetConfigResponse.Model.Builder
Sets Builder.modelType to an arbitrary JSON value.
modelType(java.lang.String) - function in dev.case.api.models.llm.LlmGetConfigResponse.Model.Builder
Type of model (e.g.
month() - function in dev.case.api.models.compute.v1.V1GetUsageParams
Month to filter usage data (1-12, defaults to current month)
month(java.util.Optional) - function in dev.case.api.models.compute.v1.V1GetUsageParams.Builder
Alias for calling Builder.month with month.orElse(null).
month(java.lang.Long) - function in dev.case.api.models.compute.v1.V1GetUsageParams.Builder
Alias for Builder.month.
month(java.lang.Long) - function in dev.case.api.models.compute.v1.V1GetUsageParams.Builder
Month to filter usage data (1-12, defaults to current month)
month() - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Period
 
month(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Period.Builder
Sets Builder.month to an arbitrary JSON value.
month(java.lang.Long) - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Period.Builder
 
monthName() - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Period
 
monthName(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Period.Builder
Sets Builder.monthName to an arbitrary JSON value.
monthName(java.lang.String) - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Period.Builder
 
MP3_44100_128 - enum entry in dev.case.api.models.voice.v1.speak.SpeakCreateParams.OutputFormat.Known
 
MP3_44100_128 - enum entry in dev.case.api.models.voice.v1.speak.SpeakCreateParams.OutputFormat.Value
 
MP3_44100_192 - enum entry in dev.case.api.models.voice.v1.speak.SpeakCreateParams.OutputFormat.Known
 
MP3_44100_192 - enum entry in dev.case.api.models.voice.v1.speak.SpeakCreateParams.OutputFormat.Value
 
multipart() - function in dev.case.api.services.async.VaultServiceAsync
 
multipart() - function in dev.case.api.services.async.VaultServiceAsync.WithRawResponse
 
multipart() - function in dev.case.api.services.async.VaultServiceAsyncImpl
 
multipart() - function in dev.case.api.services.async.VaultServiceAsyncImpl.WithRawResponseImpl
 
multipart() - function in dev.case.api.services.blocking.VaultService
 
multipart() - function in dev.case.api.services.blocking.VaultService.WithRawResponse
 
multipart() - function in dev.case.api.services.blocking.VaultServiceImpl
 
multipart() - function in dev.case.api.services.blocking.VaultServiceImpl.WithRawResponseImpl
 
MultipartAbortParams - class in dev.case.api.models.vault.multipart
Abort a multipart upload and discard uploaded parts (live).
MultipartAbortParams.Body - class in dev.case.api.models.vault.multipart.MultipartAbortParams
 
MultipartAbortParams.Body.Builder - class in dev.case.api.models.vault.multipart.MultipartAbortParams.Body
A builder for Body.
MultipartAbortParams.Builder - class in dev.case.api.models.vault.multipart.MultipartAbortParams
A builder for MultipartAbortParams.
MultipartField - class in dev.case.api.core
A class representing a field in a multipart/form-data request.
MultipartField.Builder - class in dev.case.api.core.MultipartField
A builder for MultipartField.
MultipartGetPartUrlsParams - class in dev.case.api.models.vault.multipart
Generate presigned URLs for individual multipart upload parts (live).
MultipartGetPartUrlsParams.Body - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams
 
MultipartGetPartUrlsParams.Body.Builder - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams.Body
A builder for Body.
MultipartGetPartUrlsParams.Builder - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams
A builder for MultipartGetPartUrlsParams.
MultipartGetPartUrlsParams.Part - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams
 
MultipartGetPartUrlsParams.Part.Builder - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams.Part
A builder for Part.
MultipartGetPartUrlsResponse - class in dev.case.api.models.vault.multipart
 
MultipartGetPartUrlsResponse.Builder - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsResponse
A builder for MultipartGetPartUrlsResponse.
MultipartGetPartUrlsResponse.Url - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsResponse
 
MultipartGetPartUrlsResponse.Url.Builder - class in dev.case.api.models.vault.multipart.MultipartGetPartUrlsResponse.Url
A builder for Url.
MultipartService - class in dev.case.api.services.blocking.vault
 
MultipartService.WithRawResponse - class in dev.case.api.services.blocking.vault.MultipartService
A view of MultipartService that provides access to raw HTTP responses for each method.
MultipartServiceAsync - class in dev.case.api.services.async.vault
 
MultipartServiceAsync.WithRawResponse - class in dev.case.api.services.async.vault.MultipartServiceAsync
A view of MultipartServiceAsync that provides access to raw HTTP responses for each method.
MultipartServiceAsyncImpl - class in dev.case.api.services.async.vault
 
MultipartServiceAsyncImpl.WithRawResponseImpl - class in dev.case.api.services.async.vault.MultipartServiceAsyncImpl
 
MultipartServiceImpl - class in dev.case.api.services.blocking.vault
 
MultipartServiceImpl.WithRawResponseImpl - class in dev.case.api.services.blocking.vault.MultipartServiceImpl
 
MULTIPLE_MATCHES - enum entry in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.Status.Known
 
MULTIPLE_MATCHES - enum entry in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.Status.Value
 
multipleMatches() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Summary
Citations with multiple possible matches
multipleMatches(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1VerifyResponse.Summary.Builder
Sets Builder.multipleMatches to an arbitrary JSON value.
multipleMatches(java.lang.Long) - function in dev.case.api.models.legal.v1.V1VerifyResponse.Summary.Builder
Citations with multiple possible matches
MUNICIPAL - enum entry in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Jurisdiction.Level.Known
 
MUNICIPAL - enum entry in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Jurisdiction.Level.Value
 
A  B  C  D  E  F  G  H  I  J  K  L  M  N  O  P  Q  R  S  T  U  V  W  Y  _