A  B  C  D  E  F  G  H  I  J  K  L  M  N  O  P  Q  R  S  T  U  V  W  Y  _ 

F

FAILED - enum entry in dev.case.api.models.agent.v1.run.RunCancelResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.agent.v1.run.RunCancelResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.agent.v1.run.RunGetStatusResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.agent.v1.run.RunGetStatusResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.compute.v1.instances.InstanceListResponse.Instance.Status.Known
 
FAILED - enum entry in dev.case.api.models.compute.v1.instances.InstanceListResponse.Instance.Status.Value
 
FAILED - enum entry in dev.case.api.models.ocr.v1.V1ProcessResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.ocr.v1.V1ProcessResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.ocr.v1.V1RetrieveResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.ocr.v1.V1RetrieveResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.vault.VaultConfirmUploadResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.vault.VaultConfirmUploadResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.vault.objects.ObjectGetSummarizeJobResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.vault.objects.ObjectGetSummarizeJobResponse.Status.Value
 
FAILED - enum entry in dev.case.api.models.voice.transcription.TranscriptionRetrieveResponse.Status.Known
 
FAILED - enum entry in dev.case.api.models.voice.transcription.TranscriptionRetrieveResponse.Status.Value
 
FALSE - enum entry in dev.case.api.models.vault.VaultConfirmUploadParams.Body.VaultConfirmUploadFailure.Success.Known
 
FALSE - enum entry in dev.case.api.models.vault.VaultConfirmUploadParams.Body.VaultConfirmUploadFailure.Success.Value
 
FAST - enum entry in dev.case.api.models.search.v1.V1ResearchParams.Model.Known
 
FAST - enum entry in dev.case.api.models.search.v1.V1ResearchParams.Model.Value
 
FAST - enum entry in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Model.Known
 
FAST - enum entry in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Model.Value
 
FAST - enum entry in dev.case.api.models.vault.VaultSearchParams.Method.Known
 
FAST - enum entry in dev.case.api.models.vault.VaultSearchParams.Method.Value
 
features() - function in dev.case.api.models.ocr.v1.V1ProcessParams
Additional processing options
features() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Body
Additional processing options
features(dev.case.api.core.JsonField) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Body.Builder
Sets Builder.features to an arbitrary JSON value.
features(dev.case.api.models.ocr.v1.V1ProcessParams.Features) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Body.Builder
Additional processing options
features(dev.case.api.core.JsonField) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Builder
Sets Builder.features to an arbitrary JSON value.
features(dev.case.api.models.ocr.v1.V1ProcessParams.Features) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Builder
Additional processing options
FEDERAL - enum entry in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Jurisdiction.Level.Known
 
FEDERAL - enum entry in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Jurisdiction.Level.Value
 
fields() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams
Fields to populate in the template
fields() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Body
Fields to populate in the template
fields(dev.case.api.core.JsonField) - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Body.Builder
Sets Builder.fields to an arbitrary JSON value.
fields(java.util.List) - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Body.Builder
Fields to populate in the template
fields(dev.case.api.core.JsonField) - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Builder
Sets Builder.fields to an arbitrary JSON value.
fields(java.util.List) - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Builder
Fields to populate in the template
filename() - function in dev.case.api.core.MultipartField
Returns the filename directive that will be included in the serialized field.
filename(java.util.Optional) - function in dev.case.api.core.MultipartField.Builder
Alias for calling Builder.filename with filename.orElse(null).
filename(java.lang.String) - function in dev.case.api.core.MultipartField.Builder
 
filename() - function in dev.case.api.models.vault.VaultSearchResponse.Source
 
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultSearchResponse.Source.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.VaultSearchResponse.Source.Builder
 
filename() - function in dev.case.api.models.vault.VaultUploadParams
Name of the file to upload
filename() - function in dev.case.api.models.vault.VaultUploadParams.Body
Name of the file to upload
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultUploadParams.Body.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.VaultUploadParams.Body.Builder
Name of the file to upload
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultUploadParams.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.VaultUploadParams.Builder
Name of the file to upload
filename() - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse
Original filename
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse.Builder
Original filename
filename() - function in dev.case.api.models.vault.objects.ObjectDeleteResponse.DeletedObject
Original filename
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectDeleteResponse.DeletedObject.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectDeleteResponse.DeletedObject.Builder
Original filename
filename() - function in dev.case.api.models.vault.objects.ObjectGetTextResponse.Metadata
Original filename of the document
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectGetTextResponse.Metadata.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectGetTextResponse.Metadata.Builder
Original filename of the document
filename() - function in dev.case.api.models.vault.objects.ObjectListResponse.Object
Original filename of the uploaded document
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectListResponse.Object.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectListResponse.Object.Builder
Original filename of the uploaded document
filename() - function in dev.case.api.models.vault.objects.ObjectRetrieveResponse
Original filename
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectRetrieveResponse.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectRetrieveResponse.Builder
Original filename
filename() - function in dev.case.api.models.vault.objects.ObjectUpdateParams
New filename for the document (affects display name and downloads)
filename() - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Body
New filename for the document (affects display name and downloads)
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Body.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Body.Builder
New filename for the document (affects display name and downloads)
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Builder
New filename for the document (affects display name and downloads)
filename() - function in dev.case.api.models.vault.objects.ObjectUpdateResponse
Updated filename
filename(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectUpdateResponse.Builder
Sets Builder.filename to an arbitrary JSON value.
filename(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectUpdateResponse.Builder
Updated filename
filesBucket() - function in dev.case.api.models.vault.VaultCreateResponse
S3 bucket name for document storage
filesBucket(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultCreateResponse.Builder
Sets Builder.filesBucket to an arbitrary JSON value.
filesBucket(java.lang.String) - function in dev.case.api.models.vault.VaultCreateResponse.Builder
S3 bucket name for document storage
filesBucket() - function in dev.case.api.models.vault.VaultRetrieveResponse
S3 bucket for document storage
filesBucket(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultRetrieveResponse.Builder
Sets Builder.filesBucket to an arbitrary JSON value.
filesBucket(java.lang.String) - function in dev.case.api.models.vault.VaultRetrieveResponse.Builder
S3 bucket for document storage
filesBucket() - function in dev.case.api.models.vault.VaultUpdateResponse
S3 bucket for document storage
filesBucket(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultUpdateResponse.Builder
Sets Builder.filesBucket to an arbitrary JSON value.
filesBucket(java.lang.String) - function in dev.case.api.models.vault.VaultUpdateResponse.Builder
S3 bucket for document storage
FILING_DATE - enum entry in dev.case.api.models.legal.v1.V1PatentSearchParams.SortBy.Known
 
FILING_DATE - enum entry in dev.case.api.models.legal.v1.V1PatentSearchParams.SortBy.Value
 
filingDate() - function in dev.case.api.models.legal.v1.V1PatentSearchResponse.Result
Date the application was filed
filingDate(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1PatentSearchResponse.Result.Builder
Sets Builder.filingDate to an arbitrary JSON value.
filingDate(java.time.LocalDate) - function in dev.case.api.models.legal.v1.V1PatentSearchResponse.Result.Builder
Date the application was filed
filingDate(java.util.Optional) - function in dev.case.api.models.legal.v1.V1PatentSearchResponse.Result.Builder
Alias for calling Builder.filingDate with filingDate.orElse(null).
filingDate() - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse
Date the application was filed
filingDate(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Sets Builder.filingDate to an arbitrary JSON value.
filingDate(java.time.LocalDate) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Date the application was filed
filingDate(java.util.Optional) - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Builder
Alias for calling Builder.filingDate with filingDate.orElse(null).
filingDateFrom() - function in dev.case.api.models.legal.v1.V1PatentSearchParams
Start of filing date range (YYYY-MM-DD)
filingDateFrom() - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Body
Start of filing date range (YYYY-MM-DD)
filingDateFrom(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Body.Builder
Sets Builder.filingDateFrom to an arbitrary JSON value.
filingDateFrom(java.time.LocalDate) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Body.Builder
Start of filing date range (YYYY-MM-DD)
filingDateFrom(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Builder
Sets Builder.filingDateFrom to an arbitrary JSON value.
filingDateFrom(java.time.LocalDate) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Builder
Start of filing date range (YYYY-MM-DD)
filingDateTo() - function in dev.case.api.models.legal.v1.V1PatentSearchParams
End of filing date range (YYYY-MM-DD)
filingDateTo() - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Body
End of filing date range (YYYY-MM-DD)
filingDateTo(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Body.Builder
Sets Builder.filingDateTo to an arbitrary JSON value.
filingDateTo(java.time.LocalDate) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Body.Builder
End of filing date range (YYYY-MM-DD)
filingDateTo(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Builder
Sets Builder.filingDateTo to an arbitrary JSON value.
filingDateTo(java.time.LocalDate) - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Builder
End of filing date range (YYYY-MM-DD)
fillInStackTrace() - function in kotlin.Throwable
 
filters() - function in dev.case.api.models.vault.VaultSearchParams
Filters to narrow search results to specific documents
filters() - function in dev.case.api.models.vault.VaultSearchParams.Body
Filters to narrow search results to specific documents
filters(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultSearchParams.Body.Builder
Sets Builder.filters to an arbitrary JSON value.
filters(dev.case.api.models.vault.VaultSearchParams.Filters) - function in dev.case.api.models.vault.VaultSearchParams.Body.Builder
Filters to narrow search results to specific documents
filters(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.VaultSearchParams.Builder
Sets Builder.filters to an arbitrary JSON value.
filters(dev.case.api.models.vault.VaultSearchParams.Filters) - function in dev.case.api.models.vault.VaultSearchParams.Builder
Filters to narrow search results to specific documents
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.async.legal.V1ServiceAsync
Search for legal sources including cases, statutes, and regulations from authoritative legal databases.
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.async.legal.V1ServiceAsync
Search for legal sources including cases, statutes, and regulations from authoritative legal databases.
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.async.legal.V1ServiceAsync
 
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.async.legal.V1ServiceAsync.WithRawResponse
Returns a raw HTTP response for post /legal/v1/find, but is otherwise the same as V1ServiceAsync.find.
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.async.legal.V1ServiceAsync.WithRawResponse
Returns a raw HTTP response for post /legal/v1/find, but is otherwise the same as V1ServiceAsync.find.
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.async.legal.V1ServiceAsync.WithRawResponse
 
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.async.legal.V1ServiceAsyncImpl
 
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.async.legal.V1ServiceAsyncImpl.WithRawResponseImpl
 
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.blocking.legal.V1Service
Search for legal sources including cases, statutes, and regulations from authoritative legal databases.
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.blocking.legal.V1Service
Search for legal sources including cases, statutes, and regulations from authoritative legal databases.
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.blocking.legal.V1Service
 
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.blocking.legal.V1Service.WithRawResponse
Returns a raw HTTP response for post /legal/v1/find, but is otherwise the same as V1Service.find.
find(dev.case.api.models.legal.v1.V1FindParams) - function in dev.case.api.services.blocking.legal.V1Service.WithRawResponse
Returns a raw HTTP response for post /legal/v1/find, but is otherwise the same as V1Service.find.
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.blocking.legal.V1Service.WithRawResponse
 
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.blocking.legal.V1ServiceImpl
 
find(dev.case.api.models.legal.v1.V1FindParams,dev.case.api.core.RequestOptions) - function in dev.case.api.services.blocking.legal.V1ServiceImpl.WithRawResponseImpl
 
findBackReference(java.lang.String) - function in com.fasterxml.jackson.databind.JsonDeserializer
 
finishReason() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice
 
finishReason(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice.Builder
Sets Builder.finishReason to an arbitrary JSON value.
finishReason(java.lang.String) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice.Builder
 
FLOAT - enum entry in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.EncodingFormat.Known
 
FLOAT - enum entry in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.EncodingFormat.Value
 
FOOTER - enum entry in dev.case.api.models.format.v1.templates.TemplateCreateParams.Type.Known
 
FOOTER - enum entry in dev.case.api.models.format.v1.templates.TemplateCreateParams.Type.Value
 
force() - function in dev.case.api.models.vault.objects.ObjectDeleteParams
Force delete a stuck document that is still in 'processing' state.
force(dev.case.api.models.vault.objects.ObjectDeleteParams.Force) - function in dev.case.api.models.vault.objects.ObjectDeleteParams.Builder
Force delete a stuck document that is still in 'processing' state.
force(java.util.Optional) - function in dev.case.api.models.vault.objects.ObjectDeleteParams.Builder
Alias for calling Builder.force with force.orElse(null).
format() - function in dev.case.api.client.CasedevClient
 
format() - function in dev.case.api.client.CasedevClient.WithRawResponse
 
format() - function in dev.case.api.client.CasedevClientAsync
 
format() - function in dev.case.api.client.CasedevClientAsync.WithRawResponse
 
format() - function in dev.case.api.client.CasedevClientAsyncImpl
 
format() - function in dev.case.api.client.CasedevClientAsyncImpl.WithRawResponseImpl
 
format() - function in dev.case.api.client.CasedevClientImpl
 
format() - function in dev.case.api.client.CasedevClientImpl.WithRawResponseImpl
 
format() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables
Output format for extracted tables
format(dev.case.api.core.JsonField) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables.Builder
Sets Builder.format to an arbitrary JSON value.
format(dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables.Format) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables.Builder
Output format for extracted tables
format() - function in dev.case.api.models.translate.v1.V1TranslateParams
Format of the source text.
format() - function in dev.case.api.models.translate.v1.V1TranslateParams.Body
Format of the source text.
format(dev.case.api.core.JsonField) - function in dev.case.api.models.translate.v1.V1TranslateParams.Body.Builder
Sets Builder.format to an arbitrary JSON value.
format(dev.case.api.models.translate.v1.V1TranslateParams.Format) - function in dev.case.api.models.translate.v1.V1TranslateParams.Body.Builder
Format of the source text.
format(dev.case.api.core.JsonField) - function in dev.case.api.models.translate.v1.V1TranslateParams.Builder
Sets Builder.format to an arbitrary JSON value.
format(dev.case.api.models.translate.v1.V1TranslateParams.Format) - function in dev.case.api.models.translate.v1.V1TranslateParams.Builder
Format of the source text.
format() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams
Output format for the transcript when using vault mode
format() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Body
Output format for the transcript when using vault mode
format(dev.case.api.core.JsonField) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Body.Builder
Sets Builder.format to an arbitrary JSON value.
format(dev.case.api.models.voice.transcription.TranscriptionCreateParams.Format) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Body.Builder
Output format for the transcript when using vault mode
format(dev.case.api.core.JsonField) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Builder
Sets Builder.format to an arbitrary JSON value.
format(dev.case.api.models.voice.transcription.TranscriptionCreateParams.Format) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Builder
Output format for the transcript when using vault mode
FormatService - class in dev.case.api.services.blocking
 
FormatService.WithRawResponse - class in dev.case.api.services.blocking.FormatService
A view of FormatService that provides access to raw HTTP responses for each method.
FormatServiceAsync - class in dev.case.api.services.async
 
FormatServiceAsync.WithRawResponse - class in dev.case.api.services.async.FormatServiceAsync
A view of FormatServiceAsync that provides access to raw HTTP responses for each method.
FormatServiceAsyncImpl - class in dev.case.api.services.async
 
FormatServiceAsyncImpl.WithRawResponseImpl - class in dev.case.api.services.async.FormatServiceAsyncImpl
 
FormatServiceImpl - class in dev.case.api.services.blocking
 
FormatServiceImpl.WithRawResponseImpl - class in dev.case.api.services.blocking.FormatServiceImpl
 
formatText() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams
Format text with proper capitalization
formatText() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Body
Format text with proper capitalization
formatText(dev.case.api.core.JsonField) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Body.Builder
Sets Builder.formatText to an arbitrary JSON value.
formatText(java.lang.Boolean) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Body.Builder
Format text with proper capitalization
formatText(dev.case.api.core.JsonField) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Builder
Sets Builder.formatText to an arbitrary JSON value.
formatText(java.lang.Boolean) - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Builder
Format text with proper capitalization
forms() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features
Detect and extract form fields
forms(dev.case.api.core.JsonField) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Builder
Sets Builder.forms to an arbitrary JSON value.
forms(dev.case.api.models.ocr.v1.V1ProcessParams.Features.Forms) - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Builder
Detect and extract form fields
found() - function in dev.case.api.models.legal.v1.V1FindResponse
Number of candidates found
found(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1FindResponse.Builder
Sets Builder.found to an arbitrary JSON value.
found(java.lang.Long) - function in dev.case.api.models.legal.v1.V1FindResponse.Builder
Number of candidates found
found() - function in dev.case.api.models.legal.v1.V1GetCitationsResponse.Citation
Whether citation was found in CourtListener database
found(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1GetCitationsResponse.Citation.Builder
Sets Builder.found to an arbitrary JSON value.
found(java.lang.Boolean) - function in dev.case.api.models.legal.v1.V1GetCitationsResponse.Citation.Builder
Whether citation was found in CourtListener database
found() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse
Number of matching jurisdictions
found(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Builder
Sets Builder.found to an arbitrary JSON value.
found(java.lang.Long) - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Builder
Number of matching jurisdictions
found() - function in dev.case.api.models.legal.v1.V1ResearchResponse
Number of candidates found
found(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Builder
Sets Builder.found to an arbitrary JSON value.
found(java.lang.Long) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Builder
Number of candidates found
found() - function in dev.case.api.models.legal.v1.V1SimilarResponse
Number of similar sources found
found(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1SimilarResponse.Builder
Sets Builder.found to an arbitrary JSON value.
found(java.lang.Long) - function in dev.case.api.models.legal.v1.V1SimilarResponse.Builder
Number of similar sources found
framework() - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams
Framework (e.g.
framework() - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.Body
Framework (e.g.
framework(dev.case.api.core.JsonField) - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.Body.Builder
Sets Builder.framework to an arbitrary JSON value.
framework(java.lang.String) - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.Body.Builder
Framework (e.g.
framework(dev.case.api.core.JsonField) - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.Builder
Sets Builder.framework to an arbitrary JSON value.
framework(java.lang.String) - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.Builder
Framework (e.g.
framework() - function in dev.case.api.models.applications.v1.projects.ProjectListResponse.Project
 
framework(dev.case.api.core.JsonField) - function in dev.case.api.models.applications.v1.projects.ProjectListResponse.Project.Builder
Sets Builder.framework to an arbitrary JSON value.
framework(java.lang.String) - function in dev.case.api.models.applications.v1.projects.ProjectListResponse.Project.Builder
 
freeBranches() - function in dev.case.api.models.database.v1.V1GetUsageResponse.Pricing
Number of free branches included
freeBranches(dev.case.api.core.JsonField) - function in dev.case.api.models.database.v1.V1GetUsageResponse.Pricing.Builder
Sets Builder.freeBranches to an arbitrary JSON value.
freeBranches(java.lang.Long) - function in dev.case.api.models.database.v1.V1GetUsageResponse.Pricing.Builder
Number of free branches included
frequencyPenalty() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams
Frequency penalty parameter
frequencyPenalty() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body
Frequency penalty parameter
frequencyPenalty(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
Sets Builder.frequencyPenalty to an arbitrary JSON value.
frequencyPenalty(java.lang.Double) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body.Builder
Frequency penalty parameter
frequencyPenalty(dev.case.api.core.JsonField) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
Sets Builder.frequencyPenalty to an arbitrary JSON value.
frequencyPenalty(java.lang.Double) - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Builder
Frequency penalty parameter
from(java.lang.Object) - function in dev.case.api.core.JsonValue.Companion
Converts the given value to a JsonValue.
from() - function in dev.case.api.models.superdoc.v1.V1ConvertParams
Source format of the document
from() - function in dev.case.api.models.superdoc.v1.V1ConvertParams.Body
Source format of the document
from(dev.case.api.core.MultipartField) - function in dev.case.api.models.superdoc.v1.V1ConvertParams.Body.Builder
Sets Builder.from to an arbitrary multipart value.
from(dev.case.api.models.superdoc.v1.V1ConvertParams.From) - function in dev.case.api.models.superdoc.v1.V1ConvertParams.Body.Builder
Source format of the document
from(dev.case.api.core.MultipartField) - function in dev.case.api.models.superdoc.v1.V1ConvertParams.Builder
Sets Builder.from to an arbitrary multipart value.
from(dev.case.api.models.superdoc.v1.V1ConvertParams.From) - function in dev.case.api.models.superdoc.v1.V1ConvertParams.Builder
Source format of the document
fromEnv() - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
Updates configuration using system properties and environment variables.
fromEnv() - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Companion
Returns a client configured using system properties and environment variables.
fromEnv() - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
Updates configuration using system properties and environment variables.
fromEnv() - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Companion
Returns a client configured using system properties and environment variables.
fromEnv() - function in dev.case.api.core.ClientOptions.Builder
Updates configuration using system properties and environment variables.
fromEnv() - function in dev.case.api.core.ClientOptions.Companion
Returns options configured using system properties and environment variables.
fromJsonNode(com.fasterxml.jackson.databind.JsonNode) - function in dev.case.api.core.JsonValue.Companion
Returns a JsonValue converted from the given Jackson JsonNode.
A  B  C  D  E  F  G  H  I  J  K  L  M  N  O  P  Q  R  S  T  U  V  W  Y  _