Class AgentDeleteResponse
-
- All Implemented Interfaces:
public final class AgentDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentDeleteResponse.BuilderA builder for AgentDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>ok()final JsonField<Boolean>_ok()Returns the raw JSON value of ok. final Map<String, JsonValue>_additionalProperties()final AgentDeleteResponse.BuildertoBuilder()final AgentDeleteResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AgentDeleteResponse. -
-
Method Detail
-
_ok
final JsonField<Boolean> _ok()
Returns the raw JSON value of ok.
Unlike ok, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentDeleteResponse.Builder toBuilder()
-
validate
final AgentDeleteResponse validate()
-
builder
final static AgentDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of AgentDeleteResponse.
-
-
-
-