Class AgentListResponse
-
- All Implemented Interfaces:
public final class AgentListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentListResponse.BuilderA builder for AgentListResponse.
public final classAgentListResponse.Agent
-
Method Summary
Modifier and Type Method Description final Optional<List<AgentListResponse.Agent>>agents()final JsonField<List<AgentListResponse.Agent>>_agents()Returns the raw JSON value of agents. final Map<String, JsonValue>_additionalProperties()final AgentListResponse.BuildertoBuilder()final AgentListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AgentListResponse. -
-
Method Detail
-
agents
final Optional<List<AgentListResponse.Agent>> agents()
-
_agents
final JsonField<List<AgentListResponse.Agent>> _agents()
Returns the raw JSON value of agents.
Unlike agents, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentListResponse.Builder toBuilder()
-
validate
final AgentListResponse validate()
-
builder
final static AgentListResponse.Builder builder()
Returns a mutable builder for constructing an instance of AgentListResponse.
-
-
-
-