Class AgentListResponse.Builder
-
- All Implemented Interfaces:
public final class AgentListResponse.BuilderA builder for AgentListResponse.
-
-
Method Summary
Modifier and Type Method Description final AgentListResponse.Builderagents(List<AgentListResponse.Agent> agents)final AgentListResponse.Builderagents(JsonField<List<AgentListResponse.Agent>> agents)Sets Builder.agents to an arbitrary JSON value. final AgentListResponse.BuilderaddAgent(AgentListResponse.Agent agent)Adds a single Agent to agents. final AgentListResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AgentListResponse.BuilderputAdditionalProperty(String key, JsonValue value)final AgentListResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AgentListResponse.BuilderremoveAdditionalProperty(String key)final AgentListResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final AgentListResponsebuild()Returns an immutable instance of AgentListResponse. -
-
Method Detail
-
agents
final AgentListResponse.Builder agents(List<AgentListResponse.Agent> agents)
-
agents
final AgentListResponse.Builder agents(JsonField<List<AgentListResponse.Agent>> agents)
Sets Builder.agents to an arbitrary JSON value.
You should usually call Builder.agents with a well-typed
List<Agent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAgent
final AgentListResponse.Builder addAgent(AgentListResponse.Agent agent)
-
additionalProperties
final AgentListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AgentListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AgentListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AgentListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AgentListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AgentListResponse build()
Returns an immutable instance of AgentListResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-