Class AgentUpdateParams.Body
-
- All Implemented Interfaces:
public final class AgentUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()Updated agent description. final Optional<List<String>>disabledTools()Denylist of tools the agent cannot use. final Optional<List<String>>enabledTools()Allowlist of tools the agent can use. final Optional<String>instructions()Updated system instructions that guide agent behavior final Optional<String>model()Model identifier the agent should use for future runs final Optional<String>name()Updated agent display name final JsonValue_sandbox()Sandbox configuration override for future agent runs. final Optional<List<String>>vaultGroups()Vault group IDs the agent can access. final Optional<List<String>>vaultIds()Vault IDs the agent can access directly. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<String>>_disabledTools()Returns the raw JSON value of disabledTools. final JsonField<List<String>>_enabledTools()Returns the raw JSON value of enabledTools. final JsonField<String>_instructions()Returns the raw JSON value of instructions. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<List<String>>_vaultGroups()Returns the raw JSON value of vaultGroups. final JsonField<List<String>>_vaultIds()Returns the raw JSON value of vaultIds. final Map<String, JsonValue>_additionalProperties()final AgentUpdateParams.Body.BuildertoBuilder()final AgentUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AgentUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
Updated agent description. Pass null to clear if supported by the client.
-
disabledTools
final Optional<List<String>> disabledTools()
Denylist of tools the agent cannot use. Mutually exclusive with enabledTools — set one or the other, not both. Pass null to clear.
-
enabledTools
final Optional<List<String>> enabledTools()
Allowlist of tools the agent can use. Mutually exclusive with disabledTools — set one or the other, not both. Pass null to clear.
-
instructions
final Optional<String> instructions()
Updated system instructions that guide agent behavior
-
_sandbox
final JsonValue _sandbox()
Sandbox configuration override for future agent runs. Pass null to clear.
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.sandbox().convert(MyClass.class);
-
vaultGroups
final Optional<List<String>> vaultGroups()
Vault group IDs the agent can access. Pass null to clear.
-
vaultIds
final Optional<List<String>> vaultIds()
Vault IDs the agent can access directly. Pass null to clear.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_disabledTools
final JsonField<List<String>> _disabledTools()
Returns the raw JSON value of disabledTools.
Unlike disabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_enabledTools
final JsonField<List<String>> _enabledTools()
Returns the raw JSON value of enabledTools.
Unlike enabledTools, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultGroups
final JsonField<List<String>> _vaultGroups()
Returns the raw JSON value of vaultGroups.
Unlike vaultGroups, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultIds
final JsonField<List<String>> _vaultIds()
Returns the raw JSON value of vaultIds.
Unlike vaultIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AgentUpdateParams.Body.Builder toBuilder()
-
validate
final AgentUpdateParams.Body validate()
-
builder
final static AgentUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-