Class ChatCancelResponse
-
- All Implemented Interfaces:
public final class ChatCancelResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCancelResponse.BuilderA builder for ChatCancelResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Boolean>ok()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Boolean>_ok()Returns the raw JSON value of ok. final Map<String, JsonValue>_additionalProperties()final ChatCancelResponse.BuildertoBuilder()final ChatCancelResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCancelResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ChatCancelResponse. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_ok
final JsonField<Boolean> _ok()
Returns the raw JSON value of ok.
Unlike ok, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCancelResponse.Builder toBuilder()
-
validate
final ChatCancelResponse validate()
-
builder
final static ChatCancelResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChatCancelResponse.
-
-
-
-