Class ChatRespondParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ChatRespondParams implements Params
Streams a single assistant turn as normalized state events with stable turn, message, and part ids. Emits session.usage before turn.completed when token data is available.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatRespondParams.BuilderA builder for ChatRespondParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final JsonValuebody()OpenCode message payload. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ChatRespondParams.BuildertoBuilder()final JsonValue_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatRespondParams.Builderbuilder()Returns a mutable builder for constructing an instance of ChatRespondParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ChatRespondParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ChatRespondParams.Builder builder()
Returns a mutable builder for constructing an instance of ChatRespondParams.
The following fields are required:
.body()
-
-
-
-