Class ChatSendMessageParams.Body
-
- All Implemented Interfaces:
public final class ChatSendMessageParams.BodyMessage payload following the AI SDK UIMessage format. The body is passed through 1:1 to the underlying OpenCode session. Currently only text parts are supported.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatSendMessageParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<List<ChatSendMessageParams.Part>>parts()Message content parts. final JsonField<List<ChatSendMessageParams.Part>>_parts()Returns the raw JSON value of parts. final Map<String, JsonValue>_additionalProperties()final ChatSendMessageParams.Body.BuildertoBuilder()final ChatSendMessageParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatSendMessageParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
parts
final Optional<List<ChatSendMessageParams.Part>> parts()
Message content parts. Currently only "text" type is supported. Additional types (e.g. file, image) may be added in future versions.
-
_parts
final JsonField<List<ChatSendMessageParams.Part>> _parts()
Returns the raw JSON value of parts.
Unlike parts, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatSendMessageParams.Body.Builder toBuilder()
-
validate
final ChatSendMessageParams.Body validate()
-
builder
final static ChatSendMessageParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-