Package dev.case.api.models.agent.v1.run
Class RunCreateParams.Body
-
- All Implemented Interfaces:
public final class RunCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringagentId()ID of the agent to run final Stringprompt()Task prompt for the agent final Optional<String>guidance()Additional guidance for this run final Optional<String>model()Override the agent default model for this run final JsonField<String>_agentId()Returns the raw JSON value of agentId. final JsonField<String>_prompt()Returns the raw JSON value of prompt. final JsonField<String>_guidance()Returns the raw JSON value of guidance. final JsonField<String>_model()Returns the raw JSON value of model. final Map<String, JsonValue>_additionalProperties()final RunCreateParams.Body.BuildertoBuilder()final RunCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_guidance
final JsonField<String> _guidance()
Returns the raw JSON value of guidance.
Unlike guidance, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunCreateParams.Body.Builder toBuilder()
-
validate
final RunCreateParams.Body validate()
-
builder
final static RunCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.agentId() .prompt()
-
-
-
-