Package dev.case.api.models.agent.v1.run
Class RunCreateResponse
-
- All Implemented Interfaces:
public final class RunCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunCreateResponse.BuilderA builder for RunCreateResponse.
public final classRunCreateResponse.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>agentId()final Optional<OffsetDateTime>createdAt()final Optional<List<String>>objectIds()final Optional<RunCreateResponse.Status>status()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_agentId()Returns the raw JSON value of agentId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<List<String>>_objectIds()Returns the raw JSON value of objectIds. final JsonField<RunCreateResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final RunCreateResponse.BuildertoBuilder()final RunCreateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RunCreateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
status
final Optional<RunCreateResponse.Status> status()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_objectIds
final JsonField<List<String>> _objectIds()
Returns the raw JSON value of objectIds.
Unlike objectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RunCreateResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunCreateResponse.Builder toBuilder()
-
validate
final RunCreateResponse validate()
-
builder
final static RunCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of RunCreateResponse.
-
-
-
-