Class RunGetDetailsResponse.Step
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.Step
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.Step.BuilderA builder for Step.
public final classRunGetDetailsResponse.Step.Type
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>content()final Optional<Long>durationMs()final Optional<OffsetDateTime>timestamp()final JsonValue_toolInput()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = step.toolInput().convert(MyClass.class);final Optional<String>toolName()final JsonValue_toolOutput()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = step.toolOutput().convert(MyClass.class);final Optional<RunGetDetailsResponse.Step.Type>type()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<Long>_durationMs()Returns the raw JSON value of durationMs. final JsonField<OffsetDateTime>_timestamp()Returns the raw JSON value of timestamp. final JsonField<String>_toolName()Returns the raw JSON value of toolName. final JsonField<RunGetDetailsResponse.Step.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final RunGetDetailsResponse.Step.BuildertoBuilder()final RunGetDetailsResponse.Stepvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RunGetDetailsResponse.Step.Builderbuilder()Returns a mutable builder for constructing an instance of Step. -
-
Method Detail
-
durationMs
final Optional<Long> durationMs()
-
timestamp
final Optional<OffsetDateTime> timestamp()
-
_toolInput
final JsonValue _toolInput()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = step.toolInput().convert(MyClass.class);
-
_toolOutput
final JsonValue _toolOutput()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = step.toolOutput().convert(MyClass.class);
-
type
final Optional<RunGetDetailsResponse.Step.Type> type()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_durationMs
final JsonField<Long> _durationMs()
Returns the raw JSON value of durationMs.
Unlike durationMs, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_toolName
final JsonField<String> _toolName()
Returns the raw JSON value of toolName.
Unlike toolName, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RunGetDetailsResponse.Step.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Step.Builder toBuilder()
-
validate
final RunGetDetailsResponse.Step validate()
-
builder
final static RunGetDetailsResponse.Step.Builder builder()
Returns a mutable builder for constructing an instance of Step.
-
-
-
-