Class RunGetDetailsResponse.Usage
-
- All Implemented Interfaces:
public final class RunGetDetailsResponse.UsageToken usage statistics
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunGetDetailsResponse.Usage.BuilderA builder for Usage.
public final classRunGetDetailsResponse.Usage.Entrypublic final classRunGetDetailsResponse.Usage.Summary
-
Method Summary
-
-
Method Detail
-
durationMs
final Optional<Long> durationMs()
-
entries
final Optional<List<RunGetDetailsResponse.Usage.Entry>> entries()
-
inputTokens
final Optional<Long> inputTokens()
-
outputTokens
final Optional<Long> outputTokens()
-
summary
final Optional<RunGetDetailsResponse.Usage.Summary> summary()
-
_durationMs
final JsonField<Long> _durationMs()
Returns the raw JSON value of durationMs.
Unlike durationMs, this method doesn't throw if the JSON field has an unexpected type.
-
_entries
final JsonField<List<RunGetDetailsResponse.Usage.Entry>> _entries()
Returns the raw JSON value of entries.
Unlike entries, this method doesn't throw if the JSON field has an unexpected type.
-
_inputTokens
final JsonField<Long> _inputTokens()
Returns the raw JSON value of inputTokens.
Unlike inputTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_outputTokens
final JsonField<Long> _outputTokens()
Returns the raw JSON value of outputTokens.
Unlike outputTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<RunGetDetailsResponse.Usage.Summary> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_toolCalls
final JsonField<Long> _toolCalls()
Returns the raw JSON value of toolCalls.
Unlike toolCalls, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunGetDetailsResponse.Usage.Builder toBuilder()
-
validate
final RunGetDetailsResponse.Usage validate()
-
builder
final static RunGetDetailsResponse.Usage.Builder builder()
Returns a mutable builder for constructing an instance of Usage.
-
-
-
-