Class RunListResponse.Run
-
- All Implemented Interfaces:
public final class RunListResponse.Run
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunListResponse.Run.BuilderA builder for Run.
public final classRunListResponse.Run.Status
-
Method Summary
-
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
startedAt
final Optional<OffsetDateTime> startedAt()
-
status
final Optional<RunListResponse.Run.Status> status()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_agentId
final JsonField<String> _agentId()
Returns the raw JSON value of agentId.
Unlike agentId, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_prompt
final JsonField<String> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RunListResponse.Run.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RunListResponse.Run.Builder toBuilder()
-
validate
final RunListResponse.Run validate()
-
builder
final static RunListResponse.Run.Builder builder()
Returns a mutable builder for constructing an instance of Run.
-
-
-
-