Class DeploymentCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class DeploymentCreateParams implements Params
Creates a deployment for an existing project by fetching repository files from GitHub and uploading them to the hosting provider. Use ref to deploy a branch, tag, or commit other than the project default branch.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeploymentCreateParams.BuilderA builder for DeploymentCreateParams.
public final classDeploymentCreateParams.Bodypublic final classDeploymentCreateParams.TargetDeployment target environment
-
Method Summary
Modifier and Type Method Description final StringprojectId()Project ID to deploy final Optional<String>ref()Git branch, tag, or commit to deploy. final Optional<DeploymentCreateParams.Target>target()Deployment target environment final JsonField<String>_projectId()Returns the raw JSON value of projectId. final JsonField<String>_ref()Returns the raw JSON value of ref. final JsonField<DeploymentCreateParams.Target>_target()Returns the raw JSON value of target. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DeploymentCreateParams.BuildertoBuilder()final DeploymentCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeploymentCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of DeploymentCreateParams. -
-
Method Detail
-
ref
final Optional<String> ref()
Git branch, tag, or commit to deploy. Defaults to the project branch.
-
target
final Optional<DeploymentCreateParams.Target> target()
Deployment target environment
-
_projectId
final JsonField<String> _projectId()
Returns the raw JSON value of projectId.
Unlike projectId, this method doesn't throw if the JSON field has an unexpected type.
-
_ref
final JsonField<String> _ref()
Returns the raw JSON value of ref.
Unlike ref, this method doesn't throw if the JSON field has an unexpected type.
-
_target
final JsonField<DeploymentCreateParams.Target> _target()
Returns the raw JSON value of target.
Unlike target, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DeploymentCreateParams.Builder toBuilder()
-
_body
final DeploymentCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static DeploymentCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of DeploymentCreateParams.
The following fields are required:
.projectId()
-
-
-
-