Package dev.case.api.models.applications.v1.deployments
See: Description
-
Class Summary Class Description Builder A builder for DeploymentCancelParams. Builder A builder for Body. Body DeploymentCancelParams Cancel a running deployment Builder A builder for DeploymentCreateFromFilesParams. DeploymentCreateFromFilesParams Create a deployment from raw file contents (for Thurgood sandbox deployments) Builder A builder for DeploymentCreateParams. Builder A builder for Body. Body Target Deployment target DeploymentCreateParams Trigger a new deployment for a project Builder A builder for DeploymentGetLogsParams. DeploymentGetLogsParams Get build logs for a specific deployment Builder A builder for DeploymentGetStatusParams. DeploymentGetStatusParams Get the current status of a deployment Builder A builder for DeploymentListParams. Target Filter by deployment target DeploymentListParams List deployments for a project Builder A builder for DeploymentRetrieveParams. DeploymentRetrieveParams Get details of a specific deployment including build logs Builder A builder for DeploymentStreamParams. DeploymentStreamParams Stream real-time deployment progress events via Server-Sent Events