Class ProjectCreateDeploymentParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectCreateDeploymentParams implements Params
Trigger a new deployment for a project.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateDeploymentParams.BuilderA builder for ProjectCreateDeploymentParams.
public final classProjectCreateDeploymentParams.Bodypublic final classProjectCreateDeploymentParams.EnvironmentVariable
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<List<ProjectCreateDeploymentParams.EnvironmentVariable>>environmentVariables()Additional environment variables to set or update before deployment final JsonField<List<ProjectCreateDeploymentParams.EnvironmentVariable>>_environmentVariables()Returns the raw JSON value of environmentVariables. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectCreateDeploymentParams.BuildertoBuilder()final ProjectCreateDeploymentParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateDeploymentParamsnone()final static ProjectCreateDeploymentParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateDeploymentParams. -
-
Method Detail
-
environmentVariables
final Optional<List<ProjectCreateDeploymentParams.EnvironmentVariable>> environmentVariables()
Additional environment variables to set or update before deployment
-
_environmentVariables
final JsonField<List<ProjectCreateDeploymentParams.EnvironmentVariable>> _environmentVariables()
Returns the raw JSON value of environmentVariables.
Unlike environmentVariables, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectCreateDeploymentParams.Builder toBuilder()
-
_body
final ProjectCreateDeploymentParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ProjectCreateDeploymentParams none()
-
builder
final static ProjectCreateDeploymentParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateDeploymentParams.
-
-
-
-