Class ProjectCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectCreateParams implements Params
Create a new web application project
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateParams.BuilderA builder for ProjectCreateParams.
public final classProjectCreateParams.Bodypublic final classProjectCreateParams.EnvironmentVariable
-
Method Summary
Modifier and Type Method Description final StringgitRepo()GitHub repository URL or "owner/repo" final Stringname()Project name final Optional<String>buildCommand()Custom build command final Optional<List<ProjectCreateParams.EnvironmentVariable>>environmentVariables()Environment variables to set on the project final Optional<String>framework()Framework (e.g. final Optional<String>gitBranch()Git branch to deploy final Optional<String>installCommand()Custom install command final Optional<String>outputDirectory()Build output directory final Optional<String>rootDirectory()Root directory of the project final JsonField<String>_gitRepo()Returns the raw JSON value of gitRepo. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_buildCommand()Returns the raw JSON value of buildCommand. final JsonField<List<ProjectCreateParams.EnvironmentVariable>>_environmentVariables()Returns the raw JSON value of environmentVariables. final JsonField<String>_framework()Returns the raw JSON value of framework. final JsonField<String>_gitBranch()Returns the raw JSON value of gitBranch. final JsonField<String>_installCommand()Returns the raw JSON value of installCommand. final JsonField<String>_outputDirectory()Returns the raw JSON value of outputDirectory. final JsonField<String>_rootDirectory()Returns the raw JSON value of rootDirectory. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectCreateParams.BuildertoBuilder()final ProjectCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateParams. -
-
Method Detail
-
buildCommand
final Optional<String> buildCommand()
Custom build command
-
environmentVariables
final Optional<List<ProjectCreateParams.EnvironmentVariable>> environmentVariables()
Environment variables to set on the project
-
installCommand
final Optional<String> installCommand()
Custom install command
-
outputDirectory
final Optional<String> outputDirectory()
Build output directory
-
rootDirectory
final Optional<String> rootDirectory()
Root directory of the project
-
_gitRepo
final JsonField<String> _gitRepo()
Returns the raw JSON value of gitRepo.
Unlike gitRepo, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_buildCommand
final JsonField<String> _buildCommand()
Returns the raw JSON value of buildCommand.
Unlike buildCommand, this method doesn't throw if the JSON field has an unexpected type.
-
_environmentVariables
final JsonField<List<ProjectCreateParams.EnvironmentVariable>> _environmentVariables()
Returns the raw JSON value of environmentVariables.
Unlike environmentVariables, this method doesn't throw if the JSON field has an unexpected type.
-
_framework
final JsonField<String> _framework()
Returns the raw JSON value of framework.
Unlike framework, this method doesn't throw if the JSON field has an unexpected type.
-
_gitBranch
final JsonField<String> _gitBranch()
Returns the raw JSON value of gitBranch.
Unlike gitBranch, this method doesn't throw if the JSON field has an unexpected type.
-
_installCommand
final JsonField<String> _installCommand()
Returns the raw JSON value of installCommand.
Unlike installCommand, this method doesn't throw if the JSON field has an unexpected type.
-
_outputDirectory
final JsonField<String> _outputDirectory()
Returns the raw JSON value of outputDirectory.
Unlike outputDirectory, this method doesn't throw if the JSON field has an unexpected type.
-
_rootDirectory
final JsonField<String> _rootDirectory()
Returns the raw JSON value of rootDirectory.
Unlike rootDirectory, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectCreateParams.Builder toBuilder()
-
_body
final ProjectCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ProjectCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateParams.
The following fields are required:
.gitRepo() .name()
-
-
-
-