Class ProjectListDeploymentsParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectListDeploymentsParams implements Params
List deployments for a specific project
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListDeploymentsParams.BuilderA builder for ProjectListDeploymentsParams.
public final classProjectListDeploymentsParams.TargetFilter by deployment target
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Double>limit()Maximum number of deployments to return final Optional<String>state()Filter by deployment state final Optional<ProjectListDeploymentsParams.Target>target()Filter by deployment target final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectListDeploymentsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListDeploymentsParamsnone()final static ProjectListDeploymentsParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectListDeploymentsParams. -
-
Method Detail
-
target
final Optional<ProjectListDeploymentsParams.Target> target()
Filter by deployment target
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectListDeploymentsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ProjectListDeploymentsParams none()
-
builder
final static ProjectListDeploymentsParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectListDeploymentsParams.
-
-
-
-