Class ProjectRetrieveParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ProjectRetrieveParams
     implements Params
                        

    Returns project details, domains, and recent deployment information for one application project or deployed Thurgood app. Use this endpoint when you need a single record with hosting metadata for a details view.