Class EnvironmentCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class EnvironmentCreateParams implements Params
Creates a new compute environment for running serverless workloads. Each environment gets its own isolated namespace with a unique domain for hosting applications and APIs. The first environment created becomes the default environment for the organization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentCreateParams.BuilderA builder for EnvironmentCreateParams.
public final classEnvironmentCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Stringname()Environment name (alphanumeric, hyphens, and underscores only) final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EnvironmentCreateParams.BuildertoBuilder()final EnvironmentCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnvironmentCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EnvironmentCreateParams. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EnvironmentCreateParams.Builder toBuilder()
-
_body
final EnvironmentCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EnvironmentCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of EnvironmentCreateParams.
The following fields are required:
.name()
-
-
-
-