Class EnvironmentListResponse.Environment
-
- All Implemented Interfaces:
public final class EnvironmentListResponse.Environment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnvironmentListResponse.Environment.BuilderA builder for Environment.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique environment identifier final Optional<OffsetDateTime>createdAt()Environment creation timestamp final Optional<String>domain()Environment domain final Optional<Boolean>isDefault()Whether this is the default environment final Optional<String>name()Human-readable environment name final Optional<String>slug()URL-safe environment identifier final Optional<String>status()Environment status final Optional<OffsetDateTime>updatedAt()Last update timestamp final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_domain()Returns the raw JSON value of domain. final JsonField<Boolean>_isDefault()Returns the raw JSON value of isDefault. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final EnvironmentListResponse.Environment.BuildertoBuilder()final EnvironmentListResponse.Environmentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnvironmentListResponse.Environment.Builderbuilder()Returns a mutable builder for constructing an instance of Environment. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Environment creation timestamp
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Last update timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_isDefault
final JsonField<Boolean> _isDefault()
Returns the raw JSON value of isDefault.
Unlike isDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnvironmentListResponse.Environment.Builder toBuilder()
-
validate
final EnvironmentListResponse.Environment validate()
-
builder
final static EnvironmentListResponse.Environment.Builder builder()
Returns a mutable builder for constructing an instance of Environment.
-
-
-
-