Class InstanceCreateResponse
-
- All Implemented Interfaces:
public final class InstanceCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceCreateResponse.BuilderA builder for InstanceCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Long>autoShutdownMinutes()final Optional<String>createdAt()final Optional<String>gpu()final Optional<String>instanceType()final Optional<String>message()final Optional<String>name()final Optional<String>pricePerHour()final Optional<String>region()final JsonValue_specs()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = instanceCreateResponse.specs().convert(MyClass.class);final Optional<String>status()final Optional<List<JsonValue>>vaults()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_autoShutdownMinutes()Returns the raw JSON value of autoShutdownMinutes. final JsonField<String>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_gpu()Returns the raw JSON value of gpu. final JsonField<String>_instanceType()Returns the raw JSON value of instanceType. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_pricePerHour()Returns the raw JSON value of pricePerHour. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<List<JsonValue>>_vaults()Returns the raw JSON value of vaults. final Map<String, JsonValue>_additionalProperties()final InstanceCreateResponse.BuildertoBuilder()final InstanceCreateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InstanceCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of InstanceCreateResponse. -
-
Method Detail
-
autoShutdownMinutes
final Optional<Long> autoShutdownMinutes()
-
instanceType
final Optional<String> instanceType()
-
pricePerHour
final Optional<String> pricePerHour()
-
_specs
final JsonValue _specs()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = instanceCreateResponse.specs().convert(MyClass.class);
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_autoShutdownMinutes
final JsonField<Long> _autoShutdownMinutes()
Returns the raw JSON value of autoShutdownMinutes.
Unlike autoShutdownMinutes, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<String> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_gpu
final JsonField<String> _gpu()
Returns the raw JSON value of gpu.
Unlike gpu, this method doesn't throw if the JSON field has an unexpected type.
-
_instanceType
final JsonField<String> _instanceType()
Returns the raw JSON value of instanceType.
Unlike instanceType, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_pricePerHour
final JsonField<String> _pricePerHour()
Returns the raw JSON value of pricePerHour.
Unlike pricePerHour, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_vaults
final JsonField<List<JsonValue>> _vaults()
Returns the raw JSON value of vaults.
Unlike vaults, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InstanceCreateResponse.Builder toBuilder()
-
validate
final InstanceCreateResponse validate()
-
builder
final static InstanceCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of InstanceCreateResponse.
-
-
-
-