Class InstanceDeleteResponse
-
- All Implemented Interfaces:
public final class InstanceDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceDeleteResponse.BuilderA builder for InstanceDeleteResponse.
-
Method Summary
-
-
Method Detail
-
totalRuntimeSeconds
final Optional<Long> totalRuntimeSeconds()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCost
final JsonField<String> _totalCost()
Returns the raw JSON value of totalCost.
Unlike totalCost, this method doesn't throw if the JSON field has an unexpected type.
-
_totalRuntimeSeconds
final JsonField<Long> _totalRuntimeSeconds()
Returns the raw JSON value of totalRuntimeSeconds.
Unlike totalRuntimeSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InstanceDeleteResponse.Builder toBuilder()
-
validate
final InstanceDeleteResponse validate()
-
builder
final static InstanceDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of InstanceDeleteResponse.
-
-
-
-