Class InstanceListResponse.Instance
-
- All Implemented Interfaces:
public final class InstanceListResponse.Instance
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceListResponse.Instance.BuilderA builder for Instance.
public final classInstanceListResponse.Instance.Status
-
Method Summary
-
-
Method Detail
-
autoShutdownMinutes
final Optional<Long> autoShutdownMinutes()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
instanceType
final Optional<String> instanceType()
-
pricePerHour
final Optional<String> pricePerHour()
-
startedAt
final Optional<OffsetDateTime> startedAt()
-
status
final Optional<InstanceListResponse.Instance.Status> status()
-
totalRuntimeSeconds
final Optional<Long> totalRuntimeSeconds()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_autoShutdownMinutes
final JsonField<Long> _autoShutdownMinutes()
Returns the raw JSON value of autoShutdownMinutes.
Unlike autoShutdownMinutes, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_gpu
final JsonField<String> _gpu()
Returns the raw JSON value of gpu.
Unlike gpu, this method doesn't throw if the JSON field has an unexpected type.
-
_instanceType
final JsonField<String> _instanceType()
Returns the raw JSON value of instanceType.
Unlike instanceType, this method doesn't throw if the JSON field has an unexpected type.
-
_ip
final JsonField<String> _ip()
Returns the raw JSON value of ip.
Unlike ip, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_pricePerHour
final JsonField<String> _pricePerHour()
Returns the raw JSON value of pricePerHour.
Unlike pricePerHour, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InstanceListResponse.Instance.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCost
final JsonField<String> _totalCost()
Returns the raw JSON value of totalCost.
Unlike totalCost, this method doesn't throw if the JSON field has an unexpected type.
-
_totalRuntimeSeconds
final JsonField<Long> _totalRuntimeSeconds()
Returns the raw JSON value of totalRuntimeSeconds.
Unlike totalRuntimeSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InstanceListResponse.Instance.Builder toBuilder()
-
validate
final InstanceListResponse.Instance validate()
-
builder
final static InstanceListResponse.Instance.Builder builder()
Returns a mutable builder for constructing an instance of Instance.
-
-
-
-