Class InstanceRetrieveResponse
-
- All Implemented Interfaces:
public final class InstanceRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstanceRetrieveResponse.BuilderA builder for InstanceRetrieveResponse.
public final classInstanceRetrieveResponse.Ssh
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Long>autoShutdownMinutes()final Optional<String>createdAt()final Optional<String>currentCost()final Optional<Long>currentRuntimeSeconds()final Optional<String>gpu()final Optional<String>instanceType()final Optional<String>ip()final Optional<String>name()final Optional<String>pricePerHour()final Optional<String>region()final JsonValue_specs()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = instanceRetrieveResponse.specs().convert(MyClass.class);final Optional<InstanceRetrieveResponse.Ssh>ssh()final Optional<String>startedAt()final Optional<String>status()final JsonValue_vaultMounts()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = instanceRetrieveResponse.vaultMounts().convert(MyClass.class);final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_autoShutdownMinutes()Returns the raw JSON value of autoShutdownMinutes. final JsonField<String>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_currentCost()Returns the raw JSON value of currentCost. final JsonField<Long>_currentRuntimeSeconds()Returns the raw JSON value of currentRuntimeSeconds. final JsonField<String>_gpu()Returns the raw JSON value of gpu. final JsonField<String>_instanceType()Returns the raw JSON value of instanceType. final JsonField<String>_ip()Returns the raw JSON value of ip. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_pricePerHour()Returns the raw JSON value of pricePerHour. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<InstanceRetrieveResponse.Ssh>_ssh()Returns the raw JSON value of ssh. final JsonField<String>_startedAt()Returns the raw JSON value of startedAt. final JsonField<String>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final InstanceRetrieveResponse.BuildertoBuilder()final InstanceRetrieveResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InstanceRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of InstanceRetrieveResponse. -
-
Method Detail
-
autoShutdownMinutes
final Optional<Long> autoShutdownMinutes()
-
currentCost
final Optional<String> currentCost()
-
currentRuntimeSeconds
final Optional<Long> currentRuntimeSeconds()
-
instanceType
final Optional<String> instanceType()
-
pricePerHour
final Optional<String> pricePerHour()
-
_specs
final JsonValue _specs()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = instanceRetrieveResponse.specs().convert(MyClass.class);
-
ssh
final Optional<InstanceRetrieveResponse.Ssh> ssh()
-
_vaultMounts
final JsonValue _vaultMounts()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = instanceRetrieveResponse.vaultMounts().convert(MyClass.class);
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_autoShutdownMinutes
final JsonField<Long> _autoShutdownMinutes()
Returns the raw JSON value of autoShutdownMinutes.
Unlike autoShutdownMinutes, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<String> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currentCost
final JsonField<String> _currentCost()
Returns the raw JSON value of currentCost.
Unlike currentCost, this method doesn't throw if the JSON field has an unexpected type.
-
_currentRuntimeSeconds
final JsonField<Long> _currentRuntimeSeconds()
Returns the raw JSON value of currentRuntimeSeconds.
Unlike currentRuntimeSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_gpu
final JsonField<String> _gpu()
Returns the raw JSON value of gpu.
Unlike gpu, this method doesn't throw if the JSON field has an unexpected type.
-
_instanceType
final JsonField<String> _instanceType()
Returns the raw JSON value of instanceType.
Unlike instanceType, this method doesn't throw if the JSON field has an unexpected type.
-
_ip
final JsonField<String> _ip()
Returns the raw JSON value of ip.
Unlike ip, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_pricePerHour
final JsonField<String> _pricePerHour()
Returns the raw JSON value of pricePerHour.
Unlike pricePerHour, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_ssh
final JsonField<InstanceRetrieveResponse.Ssh> _ssh()
Returns the raw JSON value of ssh.
Unlike ssh, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<String> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InstanceRetrieveResponse.Builder toBuilder()
-
validate
final InstanceRetrieveResponse validate()
-
builder
final static InstanceRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of InstanceRetrieveResponse.
-
-
-
-