Class SecretCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SecretCreateParams implements Params
Creates a new secret group in a compute environment. Secret groups organize related secrets for use in serverless functions and workflows. If no environment is specified, the group is created in the default environment.
Features:
Organize secrets by logical groups (e.g., database, APIs, third-party services)
Environment-based isolation
Validation of group names
Conflict detection for existing groups
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretCreateParams.BuilderA builder for SecretCreateParams.
public final classSecretCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Stringname()Unique name for the secret group. final Optional<String>description()Optional description of the secret group's purpose final Optional<String>env()Environment name where the secret group will be created. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_env()Returns the raw JSON value of env. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SecretCreateParams.BuildertoBuilder()final SecretCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SecretCreateParams. -
-
Method Detail
-
name
final String name()
Unique name for the secret group. Must contain only letters, numbers, hyphens, and underscores.
-
description
final Optional<String> description()
Optional description of the secret group's purpose
-
env
final Optional<String> env()
Environment name where the secret group will be created. Uses default environment if not specified.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_env
final JsonField<String> _env()
Returns the raw JSON value of env.
Unlike env, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SecretCreateParams.Builder toBuilder()
-
_body
final SecretCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SecretCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of SecretCreateParams.
The following fields are required:
.name()
-
-
-
-