Class SecretCreateParams.Body
-
- All Implemented Interfaces:
public final class SecretCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()Unique name for the secret group. final Optional<String>description()Optional description of the secret group's purpose final Optional<String>env()Environment name where the secret group will be created. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_env()Returns the raw JSON value of env. final Map<String, JsonValue>_additionalProperties()final SecretCreateParams.Body.BuildertoBuilder()final SecretCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
name
final String name()
Unique name for the secret group. Must contain only letters, numbers, hyphens, and underscores.
-
description
final Optional<String> description()
Optional description of the secret group's purpose
-
env
final Optional<String> env()
Environment name where the secret group will be created. Uses default environment if not specified.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_env
final JsonField<String> _env()
Returns the raw JSON value of env.
Unlike env, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretCreateParams.Body.Builder toBuilder()
-
validate
final SecretCreateParams.Body validate()
-
builder
final static SecretCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-