Class SecretDeleteGroupParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SecretDeleteGroupParams implements Params
Delete an entire secret group or a specific key within a secret group. When deleting a specific key, the remaining secrets in the group are preserved. When deleting the entire group, all secrets and the group itself are removed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretDeleteGroupParams.BuilderA builder for SecretDeleteGroupParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>group()final Optional<String>env()Environment name. final Optional<String>key()Specific key to delete within the group. final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SecretDeleteGroupParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretDeleteGroupParamsnone()final static SecretDeleteGroupParams.Builderbuilder()Returns a mutable builder for constructing an instance of SecretDeleteGroupParams. -
-
Method Detail
-
key
final Optional<String> key()
Specific key to delete within the group. If not provided, the entire group is deleted
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SecretDeleteGroupParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SecretDeleteGroupParams none()
-
builder
final static SecretDeleteGroupParams.Builder builder()
Returns a mutable builder for constructing an instance of SecretDeleteGroupParams.
-
-
-
-