Class SecretListResponse.Group
-
- All Implemented Interfaces:
public final class SecretListResponse.Group
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretListResponse.Group.BuilderA builder for Group.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique identifier for the secret group final Optional<OffsetDateTime>createdAt()When the secret group was created final Optional<String>description()Description of the secret group final Optional<String>name()Name of the secret group final Optional<OffsetDateTime>updatedAt()When the secret group was last updated final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final SecretListResponse.Group.BuildertoBuilder()final SecretListResponse.Groupvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretListResponse.Group.Builderbuilder()Returns a mutable builder for constructing an instance of Group. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
When the secret group was created
-
description
final Optional<String> description()
Description of the secret group
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
When the secret group was last updated
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretListResponse.Group.Builder toBuilder()
-
validate
final SecretListResponse.Group validate()
-
builder
final static SecretListResponse.Group.Builder builder()
Returns a mutable builder for constructing an instance of Group.
-
-
-
-