Class SecretRetrieveGroupResponse.Key
-
- All Implemented Interfaces:
public final class SecretRetrieveGroupResponse.Key
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretRetrieveGroupResponse.Key.BuilderA builder for Key.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>createdAt()When the secret was created final Optional<String>key()Name of the secret key final Optional<OffsetDateTime>updatedAt()When the secret was last updated final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_key()Returns the raw JSON value of key. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final SecretRetrieveGroupResponse.Key.BuildertoBuilder()final SecretRetrieveGroupResponse.Keyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretRetrieveGroupResponse.Key.Builderbuilder()Returns a mutable builder for constructing an instance of Key. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
When the secret was created
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
When the secret was last updated
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_key
final JsonField<String> _key()
Returns the raw JSON value of key.
Unlike key, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretRetrieveGroupResponse.Key.Builder toBuilder()
-
validate
final SecretRetrieveGroupResponse.Key validate()
-
builder
final static SecretRetrieveGroupResponse.Key.Builder builder()
Returns a mutable builder for constructing an instance of Key.
-
-
-
-