Class SecretUpdateGroupParams.Body
-
- All Implemented Interfaces:
public final class SecretUpdateGroupParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSecretUpdateGroupParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final SecretUpdateGroupParams.Secretssecrets()Key-value pairs of secrets to set final Optional<String>env()Environment name (optional, uses default if not specified) final JsonField<SecretUpdateGroupParams.Secrets>_secrets()Returns the raw JSON value of secrets. final JsonField<String>_env()Returns the raw JSON value of env. final Map<String, JsonValue>_additionalProperties()final SecretUpdateGroupParams.Body.BuildertoBuilder()final SecretUpdateGroupParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SecretUpdateGroupParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
secrets
final SecretUpdateGroupParams.Secrets secrets()
Key-value pairs of secrets to set
-
_secrets
final JsonField<SecretUpdateGroupParams.Secrets> _secrets()
Returns the raw JSON value of secrets.
Unlike secrets, this method doesn't throw if the JSON field has an unexpected type.
-
_env
final JsonField<String> _env()
Returns the raw JSON value of env.
Unlike env, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SecretUpdateGroupParams.Body.Builder toBuilder()
-
validate
final SecretUpdateGroupParams.Body validate()
-
builder
final static SecretUpdateGroupParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.secrets()
-
-
-
-