Package dev.case.api.models.database.v1
Class V1GetUsageParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1GetUsageParams implements Params
Returns detailed database usage statistics and billing information for the current billing period. Includes compute hours, storage, data transfer, and branch counts with associated costs broken down by project.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageParams.BuilderA builder for V1GetUsageParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1GetUsageParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageParamsnone()final static V1GetUsageParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1GetUsageParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1GetUsageParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static V1GetUsageParams none()
-
builder
final static V1GetUsageParams.Builder builder()
Returns a mutable builder for constructing an instance of V1GetUsageParams.
-
-
-
-