Package dev.case.api.models.database.v1
Class V1GetUsageResponse.Period
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Period
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.Period.BuilderA builder for Period.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>end()End of the billing period final Optional<OffsetDateTime>start()Start of the billing period final JsonField<OffsetDateTime>_end()Returns the raw JSON value of end. final JsonField<OffsetDateTime>_start()Returns the raw JSON value of start. final Map<String, JsonValue>_additionalProperties()final V1GetUsageResponse.Period.BuildertoBuilder()final V1GetUsageResponse.Periodvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageResponse.Period.Builderbuilder()Returns a mutable builder for constructing an instance of Period. -
-
Method Detail
-
end
final Optional<OffsetDateTime> end()
End of the billing period
-
start
final Optional<OffsetDateTime> start()
Start of the billing period
-
_end
final JsonField<OffsetDateTime> _end()
Returns the raw JSON value of end.
Unlike end, this method doesn't throw if the JSON field has an unexpected type.
-
_start
final JsonField<OffsetDateTime> _start()
Returns the raw JSON value of start.
Unlike start, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Period.Builder toBuilder()
-
validate
final V1GetUsageResponse.Period validate()
-
builder
final static V1GetUsageResponse.Period.Builder builder()
Returns a mutable builder for constructing an instance of Period.
-
-
-
-