Class V1GetUsageResponse.Project
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Project
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.Project.BuilderA builder for Project.
public final classV1GetUsageResponse.Project.Costs
-
Method Summary
-
-
Method Detail
-
branchCount
final Optional<Long> branchCount()
-
computeCuHours
final Optional<Double> computeCuHours()
-
costs
final Optional<V1GetUsageResponse.Project.Costs> costs()
-
lastUpdated
final Optional<OffsetDateTime> lastUpdated()
-
projectName
final Optional<String> projectName()
-
storageGbMonths
final Optional<Double> storageGbMonths()
-
transferGb
final Optional<Double> transferGb()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_branchCount
final JsonField<Long> _branchCount()
Returns the raw JSON value of branchCount.
Unlike branchCount, this method doesn't throw if the JSON field has an unexpected type.
-
_computeCuHours
final JsonField<Double> _computeCuHours()
Returns the raw JSON value of computeCuHours.
Unlike computeCuHours, this method doesn't throw if the JSON field has an unexpected type.
-
_costs
final JsonField<V1GetUsageResponse.Project.Costs> _costs()
Returns the raw JSON value of costs.
Unlike costs, this method doesn't throw if the JSON field has an unexpected type.
-
_lastUpdated
final JsonField<OffsetDateTime> _lastUpdated()
Returns the raw JSON value of lastUpdated.
Unlike lastUpdated, this method doesn't throw if the JSON field has an unexpected type.
-
_projectId
final JsonField<String> _projectId()
Returns the raw JSON value of projectId.
Unlike projectId, this method doesn't throw if the JSON field has an unexpected type.
-
_projectName
final JsonField<String> _projectName()
Returns the raw JSON value of projectName.
Unlike projectName, this method doesn't throw if the JSON field has an unexpected type.
-
_storageGbMonths
final JsonField<Double> _storageGbMonths()
Returns the raw JSON value of storageGbMonths.
Unlike storageGbMonths, this method doesn't throw if the JSON field has an unexpected type.
-
_transferGb
final JsonField<Double> _transferGb()
Returns the raw JSON value of transferGb.
Unlike transferGb, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Project.Builder toBuilder()
-
validate
final V1GetUsageResponse.Project validate()
-
builder
final static V1GetUsageResponse.Project.Builder builder()
Returns a mutable builder for constructing an instance of Project.
-
-
-
-