Package dev.case.api.models.database.v1
Class V1GetUsageResponse.Project.Costs
-
- All Implemented Interfaces:
public final class V1GetUsageResponse.Project.Costs
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1GetUsageResponse.Project.Costs.BuilderA builder for Costs.
-
Method Summary
Modifier and Type Method Description final Optional<String>branches()final Optional<String>compute()final Optional<String>storage()final Optional<String>total()final Optional<String>transfer()final JsonField<String>_branches()Returns the raw JSON value of branches. final JsonField<String>_compute()Returns the raw JSON value of compute. final JsonField<String>_storage()Returns the raw JSON value of storage. final JsonField<String>_total()Returns the raw JSON value of total. final JsonField<String>_transfer()Returns the raw JSON value of transfer. final Map<String, JsonValue>_additionalProperties()final V1GetUsageResponse.Project.Costs.BuildertoBuilder()final V1GetUsageResponse.Project.Costsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1GetUsageResponse.Project.Costs.Builderbuilder()Returns a mutable builder for constructing an instance of Costs. -
-
Method Detail
-
_branches
final JsonField<String> _branches()
Returns the raw JSON value of branches.
Unlike branches, this method doesn't throw if the JSON field has an unexpected type.
-
_compute
final JsonField<String> _compute()
Returns the raw JSON value of compute.
Unlike compute, this method doesn't throw if the JSON field has an unexpected type.
-
_storage
final JsonField<String> _storage()
Returns the raw JSON value of storage.
Unlike storage, this method doesn't throw if the JSON field has an unexpected type.
-
_total
final JsonField<String> _total()
Returns the raw JSON value of total.
Unlike total, this method doesn't throw if the JSON field has an unexpected type.
-
_transfer
final JsonField<String> _transfer()
Returns the raw JSON value of transfer.
Unlike transfer, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1GetUsageResponse.Project.Costs.Builder toBuilder()
-
validate
final V1GetUsageResponse.Project.Costs validate()
-
builder
final static V1GetUsageResponse.Project.Costs.Builder builder()
Returns a mutable builder for constructing an instance of Costs.
-
-
-
-