Class ProjectCreateParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectCreateParams implements Params
Creates a new serverless Postgres database project powered by Neon. Includes automatic scaling, connection pooling, and a default 'main' branch with 'neondb' database. Supports branching for isolated dev/staging environments. Perfect for case management applications, document workflows, and litigation support systems.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateParams.BuilderA builder for ProjectCreateParams.
public final classProjectCreateParams.Bodypublic final classProjectCreateParams.RegionAWS region for database deployment
-
Method Summary
Modifier and Type Method Description final Stringname()Project name (letters, numbers, hyphens, underscores only) final Optional<String>description()Optional project description final Optional<ProjectCreateParams.Region>region()AWS region for database deployment final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<ProjectCreateParams.Region>_region()Returns the raw JSON value of region. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectCreateParams.BuildertoBuilder()final ProjectCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectCreateParams. -
-
Method Detail
-
description
final Optional<String> description()
Optional project description
-
region
final Optional<ProjectCreateParams.Region> region()
AWS region for database deployment
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<ProjectCreateParams.Region> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectCreateParams.Builder toBuilder()
-
_body
final ProjectCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ProjectCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectCreateParams.
The following fields are required:
.name()
-
-
-
-