Class ProjectListBranchesParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectListBranchesParams implements Params
Retrieves all branches for a database project. Branches enable isolated development and testing environments with instant point-in-time cloning. Each branch includes the default branch and any custom branches created for staging, testing, or feature development.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListBranchesParams.BuilderA builder for ProjectListBranchesParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectListBranchesParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListBranchesParamsnone()final static ProjectListBranchesParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectListBranchesParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectListBranchesParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ProjectListBranchesParams none()
-
builder
final static ProjectListBranchesParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectListBranchesParams.
-
-
-
-