Class ProjectListBranchesResponse
-
- All Implemented Interfaces:
public final class ProjectListBranchesResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListBranchesResponse.BuilderA builder for ProjectListBranchesResponse.
public final classProjectListBranchesResponse.Branch
-
Method Summary
Modifier and Type Method Description final List<ProjectListBranchesResponse.Branch>branches()final JsonField<List<ProjectListBranchesResponse.Branch>>_branches()Returns the raw JSON value of branches. final Map<String, JsonValue>_additionalProperties()final ProjectListBranchesResponse.BuildertoBuilder()final ProjectListBranchesResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListBranchesResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectListBranchesResponse. -
-
Method Detail
-
branches
final List<ProjectListBranchesResponse.Branch> branches()
-
_branches
final JsonField<List<ProjectListBranchesResponse.Branch>> _branches()
Returns the raw JSON value of branches.
Unlike branches, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListBranchesResponse.Builder toBuilder()
-
validate
final ProjectListBranchesResponse validate()
-
builder
final static ProjectListBranchesResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProjectListBranchesResponse.
The following fields are required:
.branches()
-
-
-
-