Class ProjectListBranchesResponse.Branch
-
- All Implemented Interfaces:
public final class ProjectListBranchesResponse.Branch
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListBranchesResponse.Branch.BuilderA builder for Branch.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Branch ID final Optional<OffsetDateTime>createdAt()Branch creation timestamp final Optional<Boolean>isDefault()Whether this is the default branch final Optional<String>name()Branch name final Optional<String>parentBranchId()Parent branch ID (null for default branch) final Optional<String>status()Branch status final Optional<OffsetDateTime>updatedAt()Branch last update timestamp final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Boolean>_isDefault()Returns the raw JSON value of isDefault. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_parentBranchId()Returns the raw JSON value of parentBranchId. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final ProjectListBranchesResponse.Branch.BuildertoBuilder()final ProjectListBranchesResponse.Branchvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListBranchesResponse.Branch.Builderbuilder()Returns a mutable builder for constructing an instance of Branch. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Branch creation timestamp
-
parentBranchId
final Optional<String> parentBranchId()
Parent branch ID (null for default branch)
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Branch last update timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_isDefault
final JsonField<Boolean> _isDefault()
Returns the raw JSON value of isDefault.
Unlike isDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_parentBranchId
final JsonField<String> _parentBranchId()
Returns the raw JSON value of parentBranchId.
Unlike parentBranchId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListBranchesResponse.Branch.Builder toBuilder()
-
validate
final ProjectListBranchesResponse.Branch validate()
-
builder
final static ProjectListBranchesResponse.Branch.Builder builder()
Returns a mutable builder for constructing an instance of Branch.
-
-
-
-