Class ProjectListParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ProjectListParams implements Params
Retrieves all serverless Postgres database projects for the authenticated organization. Includes storage and compute metrics, plus linked deployments from Thurgood apps and Compute instances.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListParams.BuilderA builder for ProjectListParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProjectListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListParamsnone()final static ProjectListParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectListParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProjectListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ProjectListParams none()
-
builder
final static ProjectListParams.Builder builder()
Returns a mutable builder for constructing an instance of ProjectListParams.
-
-
-
-