Class ProjectListResponse
-
- All Implemented Interfaces:
public final class ProjectListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListResponse.BuilderA builder for ProjectListResponse.
public final classProjectListResponse.Project
-
Method Summary
Modifier and Type Method Description final List<ProjectListResponse.Project>projects()final JsonField<List<ProjectListResponse.Project>>_projects()Returns the raw JSON value of projects. final Map<String, JsonValue>_additionalProperties()final ProjectListResponse.BuildertoBuilder()final ProjectListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProjectListResponse. -
-
Method Detail
-
projects
final List<ProjectListResponse.Project> projects()
-
_projects
final JsonField<List<ProjectListResponse.Project>> _projects()
Returns the raw JSON value of projects.
Unlike projects, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListResponse.Builder toBuilder()
-
validate
final ProjectListResponse validate()
-
builder
final static ProjectListResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProjectListResponse.
The following fields are required:
.projects()
-
-
-
-