Class ProjectListResponse.Project
-
- All Implemented Interfaces:
public final class ProjectListResponse.Project
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListResponse.Project.BuilderA builder for Project.
public final classProjectListResponse.Project.LinkedDeploymentpublic final classProjectListResponse.Project.StatusCurrent project status
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Project ID final Optional<Double>computeTimeSeconds()Total compute time consumed in seconds final Optional<OffsetDateTime>createdAt()Project creation timestamp final Optional<String>description()Project description final Optional<List<ProjectListResponse.Project.LinkedDeployment>>linkedDeployments()Linked application deployments using this database final Optional<String>name()Project name final Optional<Long>pgVersion()PostgreSQL major version final Optional<String>region()AWS region where database is deployed final Optional<ProjectListResponse.Project.Status>status()Current project status final Optional<Double>storageSizeBytes()Current storage usage in bytes final Optional<OffsetDateTime>updatedAt()Project last update timestamp final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Double>_computeTimeSeconds()Returns the raw JSON value of computeTimeSeconds. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<ProjectListResponse.Project.LinkedDeployment>>_linkedDeployments()Returns the raw JSON value of linkedDeployments. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_pgVersion()Returns the raw JSON value of pgVersion. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<ProjectListResponse.Project.Status>_status()Returns the raw JSON value of status. final JsonField<Double>_storageSizeBytes()Returns the raw JSON value of storageSizeBytes. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final ProjectListResponse.Project.BuildertoBuilder()final ProjectListResponse.Projectvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListResponse.Project.Builderbuilder()Returns a mutable builder for constructing an instance of Project. -
-
Method Detail
-
computeTimeSeconds
final Optional<Double> computeTimeSeconds()
Total compute time consumed in seconds
-
createdAt
final Optional<OffsetDateTime> createdAt()
Project creation timestamp
-
description
final Optional<String> description()
Project description
-
linkedDeployments
final Optional<List<ProjectListResponse.Project.LinkedDeployment>> linkedDeployments()
Linked application deployments using this database
-
status
final Optional<ProjectListResponse.Project.Status> status()
Current project status
-
storageSizeBytes
final Optional<Double> storageSizeBytes()
Current storage usage in bytes
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Project last update timestamp
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_computeTimeSeconds
final JsonField<Double> _computeTimeSeconds()
Returns the raw JSON value of computeTimeSeconds.
Unlike computeTimeSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_linkedDeployments
final JsonField<List<ProjectListResponse.Project.LinkedDeployment>> _linkedDeployments()
Returns the raw JSON value of linkedDeployments.
Unlike linkedDeployments, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_pgVersion
final JsonField<Long> _pgVersion()
Returns the raw JSON value of pgVersion.
Unlike pgVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ProjectListResponse.Project.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_storageSizeBytes
final JsonField<Double> _storageSizeBytes()
Returns the raw JSON value of storageSizeBytes.
Unlike storageSizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListResponse.Project.Builder toBuilder()
-
validate
final ProjectListResponse.Project validate()
-
builder
final static ProjectListResponse.Project.Builder builder()
Returns a mutable builder for constructing an instance of Project.
-
-
-
-