Class ProjectRetrieveResponse.LinkedDeployment
-
- All Implemented Interfaces:
public final class ProjectRetrieveResponse.LinkedDeployment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectRetrieveResponse.LinkedDeployment.BuilderA builder for LinkedDeployment.
public final classProjectRetrieveResponse.LinkedDeployment.TypeDeployment type
-
Method Summary
-
-
Method Detail
-
envVarName
final Optional<String> envVarName()
Environment variable name for connection string
-
type
final Optional<ProjectRetrieveResponse.LinkedDeployment.Type> type()
Deployment type
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_envVarName
final JsonField<String> _envVarName()
Returns the raw JSON value of envVarName.
Unlike envVarName, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ProjectRetrieveResponse.LinkedDeployment.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectRetrieveResponse.LinkedDeployment.Builder toBuilder()
-
validate
final ProjectRetrieveResponse.LinkedDeployment validate()
-
builder
final static ProjectRetrieveResponse.LinkedDeployment.Builder builder()
Returns a mutable builder for constructing an instance of LinkedDeployment.
-
-
-
-