Package dev.case.api.models.format.v1
Class V1CreateDocumentParams.Options
-
- All Implemented Interfaces:
public final class V1CreateDocumentParams.OptionsOptional template composition and styling settings used during document generation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateDocumentParams.Options.BuilderA builder for Options.
public final classV1CreateDocumentParams.Options.Component
-
Method Summary
Modifier and Type Method Description final Optional<List<V1CreateDocumentParams.Options.Component>>components()Template components with variables final JsonField<List<V1CreateDocumentParams.Options.Component>>_components()Returns the raw JSON value of components. final Map<String, JsonValue>_additionalProperties()final V1CreateDocumentParams.Options.BuildertoBuilder()final V1CreateDocumentParams.Optionsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateDocumentParams.Options.Builderbuilder()Returns a mutable builder for constructing an instance of Options. -
-
Method Detail
-
components
final Optional<List<V1CreateDocumentParams.Options.Component>> components()
Template components with variables
-
_components
final JsonField<List<V1CreateDocumentParams.Options.Component>> _components()
Returns the raw JSON value of components.
Unlike components, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateDocumentParams.Options.Builder toBuilder()
-
validate
final V1CreateDocumentParams.Options validate()
-
builder
final static V1CreateDocumentParams.Options.Builder builder()
Returns a mutable builder for constructing an instance of Options.
-
-
-
-