Package dev.case.api.models.format.v1
Class V1CreateDocumentParams.Options.Component
-
- All Implemented Interfaces:
public final class V1CreateDocumentParams.Options.Component
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateDocumentParams.Options.Component.BuilderA builder for Component.
-
Method Summary
Modifier and Type Method Description final Optional<String>content()Inline template content final JsonValue_styles()Custom styling optionsThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = component.styles().convert(MyClass.class);final Optional<String>templateId()ID of saved template component final JsonValue_variables()Variables for template interpolationThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = component.variables().convert(MyClass.class);final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_templateId()Returns the raw JSON value of templateId. final Map<String, JsonValue>_additionalProperties()final V1CreateDocumentParams.Options.Component.BuildertoBuilder()final V1CreateDocumentParams.Options.Componentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateDocumentParams.Options.Component.Builderbuilder()Returns a mutable builder for constructing an instance of Component. -
-
Method Detail
-
_styles
final JsonValue _styles()
Custom styling options
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = component.styles().convert(MyClass.class);
-
templateId
final Optional<String> templateId()
ID of saved template component
-
_variables
final JsonValue _variables()
Variables for template interpolation
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = component.variables().convert(MyClass.class);
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_templateId
final JsonField<String> _templateId()
Returns the raw JSON value of templateId.
Unlike templateId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateDocumentParams.Options.Component.Builder toBuilder()
-
validate
final V1CreateDocumentParams.Options.Component validate()
-
builder
final static V1CreateDocumentParams.Options.Component.Builder builder()
Returns a mutable builder for constructing an instance of Component.
-
-
-
-