Class LlmGetConfigParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class LlmGetConfigParams implements Params
Retrieves the AI Gateway configuration including all available language models and their specifications. This endpoint returns model information compatible with the Vercel AI SDK Gateway format, making it easy to integrate with existing AI applications.
Use this endpoint to:
Discover available language models
Get model specifications and pricing
Configure AI SDK clients
Build model selection interfaces
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLlmGetConfigParams.BuilderA builder for LlmGetConfigParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LlmGetConfigParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LlmGetConfigParamsnone()final static LlmGetConfigParams.Builderbuilder()Returns a mutable builder for constructing an instance of LlmGetConfigParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LlmGetConfigParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LlmGetConfigParams none()
-
builder
final static LlmGetConfigParams.Builder builder()
Returns a mutable builder for constructing an instance of LlmGetConfigParams.
-
-
-
-