Class V1CreateEmbeddingParams.Body
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateEmbeddingParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final V1CreateEmbeddingParams.Inputinput()Text or array of texts to create embeddings for final Stringmodel()Embedding model to use (e.g. final Optional<Long>dimensions()Number of dimensions for the embeddings (model-specific) final Optional<V1CreateEmbeddingParams.EncodingFormat>encodingFormat()Format for returned embeddings final Optional<String>user()Unique identifier for the end-user final JsonField<V1CreateEmbeddingParams.Input>_input()Returns the raw JSON value of input. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<Long>_dimensions()Returns the raw JSON value of dimensions. final JsonField<V1CreateEmbeddingParams.EncodingFormat>_encodingFormat()Returns the raw JSON value of encodingFormat. final JsonField<String>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalProperties()final V1CreateEmbeddingParams.Body.BuildertoBuilder()final V1CreateEmbeddingParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateEmbeddingParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
input
final V1CreateEmbeddingParams.Input input()
Text or array of texts to create embeddings for
-
model
final String model()
Embedding model to use (e.g., text-embedding-ada-002, text-embedding-3-small)
-
dimensions
final Optional<Long> dimensions()
Number of dimensions for the embeddings (model-specific)
-
encodingFormat
final Optional<V1CreateEmbeddingParams.EncodingFormat> encodingFormat()
Format for returned embeddings
-
_input
final JsonField<V1CreateEmbeddingParams.Input> _input()
Returns the raw JSON value of input.
Unlike input, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_dimensions
final JsonField<Long> _dimensions()
Returns the raw JSON value of dimensions.
Unlike dimensions, this method doesn't throw if the JSON field has an unexpected type.
-
_encodingFormat
final JsonField<V1CreateEmbeddingParams.EncodingFormat> _encodingFormat()
Returns the raw JSON value of encodingFormat.
Unlike encodingFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<String> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateEmbeddingParams.Body.Builder toBuilder()
-
validate
final V1CreateEmbeddingParams.Body validate()
-
builder
final static V1CreateEmbeddingParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.input() .model()
-
-
-
-