Package dev.case.api.models.llm.v1
Class V1CreateEmbeddingResponse
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateEmbeddingResponse.BuilderA builder for V1CreateEmbeddingResponse.
public final classV1CreateEmbeddingResponse.Datapublic final classV1CreateEmbeddingResponse.Usage
-
Method Summary
Modifier and Type Method Description final Optional<List<V1CreateEmbeddingResponse.Data>>data()final Optional<String>model()final Optional<String>object_()final Optional<V1CreateEmbeddingResponse.Usage>usage()final JsonField<List<V1CreateEmbeddingResponse.Data>>_data()Returns the raw JSON value of data. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_object_()Returns the raw JSON value of object_. final JsonField<V1CreateEmbeddingResponse.Usage>_usage()Returns the raw JSON value of usage. final Map<String, JsonValue>_additionalProperties()final V1CreateEmbeddingResponse.BuildertoBuilder()final V1CreateEmbeddingResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateEmbeddingResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1CreateEmbeddingResponse. -
-
Method Detail
-
data
final Optional<List<V1CreateEmbeddingResponse.Data>> data()
-
usage
final Optional<V1CreateEmbeddingResponse.Usage> usage()
-
_data
final JsonField<List<V1CreateEmbeddingResponse.Data>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_object_
final JsonField<String> _object_()
Returns the raw JSON value of object_.
Unlike object_, this method doesn't throw if the JSON field has an unexpected type.
-
_usage
final JsonField<V1CreateEmbeddingResponse.Usage> _usage()
Returns the raw JSON value of usage.
Unlike usage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateEmbeddingResponse.Builder toBuilder()
-
validate
final V1CreateEmbeddingResponse validate()
-
builder
final static V1CreateEmbeddingResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1CreateEmbeddingResponse.
-
-
-
-