Package dev.case.api.models.llm.v1
Class V1CreateEmbeddingResponse.Data
-
- All Implemented Interfaces:
public final class V1CreateEmbeddingResponse.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateEmbeddingResponse.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Optional<List<Double>>embedding()final Optional<Long>index()final Optional<String>object_()final JsonField<List<Double>>_embedding()Returns the raw JSON value of embedding. final JsonField<Long>_index()Returns the raw JSON value of index. final JsonField<String>_object_()Returns the raw JSON value of object_. final Map<String, JsonValue>_additionalProperties()final V1CreateEmbeddingResponse.Data.BuildertoBuilder()final V1CreateEmbeddingResponse.Datavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateEmbeddingResponse.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
_embedding
final JsonField<List<Double>> _embedding()
Returns the raw JSON value of embedding.
Unlike embedding, this method doesn't throw if the JSON field has an unexpected type.
-
_index
final JsonField<Long> _index()
Returns the raw JSON value of index.
Unlike index, this method doesn't throw if the JSON field has an unexpected type.
-
_object_
final JsonField<String> _object_()
Returns the raw JSON value of object_.
Unlike object_, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateEmbeddingResponse.Data.Builder toBuilder()
-
validate
final V1CreateEmbeddingResponse.Data validate()
-
builder
final static V1CreateEmbeddingResponse.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-