Package dev.case.api.models.llm.v1
Class V1ListModelsParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1ListModelsParams implements Params
Retrieve a list of all available language models from 40+ providers including OpenAI, Anthropic, Google, and Case.dev's specialized legal models. Returns OpenAI-compatible model metadata with pricing information.
This endpoint is compatible with OpenAI's models API format, making it easy to integrate with existing applications.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListModelsParams.BuilderA builder for V1ListModelsParams.
-
Method Summary
Modifier and Type Method Description final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1ListModelsParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListModelsParamsnone()final static V1ListModelsParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1ListModelsParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1ListModelsParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static V1ListModelsParams none()
-
builder
final static V1ListModelsParams.Builder builder()
Returns a mutable builder for constructing an instance of V1ListModelsParams.
-
-
-
-