Package dev.case.api.models.llm.v1
Class V1ListModelsResponse.Data
-
- All Implemented Interfaces:
public final class V1ListModelsResponse.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListModelsResponse.Data.BuilderA builder for Data.
public final classV1ListModelsResponse.Data.Pricing
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique model identifier final Optional<Long>created()Unix timestamp of model creation final Optional<String>object_()Object type, always 'model' final Optional<String>ownedBy()Model provider (openai, anthropic, google, casemark, etc. final Optional<V1ListModelsResponse.Data.Pricing>pricing()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_created()Returns the raw JSON value of created. final JsonField<String>_object_()Returns the raw JSON value of object_. final JsonField<String>_ownedBy()Returns the raw JSON value of ownedBy. final JsonField<V1ListModelsResponse.Data.Pricing>_pricing()Returns the raw JSON value of pricing. final Map<String, JsonValue>_additionalProperties()final V1ListModelsResponse.Data.BuildertoBuilder()final V1ListModelsResponse.Datavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListModelsResponse.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
pricing
final Optional<V1ListModelsResponse.Data.Pricing> pricing()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<Long> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_object_
final JsonField<String> _object_()
Returns the raw JSON value of object_.
Unlike object_, this method doesn't throw if the JSON field has an unexpected type.
-
_ownedBy
final JsonField<String> _ownedBy()
Returns the raw JSON value of ownedBy.
Unlike ownedBy, this method doesn't throw if the JSON field has an unexpected type.
-
_pricing
final JsonField<V1ListModelsResponse.Data.Pricing> _pricing()
Returns the raw JSON value of pricing.
Unlike pricing, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ListModelsResponse.Data.Builder toBuilder()
-
validate
final V1ListModelsResponse.Data validate()
-
builder
final static V1ListModelsResponse.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-