Package dev.case.api.models.llm.v1
Class V1ListModelsResponse.Data.Pricing
-
- All Implemented Interfaces:
public final class V1ListModelsResponse.Data.Pricing
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ListModelsResponse.Data.Pricing.BuilderA builder for Pricing.
-
Method Summary
Modifier and Type Method Description final Optional<String>input()Input token price per token final Optional<String>inputCacheRead()Cache read price per token (if supported) final Optional<String>output()Output token price per token final JsonField<String>_input()Returns the raw JSON value of input. final JsonField<String>_inputCacheRead()Returns the raw JSON value of inputCacheRead. final JsonField<String>_output()Returns the raw JSON value of output. final Map<String, JsonValue>_additionalProperties()final V1ListModelsResponse.Data.Pricing.BuildertoBuilder()final V1ListModelsResponse.Data.Pricingvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ListModelsResponse.Data.Pricing.Builderbuilder()Returns a mutable builder for constructing an instance of Pricing. -
-
Method Detail
-
inputCacheRead
final Optional<String> inputCacheRead()
Cache read price per token (if supported)
-
_input
final JsonField<String> _input()
Returns the raw JSON value of input.
Unlike input, this method doesn't throw if the JSON field has an unexpected type.
-
_inputCacheRead
final JsonField<String> _inputCacheRead()
Returns the raw JSON value of inputCacheRead.
Unlike inputCacheRead, this method doesn't throw if the JSON field has an unexpected type.
-
_output
final JsonField<String> _output()
Returns the raw JSON value of output.
Unlike output, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ListModelsResponse.Data.Pricing.Builder toBuilder()
-
validate
final V1ListModelsResponse.Data.Pricing validate()
-
builder
final static V1ListModelsResponse.Data.Pricing.Builder builder()
Returns a mutable builder for constructing an instance of Pricing.
-
-
-
-