Class ChatCreateCompletionResponse
-
- All Implemented Interfaces:
public final class ChatCreateCompletionResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateCompletionResponse.BuilderA builder for ChatCreateCompletionResponse.
public final classChatCreateCompletionResponse.Choicepublic final classChatCreateCompletionResponse.Usage
-
Method Summary
-
-
Method Detail
-
choices
final Optional<List<ChatCreateCompletionResponse.Choice>> choices()
-
usage
final Optional<ChatCreateCompletionResponse.Usage> usage()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_choices
final JsonField<List<ChatCreateCompletionResponse.Choice>> _choices()
Returns the raw JSON value of choices.
Unlike choices, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<Long> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_object_
final JsonField<String> _object_()
Returns the raw JSON value of object_.
Unlike object_, this method doesn't throw if the JSON field has an unexpected type.
-
_usage
final JsonField<ChatCreateCompletionResponse.Usage> _usage()
Returns the raw JSON value of usage.
Unlike usage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateCompletionResponse.Builder toBuilder()
-
validate
final ChatCreateCompletionResponse validate()
-
builder
final static ChatCreateCompletionResponse.Builder builder()
Returns a mutable builder for constructing an instance of ChatCreateCompletionResponse.
-
-
-
-