Package dev.case.api.models.llm.v1.chat
Class ChatCreateCompletionResponse.Choice
-
- All Implemented Interfaces:
public final class ChatCreateCompletionResponse.Choice
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatCreateCompletionResponse.Choice.BuilderA builder for Choice.
public final classChatCreateCompletionResponse.Choice.Message
-
Method Summary
Modifier and Type Method Description final Optional<String>finishReason()final Optional<Long>index()final Optional<ChatCreateCompletionResponse.Choice.Message>message()final JsonField<String>_finishReason()Returns the raw JSON value of finishReason. final JsonField<Long>_index()Returns the raw JSON value of index. final JsonField<ChatCreateCompletionResponse.Choice.Message>_message()Returns the raw JSON value of message. final Map<String, JsonValue>_additionalProperties()final ChatCreateCompletionResponse.Choice.BuildertoBuilder()final ChatCreateCompletionResponse.Choicevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatCreateCompletionResponse.Choice.Builderbuilder()Returns a mutable builder for constructing an instance of Choice. -
-
Method Detail
-
finishReason
final Optional<String> finishReason()
-
message
final Optional<ChatCreateCompletionResponse.Choice.Message> message()
-
_finishReason
final JsonField<String> _finishReason()
Returns the raw JSON value of finishReason.
Unlike finishReason, this method doesn't throw if the JSON field has an unexpected type.
-
_index
final JsonField<Long> _index()
Returns the raw JSON value of index.
Unlike index, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<ChatCreateCompletionResponse.Choice.Message> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatCreateCompletionResponse.Choice.Builder toBuilder()
-
validate
final ChatCreateCompletionResponse.Choice validate()
-
builder
final static ChatCreateCompletionResponse.Choice.Builder builder()
Returns a mutable builder for constructing an instance of Choice.
-
-
-
-