Class InboxCreateParams.Body
-
- All Implemented Interfaces:
public final class InboxCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>address()final Optional<String>displayName()final JsonField<String>_address()Returns the raw JSON value of address. final JsonField<String>_displayName()Returns the raw JSON value of displayName. final Map<String, JsonValue>_additionalProperties()final InboxCreateParams.Body.BuildertoBuilder()final InboxCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboxCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
displayName
final Optional<String> displayName()
-
_address
final JsonField<String> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboxCreateParams.Body.Builder toBuilder()
-
validate
final InboxCreateParams.Body validate()
-
builder
final static InboxCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-