Class InboxSetPolicyParams.Body
-
- All Implemented Interfaces:
public final class InboxSetPolicyParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxSetPolicyParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>allowedSenderPatterns()Exact emails, @domain rules, or * final Optional<Boolean>enforceSenderAllowlist()final Optional<List<String>>readAccessRules()Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or * final Optional<List<String>>replyAccessRules()Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or * final Optional<List<String>>sendAccessRules()Rules like organization, user:<id>, api_key, api_key:<id>, clerk_session, or * final JsonField<List<String>>_allowedSenderPatterns()Returns the raw JSON value of allowedSenderPatterns. final JsonField<Boolean>_enforceSenderAllowlist()Returns the raw JSON value of enforceSenderAllowlist. final JsonField<List<String>>_readAccessRules()Returns the raw JSON value of readAccessRules. final JsonField<List<String>>_replyAccessRules()Returns the raw JSON value of replyAccessRules. final JsonField<List<String>>_sendAccessRules()Returns the raw JSON value of sendAccessRules. final Map<String, JsonValue>_additionalProperties()final InboxSetPolicyParams.Body.BuildertoBuilder()final InboxSetPolicyParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboxSetPolicyParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
allowedSenderPatterns
final Optional<List<String>> allowedSenderPatterns()
Exact emails, @domain rules, or *
-
enforceSenderAllowlist
final Optional<Boolean> enforceSenderAllowlist()
-
readAccessRules
final Optional<List<String>> readAccessRules()
Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
replyAccessRules
final Optional<List<String>> replyAccessRules()
Rules like organization, operator, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
sendAccessRules
final Optional<List<String>> sendAccessRules()
Rules like organization, user:<id>, api_key, api_key:<id>, clerk_session, or *
-
_allowedSenderPatterns
final JsonField<List<String>> _allowedSenderPatterns()
Returns the raw JSON value of allowedSenderPatterns.
Unlike allowedSenderPatterns, this method doesn't throw if the JSON field has an unexpected type.
-
_enforceSenderAllowlist
final JsonField<Boolean> _enforceSenderAllowlist()
Returns the raw JSON value of enforceSenderAllowlist.
Unlike enforceSenderAllowlist, this method doesn't throw if the JSON field has an unexpected type.
-
_readAccessRules
final JsonField<List<String>> _readAccessRules()
Returns the raw JSON value of readAccessRules.
Unlike readAccessRules, this method doesn't throw if the JSON field has an unexpected type.
-
_replyAccessRules
final JsonField<List<String>> _replyAccessRules()
Returns the raw JSON value of replyAccessRules.
Unlike replyAccessRules, this method doesn't throw if the JSON field has an unexpected type.
-
_sendAccessRules
final JsonField<List<String>> _sendAccessRules()
Returns the raw JSON value of sendAccessRules.
Unlike sendAccessRules, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboxSetPolicyParams.Body.Builder toBuilder()
-
validate
final InboxSetPolicyParams.Body validate()
-
builder
final static InboxSetPolicyParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-