Class LogCreateParams.Body
-
- All Implemented Interfaces:
public final class LogCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLogCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringsummary()final Optional<LogCreateParams.Details>details()final Optional<String>eventType()final Optional<String>workItemId()final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<LogCreateParams.Details>_details()Returns the raw JSON value of details. final JsonField<String>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_workItemId()Returns the raw JSON value of workItemId. final Map<String, JsonValue>_additionalProperties()final LogCreateParams.Body.BuildertoBuilder()final LogCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
details
final Optional<LogCreateParams.Details> details()
-
workItemId
final Optional<String> workItemId()
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_details
final JsonField<LogCreateParams.Details> _details()
Returns the raw JSON value of details.
Unlike details, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_workItemId
final JsonField<String> _workItemId()
Returns the raw JSON value of workItemId.
Unlike workItemId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LogCreateParams.Body.Builder toBuilder()
-
validate
final LogCreateParams.Body validate()
-
builder
final static LogCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.summary()
-
-
-
-