Class LogExportParams.Scope
-
- All Implemented Interfaces:
public final class LogExportParams.ScopeFilter by scope: matter, work_item, execution, sharing, all
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLogExportParams.Scope.VisitorAn interface that defines how to map each variant of Scope to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<List<String>>strings()final BooleanisString()final BooleanisStrings()final StringasString()final List<String>asStrings()final Optional<JsonValue>_json()final <T extends Any> Taccept(LogExportParams.Scope.Visitor<T> visitor)final LogExportParams.Scopevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LogExportParams.ScopeofString(String string)final static LogExportParams.ScopeofStrings(List<String> strings)-
-
Method Detail
-
accept
final <T extends Any> T accept(LogExportParams.Scope.Visitor<T> visitor)
-
validate
final LogExportParams.Scope validate()
-
ofString
final static LogExportParams.Scope ofString(String string)
-
ofStrings
final static LogExportParams.Scope ofStrings(List<String> strings)
-
-
-
-