Class WorkItemDecideParams.Body
-
- All Implemented Interfaces:
public final class WorkItemDecideParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemDecideParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final WorkItemDecideParams.Decisiondecision()final Optional<String>agentTypeId()final Optional<WorkItemDecideParams.Metadata>metadata()final Optional<String>reason()final JsonField<WorkItemDecideParams.Decision>_decision()Returns the raw JSON value of decision. final JsonField<String>_agentTypeId()Returns the raw JSON value of agentTypeId. final JsonField<WorkItemDecideParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final WorkItemDecideParams.Body.BuildertoBuilder()final WorkItemDecideParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkItemDecideParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
decision
final WorkItemDecideParams.Decision decision()
-
agentTypeId
final Optional<String> agentTypeId()
-
metadata
final Optional<WorkItemDecideParams.Metadata> metadata()
-
_decision
final JsonField<WorkItemDecideParams.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_agentTypeId
final JsonField<String> _agentTypeId()
Returns the raw JSON value of agentTypeId.
Unlike agentTypeId, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<WorkItemDecideParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkItemDecideParams.Body.Builder toBuilder()
-
validate
final WorkItemDecideParams.Body validate()
-
builder
final static WorkItemDecideParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.decision()
-
-
-
-