Class WorkItemUpdateParams.Body
-
- All Implemented Interfaces:
public final class WorkItemUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkItemUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
assigneeId
final Optional<String> assigneeId()
-
completedAt
final Optional<OffsetDateTime> completedAt()
-
description
final Optional<String> description()
-
dueAt
final Optional<OffsetDateTime> dueAt()
-
exitCriteria
final Optional<List<String>> exitCriteria()
-
instructions
final Optional<String> instructions()
-
metadata
final Optional<WorkItemUpdateParams.Metadata> metadata()
-
priority
final Optional<WorkItemUpdateParams.Priority> priority()
-
startedAt
final Optional<OffsetDateTime> startedAt()
-
status
final Optional<WorkItemUpdateParams.Status> status()
-
type
final Optional<WorkItemUpdateParams.Type> type()
-
_assigneeId
final JsonField<String> _assigneeId()
Returns the raw JSON value of assigneeId.
Unlike assigneeId, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_dueAt
final JsonField<OffsetDateTime> _dueAt()
Returns the raw JSON value of dueAt.
Unlike dueAt, this method doesn't throw if the JSON field has an unexpected type.
-
_exitCriteria
final JsonField<List<String>> _exitCriteria()
Returns the raw JSON value of exitCriteria.
Unlike exitCriteria, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<String> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<WorkItemUpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_priority
final JsonField<WorkItemUpdateParams.Priority> _priority()
Returns the raw JSON value of priority.
Unlike priority, this method doesn't throw if the JSON field has an unexpected type.
-
_startedAt
final JsonField<OffsetDateTime> _startedAt()
Returns the raw JSON value of startedAt.
Unlike startedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<WorkItemUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<WorkItemUpdateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkItemUpdateParams.Body.Builder toBuilder()
-
validate
final WorkItemUpdateParams.Body validate()
-
builder
final static WorkItemUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-