Class V1CreateParams.Body
-
- All Implemented Interfaces:
public final class V1CreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1CreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<V1CreateParams.Message>messages()Conversation messages to extract memories from final Optional<String>category()Custom category (e.g. final Optional<String>extractionPrompt()Optional custom prompt for fact extraction final Optional<Boolean>infer()Whether to extract facts from messages (default: true) final Optional<V1CreateParams.Metadata>metadata()Additional metadata (not indexed) final Optional<String>tag1()Generic indexed filter field 1 (you decide what it means) final Optional<String>tag10()Generic indexed filter field 10 final Optional<String>tag11()Generic indexed filter field 11 final Optional<String>tag12()Generic indexed filter field 12 final Optional<String>tag2()Generic indexed filter field 2 final Optional<String>tag3()Generic indexed filter field 3 final Optional<String>tag4()Generic indexed filter field 4 final Optional<String>tag5()Generic indexed filter field 5 final Optional<String>tag6()Generic indexed filter field 6 final Optional<String>tag7()Generic indexed filter field 7 final Optional<String>tag8()Generic indexed filter field 8 final Optional<String>tag9()Generic indexed filter field 9 final JsonField<List<V1CreateParams.Message>>_messages()Returns the raw JSON value of messages. final JsonField<String>_category()Returns the raw JSON value of category. final JsonField<String>_extractionPrompt()Returns the raw JSON value of extractionPrompt. final JsonField<Boolean>_infer()Returns the raw JSON value of infer. final JsonField<V1CreateParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_tag1()Returns the raw JSON value of tag1. final JsonField<String>_tag10()Returns the raw JSON value of tag10. final JsonField<String>_tag11()Returns the raw JSON value of tag11. final JsonField<String>_tag12()Returns the raw JSON value of tag12. final JsonField<String>_tag2()Returns the raw JSON value of tag2. final JsonField<String>_tag3()Returns the raw JSON value of tag3. final JsonField<String>_tag4()Returns the raw JSON value of tag4. final JsonField<String>_tag5()Returns the raw JSON value of tag5. final JsonField<String>_tag6()Returns the raw JSON value of tag6. final JsonField<String>_tag7()Returns the raw JSON value of tag7. final JsonField<String>_tag8()Returns the raw JSON value of tag8. final JsonField<String>_tag9()Returns the raw JSON value of tag9. final Map<String, JsonValue>_additionalProperties()final V1CreateParams.Body.BuildertoBuilder()final V1CreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1CreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
messages
final List<V1CreateParams.Message> messages()
Conversation messages to extract memories from
-
extractionPrompt
final Optional<String> extractionPrompt()
Optional custom prompt for fact extraction
-
metadata
final Optional<V1CreateParams.Metadata> metadata()
Additional metadata (not indexed)
-
_messages
final JsonField<List<V1CreateParams.Message>> _messages()
Returns the raw JSON value of messages.
Unlike messages, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<String> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_extractionPrompt
final JsonField<String> _extractionPrompt()
Returns the raw JSON value of extractionPrompt.
Unlike extractionPrompt, this method doesn't throw if the JSON field has an unexpected type.
-
_infer
final JsonField<Boolean> _infer()
Returns the raw JSON value of infer.
Unlike infer, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<V1CreateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_tag1
final JsonField<String> _tag1()
Returns the raw JSON value of tag1.
Unlike tag1, this method doesn't throw if the JSON field has an unexpected type.
-
_tag10
final JsonField<String> _tag10()
Returns the raw JSON value of tag10.
Unlike tag10, this method doesn't throw if the JSON field has an unexpected type.
-
_tag11
final JsonField<String> _tag11()
Returns the raw JSON value of tag11.
Unlike tag11, this method doesn't throw if the JSON field has an unexpected type.
-
_tag12
final JsonField<String> _tag12()
Returns the raw JSON value of tag12.
Unlike tag12, this method doesn't throw if the JSON field has an unexpected type.
-
_tag2
final JsonField<String> _tag2()
Returns the raw JSON value of tag2.
Unlike tag2, this method doesn't throw if the JSON field has an unexpected type.
-
_tag3
final JsonField<String> _tag3()
Returns the raw JSON value of tag3.
Unlike tag3, this method doesn't throw if the JSON field has an unexpected type.
-
_tag4
final JsonField<String> _tag4()
Returns the raw JSON value of tag4.
Unlike tag4, this method doesn't throw if the JSON field has an unexpected type.
-
_tag5
final JsonField<String> _tag5()
Returns the raw JSON value of tag5.
Unlike tag5, this method doesn't throw if the JSON field has an unexpected type.
-
_tag6
final JsonField<String> _tag6()
Returns the raw JSON value of tag6.
Unlike tag6, this method doesn't throw if the JSON field has an unexpected type.
-
_tag7
final JsonField<String> _tag7()
Returns the raw JSON value of tag7.
Unlike tag7, this method doesn't throw if the JSON field has an unexpected type.
-
_tag8
final JsonField<String> _tag8()
Returns the raw JSON value of tag8.
Unlike tag8, this method doesn't throw if the JSON field has an unexpected type.
-
_tag9
final JsonField<String> _tag9()
Returns the raw JSON value of tag9.
Unlike tag9, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1CreateParams.Body.Builder toBuilder()
-
validate
final V1CreateParams.Body validate()
-
builder
final static V1CreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.messages()
-
-
-
-