Package dev.case.api.models.memory.v1
Class V1RetrieveResponse
-
- All Implemented Interfaces:
public final class V1RetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1RetrieveResponse.BuilderA builder for V1RetrieveResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Memory ID final Optional<OffsetDateTime>createdAt()final Optional<String>memory()Memory content final JsonValue_metadata()Memory metadataThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = v1RetrieveResponse.metadata().convert(MyClass.class);final Optional<OffsetDateTime>updatedAt()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_memory()Returns the raw JSON value of memory. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final V1RetrieveResponse.BuildertoBuilder()final V1RetrieveResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1RetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1RetrieveResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
_metadata
final JsonValue _metadata()
Memory metadata
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = v1RetrieveResponse.metadata().convert(MyClass.class);
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_memory
final JsonField<String> _memory()
Returns the raw JSON value of memory.
Unlike memory, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1RetrieveResponse.Builder toBuilder()
-
validate
final V1RetrieveResponse validate()
-
builder
final static V1RetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1RetrieveResponse.
-
-
-
-