Class V1SearchParams.Body
-
- All Implemented Interfaces:
public final class V1SearchParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SearchParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringquery()Search query for semantic matching final Optional<String>category()Filter by category final Optional<String>tag1()Filter by tag_1 final Optional<String>tag10()Filter by tag_10 final Optional<String>tag11()Filter by tag_11 final Optional<String>tag12()Filter by tag_12 final Optional<String>tag2()Filter by tag_2 final Optional<String>tag3()Filter by tag_3 final Optional<String>tag4()Filter by tag_4 final Optional<String>tag5()Filter by tag_5 final Optional<String>tag6()Filter by tag_6 final Optional<String>tag7()Filter by tag_7 final Optional<String>tag8()Filter by tag_8 final Optional<String>tag9()Filter by tag_9 final Optional<Long>topK()Maximum number of results to return final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<String>_category()Returns the raw JSON value of category. final JsonField<String>_tag1()Returns the raw JSON value of tag1. final JsonField<String>_tag10()Returns the raw JSON value of tag10. final JsonField<String>_tag11()Returns the raw JSON value of tag11. final JsonField<String>_tag12()Returns the raw JSON value of tag12. final JsonField<String>_tag2()Returns the raw JSON value of tag2. final JsonField<String>_tag3()Returns the raw JSON value of tag3. final JsonField<String>_tag4()Returns the raw JSON value of tag4. final JsonField<String>_tag5()Returns the raw JSON value of tag5. final JsonField<String>_tag6()Returns the raw JSON value of tag6. final JsonField<String>_tag7()Returns the raw JSON value of tag7. final JsonField<String>_tag8()Returns the raw JSON value of tag8. final JsonField<String>_tag9()Returns the raw JSON value of tag9. final JsonField<Long>_topK()Returns the raw JSON value of topK. final Map<String, JsonValue>_additionalProperties()final V1SearchParams.Body.BuildertoBuilder()final V1SearchParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SearchParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<String> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_tag1
final JsonField<String> _tag1()
Returns the raw JSON value of tag1.
Unlike tag1, this method doesn't throw if the JSON field has an unexpected type.
-
_tag10
final JsonField<String> _tag10()
Returns the raw JSON value of tag10.
Unlike tag10, this method doesn't throw if the JSON field has an unexpected type.
-
_tag11
final JsonField<String> _tag11()
Returns the raw JSON value of tag11.
Unlike tag11, this method doesn't throw if the JSON field has an unexpected type.
-
_tag12
final JsonField<String> _tag12()
Returns the raw JSON value of tag12.
Unlike tag12, this method doesn't throw if the JSON field has an unexpected type.
-
_tag2
final JsonField<String> _tag2()
Returns the raw JSON value of tag2.
Unlike tag2, this method doesn't throw if the JSON field has an unexpected type.
-
_tag3
final JsonField<String> _tag3()
Returns the raw JSON value of tag3.
Unlike tag3, this method doesn't throw if the JSON field has an unexpected type.
-
_tag4
final JsonField<String> _tag4()
Returns the raw JSON value of tag4.
Unlike tag4, this method doesn't throw if the JSON field has an unexpected type.
-
_tag5
final JsonField<String> _tag5()
Returns the raw JSON value of tag5.
Unlike tag5, this method doesn't throw if the JSON field has an unexpected type.
-
_tag6
final JsonField<String> _tag6()
Returns the raw JSON value of tag6.
Unlike tag6, this method doesn't throw if the JSON field has an unexpected type.
-
_tag7
final JsonField<String> _tag7()
Returns the raw JSON value of tag7.
Unlike tag7, this method doesn't throw if the JSON field has an unexpected type.
-
_tag8
final JsonField<String> _tag8()
Returns the raw JSON value of tag8.
Unlike tag8, this method doesn't throw if the JSON field has an unexpected type.
-
_tag9
final JsonField<String> _tag9()
Returns the raw JSON value of tag9.
Unlike tag9, this method doesn't throw if the JSON field has an unexpected type.
-
_topK
final JsonField<Long> _topK()
Returns the raw JSON value of topK.
Unlike topK, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SearchParams.Body.Builder toBuilder()
-
validate
final V1SearchParams.Body validate()
-
builder
final static V1SearchParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.query()
-
-
-
-