Class V1ProcessParams.Body
-
- All Implemented Interfaces:
public final class V1ProcessParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ProcessParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringdocumentUrl()URL or S3 path to the document to process final Optional<String>callbackUrl()URL to receive completion webhook final Optional<String>documentId()Optional custom document identifier final Optional<V1ProcessParams.Engine>engine()OCR engine to use final Optional<V1ProcessParams.Features>features()Additional processing options final Optional<String>resultBucket()S3 bucket to store results final Optional<String>resultPrefix()S3 key prefix for results final JsonField<String>_documentUrl()Returns the raw JSON value of documentUrl. final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final JsonField<String>_documentId()Returns the raw JSON value of documentId. final JsonField<V1ProcessParams.Engine>_engine()Returns the raw JSON value of engine. final JsonField<V1ProcessParams.Features>_features()Returns the raw JSON value of features. final JsonField<String>_resultBucket()Returns the raw JSON value of resultBucket. final JsonField<String>_resultPrefix()Returns the raw JSON value of resultPrefix. final Map<String, JsonValue>_additionalProperties()final V1ProcessParams.Body.BuildertoBuilder()final V1ProcessParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ProcessParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
documentUrl
final String documentUrl()
URL or S3 path to the document to process
-
callbackUrl
final Optional<String> callbackUrl()
URL to receive completion webhook
-
documentId
final Optional<String> documentId()
Optional custom document identifier
-
engine
final Optional<V1ProcessParams.Engine> engine()
OCR engine to use
-
features
final Optional<V1ProcessParams.Features> features()
Additional processing options
-
resultBucket
final Optional<String> resultBucket()
S3 bucket to store results
-
resultPrefix
final Optional<String> resultPrefix()
S3 key prefix for results
-
_documentUrl
final JsonField<String> _documentUrl()
Returns the raw JSON value of documentUrl.
Unlike documentUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_documentId
final JsonField<String> _documentId()
Returns the raw JSON value of documentId.
Unlike documentId, this method doesn't throw if the JSON field has an unexpected type.
-
_engine
final JsonField<V1ProcessParams.Engine> _engine()
Returns the raw JSON value of engine.
Unlike engine, this method doesn't throw if the JSON field has an unexpected type.
-
_features
final JsonField<V1ProcessParams.Features> _features()
Returns the raw JSON value of features.
Unlike features, this method doesn't throw if the JSON field has an unexpected type.
-
_resultBucket
final JsonField<String> _resultBucket()
Returns the raw JSON value of resultBucket.
Unlike resultBucket, this method doesn't throw if the JSON field has an unexpected type.
-
_resultPrefix
final JsonField<String> _resultPrefix()
Returns the raw JSON value of resultPrefix.
Unlike resultPrefix, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ProcessParams.Body.Builder toBuilder()
-
validate
final V1ProcessParams.Body validate()
-
builder
final static V1ProcessParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.documentUrl()
-
-
-
-