Class V1DetectParams.Body
-
- All Implemented Interfaces:
public final class V1DetectParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<List<V1DetectParams.Category>>categories()Privilege categories to check. final Optional<String>content()Text content to analyze (required if document_id not provided) final Optional<String>documentId()Vault object ID to analyze (required if content not provided) final Optional<Boolean>includeRationale()Include detailed rationale for each category final Optional<V1DetectParams.Jurisdiction>jurisdiction()Jurisdiction for privilege rules final Optional<String>model()LLM model to use for analysis final Optional<String>vaultId()Vault ID (required when using document_id) final JsonField<List<V1DetectParams.Category>>_categories()Returns the raw JSON value of categories. final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_documentId()Returns the raw JSON value of documentId. final JsonField<Boolean>_includeRationale()Returns the raw JSON value of includeRationale. final JsonField<V1DetectParams.Jurisdiction>_jurisdiction()Returns the raw JSON value of jurisdiction. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final V1DetectParams.Body.BuildertoBuilder()final V1DetectParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
categories
final Optional<List<V1DetectParams.Category>> categories()
Privilege categories to check. Defaults to all: attorney_client, work_product, common_interest, litigation_hold
-
content
final Optional<String> content()
Text content to analyze (required if document_id not provided)
-
documentId
final Optional<String> documentId()
Vault object ID to analyze (required if content not provided)
-
includeRationale
final Optional<Boolean> includeRationale()
Include detailed rationale for each category
-
jurisdiction
final Optional<V1DetectParams.Jurisdiction> jurisdiction()
Jurisdiction for privilege rules
-
_categories
final JsonField<List<V1DetectParams.Category>> _categories()
Returns the raw JSON value of categories.
Unlike categories, this method doesn't throw if the JSON field has an unexpected type.
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_documentId
final JsonField<String> _documentId()
Returns the raw JSON value of documentId.
Unlike documentId, this method doesn't throw if the JSON field has an unexpected type.
-
_includeRationale
final JsonField<Boolean> _includeRationale()
Returns the raw JSON value of includeRationale.
Unlike includeRationale, this method doesn't throw if the JSON field has an unexpected type.
-
_jurisdiction
final JsonField<V1DetectParams.Jurisdiction> _jurisdiction()
Returns the raw JSON value of jurisdiction.
Unlike jurisdiction, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DetectParams.Body.Builder toBuilder()
-
validate
final V1DetectParams.Body validate()
-
builder
final static V1DetectParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-