Class V1DetectResponse
-
- All Implemented Interfaces:
public final class V1DetectResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectResponse.BuilderA builder for V1DetectResponse.
public final classV1DetectResponse.Categorypublic final classV1DetectResponse.RecommendationRecommended action for discovery
-
Method Summary
Modifier and Type Method Description final List<V1DetectResponse.Category>categories()final Doubleconfidence()Overall confidence score (0-1) final StringpolicyRationale()Policy-friendly explanation for privilege log final Booleanprivileged()Whether any privilege was detected final V1DetectResponse.Recommendationrecommendation()Recommended action for discovery final JsonField<List<V1DetectResponse.Category>>_categories()Returns the raw JSON value of categories. final JsonField<Double>_confidence()Returns the raw JSON value of confidence. final JsonField<String>_policyRationale()Returns the raw JSON value of policyRationale. final JsonField<Boolean>_privileged()Returns the raw JSON value of privileged. final JsonField<V1DetectResponse.Recommendation>_recommendation()Returns the raw JSON value of recommendation. final Map<String, JsonValue>_additionalProperties()final V1DetectResponse.BuildertoBuilder()final V1DetectResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1DetectResponse. -
-
Method Detail
-
categories
final List<V1DetectResponse.Category> categories()
-
confidence
final Double confidence()
Overall confidence score (0-1)
-
policyRationale
final String policyRationale()
Policy-friendly explanation for privilege log
-
privileged
final Boolean privileged()
Whether any privilege was detected
-
recommendation
final V1DetectResponse.Recommendation recommendation()
Recommended action for discovery
-
_categories
final JsonField<List<V1DetectResponse.Category>> _categories()
Returns the raw JSON value of categories.
Unlike categories, this method doesn't throw if the JSON field has an unexpected type.
-
_confidence
final JsonField<Double> _confidence()
Returns the raw JSON value of confidence.
Unlike confidence, this method doesn't throw if the JSON field has an unexpected type.
-
_policyRationale
final JsonField<String> _policyRationale()
Returns the raw JSON value of policyRationale.
Unlike policyRationale, this method doesn't throw if the JSON field has an unexpected type.
-
_privileged
final JsonField<Boolean> _privileged()
Returns the raw JSON value of privileged.
Unlike privileged, this method doesn't throw if the JSON field has an unexpected type.
-
_recommendation
final JsonField<V1DetectResponse.Recommendation> _recommendation()
Returns the raw JSON value of recommendation.
Unlike recommendation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DetectResponse.Builder toBuilder()
-
validate
final V1DetectResponse validate()
-
builder
final static V1DetectResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1DetectResponse.
The following fields are required:
.categories() .confidence() .policyRationale() .privileged() .recommendation()
-
-
-
-