Class V1DetectResponse.Category
-
- All Implemented Interfaces:
public final class V1DetectResponse.Category
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectResponse.Category.BuilderA builder for Category.
-
Method Summary
Modifier and Type Method Description final Optional<Double>confidence()Confidence for this category (0-1) final Optional<Boolean>detected()Whether this privilege type was detected final Optional<List<String>>indicators()Specific phrases or patterns found final Optional<String>rationale()Explanation of detection result final Optional<String>type()Privilege category final JsonField<Double>_confidence()Returns the raw JSON value of confidence. final JsonField<Boolean>_detected()Returns the raw JSON value of detected. final JsonField<List<String>>_indicators()Returns the raw JSON value of indicators. final JsonField<String>_rationale()Returns the raw JSON value of rationale. final JsonField<String>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final V1DetectResponse.Category.BuildertoBuilder()final V1DetectResponse.Categoryvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectResponse.Category.Builderbuilder()Returns a mutable builder for constructing an instance of Category. -
-
Method Detail
-
confidence
final Optional<Double> confidence()
Confidence for this category (0-1)
-
indicators
final Optional<List<String>> indicators()
Specific phrases or patterns found
-
_confidence
final JsonField<Double> _confidence()
Returns the raw JSON value of confidence.
Unlike confidence, this method doesn't throw if the JSON field has an unexpected type.
-
_detected
final JsonField<Boolean> _detected()
Returns the raw JSON value of detected.
Unlike detected, this method doesn't throw if the JSON field has an unexpected type.
-
_indicators
final JsonField<List<String>> _indicators()
Returns the raw JSON value of indicators.
Unlike indicators, this method doesn't throw if the JSON field has an unexpected type.
-
_rationale
final JsonField<String> _rationale()
Returns the raw JSON value of rationale.
Unlike rationale, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DetectResponse.Category.Builder toBuilder()
-
validate
final V1DetectResponse.Category validate()
-
builder
final static V1DetectResponse.Category.Builder builder()
Returns a mutable builder for constructing an instance of Category.
-
-
-
-