Class V1ContentsParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1ContentsParams implements Params
Scrapes and extracts text content from web pages, PDFs, and documents. Useful for legal research, evidence collection, and document analysis. Supports live crawling, subpage extraction, and content summarization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ContentsParams.BuilderA builder for V1ContentsParams.
public final classV1ContentsParams.Body
-
Method Summary
Modifier and Type Method Description final List<String>urls()Array of URLs to scrape and extract content from final Optional<String>context()Context to guide content extraction and summarization final JsonValue_extras()Additional extraction optionsThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = v1ContentsParams.extras().convert(MyClass.class);final Optional<Boolean>highlights()Whether to include content highlights final Optional<Boolean>livecrawl()Whether to perform live crawling for dynamic content final Optional<Long>livecrawlTimeout()Timeout in seconds for live crawling final Optional<Boolean>subpages()Whether to extract content from linked subpages final Optional<Long>subpageTarget()Maximum number of subpages to crawl final Optional<Boolean>summary()Whether to generate content summaries final Optional<Boolean>text()Whether to extract text content final JsonField<List<String>>_urls()Returns the raw JSON value of urls. final JsonField<String>_context()Returns the raw JSON value of context. final JsonField<Boolean>_highlights()Returns the raw JSON value of highlights. final JsonField<Boolean>_livecrawl()Returns the raw JSON value of livecrawl. final JsonField<Long>_livecrawlTimeout()Returns the raw JSON value of livecrawlTimeout. final JsonField<Boolean>_subpages()Returns the raw JSON value of subpages. final JsonField<Long>_subpageTarget()Returns the raw JSON value of subpageTarget. final JsonField<Boolean>_summary()Returns the raw JSON value of summary. final JsonField<Boolean>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1ContentsParams.BuildertoBuilder()final V1ContentsParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ContentsParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1ContentsParams. -
-
Method Detail
-
_extras
final JsonValue _extras()
Additional extraction options
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = v1ContentsParams.extras().convert(MyClass.class);
-
highlights
final Optional<Boolean> highlights()
Whether to include content highlights
-
livecrawlTimeout
final Optional<Long> livecrawlTimeout()
Timeout in seconds for live crawling
-
subpageTarget
final Optional<Long> subpageTarget()
Maximum number of subpages to crawl
-
_urls
final JsonField<List<String>> _urls()
Returns the raw JSON value of urls.
Unlike urls, this method doesn't throw if the JSON field has an unexpected type.
-
_context
final JsonField<String> _context()
Returns the raw JSON value of context.
Unlike context, this method doesn't throw if the JSON field has an unexpected type.
-
_highlights
final JsonField<Boolean> _highlights()
Returns the raw JSON value of highlights.
Unlike highlights, this method doesn't throw if the JSON field has an unexpected type.
-
_livecrawl
final JsonField<Boolean> _livecrawl()
Returns the raw JSON value of livecrawl.
Unlike livecrawl, this method doesn't throw if the JSON field has an unexpected type.
-
_livecrawlTimeout
final JsonField<Long> _livecrawlTimeout()
Returns the raw JSON value of livecrawlTimeout.
Unlike livecrawlTimeout, this method doesn't throw if the JSON field has an unexpected type.
-
_subpages
final JsonField<Boolean> _subpages()
Returns the raw JSON value of subpages.
Unlike subpages, this method doesn't throw if the JSON field has an unexpected type.
-
_subpageTarget
final JsonField<Long> _subpageTarget()
Returns the raw JSON value of subpageTarget.
Unlike subpageTarget, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<Boolean> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<Boolean> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1ContentsParams.Builder toBuilder()
-
_body
final V1ContentsParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static V1ContentsParams.Builder builder()
Returns a mutable builder for constructing an instance of V1ContentsParams.
The following fields are required:
.urls()
-
-
-
-