Class V1ContentsResponse.Result
-
- All Implemented Interfaces:
public final class V1ContentsResponse.Result
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ContentsResponse.Result.BuilderA builder for Result.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>highlights()Content highlights if requested final JsonValue_metadata()Additional metadata about the contentThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = result.metadata().convert(MyClass.class);final Optional<String>summary()Content summary if requested final Optional<String>text()Extracted text content final Optional<String>title()Page title final Optional<String>url()Source URL final JsonField<List<String>>_highlights()Returns the raw JSON value of highlights. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final V1ContentsResponse.Result.BuildertoBuilder()final V1ContentsResponse.Resultvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ContentsResponse.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
highlights
final Optional<List<String>> highlights()
Content highlights if requested
-
_metadata
final JsonValue _metadata()
Additional metadata about the content
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = result.metadata().convert(MyClass.class);
-
_highlights
final JsonField<List<String>> _highlights()
Returns the raw JSON value of highlights.
Unlike highlights, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ContentsResponse.Result.Builder toBuilder()
-
validate
final V1ContentsResponse.Result validate()
-
builder
final static V1ContentsResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-