Package dev.case.api.models.search.v1
Class V1ResearchResponse
-
- All Implemented Interfaces:
public final class V1ResearchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ResearchResponse.BuilderA builder for V1ResearchResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>model()Model used for research final Optional<String>researchId()Unique identifier for this research final JsonValue_results()Research findings and analysisThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = v1ResearchResponse.results().convert(MyClass.class);final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_researchId()Returns the raw JSON value of researchId. final Map<String, JsonValue>_additionalProperties()final V1ResearchResponse.BuildertoBuilder()final V1ResearchResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1ResearchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1ResearchResponse. -
-
Method Detail
-
researchId
final Optional<String> researchId()
Unique identifier for this research
-
_results
final JsonValue _results()
Research findings and analysis
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = v1ResearchResponse.results().convert(MyClass.class);
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_researchId
final JsonField<String> _researchId()
Returns the raw JSON value of researchId.
Unlike researchId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1ResearchResponse.Builder toBuilder()
-
validate
final V1ResearchResponse validate()
-
builder
final static V1ResearchResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1ResearchResponse.
-
-
-
-