Package dev.case.api.models.search.v1
Class V1RetrieveResearchParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class V1RetrieveResearchParams implements Params
Retrieve the status and results of a deep research task by ID. Supports both standard JSON responses and streaming for real-time updates as the research progresses. Research tasks analyze topics comprehensively using web search and AI synthesis.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1RetrieveResearchParams.BuilderA builder for V1RetrieveResearchParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>events()Filter specific event types for streaming final Optional<Boolean>stream()Enable streaming for real-time updates final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final V1RetrieveResearchParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1RetrieveResearchParamsnone()final static V1RetrieveResearchParams.Builderbuilder()Returns a mutable builder for constructing an instance of V1RetrieveResearchParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final V1RetrieveResearchParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static V1RetrieveResearchParams none()
-
builder
final static V1RetrieveResearchParams.Builder builder()
Returns a mutable builder for constructing an instance of V1RetrieveResearchParams.
-
-
-
-