Class V1RetrieveResearchResponse
-
- All Implemented Interfaces:
public final class V1RetrieveResearchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1RetrieveResearchResponse.BuilderA builder for V1RetrieveResearchResponse.
public final classV1RetrieveResearchResponse.ModelResearch model used
public final classV1RetrieveResearchResponse.ResultsResearch findings and analysis
public final classV1RetrieveResearchResponse.StatusCurrent status of the research task
-
Method Summary
-
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
Task completion timestamp
-
createdAt
final Optional<OffsetDateTime> createdAt()
Task creation timestamp
-
model
final Optional<V1RetrieveResearchResponse.Model> model()
Research model used
-
results
final Optional<V1RetrieveResearchResponse.Results> results()
Research findings and analysis
-
status
final Optional<V1RetrieveResearchResponse.Status> status()
Current status of the research task
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<V1RetrieveResearchResponse.Model> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_progress
final JsonField<Double> _progress()
Returns the raw JSON value of progress.
Unlike progress, this method doesn't throw if the JSON field has an unexpected type.
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_results
final JsonField<V1RetrieveResearchResponse.Results> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<V1RetrieveResearchResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1RetrieveResearchResponse.Builder toBuilder()
-
validate
final V1RetrieveResearchResponse validate()
-
builder
final static V1RetrieveResearchResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1RetrieveResearchResponse.
-
-
-
-