Package dev.case.api.models.search.v1
Class V1SearchResponse.Result
-
- All Implemented Interfaces:
public final class V1SearchResponse.Result
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SearchResponse.Result.BuilderA builder for Result.
-
Method Summary
Modifier and Type Method Description final Optional<String>domain()Domain of the source final Optional<OffsetDateTime>publishedDate()Publication date of the content final Optional<String>snippet()Brief excerpt from the content final Optional<String>title()Title of the search result final Optional<String>url()URL of the search result final JsonField<String>_domain()Returns the raw JSON value of domain. final JsonField<OffsetDateTime>_publishedDate()Returns the raw JSON value of publishedDate. final JsonField<String>_snippet()Returns the raw JSON value of snippet. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final V1SearchResponse.Result.BuildertoBuilder()final V1SearchResponse.Resultvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SearchResponse.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
publishedDate
final Optional<OffsetDateTime> publishedDate()
Publication date of the content
-
_domain
final JsonField<String> _domain()
Returns the raw JSON value of domain.
Unlike domain, this method doesn't throw if the JSON field has an unexpected type.
-
_publishedDate
final JsonField<OffsetDateTime> _publishedDate()
Returns the raw JSON value of publishedDate.
Unlike publishedDate, this method doesn't throw if the JSON field has an unexpected type.
-
_snippet
final JsonField<String> _snippet()
Returns the raw JSON value of snippet.
Unlike snippet, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SearchResponse.Result.Builder toBuilder()
-
validate
final V1SearchResponse.Result validate()
-
builder
final static V1SearchResponse.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
-
-
-
-