Package dev.case.api.models.search.v1
Class V1SimilarResponse
-
- All Implemented Interfaces:
public final class V1SimilarResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1SimilarResponse.BuilderA builder for V1SimilarResponse.
public final classV1SimilarResponse.Result
-
Method Summary
Modifier and Type Method Description final Optional<Double>processingTime()final Optional<List<V1SimilarResponse.Result>>results()final Optional<Long>totalResults()final JsonField<Double>_processingTime()Returns the raw JSON value of processingTime. final JsonField<List<V1SimilarResponse.Result>>_results()Returns the raw JSON value of results. final JsonField<Long>_totalResults()Returns the raw JSON value of totalResults. final Map<String, JsonValue>_additionalProperties()final V1SimilarResponse.BuildertoBuilder()final V1SimilarResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1SimilarResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V1SimilarResponse. -
-
Method Detail
-
processingTime
final Optional<Double> processingTime()
-
results
final Optional<List<V1SimilarResponse.Result>> results()
-
totalResults
final Optional<Long> totalResults()
-
_processingTime
final JsonField<Double> _processingTime()
Returns the raw JSON value of processingTime.
Unlike processingTime, this method doesn't throw if the JSON field has an unexpected type.
-
_results
final JsonField<List<V1SimilarResponse.Result>> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_totalResults
final JsonField<Long> _totalResults()
Returns the raw JSON value of totalResults.
Unlike totalResults, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1SimilarResponse.Builder toBuilder()
-
validate
final V1SimilarResponse validate()
-
builder
final static V1SimilarResponse.Builder builder()
Returns a mutable builder for constructing an instance of V1SimilarResponse.
-
-
-
-