Class SkillCreateParams.Body
-
- All Implemented Interfaces:
public final class SkillCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringcontent()Full skill content in markdown final Stringname()Skill name final JsonValue_metadata()Arbitrary metadata (author, license, etc. final Optional<String>slug()URL-safe slug. final Optional<String>summary()Brief description (1-2 sentences) final Optional<List<String>>tags()Tags for categorization and search boosting final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalProperties()final SkillCreateParams.Body.BuildertoBuilder()final SkillCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_metadata
final JsonValue _metadata()
Arbitrary metadata (author, license, etc.)
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillCreateParams.Body.Builder toBuilder()
-
validate
final SkillCreateParams.Body validate()
-
builder
final static SkillCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.content() .name()
-
-
-
-