Package dev.case.api.models.skills
Class SkillDeleteResponse
-
- All Implemented Interfaces:
public final class SkillDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillDeleteResponse.BuilderA builder for SkillDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>deleted()final Optional<String>slug()final JsonField<Boolean>_deleted()Returns the raw JSON value of deleted. final JsonField<String>_slug()Returns the raw JSON value of slug. final Map<String, JsonValue>_additionalProperties()final SkillDeleteResponse.BuildertoBuilder()final SkillDeleteResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of SkillDeleteResponse. -
-
Method Detail
-
_deleted
final JsonField<Boolean> _deleted()
Returns the raw JSON value of deleted.
Unlike deleted, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillDeleteResponse.Builder toBuilder()
-
validate
final SkillDeleteResponse validate()
-
builder
final static SkillDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of SkillDeleteResponse.
-
-
-
-