Package dev.case.api.models.skills
Class SkillReadResponse.Bundle.UnionMember1
-
- All Implemented Interfaces:
public final class SkillReadResponse.Bundle.UnionMember1
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillReadResponse.Bundle.UnionMember1.BuilderA builder for UnionMember1.
public final classSkillReadResponse.Bundle.UnionMember1.Role
-
Method Summary
Modifier and Type Method Description final Stringpath()final SkillReadResponse.Bundle.UnionMember1.Rolerole()final StringrootSlug()final Optional<String>contentType()final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<SkillReadResponse.Bundle.UnionMember1.Role>_role()Returns the raw JSON value of role. final JsonField<String>_rootSlug()Returns the raw JSON value of rootSlug. final JsonField<String>_contentType()Returns the raw JSON value of contentType. final Map<String, JsonValue>_additionalProperties()final SkillReadResponse.Bundle.UnionMember1.BuildertoBuilder()final SkillReadResponse.Bundle.UnionMember1validate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillReadResponse.Bundle.UnionMember1.Builderbuilder()Returns a mutable builder for constructing an instance of UnionMember1. -
-
Method Detail
-
role
final SkillReadResponse.Bundle.UnionMember1.Role role()
-
contentType
final Optional<String> contentType()
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<SkillReadResponse.Bundle.UnionMember1.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_rootSlug
final JsonField<String> _rootSlug()
Returns the raw JSON value of rootSlug.
Unlike rootSlug, this method doesn't throw if the JSON field has an unexpected type.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillReadResponse.Bundle.UnionMember1.Builder toBuilder()
-
validate
final SkillReadResponse.Bundle.UnionMember1 validate()
-
builder
final static SkillReadResponse.Bundle.UnionMember1.Builder builder()
Returns a mutable builder for constructing an instance of UnionMember1.
The following fields are required:
.path() .role() .rootSlug()
-
-
-
-