Class SkillUpdateParams.Body
-
- All Implemented Interfaces:
public final class SkillUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>content()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);final Optional<String>name()final Optional<String>bodySlug()New slug (renames the skill) final Optional<String>summary()final Optional<List<String>>tags()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_bodySlug()Returns the raw JSON value of bodySlug. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalProperties()final SkillUpdateParams.Body.BuildertoBuilder()final SkillUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SkillUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_bodySlug
final JsonField<String> _bodySlug()
Returns the raw JSON value of bodySlug.
Unlike bodySlug, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SkillUpdateParams.Body.Builder toBuilder()
-
validate
final SkillUpdateParams.Body validate()
-
builder
final static SkillUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-