Class CustomListResponse.Skill
-
- All Implemented Interfaces:
public final class CustomListResponse.Skill
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomListResponse.Skill.BuilderA builder for Skill.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>createdAt()final JsonValue_metadata()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = skill.metadata().convert(MyClass.class);final Optional<String>name()final Optional<String>slug()final Optional<String>summary()final Optional<List<String>>tags()final Optional<OffsetDateTime>updatedAt()final Optional<Long>version()final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<Long>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final CustomListResponse.Skill.BuildertoBuilder()final CustomListResponse.Skillvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomListResponse.Skill.Builderbuilder()Returns a mutable builder for constructing an instance of Skill. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
_metadata
final JsonValue _metadata()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = skill.metadata().convert(MyClass.class);
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomListResponse.Skill.Builder toBuilder()
-
validate
final CustomListResponse.Skill validate()
-
builder
final static CustomListResponse.Skill.Builder builder()
Returns a mutable builder for constructing an instance of Skill.
-
-
-
-