Class SystemListServicesResponse.Service
-
- All Implemented Interfaces:
public final class SystemListServicesResponse.Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSystemListServicesResponse.Service.BuilderA builder for Service.
-
Method Summary
Modifier and Type Method Description final Stringid()final Stringdescription()final Stringhref()final Stringicon()final Stringname()final Longorder()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_href()Returns the raw JSON value of href. final JsonField<String>_icon()Returns the raw JSON value of icon. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_order()Returns the raw JSON value of order. final Map<String, JsonValue>_additionalProperties()final SystemListServicesResponse.Service.BuildertoBuilder()final SystemListServicesResponse.Servicevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SystemListServicesResponse.Service.Builderbuilder()Returns a mutable builder for constructing an instance of Service. -
-
Method Detail
-
description
final String description()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_href
final JsonField<String> _href()
Returns the raw JSON value of href.
Unlike href, this method doesn't throw if the JSON field has an unexpected type.
-
_icon
final JsonField<String> _icon()
Returns the raw JSON value of icon.
Unlike icon, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_order
final JsonField<Long> _order()
Returns the raw JSON value of order.
Unlike order, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SystemListServicesResponse.Service.Builder toBuilder()
-
validate
final SystemListServicesResponse.Service validate()
-
builder
final static SystemListServicesResponse.Service.Builder builder()
Returns a mutable builder for constructing an instance of Service.
The following fields are required:
.id() .description() .href() .icon() .name() .order()
-
-
-
-