Package dev.case.api.models.translate.v1
Class V1DetectResponse.Data
-
- All Implemented Interfaces:
public final class V1DetectResponse.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1DetectResponse.Data.BuilderA builder for Data.
public final classV1DetectResponse.Data.UnnamedSchemaWithArrayParent0
-
Method Summary
Modifier and Type Method Description final Optional<List<List<V1DetectResponse.Data.UnnamedSchemaWithArrayParent0>>>detections()final JsonField<List<List<V1DetectResponse.Data.UnnamedSchemaWithArrayParent0>>>_detections()Returns the raw JSON value of detections. final Map<String, JsonValue>_additionalProperties()final V1DetectResponse.Data.BuildertoBuilder()final V1DetectResponse.Datavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V1DetectResponse.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
detections
final Optional<List<List<V1DetectResponse.Data.UnnamedSchemaWithArrayParent0>>> detections()
-
_detections
final JsonField<List<List<V1DetectResponse.Data.UnnamedSchemaWithArrayParent0>>> _detections()
Returns the raw JSON value of detections.
Unlike detections, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V1DetectResponse.Data.Builder toBuilder()
-
validate
final V1DetectResponse.Data validate()
-
builder
final static V1DetectResponse.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-