Class SubscriptionTestParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class SubscriptionTestParams implements Params
Delivers a test event to a single usage webhook subscription using the same payload shape and signing behavior as production delivery.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionTestParams.BuilderA builder for SubscriptionTestParams.
public final classSubscriptionTestParams.Bodypublic final classSubscriptionTestParams.Payload
-
Method Summary
Modifier and Type Method Description final Optional<String>subscriptionId()final Optional<String>eventType()final Optional<SubscriptionTestParams.Payload>payload()final JsonField<String>_eventType()Returns the raw JSON value of eventType. final JsonField<SubscriptionTestParams.Payload>_payload()Returns the raw JSON value of payload. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SubscriptionTestParams.BuildertoBuilder()final SubscriptionTestParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SubscriptionTestParamsnone()final static SubscriptionTestParams.Builderbuilder()Returns a mutable builder for constructing an instance of SubscriptionTestParams. -
-
Method Detail
-
subscriptionId
final Optional<String> subscriptionId()
-
payload
final Optional<SubscriptionTestParams.Payload> payload()
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_payload
final JsonField<SubscriptionTestParams.Payload> _payload()
Returns the raw JSON value of payload.
Unlike payload, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SubscriptionTestParams.Builder toBuilder()
-
_body
final SubscriptionTestParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static SubscriptionTestParams none()
-
builder
final static SubscriptionTestParams.Builder builder()
Returns a mutable builder for constructing an instance of SubscriptionTestParams.
-
-
-
-