Class SubscriptionTestParams.Body
-
- All Implemented Interfaces:
public final class SubscriptionTestParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionTestParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>eventType()final Optional<SubscriptionTestParams.Payload>payload()final JsonField<String>_eventType()Returns the raw JSON value of eventType. final JsonField<SubscriptionTestParams.Payload>_payload()Returns the raw JSON value of payload. final Map<String, JsonValue>_additionalProperties()final SubscriptionTestParams.Body.BuildertoBuilder()final SubscriptionTestParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SubscriptionTestParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
payload
final Optional<SubscriptionTestParams.Payload> payload()
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_payload
final JsonField<SubscriptionTestParams.Payload> _payload()
Returns the raw JSON value of payload.
Unlike payload, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SubscriptionTestParams.Body.Builder toBuilder()
-
validate
final SubscriptionTestParams.Body validate()
-
builder
final static SubscriptionTestParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-