Class VaultCreateParams.Body
-
- All Implemented Interfaces:
public final class VaultCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()Display name for the vault final Optional<String>description()Optional description of the vault's purpose final Optional<Boolean>enableGraph()Enable knowledge graph for entity relationship mapping. final Optional<Boolean>enableIndexing()Enable vector indexing and search capabilities. final Optional<String>groupId()Assign the vault to a vault group for access control. final JsonValue_metadata()Optional metadata to attach to the vault (e.g. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_enableGraph()Returns the raw JSON value of enableGraph. final JsonField<Boolean>_enableIndexing()Returns the raw JSON value of enableIndexing. final JsonField<String>_groupId()Returns the raw JSON value of groupId. final Map<String, JsonValue>_additionalProperties()final VaultCreateParams.Body.BuildertoBuilder()final VaultCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
Optional description of the vault's purpose
-
enableGraph
final Optional<Boolean> enableGraph()
Enable knowledge graph for entity relationship mapping. Only applies when enableIndexing is true.
-
enableIndexing
final Optional<Boolean> enableIndexing()
Enable vector indexing and search capabilities. Set to false for storage-only vaults.
-
groupId
final Optional<String> groupId()
Assign the vault to a vault group for access control. Required when using a group-scoped API key.
-
_metadata
final JsonValue _metadata()
Optional metadata to attach to the vault (e.g., { containsPHI: true } for HIPAA compliance tracking)
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_enableGraph
final JsonField<Boolean> _enableGraph()
Returns the raw JSON value of enableGraph.
Unlike enableGraph, this method doesn't throw if the JSON field has an unexpected type.
-
_enableIndexing
final JsonField<Boolean> _enableIndexing()
Returns the raw JSON value of enableIndexing.
Unlike enableIndexing, this method doesn't throw if the JSON field has an unexpected type.
-
_groupId
final JsonField<String> _groupId()
Returns the raw JSON value of groupId.
Unlike groupId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultCreateParams.Body.Builder toBuilder()
-
validate
final VaultCreateParams.Body validate()
-
builder
final static VaultCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-