Class VaultCreateResponse
-
- All Implemented Interfaces:
public final class VaultCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultCreateResponse.BuilderA builder for VaultCreateResponse.
public final classVaultCreateResponse.EmbeddingProfileThe resolved embedding profile for this vault. Null for storage-only vaults.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique vault identifier final Optional<OffsetDateTime>createdAt()Vault creation timestamp final Optional<String>description()Vault description final Optional<VaultCreateResponse.EmbeddingProfile>embeddingProfile()The resolved embedding profile for this vault. final Optional<Boolean>enableIndexing()Whether vector indexing is enabled for this vault final Optional<String>filesBucket()S3 bucket name for document storage final Optional<String>indexName()Vector search index name. final Optional<String>name()Vault display name final Optional<String>region()AWS region for storage final Optional<String>vectorBucket()S3 bucket name for vector embeddings. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<VaultCreateResponse.EmbeddingProfile>_embeddingProfile()Returns the raw JSON value of embeddingProfile. final JsonField<Boolean>_enableIndexing()Returns the raw JSON value of enableIndexing. final JsonField<String>_filesBucket()Returns the raw JSON value of filesBucket. final JsonField<String>_indexName()Returns the raw JSON value of indexName. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_region()Returns the raw JSON value of region. final JsonField<String>_vectorBucket()Returns the raw JSON value of vectorBucket. final Map<String, JsonValue>_additionalProperties()final VaultCreateResponse.BuildertoBuilder()final VaultCreateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VaultCreateResponse. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Vault creation timestamp
-
description
final Optional<String> description()
Vault description
-
embeddingProfile
final Optional<VaultCreateResponse.EmbeddingProfile> embeddingProfile()
The resolved embedding profile for this vault. Null for storage-only vaults.
-
enableIndexing
final Optional<Boolean> enableIndexing()
Whether vector indexing is enabled for this vault
-
filesBucket
final Optional<String> filesBucket()
S3 bucket name for document storage
-
indexName
final Optional<String> indexName()
Vector search index name. Null for storage-only vaults.
-
vectorBucket
final Optional<String> vectorBucket()
S3 bucket name for vector embeddings. Null for storage-only vaults.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_embeddingProfile
final JsonField<VaultCreateResponse.EmbeddingProfile> _embeddingProfile()
Returns the raw JSON value of embeddingProfile.
Unlike embeddingProfile, this method doesn't throw if the JSON field has an unexpected type.
-
_enableIndexing
final JsonField<Boolean> _enableIndexing()
Returns the raw JSON value of enableIndexing.
Unlike enableIndexing, this method doesn't throw if the JSON field has an unexpected type.
-
_filesBucket
final JsonField<String> _filesBucket()
Returns the raw JSON value of filesBucket.
Unlike filesBucket, this method doesn't throw if the JSON field has an unexpected type.
-
_indexName
final JsonField<String> _indexName()
Returns the raw JSON value of indexName.
Unlike indexName, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_region
final JsonField<String> _region()
Returns the raw JSON value of region.
Unlike region, this method doesn't throw if the JSON field has an unexpected type.
-
_vectorBucket
final JsonField<String> _vectorBucket()
Returns the raw JSON value of vectorBucket.
Unlike vectorBucket, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultCreateResponse.Builder toBuilder()
-
validate
final VaultCreateResponse validate()
-
builder
final static VaultCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of VaultCreateResponse.
-
-
-
-