Package dev.case.api.models.vault
Class VaultDeleteResponse.DeletedVault
-
- All Implemented Interfaces:
public final class VaultDeleteResponse.DeletedVault
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultDeleteResponse.DeletedVault.BuilderA builder for DeletedVault.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Long>bytesFreed()final Optional<String>name()final Optional<Long>objectsDeleted()final Optional<Long>vectorsDeleted()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_bytesFreed()Returns the raw JSON value of bytesFreed. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_objectsDeleted()Returns the raw JSON value of objectsDeleted. final JsonField<Long>_vectorsDeleted()Returns the raw JSON value of vectorsDeleted. final Map<String, JsonValue>_additionalProperties()final VaultDeleteResponse.DeletedVault.BuildertoBuilder()final VaultDeleteResponse.DeletedVaultvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultDeleteResponse.DeletedVault.Builderbuilder()Returns a mutable builder for constructing an instance of DeletedVault. -
-
Method Detail
-
bytesFreed
final Optional<Long> bytesFreed()
-
objectsDeleted
final Optional<Long> objectsDeleted()
-
vectorsDeleted
final Optional<Long> vectorsDeleted()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_bytesFreed
final JsonField<Long> _bytesFreed()
Returns the raw JSON value of bytesFreed.
Unlike bytesFreed, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_objectsDeleted
final JsonField<Long> _objectsDeleted()
Returns the raw JSON value of objectsDeleted.
Unlike objectsDeleted, this method doesn't throw if the JSON field has an unexpected type.
-
_vectorsDeleted
final JsonField<Long> _vectorsDeleted()
Returns the raw JSON value of vectorsDeleted.
Unlike vectorsDeleted, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultDeleteResponse.DeletedVault.Builder toBuilder()
-
validate
final VaultDeleteResponse.DeletedVault validate()
-
builder
final static VaultDeleteResponse.DeletedVault.Builder builder()
Returns a mutable builder for constructing an instance of DeletedVault.
-
-
-
-