Class VaultIngestParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class VaultIngestParams implements Params
Triggers ingestion workflow for a vault object to extract text, generate chunks, and create embeddings. For supported file types (PDF, DOCX, PPTX, TXT, RTF, XML, HTML, Markdown, CSV/TSV, JSON/YAML/TOML, common source code files, ZIP, audio, video), processing happens asynchronously. ZIP archives are unpacked recursively up to 5 levels, and each extracted file is created as an independent vault object and ingested via the normal pipeline. For unsupported types (images, etc.), the file is marked as completed immediately without text extraction. GraphRAG indexing must be triggered separately via POST /vault/:id/graphrag/:objectId.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultIngestParams.BuilderA builder for VaultIngestParams.
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>objectId()final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final VaultIngestParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultIngestParams.Builderbuilder()Returns a mutable builder for constructing an instance of VaultIngestParams. -
-
Method Detail
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final VaultIngestParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static VaultIngestParams.Builder builder()
Returns a mutable builder for constructing an instance of VaultIngestParams.
The following fields are required:
.id()
-
-
-
-