Class VaultIngestResponse
-
- All Implemented Interfaces:
public final class VaultIngestResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultIngestResponse.BuilderA builder for VaultIngestResponse.
public final classVaultIngestResponse.StatusCurrent ingestion status. 'stored' for file types without text extraction (no chunks/vectors created).
-
Method Summary
Modifier and Type Method Description final BooleanenableGraphRag()Always false - GraphRAG must be triggered separately via POST /vault/:id/graphrag/:objectId final Stringmessage()Human-readable status message final StringobjectId()ID of the vault object being processed final VaultIngestResponse.Statusstatus()Current ingestion status. final Optional<String>workflowId()Workflow run ID for tracking progress. final JsonField<Boolean>_enableGraphRag()Returns the raw JSON value of enableGraphRag. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<VaultIngestResponse.Status>_status()Returns the raw JSON value of status. final JsonField<String>_workflowId()Returns the raw JSON value of workflowId. final Map<String, JsonValue>_additionalProperties()final VaultIngestResponse.BuildertoBuilder()final VaultIngestResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultIngestResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VaultIngestResponse. -
-
Method Detail
-
enableGraphRag
final Boolean enableGraphRag()
Always false - GraphRAG must be triggered separately via POST /vault/:id/graphrag/:objectId
-
status
final VaultIngestResponse.Status status()
Current ingestion status. 'stored' for file types without text extraction (no chunks/vectors created).
-
workflowId
final Optional<String> workflowId()
Workflow run ID for tracking progress. Null for file types that skip processing.
-
_enableGraphRag
final JsonField<Boolean> _enableGraphRag()
Returns the raw JSON value of enableGraphRag.
Unlike enableGraphRag, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<VaultIngestResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_workflowId
final JsonField<String> _workflowId()
Returns the raw JSON value of workflowId.
Unlike workflowId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultIngestResponse.Builder toBuilder()
-
validate
final VaultIngestResponse validate()
-
builder
final static VaultIngestResponse.Builder builder()
Returns a mutable builder for constructing an instance of VaultIngestResponse.
The following fields are required:
.enableGraphRag() .message() .objectId() .status() .workflowId()
-
-
-
-