Package dev.case.api.models.vault
Class VaultListResponse
-
- All Implemented Interfaces:
public final class VaultListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultListResponse.BuilderA builder for VaultListResponse.
public final classVaultListResponse.Vault
-
Method Summary
Modifier and Type Method Description final Optional<Long>total()Total number of vaults final Optional<List<VaultListResponse.Vault>>vaults()final JsonField<Long>_total()Returns the raw JSON value of total. final JsonField<List<VaultListResponse.Vault>>_vaults()Returns the raw JSON value of vaults. final Map<String, JsonValue>_additionalProperties()final VaultListResponse.BuildertoBuilder()final VaultListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VaultListResponse. -
-
Method Detail
-
vaults
final Optional<List<VaultListResponse.Vault>> vaults()
-
_total
final JsonField<Long> _total()
Returns the raw JSON value of total.
Unlike total, this method doesn't throw if the JSON field has an unexpected type.
-
_vaults
final JsonField<List<VaultListResponse.Vault>> _vaults()
Returns the raw JSON value of vaults.
Unlike vaults, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultListResponse.Builder toBuilder()
-
validate
final VaultListResponse validate()
-
builder
final static VaultListResponse.Builder builder()
Returns a mutable builder for constructing an instance of VaultListResponse.
-
-
-
-