Package dev.case.api.models.vault
Class VaultRetrieveResponse.ChunkStrategy
-
- All Implemented Interfaces:
public final class VaultRetrieveResponse.ChunkStrategyDocument chunking strategy configuration
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultRetrieveResponse.ChunkStrategy.BuilderA builder for ChunkStrategy.
-
Method Summary
Modifier and Type Method Description final Optional<Long>chunkSize()Target size for each chunk in tokens final Optional<String>method()Chunking method (e.g. final Optional<Long>minChunkSize()Minimum chunk size in tokens final Optional<Long>overlap()Number of overlapping tokens between chunks final JsonField<Long>_chunkSize()Returns the raw JSON value of chunkSize. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<Long>_minChunkSize()Returns the raw JSON value of minChunkSize. final JsonField<Long>_overlap()Returns the raw JSON value of overlap. final Map<String, JsonValue>_additionalProperties()final VaultRetrieveResponse.ChunkStrategy.BuildertoBuilder()final VaultRetrieveResponse.ChunkStrategyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultRetrieveResponse.ChunkStrategy.Builderbuilder()Returns a mutable builder for constructing an instance of ChunkStrategy. -
-
Method Detail
-
minChunkSize
final Optional<Long> minChunkSize()
Minimum chunk size in tokens
-
_chunkSize
final JsonField<Long> _chunkSize()
Returns the raw JSON value of chunkSize.
Unlike chunkSize, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_minChunkSize
final JsonField<Long> _minChunkSize()
Returns the raw JSON value of minChunkSize.
Unlike minChunkSize, this method doesn't throw if the JSON field has an unexpected type.
-
_overlap
final JsonField<Long> _overlap()
Returns the raw JSON value of overlap.
Unlike overlap, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultRetrieveResponse.ChunkStrategy.Builder toBuilder()
-
validate
final VaultRetrieveResponse.ChunkStrategy validate()
-
builder
final static VaultRetrieveResponse.ChunkStrategy.Builder builder()
Returns a mutable builder for constructing an instance of ChunkStrategy.
-
-
-
-