Class VaultSearchResponse
-
- All Implemented Interfaces:
public final class VaultSearchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultSearchResponse.BuilderA builder for VaultSearchResponse.
public final classVaultSearchResponse.Chunkpublic final classVaultSearchResponse.Source
-
Method Summary
Modifier and Type Method Description final Optional<List<VaultSearchResponse.Chunk>>chunks()Relevant text chunks with similarity scores and page locations final Optional<String>method()Search method used final Optional<String>query()Original search query final Optional<String>response()AI-generated answer based on search results (for global/entity methods) final Optional<List<VaultSearchResponse.Source>>sources()final Optional<String>vaultId()ID of the searched vault final JsonField<List<VaultSearchResponse.Chunk>>_chunks()Returns the raw JSON value of chunks. final JsonField<String>_method()Returns the raw JSON value of method. final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<String>_response()Returns the raw JSON value of response. final JsonField<List<VaultSearchResponse.Source>>_sources()Returns the raw JSON value of sources. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final VaultSearchResponse.BuildertoBuilder()final VaultSearchResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultSearchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VaultSearchResponse. -
-
Method Detail
-
chunks
final Optional<List<VaultSearchResponse.Chunk>> chunks()
Relevant text chunks with similarity scores and page locations
-
response
final Optional<String> response()
AI-generated answer based on search results (for global/entity methods)
-
sources
final Optional<List<VaultSearchResponse.Source>> sources()
-
_chunks
final JsonField<List<VaultSearchResponse.Chunk>> _chunks()
Returns the raw JSON value of chunks.
Unlike chunks, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<String> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_response
final JsonField<String> _response()
Returns the raw JSON value of response.
Unlike response, this method doesn't throw if the JSON field has an unexpected type.
-
_sources
final JsonField<List<VaultSearchResponse.Source>> _sources()
Returns the raw JSON value of sources.
Unlike sources, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultSearchResponse.Builder toBuilder()
-
validate
final VaultSearchResponse validate()
-
builder
final static VaultSearchResponse.Builder builder()
Returns a mutable builder for constructing an instance of VaultSearchResponse.
-
-
-
-