Class VaultSearchResponse.Chunk
-
- All Implemented Interfaces:
public final class VaultSearchResponse.Chunk
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultSearchResponse.Chunk.BuilderA builder for Chunk.
-
Method Summary
Modifier and Type Method Description final Optional<Long>chunkIndex()Index of the chunk within the document (0-based) final Optional<Double>distance()Vector similarity distance (lower is more similar) final Optional<String>objectId()ID of the source document final Optional<Long>pageEnd()PDF page number where the chunk ends (1-indexed). final Optional<Long>pageStart()PDF page number where the chunk begins (1-indexed). final Optional<Double>score()Relevance score (deprecated, use distance or hybridScore) final Optional<String>source()Source identifier (deprecated, use object_id) final Optional<String>text()Preview of the chunk text (up to 500 characters) final Optional<Long>wordEndIndex()Ending word index (0-based) in the OCR word list. final Optional<Long>wordStartIndex()Starting word index (0-based) in the OCR word list. final JsonField<Long>_chunkIndex()Returns the raw JSON value of chunkIndex. final JsonField<Double>_distance()Returns the raw JSON value of distance. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<Long>_pageEnd()Returns the raw JSON value of pageEnd. final JsonField<Long>_pageStart()Returns the raw JSON value of pageStart. final JsonField<Double>_score()Returns the raw JSON value of score. final JsonField<String>_source()Returns the raw JSON value of source. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<Long>_wordEndIndex()Returns the raw JSON value of wordEndIndex. final JsonField<Long>_wordStartIndex()Returns the raw JSON value of wordStartIndex. final Map<String, JsonValue>_additionalProperties()final VaultSearchResponse.Chunk.BuildertoBuilder()final VaultSearchResponse.Chunkvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultSearchResponse.Chunk.Builderbuilder()Returns a mutable builder for constructing an instance of Chunk. -
-
Method Detail
-
chunkIndex
final Optional<Long> chunkIndex()
Index of the chunk within the document (0-based)
-
pageEnd
final Optional<Long> pageEnd()
PDF page number where the chunk ends (1-indexed). Null for non-PDF documents or documents ingested before page tracking was added.
-
pageStart
final Optional<Long> pageStart()
PDF page number where the chunk begins (1-indexed). Null for non-PDF documents or documents ingested before page tracking was added.
-
wordEndIndex
final Optional<Long> wordEndIndex()
Ending word index (0-based) in the OCR word list. Use with GET /vault/:id/objects/:objectId/ocr-words to retrieve bounding boxes for highlighting.
-
wordStartIndex
final Optional<Long> wordStartIndex()
Starting word index (0-based) in the OCR word list. Use with GET /vault/:id/objects/:objectId/ocr-words to retrieve bounding boxes for highlighting.
-
_chunkIndex
final JsonField<Long> _chunkIndex()
Returns the raw JSON value of chunkIndex.
Unlike chunkIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_distance
final JsonField<Double> _distance()
Returns the raw JSON value of distance.
Unlike distance, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_pageEnd
final JsonField<Long> _pageEnd()
Returns the raw JSON value of pageEnd.
Unlike pageEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_pageStart
final JsonField<Long> _pageStart()
Returns the raw JSON value of pageStart.
Unlike pageStart, this method doesn't throw if the JSON field has an unexpected type.
-
_score
final JsonField<Double> _score()
Returns the raw JSON value of score.
Unlike score, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<String> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_wordEndIndex
final JsonField<Long> _wordEndIndex()
Returns the raw JSON value of wordEndIndex.
Unlike wordEndIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_wordStartIndex
final JsonField<Long> _wordStartIndex()
Returns the raw JSON value of wordStartIndex.
Unlike wordStartIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultSearchResponse.Chunk.Builder toBuilder()
-
validate
final VaultSearchResponse.Chunk validate()
-
builder
final static VaultSearchResponse.Chunk.Builder builder()
Returns a mutable builder for constructing an instance of Chunk.
-
-
-
-