Class VaultUploadParams.Body
-
- All Implemented Interfaces:
public final class VaultUploadParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultUploadParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcontentType()MIME type of the file (e.g. final Stringfilename()Name of the file to upload final Optional<Boolean>autoIndex()Whether to automatically process and index the file for search final JsonValue_metadata()Additional metadata to associate with the fileThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);final Optional<String>path()Optional folder path for hierarchy preservation. final Optional<Long>sizeBytes()File size in bytes (optional, max 5GB for single PUT uploads). final JsonField<String>_contentType()Returns the raw JSON value of contentType. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<Boolean>_autoIndex()Returns the raw JSON value of autoIndex. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<Long>_sizeBytes()Returns the raw JSON value of sizeBytes. final Map<String, JsonValue>_additionalProperties()final VaultUploadParams.Body.BuildertoBuilder()final VaultUploadParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultUploadParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
contentType
final String contentType()
MIME type of the file (e.g., application/pdf, image/jpeg)
-
autoIndex
final Optional<Boolean> autoIndex()
Whether to automatically process and index the file for search
-
_metadata
final JsonValue _metadata()
Additional metadata to associate with the file
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.metadata().convert(MyClass.class);
-
path
final Optional<String> path()
Optional folder path for hierarchy preservation. Allows integrations to maintain source folder structure from systems like NetDocs, Clio, or Smokeball. Example: '/Discovery/Depositions/2024'
-
sizeBytes
final Optional<Long> sizeBytes()
File size in bytes (optional, max 5GB for single PUT uploads). When provided, enforces exact file size at S3 level.
-
_contentType
final JsonField<String> _contentType()
Returns the raw JSON value of contentType.
Unlike contentType, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_autoIndex
final JsonField<Boolean> _autoIndex()
Returns the raw JSON value of autoIndex.
Unlike autoIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_sizeBytes
final JsonField<Long> _sizeBytes()
Returns the raw JSON value of sizeBytes.
Unlike sizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultUploadParams.Body.Builder toBuilder()
-
validate
final VaultUploadParams.Body validate()
-
builder
final static VaultUploadParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.contentType() .filename()
-
-
-
-