Class VaultUploadResponse
-
- All Implemented Interfaces:
public final class VaultUploadResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVaultUploadResponse.BuilderA builder for VaultUploadResponse.
public final classVaultUploadResponse.Instructions
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>autoIndex()Whether the file will be automatically indexed final Optional<Boolean>enableIndexing()Whether the vault supports indexing. final Optional<Double>expiresIn()URL expiration time in seconds final Optional<VaultUploadResponse.Instructions>instructions()final Optional<String>nextStep()Next API endpoint to call for processing final Optional<String>objectId()Unique identifier for the uploaded object final Optional<String>path()Folder path for hierarchy if provided final Optional<String>s3Key()S3 object key for the file final Optional<String>uploadUrl()Presigned URL for uploading the file final JsonField<Boolean>_autoIndex()Returns the raw JSON value of autoIndex. final JsonField<Boolean>_enableIndexing()Returns the raw JSON value of enableIndexing. final JsonField<Double>_expiresIn()Returns the raw JSON value of expiresIn. final JsonField<VaultUploadResponse.Instructions>_instructions()Returns the raw JSON value of instructions. final JsonField<String>_nextStep()Returns the raw JSON value of nextStep. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<String>_s3Key()Returns the raw JSON value of s3Key. final JsonField<String>_uploadUrl()Returns the raw JSON value of uploadUrl. final Map<String, JsonValue>_additionalProperties()final VaultUploadResponse.BuildertoBuilder()final VaultUploadResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VaultUploadResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VaultUploadResponse. -
-
Method Detail
-
enableIndexing
final Optional<Boolean> enableIndexing()
Whether the vault supports indexing. False for storage-only vaults.
-
instructions
final Optional<VaultUploadResponse.Instructions> instructions()
-
_autoIndex
final JsonField<Boolean> _autoIndex()
Returns the raw JSON value of autoIndex.
Unlike autoIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_enableIndexing
final JsonField<Boolean> _enableIndexing()
Returns the raw JSON value of enableIndexing.
Unlike enableIndexing, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresIn
final JsonField<Double> _expiresIn()
Returns the raw JSON value of expiresIn.
Unlike expiresIn, this method doesn't throw if the JSON field has an unexpected type.
-
_instructions
final JsonField<VaultUploadResponse.Instructions> _instructions()
Returns the raw JSON value of instructions.
Unlike instructions, this method doesn't throw if the JSON field has an unexpected type.
-
_nextStep
final JsonField<String> _nextStep()
Returns the raw JSON value of nextStep.
Unlike nextStep, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_s3Key
final JsonField<String> _s3Key()
Returns the raw JSON value of s3Key.
Unlike s3Key, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadUrl
final JsonField<String> _uploadUrl()
Returns the raw JSON value of uploadUrl.
Unlike uploadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VaultUploadResponse.Builder toBuilder()
-
validate
final VaultUploadResponse validate()
-
builder
final static VaultUploadResponse.Builder builder()
Returns a mutable builder for constructing an instance of VaultUploadResponse.
-
-
-
-