Class SubscriptionUpdateParams.Body
-
- All Implemented Interfaces:
public final class SubscriptionUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubscriptionUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>callbackUrl()Updated webhook endpoint URL for deliveries final Optional<Boolean>clearSigningSecret()Whether to remove the existing signing secret final Optional<List<String>>eventTypes()Updated event types to deliver for this subscription final Optional<Boolean>isActive()Whether the subscription should continue delivering events final Optional<List<String>>objectIds()Updated vault object IDs to limit notifications to. final Optional<String>signingSecret()Replacement secret used to sign webhook deliveries final JsonField<String>_callbackUrl()Returns the raw JSON value of callbackUrl. final JsonField<Boolean>_clearSigningSecret()Returns the raw JSON value of clearSigningSecret. final JsonField<List<String>>_eventTypes()Returns the raw JSON value of eventTypes. final JsonField<Boolean>_isActive()Returns the raw JSON value of isActive. final JsonField<List<String>>_objectIds()Returns the raw JSON value of objectIds. final JsonField<String>_signingSecret()Returns the raw JSON value of signingSecret. final Map<String, JsonValue>_additionalProperties()final SubscriptionUpdateParams.Body.BuildertoBuilder()final SubscriptionUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SubscriptionUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
callbackUrl
final Optional<String> callbackUrl()
Updated webhook endpoint URL for deliveries
-
clearSigningSecret
final Optional<Boolean> clearSigningSecret()
Whether to remove the existing signing secret
-
eventTypes
final Optional<List<String>> eventTypes()
Updated event types to deliver for this subscription
-
isActive
final Optional<Boolean> isActive()
Whether the subscription should continue delivering events
-
objectIds
final Optional<List<String>> objectIds()
Updated vault object IDs to limit notifications to. Pass an empty array to remove the filter.
-
signingSecret
final Optional<String> signingSecret()
Replacement secret used to sign webhook deliveries
-
_callbackUrl
final JsonField<String> _callbackUrl()
Returns the raw JSON value of callbackUrl.
Unlike callbackUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_clearSigningSecret
final JsonField<Boolean> _clearSigningSecret()
Returns the raw JSON value of clearSigningSecret.
Unlike clearSigningSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<String>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_objectIds
final JsonField<List<String>> _objectIds()
Returns the raw JSON value of objectIds.
Unlike objectIds, this method doesn't throw if the JSON field has an unexpected type.
-
_signingSecret
final JsonField<String> _signingSecret()
Returns the raw JSON value of signingSecret.
Unlike signingSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SubscriptionUpdateParams.Body.Builder toBuilder()
-
validate
final SubscriptionUpdateParams.Body validate()
-
builder
final static SubscriptionUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-