Class GraphragGetStatsParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class GraphragGetStatsParams implements Params
Retrieve GraphRAG (Graph Retrieval-Augmented Generation) statistics for a specific vault. This includes metrics about the knowledge graph structure, entity relationships, and processing status that enable advanced semantic search and AI-powered document analysis.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragGetStatsParams.BuilderA builder for GraphragGetStatsParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final GraphragGetStatsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static GraphragGetStatsParamsnone()final static GraphragGetStatsParams.Builderbuilder()Returns a mutable builder for constructing an instance of GraphragGetStatsParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final GraphragGetStatsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static GraphragGetStatsParams none()
-
builder
final static GraphragGetStatsParams.Builder builder()
Returns a mutable builder for constructing an instance of GraphragGetStatsParams.
-
-
-
-