Class GraphragGetStatsResponse
-
- All Implemented Interfaces:
public final class GraphragGetStatsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragGetStatsResponse.BuilderA builder for GraphragGetStatsResponse.
public final classGraphragGetStatsResponse.StatusCurrent processing status
-
Method Summary
Modifier and Type Method Description final Optional<Long>communities()Number of entity communities identified final Optional<Long>documents()Number of processed documents final Optional<Long>entities()Total number of entities extracted from documents final Optional<OffsetDateTime>lastProcessed()Timestamp of last GraphRAG processing final Optional<Long>relationships()Total number of relationships between entities final Optional<GraphragGetStatsResponse.Status>status()Current processing status final JsonField<Long>_communities()Returns the raw JSON value of communities. final JsonField<Long>_documents()Returns the raw JSON value of documents. final JsonField<Long>_entities()Returns the raw JSON value of entities. final JsonField<OffsetDateTime>_lastProcessed()Returns the raw JSON value of lastProcessed. final JsonField<Long>_relationships()Returns the raw JSON value of relationships. final JsonField<GraphragGetStatsResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final GraphragGetStatsResponse.BuildertoBuilder()final GraphragGetStatsResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static GraphragGetStatsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of GraphragGetStatsResponse. -
-
Method Detail
-
communities
final Optional<Long> communities()
Number of entity communities identified
-
lastProcessed
final Optional<OffsetDateTime> lastProcessed()
Timestamp of last GraphRAG processing
-
relationships
final Optional<Long> relationships()
Total number of relationships between entities
-
status
final Optional<GraphragGetStatsResponse.Status> status()
Current processing status
-
_communities
final JsonField<Long> _communities()
Returns the raw JSON value of communities.
Unlike communities, this method doesn't throw if the JSON field has an unexpected type.
-
_documents
final JsonField<Long> _documents()
Returns the raw JSON value of documents.
Unlike documents, this method doesn't throw if the JSON field has an unexpected type.
-
_entities
final JsonField<Long> _entities()
Returns the raw JSON value of entities.
Unlike entities, this method doesn't throw if the JSON field has an unexpected type.
-
_lastProcessed
final JsonField<OffsetDateTime> _lastProcessed()
Returns the raw JSON value of lastProcessed.
Unlike lastProcessed, this method doesn't throw if the JSON field has an unexpected type.
-
_relationships
final JsonField<Long> _relationships()
Returns the raw JSON value of relationships.
Unlike relationships, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<GraphragGetStatsResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final GraphragGetStatsResponse.Builder toBuilder()
-
validate
final GraphragGetStatsResponse validate()
-
builder
final static GraphragGetStatsResponse.Builder builder()
Returns a mutable builder for constructing an instance of GraphragGetStatsResponse.
-
-
-
-