Class GraphragInitParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class GraphragInitParams implements Params
Initialize a GraphRAG workspace for a vault to enable advanced knowledge graph and retrieval-augmented generation capabilities. This creates the necessary infrastructure for semantic document analysis and graph-based querying within the vault.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGraphragInitParams.BuilderA builder for GraphragInitParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final GraphragInitParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static GraphragInitParamsnone()final static GraphragInitParams.Builderbuilder()Returns a mutable builder for constructing an instance of GraphragInitParams. -
-
Method Detail
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final GraphragInitParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static GraphragInitParams none()
-
builder
final static GraphragInitParams.Builder builder()
Returns a mutable builder for constructing an instance of GraphragInitParams.
-
-
-
-