Package dev.case.api.models.vault.memory
Class MemorySearchParams.Body
-
- All Implemented Interfaces:
public final class MemorySearchParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemorySearchParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringquery()final Optional<Long>limit()final Optional<List<String>>tags()final Optional<List<String>>types()final JsonField<String>_query()Returns the raw JSON value of query. final JsonField<Long>_limit()Returns the raw JSON value of limit. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<List<String>>_types()Returns the raw JSON value of types. final Map<String, JsonValue>_additionalProperties()final MemorySearchParams.Body.BuildertoBuilder()final MemorySearchParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MemorySearchParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_query
final JsonField<String> _query()
Returns the raw JSON value of query.
Unlike query, this method doesn't throw if the JSON field has an unexpected type.
-
_limit
final JsonField<Long> _limit()
Returns the raw JSON value of limit.
Unlike limit, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_types
final JsonField<List<String>> _types()
Returns the raw JSON value of types.
Unlike types, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MemorySearchParams.Body.Builder toBuilder()
-
validate
final MemorySearchParams.Body validate()
-
builder
final static MemorySearchParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.query()
-
-
-
-