Package dev.case.api.models.vault.memory
Class MemorySearchResponse
-
- All Implemented Interfaces:
public final class MemorySearchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemorySearchResponse.BuilderA builder for MemorySearchResponse.
public final classMemorySearchResponse.Result
-
Method Summary
Modifier and Type Method Description final Optional<List<MemorySearchResponse.Result>>results()final JsonField<List<MemorySearchResponse.Result>>_results()Returns the raw JSON value of results. final Map<String, JsonValue>_additionalProperties()final MemorySearchResponse.BuildertoBuilder()final MemorySearchResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MemorySearchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of MemorySearchResponse. -
-
Method Detail
-
results
final Optional<List<MemorySearchResponse.Result>> results()
-
_results
final JsonField<List<MemorySearchResponse.Result>> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MemorySearchResponse.Builder toBuilder()
-
validate
final MemorySearchResponse validate()
-
builder
final static MemorySearchResponse.Builder builder()
Returns a mutable builder for constructing an instance of MemorySearchResponse.
-
-
-
-