Package dev.case.api.models.vault.memory
Class MemoryUpdateParams.Body
-
- All Implemented Interfaces:
public final class MemoryUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMemoryUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>content()final Optional<String>source()final Optional<List<String>>tags()final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_source()Returns the raw JSON value of source. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final Map<String, JsonValue>_additionalProperties()final MemoryUpdateParams.Body.BuildertoBuilder()final MemoryUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MemoryUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<String> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MemoryUpdateParams.Body.Builder toBuilder()
-
validate
final MemoryUpdateParams.Body validate()
-
builder
final static MemoryUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-