Class ObjectDeleteParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ObjectDeleteParams
     implements Params
                        

    Permanently deletes a document from the vault including all associated vectors, chunks, graph data, and the original file. This operation cannot be undone.