Class ObjectDeleteParams.Force
-
- All Implemented Interfaces:
-
dev.case.api.core.Enum
public final class ObjectDeleteParams.Force implements EnumForce delete a stuck document that is still in 'processing' state. Use this if a document got stuck during ingestion (e.g., OCR timeout).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumObjectDeleteParams.Force.KnownAn enum containing Force's known values.
public enumObjectDeleteParams.Force.ValueAn enum containing Force's known values, as well as an _UNKNOWN member.
An instance of Force can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static ObjectDeleteParams.ForceTRUE
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final ObjectDeleteParams.Force.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final ObjectDeleteParams.Force.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final ObjectDeleteParams.Forcevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectDeleteParams.Forceof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final ObjectDeleteParams.Force.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final ObjectDeleteParams.Force.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final ObjectDeleteParams.Force validate()
-
of
final static ObjectDeleteParams.Force of(String value)
-
-
-
-