Class ObjectGetChunksParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ObjectGetChunksParams implements Params
Retrieves full extracted chunk text for a processed vault object. Use this after search when a truncated preview is not enough and you need the exact chunk text or adjacent chunks for surrounding context such as tables, exhibit lists, or multi-part passages.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetChunksParams.BuilderA builder for ObjectGetChunksParams.
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>objectId()final Optional<Long>end()The last chunk index to return (inclusive). final Optional<Long>start()The first chunk index to return (0-based). final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ObjectGetChunksParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetChunksParams.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectGetChunksParams. -
-
Method Detail
-
end
final Optional<Long> end()
The last chunk index to return (inclusive). If omitted, only the
startchunk is returned. Ranges are limited to 10 chunks.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ObjectGetChunksParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ObjectGetChunksParams.Builder builder()
Returns a mutable builder for constructing an instance of ObjectGetChunksParams.
The following fields are required:
.id()
-
-
-
-