Class ObjectGetChunksResponse
-
- All Implemented Interfaces:
public final class ObjectGetChunksResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetChunksResponse.BuilderA builder for ObjectGetChunksResponse.
public final classObjectGetChunksResponse.Chunk
-
Method Summary
Modifier and Type Method Description final List<ObjectGetChunksResponse.Chunk>chunks()Full chunk objects for the requested range final StringobjectId()The object ID final LongtotalChunks()Total number of chunks stored for the object final StringvaultId()The vault ID final JsonField<List<ObjectGetChunksResponse.Chunk>>_chunks()Returns the raw JSON value of chunks. final JsonField<String>_objectId()Returns the raw JSON value of objectId. final JsonField<Long>_totalChunks()Returns the raw JSON value of totalChunks. final JsonField<String>_vaultId()Returns the raw JSON value of vaultId. final Map<String, JsonValue>_additionalProperties()final ObjectGetChunksResponse.BuildertoBuilder()final ObjectGetChunksResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetChunksResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectGetChunksResponse. -
-
Method Detail
-
chunks
final List<ObjectGetChunksResponse.Chunk> chunks()
Full chunk objects for the requested range
-
totalChunks
final Long totalChunks()
Total number of chunks stored for the object
-
_chunks
final JsonField<List<ObjectGetChunksResponse.Chunk>> _chunks()
Returns the raw JSON value of chunks.
Unlike chunks, this method doesn't throw if the JSON field has an unexpected type.
-
_objectId
final JsonField<String> _objectId()
Returns the raw JSON value of objectId.
Unlike objectId, this method doesn't throw if the JSON field has an unexpected type.
-
_totalChunks
final JsonField<Long> _totalChunks()
Returns the raw JSON value of totalChunks.
Unlike totalChunks, this method doesn't throw if the JSON field has an unexpected type.
-
_vaultId
final JsonField<String> _vaultId()
Returns the raw JSON value of vaultId.
Unlike vaultId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetChunksResponse.Builder toBuilder()
-
validate
final ObjectGetChunksResponse validate()
-
builder
final static ObjectGetChunksResponse.Builder builder()
Returns a mutable builder for constructing an instance of ObjectGetChunksResponse.
The following fields are required:
.chunks() .objectId() .totalChunks() .vaultId()
-
-
-
-