Class ObjectGetOcrWordsParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class ObjectGetOcrWordsParams implements Params
Retrieves word-level OCR bounding box data for a processed PDF document. Each word includes its text, normalized bounding box coordinates (0-1 range), confidence score, and global word index. Use this data to highlight specific text ranges in a PDF viewer based on word indices from search results.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetOcrWordsParams.BuilderA builder for ObjectGetOcrWordsParams.
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>objectId()final Optional<Long>page()Filter to a specific page number (1-indexed). final Optional<Long>wordEnd()Filter to words ending at this index (inclusive). final Optional<Long>wordStart()Filter to words starting at this index (inclusive). final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ObjectGetOcrWordsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetOcrWordsParams.Builderbuilder()Returns a mutable builder for constructing an instance of ObjectGetOcrWordsParams. -
-
Method Detail
-
page
final Optional<Long> page()
Filter to a specific page number (1-indexed). If omitted, returns all pages.
-
wordEnd
final Optional<Long> wordEnd()
Filter to words ending at this index (inclusive). Useful for retrieving words for a specific chunk.
-
wordStart
final Optional<Long> wordStart()
Filter to words starting at this index (inclusive). Useful for retrieving words for a specific chunk.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ObjectGetOcrWordsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ObjectGetOcrWordsParams.Builder builder()
Returns a mutable builder for constructing an instance of ObjectGetOcrWordsParams.
The following fields are required:
.id()
-
-
-
-