Class ObjectGetOcrWordsResponse.Page
-
- All Implemented Interfaces:
public final class ObjectGetOcrWordsResponse.Page
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetOcrWordsResponse.Page.BuilderA builder for Page.
public final classObjectGetOcrWordsResponse.Page.Word
-
Method Summary
Modifier and Type Method Description final Optional<Long>page()Page number (1-indexed) final Optional<List<ObjectGetOcrWordsResponse.Page.Word>>words()final JsonField<Long>_page()Returns the raw JSON value of page. final JsonField<List<ObjectGetOcrWordsResponse.Page.Word>>_words()Returns the raw JSON value of words. final Map<String, JsonValue>_additionalProperties()final ObjectGetOcrWordsResponse.Page.BuildertoBuilder()final ObjectGetOcrWordsResponse.Pagevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetOcrWordsResponse.Page.Builderbuilder()Returns a mutable builder for constructing an instance of Page. -
-
Method Detail
-
words
final Optional<List<ObjectGetOcrWordsResponse.Page.Word>> words()
-
_page
final JsonField<Long> _page()
Returns the raw JSON value of page.
Unlike page, this method doesn't throw if the JSON field has an unexpected type.
-
_words
final JsonField<List<ObjectGetOcrWordsResponse.Page.Word>> _words()
Returns the raw JSON value of words.
Unlike words, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetOcrWordsResponse.Page.Builder toBuilder()
-
validate
final ObjectGetOcrWordsResponse.Page validate()
-
builder
final static ObjectGetOcrWordsResponse.Page.Builder builder()
Returns a mutable builder for constructing an instance of Page.
-
-
-
-