Class ObjectGetOcrWordsResponse.Page.Word
-
- All Implemented Interfaces:
public final class ObjectGetOcrWordsResponse.Page.Word
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectGetOcrWordsResponse.Page.Word.BuilderA builder for Word.
-
Method Summary
Modifier and Type Method Description final Optional<List<Double>>bbox()Bounding box x0, y0, x1, y1 normalized to 0-1 range final Optional<Double>confidence()OCR confidence score (0-1) final Optional<String>text()The word text final Optional<Long>wordIndex()Global word index across the entire document (0-based) final JsonField<List<Double>>_bbox()Returns the raw JSON value of bbox. final JsonField<Double>_confidence()Returns the raw JSON value of confidence. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<Long>_wordIndex()Returns the raw JSON value of wordIndex. final Map<String, JsonValue>_additionalProperties()final ObjectGetOcrWordsResponse.Page.Word.BuildertoBuilder()final ObjectGetOcrWordsResponse.Page.Wordvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ObjectGetOcrWordsResponse.Page.Word.Builderbuilder()Returns a mutable builder for constructing an instance of Word. -
-
Method Detail
-
confidence
final Optional<Double> confidence()
OCR confidence score (0-1)
-
_bbox
final JsonField<List<Double>> _bbox()
Returns the raw JSON value of bbox.
Unlike bbox, this method doesn't throw if the JSON field has an unexpected type.
-
_confidence
final JsonField<Double> _confidence()
Returns the raw JSON value of confidence.
Unlike confidence, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_wordIndex
final JsonField<Long> _wordIndex()
Returns the raw JSON value of wordIndex.
Unlike wordIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ObjectGetOcrWordsResponse.Page.Word.Builder toBuilder()
-
validate
final ObjectGetOcrWordsResponse.Page.Word validate()
-
builder
final static ObjectGetOcrWordsResponse.Page.Word.Builder builder()
Returns a mutable builder for constructing an instance of Word.
-
-
-
-