Class ObjectUpdateParams

  • All Implemented Interfaces:
    dev.case.api.core.Params

    
    public final class ObjectUpdateParams
     implements Params
                        

    Update a document's filename, path, or metadata. Use this to rename files or organize them into virtual folders. The path is stored in metadata.path and can be used to build folder hierarchies in your application.