Class BoostListGenerateResponse
-
- All Implemented Interfaces:
public final class BoostListGenerateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBoostListGenerateResponse.BuilderA builder for BoostListGenerateResponse.
public final classBoostListGenerateResponse.Itempublic final classBoostListGenerateResponse.Source
-
Method Summary
Modifier and Type Method Description final Optional<List<BoostListGenerateResponse.Item>>items()final Optional<BoostListGenerateResponse.Source>source()final Optional<List<String>>sourceIds()final JsonField<List<BoostListGenerateResponse.Item>>_items()Returns the raw JSON value of items. final JsonField<BoostListGenerateResponse.Source>_source()Returns the raw JSON value of source. final JsonField<List<String>>_sourceIds()Returns the raw JSON value of sourceIds. final Map<String, JsonValue>_additionalProperties()final BoostListGenerateResponse.BuildertoBuilder()final BoostListGenerateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BoostListGenerateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of BoostListGenerateResponse. -
-
Method Detail
-
items
final Optional<List<BoostListGenerateResponse.Item>> items()
-
source
final Optional<BoostListGenerateResponse.Source> source()
-
_items
final JsonField<List<BoostListGenerateResponse.Item>> _items()
Returns the raw JSON value of items.
Unlike items, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<BoostListGenerateResponse.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceIds
final JsonField<List<String>> _sourceIds()
Returns the raw JSON value of sourceIds.
Unlike sourceIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BoostListGenerateResponse.Builder toBuilder()
-
validate
final BoostListGenerateResponse validate()
-
builder
final static BoostListGenerateResponse.Builder builder()
Returns a mutable builder for constructing an instance of BoostListGenerateResponse.
-
-
-
-