Class EndpointCreateParams.Body
-
- All Implemented Interfaces:
public final class EndpointCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<String>eventTypeFilters()Glob patterns of event types to deliver (e.g. final Stringurl()HTTPS callback URL that will receive event deliveries final Optional<String>description()Human-readable label for this endpoint final Optional<EndpointCreateParams.ResourceScopes>resourceScopes()Optional per-resource allowlists. final JsonField<List<String>>_eventTypeFilters()Returns the raw JSON value of eventTypeFilters. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<EndpointCreateParams.ResourceScopes>_resourceScopes()Returns the raw JSON value of resourceScopes. final Map<String, JsonValue>_additionalProperties()final EndpointCreateParams.Body.BuildertoBuilder()final EndpointCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
eventTypeFilters
final List<String> eventTypeFilters()
Glob patterns of event types to deliver (e.g. "vault.", "ocr.job.completed", "")
-
description
final Optional<String> description()
Human-readable label for this endpoint
-
resourceScopes
final Optional<EndpointCreateParams.ResourceScopes> resourceScopes()
Optional per-resource allowlists. If vaultIds is set, only events for those vaults are delivered. Same for matterIds.
-
_eventTypeFilters
final JsonField<List<String>> _eventTypeFilters()
Returns the raw JSON value of eventTypeFilters.
Unlike eventTypeFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_resourceScopes
final JsonField<EndpointCreateParams.ResourceScopes> _resourceScopes()
Returns the raw JSON value of resourceScopes.
Unlike resourceScopes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EndpointCreateParams.Body.Builder toBuilder()
-
validate
final EndpointCreateParams.Body validate()
-
builder
final static EndpointCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.eventTypeFilters() .url()
-
-
-
-