Class EndpointRotateSecretParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class EndpointRotateSecretParams implements Params
Generates a new signing secret for the endpoint. The previous secret remains valid until
previousSecretExpiresInSecelapses (default 24h, max 30 days). During the grace window deliveries are signed with both secrets so receivers can migrate without downtime. Returns the new secret — this is the only time it is shown in plaintext.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointRotateSecretParams.BuilderA builder for EndpointRotateSecretParams.
public final classEndpointRotateSecretParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<Long>previousSecretExpiresInSec()How long (seconds) the old secret continues to be accepted. final JsonField<Long>_previousSecretExpiresInSec()Returns the raw JSON value of previousSecretExpiresInSec. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EndpointRotateSecretParams.BuildertoBuilder()final EndpointRotateSecretParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointRotateSecretParamsnone()final static EndpointRotateSecretParams.Builderbuilder()Returns a mutable builder for constructing an instance of EndpointRotateSecretParams. -
-
Method Detail
-
previousSecretExpiresInSec
final Optional<Long> previousSecretExpiresInSec()
How long (seconds) the old secret continues to be accepted. 0 invalidates immediately. Default: 86400 (24h).
-
_previousSecretExpiresInSec
final JsonField<Long> _previousSecretExpiresInSec()
Returns the raw JSON value of previousSecretExpiresInSec.
Unlike previousSecretExpiresInSec, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EndpointRotateSecretParams.Builder toBuilder()
-
_body
final EndpointRotateSecretParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EndpointRotateSecretParams none()
-
builder
final static EndpointRotateSecretParams.Builder builder()
Returns a mutable builder for constructing an instance of EndpointRotateSecretParams.
-
-
-
-