Class EndpointTestParams
-
- All Implemented Interfaces:
-
dev.case.api.core.Params
public final class EndpointTestParams implements Params
Synchronously delivers a synthetic
webhook.testevent to the endpoint and returns the HTTP result. No retries. Useful for validating that a new endpoint is reachable and its signature verifier works. The delivery is not persisted in the delivery history.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointTestParams.BuilderA builder for EndpointTestParams.
public final classEndpointTestParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>eventType()Event type to simulate. final JsonValue_payload()Custom datapayload.final JsonField<String>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EndpointTestParams.BuildertoBuilder()final EndpointTestParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EndpointTestParamsnone()final static EndpointTestParams.Builderbuilder()Returns a mutable builder for constructing an instance of EndpointTestParams. -
-
Method Detail
-
_payload
final JsonValue _payload()
Custom
datapayload. Defaults to a small placeholder.This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = endpointTestParams.payload().convert(MyClass.class);
-
_eventType
final JsonField<String> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EndpointTestParams.Builder toBuilder()
-
_body
final EndpointTestParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EndpointTestParams none()
-
builder
final static EndpointTestParams.Builder builder()
Returns a mutable builder for constructing an instance of EndpointTestParams.
-
-
-
-