Class EndpointUpdateParams.Body
-
- All Implemented Interfaces:
public final class EndpointUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEndpointUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
description
final Optional<String> description()
-
eventTypeFilters
final Optional<List<String>> eventTypeFilters()
-
resourceScopes
final Optional<EndpointUpdateParams.ResourceScopes> resourceScopes()
-
status
final Optional<EndpointUpdateParams.Status> status()
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypeFilters
final JsonField<List<String>> _eventTypeFilters()
Returns the raw JSON value of eventTypeFilters.
Unlike eventTypeFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_resourceScopes
final JsonField<EndpointUpdateParams.ResourceScopes> _resourceScopes()
Returns the raw JSON value of resourceScopes.
Unlike resourceScopes, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EndpointUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EndpointUpdateParams.Body.Builder toBuilder()
-
validate
final EndpointUpdateParams.Body validate()
-
builder
final static EndpointUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-