Package dev.case.api.services.async
Class LegalServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.LegalServiceAsync.WithRawResponse
public final class LegalServiceAsyncImpl.WithRawResponseImpl implements LegalServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LegalServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
LegalServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-