Package dev.case.api.services.async
Class MemoryServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.MemoryServiceAsync.WithRawResponse
public final class MemoryServiceAsyncImpl.WithRawResponseImpl implements MemoryServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MemoryServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
MemoryServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-