Package dev.case.api.services.async
Class PrivilegeServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.PrivilegeServiceAsync.WithRawResponse
public final class PrivilegeServiceAsyncImpl.WithRawResponseImpl implements PrivilegeServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PrivilegeServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
PrivilegeServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-