Package dev.case.api.services.async
Interface SkillServiceAsync
-
- All Implemented Interfaces:
public interface SkillServiceAsyncSearch and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSkillServiceAsync.WithRawResponseA view of SkillServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract SkillServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SkillServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
read
CompletableFuture<SkillReadResponse> read(String slug)
Read the full content of a legal skill by its slug. Returns markdown content, tags, and metadata.
-
read
CompletableFuture<SkillReadResponse> read(String slug, SkillReadParams params, RequestOptions requestOptions)
-
read
CompletableFuture<SkillReadResponse> read(String slug, SkillReadParams params)
-
read
abstract CompletableFuture<SkillReadResponse> read(SkillReadParams params, RequestOptions requestOptions)
-
read
CompletableFuture<SkillReadResponse> read(SkillReadParams params)
-
read
CompletableFuture<SkillReadResponse> read(String slug, RequestOptions requestOptions)
-
resolve
CompletableFuture<SkillResolveResponse> resolve(SkillResolveParams params)
Search the Legal Skills Store using hybrid search (text + tag + semantic). Returns ranked results with relevance scores.
-
resolve
abstract CompletableFuture<SkillResolveResponse> resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-