Package dev.case.api.services.async
Class SkillServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SkillServiceAsync
public final class SkillServiceAsyncImpl implements SkillServiceAsync
Search and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SkillServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SkillServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<SkillReadResponse>read(SkillReadParams params, RequestOptions requestOptions)CompletableFuture<SkillResolveResponse>resolve(SkillResolveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SkillServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SkillServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
read
CompletableFuture<SkillReadResponse> read(SkillReadParams params, RequestOptions requestOptions)
-
resolve
CompletableFuture<SkillResolveResponse> resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-