Package dev.case.api.services.async
Class SuperdocServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.SuperdocServiceAsync.WithRawResponse
public final class SuperdocServiceAsyncImpl.WithRawResponseImpl implements SuperdocServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SuperdocServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
SuperdocServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-