Package dev.case.api.services.async
Class VoiceServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.VoiceServiceAsync.WithRawResponse
public final class VoiceServiceAsyncImpl.WithRawResponseImpl implements VoiceServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description VoiceServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamingServiceAsync.WithRawResponsestreaming()TranscriptionServiceAsync.WithRawResponsetranscription()V1ServiceAsync.WithRawResponsev1()-
-
Method Detail
-
withOptions
VoiceServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
StreamingServiceAsync.WithRawResponse streaming()
-
transcription
TranscriptionServiceAsync.WithRawResponse transcription()
-
-
-
-