Interface V1ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentServiceAsync.WithRawResponseagents()abstract RunServiceAsync.WithRawResponserun()abstract ExecuteServiceAsync.WithRawResponseexecute()abstract ChatServiceAsync.WithRawResponsechat()-
-
Method Detail
-
withOptions
abstract V1ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
abstract AgentServiceAsync.WithRawResponse agents()
-
run
abstract RunServiceAsync.WithRawResponse run()
-
execute
abstract ExecuteServiceAsync.WithRawResponse execute()
-
chat
abstract ChatServiceAsync.WithRawResponse chat()
-
-
-
-