Class V2ServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.agent.V2ServiceAsync
public final class V2ServiceAsyncImpl implements V2ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V2ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V2ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RunServiceAsyncrun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ExecuteServiceAsyncexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatServiceAsyncchat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
V2ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V2ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
run
RunServiceAsync run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
ExecuteServiceAsync execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
ChatServiceAsync chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-