Interface DeploymentServiceAsync
-
- All Implemented Interfaces:
public interface DeploymentServiceAsyncWeb application deployment management
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDeploymentServiceAsync.WithRawResponseA view of DeploymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DeploymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DeploymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(DeploymentCreateParams params)
Trigger a new deployment for a project
-
create
abstract CompletableFuture<Void> create(DeploymentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String id, DeploymentRetrieveParams params)
Get details of a specific deployment including build logs
-
retrieve
CompletableFuture<Void> retrieve(String id, DeploymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(DeploymentRetrieveParams params)
-
retrieve
abstract CompletableFuture<Void> retrieve(DeploymentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<Void> list(DeploymentListParams params)
List deployments for a project
-
list
abstract CompletableFuture<Void> list(DeploymentListParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<Void> cancel(String id, DeploymentCancelParams params)
Cancel a running deployment
-
cancel
CompletableFuture<Void> cancel(String id, DeploymentCancelParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<Void> cancel(DeploymentCancelParams params)
-
cancel
abstract CompletableFuture<Void> cancel(DeploymentCancelParams params, RequestOptions requestOptions)
-
createFromFiles
CompletableFuture<Void> createFromFiles()
Create a deployment from raw file contents (for Thurgood sandbox deployments)
-
createFromFiles
abstract CompletableFuture<Void> createFromFiles(DeploymentCreateFromFilesParams params, RequestOptions requestOptions)
-
createFromFiles
CompletableFuture<Void> createFromFiles(DeploymentCreateFromFilesParams params)
-
createFromFiles
CompletableFuture<Void> createFromFiles(RequestOptions requestOptions)
-
getLogs
CompletableFuture<Void> getLogs(String id, DeploymentGetLogsParams params)
Get build logs for a specific deployment
-
getLogs
CompletableFuture<Void> getLogs(String id, DeploymentGetLogsParams params, RequestOptions requestOptions)
-
getLogs
CompletableFuture<Void> getLogs(DeploymentGetLogsParams params)
-
getLogs
abstract CompletableFuture<Void> getLogs(DeploymentGetLogsParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<Void> getStatus(String id)
Get the current status of a deployment
-
getStatus
CompletableFuture<Void> getStatus(String id, DeploymentGetStatusParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<Void> getStatus(String id, DeploymentGetStatusParams params)
-
getStatus
abstract CompletableFuture<Void> getStatus(DeploymentGetStatusParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<Void> getStatus(DeploymentGetStatusParams params)
-
getStatus
CompletableFuture<Void> getStatus(String id, RequestOptions requestOptions)
-
stream
CompletableFuture<Void> stream(String id, DeploymentStreamParams params)
Stream real-time deployment progress events via Server-Sent Events
-
stream
CompletableFuture<Void> stream(String id, DeploymentStreamParams params, RequestOptions requestOptions)
-
stream
CompletableFuture<Void> stream(DeploymentStreamParams params)
-
stream
abstract CompletableFuture<Void> stream(DeploymentStreamParams params, RequestOptions requestOptions)
-
-
-
-