Interface ProjectServiceAsync
-
- All Implemented Interfaces:
public interface ProjectServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProjectServiceAsync.WithRawResponseA view of ProjectServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ProjectServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProjectServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Void> create(ProjectCreateParams params)
Create a new web application project
-
create
abstract CompletableFuture<Void> create(ProjectCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String id)
Get details of a specific web application project
-
retrieve
CompletableFuture<Void> retrieve(String id, ProjectRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(String id, ProjectRetrieveParams params)
-
retrieve
abstract CompletableFuture<Void> retrieve(ProjectRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Void> retrieve(ProjectRetrieveParams params)
-
retrieve
CompletableFuture<Void> retrieve(String id, RequestOptions requestOptions)
-
list
CompletableFuture<ProjectListResponse> list()
List all web application projects
-
list
abstract CompletableFuture<ProjectListResponse> list(ProjectListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProjectListResponse> list(ProjectListParams params)
-
list
CompletableFuture<ProjectListResponse> list(RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id)
Delete a web application project
-
delete
CompletableFuture<Void> delete(String id, ProjectDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id, ProjectDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(ProjectDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(ProjectDeleteParams params)
-
delete
CompletableFuture<Void> delete(String id, RequestOptions requestOptions)
-
createDeployment
CompletableFuture<Void> createDeployment(String id)
Trigger a new deployment for a project.
-
createDeployment
CompletableFuture<Void> createDeployment(String id, ProjectCreateDeploymentParams params, RequestOptions requestOptions)
-
createDeployment
CompletableFuture<Void> createDeployment(String id, ProjectCreateDeploymentParams params)
-
createDeployment
abstract CompletableFuture<Void> createDeployment(ProjectCreateDeploymentParams params, RequestOptions requestOptions)
-
createDeployment
CompletableFuture<Void> createDeployment(ProjectCreateDeploymentParams params)
-
createDeployment
CompletableFuture<Void> createDeployment(String id, RequestOptions requestOptions)
-
createDomain
CompletableFuture<Void> createDomain(String id, ProjectCreateDomainParams params)
Add a custom domain to a project
-
createDomain
CompletableFuture<Void> createDomain(String id, ProjectCreateDomainParams params, RequestOptions requestOptions)
-
createDomain
CompletableFuture<Void> createDomain(ProjectCreateDomainParams params)
-
createDomain
abstract CompletableFuture<Void> createDomain(ProjectCreateDomainParams params, RequestOptions requestOptions)
-
createEnv
CompletableFuture<Void> createEnv(String id, ProjectCreateEnvParams params)
Create a new environment variable for a project
-
createEnv
CompletableFuture<Void> createEnv(String id, ProjectCreateEnvParams params, RequestOptions requestOptions)
-
createEnv
CompletableFuture<Void> createEnv(ProjectCreateEnvParams params)
-
createEnv
abstract CompletableFuture<Void> createEnv(ProjectCreateEnvParams params, RequestOptions requestOptions)
-
deleteDomain
CompletableFuture<Void> deleteDomain(String domain, ProjectDeleteDomainParams params)
Remove a domain from a project
-
deleteDomain
CompletableFuture<Void> deleteDomain(String domain, ProjectDeleteDomainParams params, RequestOptions requestOptions)
-
deleteDomain
CompletableFuture<Void> deleteDomain(ProjectDeleteDomainParams params)
-
deleteDomain
abstract CompletableFuture<Void> deleteDomain(ProjectDeleteDomainParams params, RequestOptions requestOptions)
-
deleteEnv
CompletableFuture<Void> deleteEnv(String envId, ProjectDeleteEnvParams params)
Delete an environment variable from a project
-
deleteEnv
CompletableFuture<Void> deleteEnv(String envId, ProjectDeleteEnvParams params, RequestOptions requestOptions)
-
deleteEnv
CompletableFuture<Void> deleteEnv(ProjectDeleteEnvParams params)
-
deleteEnv
abstract CompletableFuture<Void> deleteEnv(ProjectDeleteEnvParams params, RequestOptions requestOptions)
-
getRuntimeLogs
CompletableFuture<Void> getRuntimeLogs(String id)
Get runtime/function logs for a project
-
getRuntimeLogs
CompletableFuture<Void> getRuntimeLogs(String id, ProjectGetRuntimeLogsParams params, RequestOptions requestOptions)
-
getRuntimeLogs
CompletableFuture<Void> getRuntimeLogs(String id, ProjectGetRuntimeLogsParams params)
-
getRuntimeLogs
abstract CompletableFuture<Void> getRuntimeLogs(ProjectGetRuntimeLogsParams params, RequestOptions requestOptions)
-
getRuntimeLogs
CompletableFuture<Void> getRuntimeLogs(ProjectGetRuntimeLogsParams params)
-
getRuntimeLogs
CompletableFuture<Void> getRuntimeLogs(String id, RequestOptions requestOptions)
-
listDeployments
CompletableFuture<Void> listDeployments(String id)
List deployments for a specific project
-
listDeployments
CompletableFuture<Void> listDeployments(String id, ProjectListDeploymentsParams params, RequestOptions requestOptions)
-
listDeployments
CompletableFuture<Void> listDeployments(String id, ProjectListDeploymentsParams params)
-
listDeployments
abstract CompletableFuture<Void> listDeployments(ProjectListDeploymentsParams params, RequestOptions requestOptions)
-
listDeployments
CompletableFuture<Void> listDeployments(ProjectListDeploymentsParams params)
-
listDeployments
CompletableFuture<Void> listDeployments(String id, RequestOptions requestOptions)
-
listDomains
CompletableFuture<Void> listDomains(String id)
List all domains configured for a project
-
listDomains
CompletableFuture<Void> listDomains(String id, ProjectListDomainsParams params, RequestOptions requestOptions)
-
listDomains
CompletableFuture<Void> listDomains(String id, ProjectListDomainsParams params)
-
listDomains
abstract CompletableFuture<Void> listDomains(ProjectListDomainsParams params, RequestOptions requestOptions)
-
listDomains
CompletableFuture<Void> listDomains(ProjectListDomainsParams params)
-
listDomains
CompletableFuture<Void> listDomains(String id, RequestOptions requestOptions)
-
listEnv
CompletableFuture<Void> listEnv(String id)
List all environment variables for a project (values are hidden unless decrypt=true)
-
listEnv
CompletableFuture<Void> listEnv(String id, ProjectListEnvParams params, RequestOptions requestOptions)
-
listEnv
CompletableFuture<Void> listEnv(String id, ProjectListEnvParams params)
-
listEnv
abstract CompletableFuture<Void> listEnv(ProjectListEnvParams params, RequestOptions requestOptions)
-
listEnv
CompletableFuture<Void> listEnv(ProjectListEnvParams params)
-
listEnv
CompletableFuture<Void> listEnv(String id, RequestOptions requestOptions)
-
-
-
-