Interface V1ServiceAsync
-
- All Implemented Interfaces:
public interface V1ServiceAsyncServerless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1ServiceAsync.WithRawResponseA view of V1ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract EnvironmentServiceAsyncenvironments()Serverless GPU and CPU infrastructure abstract SecretServiceAsyncsecrets()Serverless GPU and CPU infrastructure CompletableFuture<V1GetUsageResponse>getUsage()Returns detailed compute usage statistics and billing information for your organization. abstract CompletableFuture<V1GetUsageResponse>getUsage(V1GetUsageParams params, RequestOptions requestOptions)CompletableFuture<V1GetUsageResponse>getUsage(V1GetUsageParams params)CompletableFuture<V1GetUsageResponse>getUsage(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
abstract EnvironmentServiceAsync environments()
Serverless GPU and CPU infrastructure
-
secrets
abstract SecretServiceAsync secrets()
Serverless GPU and CPU infrastructure
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage()
Returns detailed compute usage statistics and billing information for your organization. Includes GPU and CPU hours, total runs, costs, and breakdowns by environment. Use optional query parameters to filter by specific year and month.
-
getUsage
abstract CompletableFuture<V1GetUsageResponse> getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage(V1GetUsageParams params)
-
getUsage
CompletableFuture<V1GetUsageResponse> getUsage(RequestOptions requestOptions)
-
-
-
-