Class ObjectServiceAsyncImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.async.vault.ObjectServiceAsync
public final class ObjectServiceAsyncImpl implements ObjectServiceAsync
Secure document storage with semantic search and GraphRAG
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classObjectServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dev.case.api.services.async.vault.ObjectServiceAsync
createPresignedUrl, createPresignedUrl, createPresignedUrl, delete, delete, delete, download, download, download, getOcrWords, getOcrWords, getOcrWords, getSummarizeJob, getSummarizeJob, getSummarizeJob, getText, getText, getText, list, list, list, list, list, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ObjectServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ObjectServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<ObjectRetrieveResponse> retrieve(ObjectRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ObjectUpdateResponse> update(ObjectUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ObjectListResponse> list(ObjectListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<ObjectDeleteResponse> delete(ObjectDeleteParams params, RequestOptions requestOptions)
-
createPresignedUrl
CompletableFuture<ObjectCreatePresignedUrlResponse> createPresignedUrl(ObjectCreatePresignedUrlParams params, RequestOptions requestOptions)
-
download
CompletableFuture<HttpResponse> download(ObjectDownloadParams params, RequestOptions requestOptions)
-
getOcrWords
CompletableFuture<ObjectGetOcrWordsResponse> getOcrWords(ObjectGetOcrWordsParams params, RequestOptions requestOptions)
-
getSummarizeJob
CompletableFuture<ObjectGetSummarizeJobResponse> getSummarizeJob(ObjectGetSummarizeJobParams params, RequestOptions requestOptions)
-
getText
CompletableFuture<ObjectGetTextResponse> getText(ObjectGetTextParams params, RequestOptions requestOptions)
-
-
-
-