Package dev.case.api.services.blocking
Class OcrServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.OcrService
public final class OcrServiceImpl implements OcrService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOcrServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OcrService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OcrServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. V1Servicev1()Extract text from PDFs, images, and scanned documents -
-
Method Detail
-
withRawResponse
OcrService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OcrService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-