Package dev.case.api.services.blocking
Interface SkillService
-
- All Implemented Interfaces:
public interface SkillServiceSearch and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSkillService.WithRawResponseA view of SkillService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SkillService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SkillServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SkillReadResponseread(String slug)Read the full content of a legal skill by its slug. SkillReadResponseread(String slug, SkillReadParams params, RequestOptions requestOptions)SkillReadResponseread(String slug, SkillReadParams params)abstract SkillReadResponseread(SkillReadParams params, RequestOptions requestOptions)SkillReadResponseread(SkillReadParams params)SkillReadResponseread(String slug, RequestOptions requestOptions)SkillResolveResponseresolve(SkillResolveParams params)Search the Legal Skills Store using hybrid search (text + tag + semantic). abstract SkillResolveResponseresolve(SkillResolveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SkillService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SkillService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
read
SkillReadResponse read(String slug)
Read the full content of a legal skill by its slug. Returns markdown content, tags, and metadata.
-
read
SkillReadResponse read(String slug, SkillReadParams params, RequestOptions requestOptions)
-
read
SkillReadResponse read(String slug, SkillReadParams params)
-
read
abstract SkillReadResponse read(SkillReadParams params, RequestOptions requestOptions)
-
read
SkillReadResponse read(SkillReadParams params)
-
read
SkillReadResponse read(String slug, RequestOptions requestOptions)
-
resolve
SkillResolveResponse resolve(SkillResolveParams params)
Search the Legal Skills Store using hybrid search (text + tag + semantic). Returns ranked results with relevance scores.
-
resolve
abstract SkillResolveResponse resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-