Package dev.case.api.services.blocking
Class SkillServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SkillService
public final class SkillServiceImpl implements SkillService
Search and read legal AI skills for agents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSkillServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SkillService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SkillServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SkillReadResponseread(SkillReadParams params, RequestOptions requestOptions)SkillResolveResponseresolve(SkillResolveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SkillService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SkillService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
read
SkillReadResponse read(SkillReadParams params, RequestOptions requestOptions)
-
resolve
SkillResolveResponse resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-