Package dev.case.api.services.blocking
Class SkillServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.SkillService.WithRawResponse
public final class SkillServiceImpl.WithRawResponseImpl implements SkillService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SkillService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<SkillReadResponse>read(SkillReadParams params, RequestOptions requestOptions)HttpResponseFor<SkillResolveResponse>resolve(SkillResolveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
SkillService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
read
HttpResponseFor<SkillReadResponse> read(SkillReadParams params, RequestOptions requestOptions)
-
resolve
HttpResponseFor<SkillResolveResponse> resolve(SkillResolveParams params, RequestOptions requestOptions)
-
-
-
-