Package dev.case.api.services.blocking
Interface VoiceService.WithRawResponse
-
- All Implemented Interfaces:
public interface VoiceService.WithRawResponseA view of VoiceService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract VoiceService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract StreamingService.WithRawResponsestreaming()abstract TranscriptionService.WithRawResponsetranscription()abstract V1Service.WithRawResponsev1()-
-
Method Detail
-
withOptions
abstract VoiceService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
streaming
abstract StreamingService.WithRawResponse streaming()
-
transcription
abstract TranscriptionService.WithRawResponse transcription()
-
v1
abstract V1Service.WithRawResponse v1()
-
-
-
-