Interface V1Service
-
- All Implemented Interfaces:
public interface V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentServiceagents()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract RunServicerun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract ExecuteServiceexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows abstract ChatServicechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
abstract AgentService agents()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
run
abstract RunService run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
abstract ExecuteService execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
abstract ChatService chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-