Interface V1Service
-
- All Implemented Interfaces:
public interface V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentServiceagents()abstract RunServicerun()abstract ExecuteServiceexecute()abstract ChatServicechat()-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
abstract AgentService agents()
-
run
abstract RunService run()
-
execute
abstract ExecuteService execute()
-
chat
abstract ChatService chat()
-
-
-
-