Interface V1Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AgentService.WithRawResponseagents()abstract RunService.WithRawResponserun()abstract ExecuteService.WithRawResponseexecute()abstract ChatService.WithRawResponsechat()-
-
Method Detail
-
withOptions
abstract V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
abstract AgentService.WithRawResponse agents()
-
run
abstract RunService.WithRawResponse run()
-
execute
abstract ExecuteService.WithRawResponse execute()
-
chat
abstract ChatService.WithRawResponse chat()
-
-
-
-