Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.V1Service
public final class V1ServiceImpl implements V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentServiceagents()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows RunServicerun()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ExecuteServiceexecute()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows ChatServicechat()Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows -
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
AgentService agents()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
run
RunService run()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
execute
ExecuteService execute()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
chat
ChatService chat()
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
-
-