Class V1ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.agent.V1Service.WithRawResponse
public final class V1ServiceImpl.WithRawResponseImpl implements V1Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentService.WithRawResponseagents()RunService.WithRawResponserun()ExecuteService.WithRawResponseexecute()ChatService.WithRawResponsechat()-
-
Method Detail
-
withOptions
V1Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
agents
AgentService.WithRawResponse agents()
-
execute
ExecuteService.WithRawResponse execute()
-
chat
ChatService.WithRawResponse chat()
-
-
-
-