Interface V2Service

  • All Implemented Interfaces:

    
    public interface V2Service
    
                        
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public interface V2Service.WithRawResponse

      A view of V2Service that provides access to raw HTTP responses for each method.

    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Method Summary

      Modifier and Type Method Description
      abstract V2Service.WithRawResponse withRawResponse() Returns a view of this service that provides access to raw HTTP responses for each method.
      abstract V2Service withOptions(Consumer<ClientOptions.Builder> modifier) Returns a view of this service with the given option modifications applied.
      abstract RunService run() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      abstract ExecuteService execute() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      abstract ChatService chat() Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

    • Method Detail

      • run

         abstract RunService run()

        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows

      • execute

         abstract ExecuteService execute()

        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows

      • chat

         abstract ChatService chat()

        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows