Interface ExecuteService
-
- All Implemented Interfaces:
public interface ExecuteService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExecuteService.WithRawResponseA view of ExecuteService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExecuteService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ExecuteServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ExecuteCreateResponsecreate(ExecuteCreateParams params)Creates an ephemeral agent and immediately executes a run. abstract ExecuteCreateResponsecreate(ExecuteCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ExecuteService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExecuteService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
ExecuteCreateResponse create(ExecuteCreateParams params)
Creates an ephemeral agent and immediately executes a run. Returns the run ID for polling status and results. This is the fastest way to run an agent without managing agent lifecycle.
-
create
abstract ExecuteCreateResponse create(ExecuteCreateParams params, RequestOptions requestOptions)
-
-
-
-