Interface DeploymentService
-
- All Implemented Interfaces:
public interface DeploymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDeploymentService.WithRawResponseA view of DeploymentService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DeploymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DeploymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(DeploymentCreateParams params)
Trigger a new deployment for a project
-
create
abstract Unit create(DeploymentCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(String id, DeploymentRetrieveParams params)
Get details of a specific deployment including build logs
-
retrieve
Unit retrieve(String id, DeploymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(DeploymentRetrieveParams params)
-
retrieve
abstract Unit retrieve(DeploymentRetrieveParams params, RequestOptions requestOptions)
-
list
Unit list(DeploymentListParams params)
List deployments for a project
-
list
abstract Unit list(DeploymentListParams params, RequestOptions requestOptions)
-
cancel
Unit cancel(String id, DeploymentCancelParams params)
Cancel a running deployment
-
cancel
Unit cancel(String id, DeploymentCancelParams params, RequestOptions requestOptions)
-
cancel
Unit cancel(DeploymentCancelParams params)
-
cancel
abstract Unit cancel(DeploymentCancelParams params, RequestOptions requestOptions)
-
createFromFiles
Unit createFromFiles()
Create a deployment from raw file contents (for Thurgood sandbox deployments)
-
createFromFiles
abstract Unit createFromFiles(DeploymentCreateFromFilesParams params, RequestOptions requestOptions)
-
createFromFiles
Unit createFromFiles(DeploymentCreateFromFilesParams params)
-
createFromFiles
Unit createFromFiles(RequestOptions requestOptions)
-
getLogs
Unit getLogs(String id, DeploymentGetLogsParams params)
Get build logs for a specific deployment
-
getLogs
Unit getLogs(String id, DeploymentGetLogsParams params, RequestOptions requestOptions)
-
getLogs
Unit getLogs(DeploymentGetLogsParams params)
-
getLogs
abstract Unit getLogs(DeploymentGetLogsParams params, RequestOptions requestOptions)
-
getStatus
Unit getStatus(String id, DeploymentGetStatusParams params, RequestOptions requestOptions)
-
getStatus
Unit getStatus(String id, DeploymentGetStatusParams params)
-
getStatus
abstract Unit getStatus(DeploymentGetStatusParams params, RequestOptions requestOptions)
-
getStatus
Unit getStatus(DeploymentGetStatusParams params)
-
getStatus
Unit getStatus(String id, RequestOptions requestOptions)
-
stream
Unit stream(String id, DeploymentStreamParams params)
Stream real-time deployment progress events via Server-Sent Events
-
stream
Unit stream(String id, DeploymentStreamParams params, RequestOptions requestOptions)
-
stream
Unit stream(DeploymentStreamParams params)
-
stream
abstract Unit stream(DeploymentStreamParams params, RequestOptions requestOptions)
-
-
-
-