Interface V1Service
-
- All Implemented Interfaces:
public interface V1ServiceServerless GPU and CPU infrastructure
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV1Service.WithRawResponseA view of V1Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract EnvironmentServiceenvironments()Serverless GPU and CPU infrastructure abstract SecretServicesecrets()Serverless GPU and CPU infrastructure V1GetUsageResponsegetUsage()Returns detailed compute usage statistics and billing information for your organization. abstract V1GetUsageResponsegetUsage(V1GetUsageParams params, RequestOptions requestOptions)V1GetUsageResponsegetUsage(V1GetUsageParams params)V1GetUsageResponsegetUsage(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
abstract EnvironmentService environments()
Serverless GPU and CPU infrastructure
-
secrets
abstract SecretService secrets()
Serverless GPU and CPU infrastructure
-
getUsage
V1GetUsageResponse getUsage()
Returns detailed compute usage statistics and billing information for your organization. Includes GPU and CPU hours, total runs, costs, and breakdowns by environment. Use optional query parameters to filter by specific year and month.
-
getUsage
abstract V1GetUsageResponse getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
getUsage
V1GetUsageResponse getUsage(V1GetUsageParams params)
-
getUsage
V1GetUsageResponse getUsage(RequestOptions requestOptions)
-
-
-
-