Class V1ServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.compute.V1Service
public final class V1ServiceImpl implements V1Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV1ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V1Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V1ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EnvironmentServiceenvironments()InstanceTypeServiceinstanceTypes()InstanceServiceinstances()SecretServicesecrets()UnitgetPricing(V1GetPricingParams params, RequestOptions requestOptions)V1GetUsageResponsegetUsage(V1GetUsageParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
V1Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V1Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
environments
EnvironmentService environments()
-
instanceTypes
InstanceTypeService instanceTypes()
-
instances
InstanceService instances()
-
secrets
SecretService secrets()
-
getPricing
Unit getPricing(V1GetPricingParams params, RequestOptions requestOptions)
-
getUsage
V1GetUsageResponse getUsage(V1GetUsageParams params, RequestOptions requestOptions)
-
-
-
-