Class InboxServiceImpl
-
- All Implemented Interfaces:
-
dev.case.api.services.blocking.mail.v1.InboxService
public final class InboxServiceImpl implements InboxService
Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboxServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboxService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboxServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Unitcreate(InboxCreateParams params, RequestOptions requestOptions)Unitretrieve(InboxRetrieveParams params, RequestOptions requestOptions)Unitlist(InboxListParams params, RequestOptions requestOptions)Unitdelete(InboxDeleteParams params, RequestOptions requestOptions)UnitgetAttachment(InboxGetAttachmentParams params, RequestOptions requestOptions)UnitgetMessage(InboxGetMessageParams params, RequestOptions requestOptions)UnitlistMessages(InboxListMessagesParams params, RequestOptions requestOptions)Unitreply(InboxReplyParams params, RequestOptions requestOptions)Unitsend(InboxSendParams params, RequestOptions requestOptions)-
Methods inherited from class dev.case.api.services.blocking.mail.v1.InboxService
create, create, create, delete, delete, delete, delete, delete, getAttachment, getAttachment, getAttachment, getMessage, getMessage, getMessage, list, list, list, listMessages, listMessages, listMessages, listMessages, listMessages, reply, reply, reply, retrieve, retrieve, retrieve, retrieve, retrieve, send, send, send, send, send -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboxService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboxService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Unit create(InboxCreateParams params, RequestOptions requestOptions)
-
retrieve
Unit retrieve(InboxRetrieveParams params, RequestOptions requestOptions)
-
list
Unit list(InboxListParams params, RequestOptions requestOptions)
-
delete
Unit delete(InboxDeleteParams params, RequestOptions requestOptions)
-
getAttachment
Unit getAttachment(InboxGetAttachmentParams params, RequestOptions requestOptions)
-
getMessage
Unit getMessage(InboxGetMessageParams params, RequestOptions requestOptions)
-
listMessages
Unit listMessages(InboxListMessagesParams params, RequestOptions requestOptions)
-
reply
Unit reply(InboxReplyParams params, RequestOptions requestOptions)
-
send
Unit send(InboxSendParams params, RequestOptions requestOptions)
-
-
-
-