A
B
C
D
E
F
G
H
I
J
K
L
M
N
O
P
Q
R
S
T
U
V
W
Y
_
J
- jobId() - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobParams
- jobId(java.util.Optional) - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobParams.Builder
- Alias for calling Builder.jobId with
jobId.orElse(null). - jobId(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobParams.Builder
- jobId() - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobResponse
- Case.
- jobId(dev.case.api.core.JsonField) - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobResponse.Builder
- Sets Builder.jobId to an arbitrary JSON value.
- jobId(java.lang.String) - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobResponse.Builder
- Case.
- JSON - enum entry in dev.case.api.models.format.v1.V1CreateDocumentParams.InputFormat.Known
- JSON - enum entry in dev.case.api.models.format.v1.V1CreateDocumentParams.InputFormat.Value
- JSON - enum entry in dev.case.api.models.ocr.v1.V1DownloadParams.Type.Known
- JSON - enum entry in dev.case.api.models.ocr.v1.V1DownloadParams.Type.Value
- JSON - enum entry in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables.Format.Known
- JSON - enum entry in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables.Format.Value
- JSON - enum entry in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Format.Known
- JSON - enum entry in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Format.Value
- JsonArray - class in dev.case.api.core
- A JsonValue representing a JSON array value.
- JsonBoolean - class in dev.case.api.core
- A JsonValue representing a JSON boolean value.
- JsonField - class in dev.case.api.core
- A class representing a serializable JSON field.
- JsonField.Deserializer - class in dev.case.api.core.JsonField
- JsonField.IsMissing - class in dev.case.api.core.JsonField
- This class is a Jackson filter that can be used to exclude missing properties from objects.
- JsonField.Visitor - class in dev.case.api.core.JsonField
- An interface that defines how to map each possible state of a
JsonField<T>to a value of type R. - jsonMapper(com.fasterxml.jackson.databind.json.JsonMapper) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
- The Jackson JSON mapper to use for serializing and deserializing JSON.
- jsonMapper(com.fasterxml.jackson.databind.json.JsonMapper) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
- The Jackson JSON mapper to use for serializing and deserializing JSON.
- jsonMapper() - function in dev.case.api.core.ClientOptions
- The Jackson JSON mapper to use for serializing and deserializing JSON.
- jsonMapper(com.fasterxml.jackson.databind.json.JsonMapper) - function in dev.case.api.core.ClientOptions.Builder
- The Jackson JSON mapper to use for serializing and deserializing JSON.
- jsonMapper() - function in dev.case.api.core.ObjectMappers
- JsonMissing - class in dev.case.api.core
- A JsonValue representing an omitted JSON field.
- JsonMissing.Serializer - class in dev.case.api.core.JsonMissing
- JsonNull - class in dev.case.api.core
- A JsonValue representing a JSON
nullvalue. - JsonNumber - class in dev.case.api.core
- A JsonValue representing a JSON number value.
- JsonObject - class in dev.case.api.core
- A JsonValue representing a JSON object value.
- JsonString - class in dev.case.api.core
- A JsonValue representing a JSON string value.
- JsonValue - class in dev.case.api.core
- A class representing an arbitrary JSON value.
- JsonValue.Deserializer - class in dev.case.api.core.JsonValue
- JsonValue.Visitor - class in dev.case.api.core.JsonValue
- An interface that defines how to map each variant state of a JsonValue to a value of type R.
- jurisdiction() - function in dev.case.api.models.legal.v1.V1FindParams
- Optional jurisdiction ID from resolveJurisdiction (e.g.
- jurisdiction() - function in dev.case.api.models.legal.v1.V1FindParams.Body
- Optional jurisdiction ID from resolveJurisdiction (e.g.
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1FindParams.Body.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1FindParams.Body.Builder
- Optional jurisdiction ID from resolveJurisdiction (e.g.
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1FindParams.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1FindParams.Builder
- Optional jurisdiction ID from resolveJurisdiction (e.g.
- jurisdiction() - function in dev.case.api.models.legal.v1.V1FindResponse
- Jurisdiction filter applied
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1FindResponse.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1FindResponse.Builder
- Jurisdiction filter applied
- jurisdiction() - function in dev.case.api.models.legal.v1.V1ResearchParams
- Optional jurisdiction ID from resolveJurisdiction
- jurisdiction() - function in dev.case.api.models.legal.v1.V1ResearchParams.Body
- Optional jurisdiction ID from resolveJurisdiction
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ResearchParams.Body.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1ResearchParams.Body.Builder
- Optional jurisdiction ID from resolveJurisdiction
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ResearchParams.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1ResearchParams.Builder
- Optional jurisdiction ID from resolveJurisdiction
- jurisdiction() - function in dev.case.api.models.legal.v1.V1ResearchResponse
- Jurisdiction filter applied
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Builder
- Jurisdiction filter applied
- jurisdiction() - function in dev.case.api.models.legal.v1.V1SimilarParams
- Optional jurisdiction ID to filter results
- jurisdiction() - function in dev.case.api.models.legal.v1.V1SimilarParams.Body
- Optional jurisdiction ID to filter results
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1SimilarParams.Body.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1SimilarParams.Body.Builder
- Optional jurisdiction ID to filter results
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1SimilarParams.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1SimilarParams.Builder
- Optional jurisdiction ID to filter results
- jurisdiction() - function in dev.case.api.models.legal.v1.V1SimilarResponse
- Jurisdiction filter applied
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1SimilarResponse.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(java.lang.String) - function in dev.case.api.models.legal.v1.V1SimilarResponse.Builder
- Jurisdiction filter applied
- jurisdiction() - function in dev.case.api.models.privilege.v1.V1DetectParams
- Jurisdiction for privilege rules
- jurisdiction() - function in dev.case.api.models.privilege.v1.V1DetectParams.Body
- Jurisdiction for privilege rules
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.privilege.v1.V1DetectParams.Body.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(dev.case.api.models.privilege.v1.V1DetectParams.Jurisdiction) - function in dev.case.api.models.privilege.v1.V1DetectParams.Body.Builder
- Jurisdiction for privilege rules
- jurisdiction(dev.case.api.core.JsonField) - function in dev.case.api.models.privilege.v1.V1DetectParams.Builder
- Sets Builder.jurisdiction to an arbitrary JSON value.
- jurisdiction(dev.case.api.models.privilege.v1.V1DetectParams.Jurisdiction) - function in dev.case.api.models.privilege.v1.V1DetectParams.Builder
- Jurisdiction for privilege rules
- jurisdictions() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse
- jurisdictions(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Builder
- Sets Builder.jurisdictions to an arbitrary JSON value.
- jurisdictions(java.util.List) - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Builder