A
B
C
D
E
F
G
H
I
J
K
L
M
N
O
P
Q
R
S
T
U
V
W
Y
_
H
- handle(dev.case.api.core.http.HttpResponse) - function in dev.case.api.core.http.HttpResponse.Handler
- handledType() - function in com.fasterxml.jackson.databind.deser.std.StdDeserializer
- handledType() - function in com.fasterxml.jackson.databind.ser.std.StdSerializer
- handledType() - function in com.fasterxml.jackson.databind.ser.std.StdSerializer
- hashCode() - function in dev.case.api.core.JsonArray
- hashCode() - function in dev.case.api.core.JsonBoolean
- hashCode() - function in dev.case.api.core.JsonField.IsMissing
- hashCode() - function in dev.case.api.core.JsonNumber
- hashCode() - function in dev.case.api.core.JsonObject
- hashCode() - function in dev.case.api.core.JsonString
- hashCode() - function in dev.case.api.core.KnownValue
- hashCode() - function in dev.case.api.core.MultipartField
- hashCode() - function in dev.case.api.core.Timeout
- hashCode() - function in dev.case.api.core.http.Headers
- hashCode() - function in dev.case.api.core.http.QueryParams
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentCreateParams
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Body
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentCreateParams.Sandbox
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentCreateResponse
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentDeleteParams
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentDeleteResponse
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentListParams
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentListResponse
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentListResponse.Agent
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentRetrieveParams
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentRetrieveResponse
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentUpdateParams.Body
- hashCode() - function in dev.case.api.models.agent.v1.agents.AgentUpdateResponse
- hashCode() - function in dev.case.api.models.agent.v1.run.RunCancelParams
- hashCode() - function in dev.case.api.models.agent.v1.run.RunCancelResponse
- hashCode() - function in dev.case.api.models.agent.v1.run.RunCancelResponse.Status
- hashCode() - function in dev.case.api.models.agent.v1.run.RunCreateParams
- hashCode() - function in dev.case.api.models.agent.v1.run.RunCreateParams.Body
- hashCode() - function in dev.case.api.models.agent.v1.run.RunCreateResponse
- hashCode() - function in dev.case.api.models.agent.v1.run.RunCreateResponse.Status
- hashCode() - function in dev.case.api.models.agent.v1.run.RunExecParams
- hashCode() - function in dev.case.api.models.agent.v1.run.RunExecResponse
- hashCode() - function in dev.case.api.models.agent.v1.run.RunExecResponse.Status
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsParams
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Result
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Result.Logs
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Status
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Step
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Step.Type
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetDetailsResponse.Usage
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetStatusParams
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetStatusResponse
- hashCode() - function in dev.case.api.models.agent.v1.run.RunGetStatusResponse.Status
- hashCode() - function in dev.case.api.models.agent.v1.run.RunWatchParams
- hashCode() - function in dev.case.api.models.agent.v1.run.RunWatchParams.Body
- hashCode() - function in dev.case.api.models.agent.v1.run.RunWatchResponse
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentCancelParams
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentCancelParams.Body
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentCreateFromFilesParams
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentCreateParams
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentCreateParams.Body
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentCreateParams.Target
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentGetLogsParams
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentGetStatusParams
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentListParams
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentListParams.Target
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentRetrieveParams
- hashCode() - function in dev.case.api.models.applications.v1.deployments.DeploymentStreamParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateDeploymentParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateDeploymentParams.Body
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateDeploymentParams.EnvironmentVariable
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateDeploymentParams.EnvironmentVariable.Target
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateDeploymentParams.EnvironmentVariable.Type
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateDomainParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateDomainParams.Body
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateEnvParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateEnvParams.Body
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateEnvParams.Target
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateEnvParams.Type
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.Body
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.EnvironmentVariable
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.EnvironmentVariable.Target
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectCreateParams.EnvironmentVariable.Type
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectDeleteDomainParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectDeleteEnvParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectDeleteParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectGetRuntimeLogsParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListDeploymentsParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListDeploymentsParams.Target
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListDomainsParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListEnvParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListParams
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListResponse
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListResponse.Project
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectListResponse.Project.Domain
- hashCode() - function in dev.case.api.models.applications.v1.projects.ProjectRetrieveParams
- hashCode() - function in dev.case.api.models.applications.v1.workflows.WorkflowGetStatusParams
- hashCode() - function in dev.case.api.models.compute.v1.V1GetPricingParams
- hashCode() - function in dev.case.api.models.compute.v1.V1GetUsageParams
- hashCode() - function in dev.case.api.models.compute.v1.V1GetUsageResponse
- hashCode() - function in dev.case.api.models.compute.v1.V1GetUsageResponse.ByEnvironment
- hashCode() - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Period
- hashCode() - function in dev.case.api.models.compute.v1.V1GetUsageResponse.Summary
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentCreateParams
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentCreateParams.Body
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentCreateResponse
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentCreateResponse.Status
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentDeleteParams
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentDeleteResponse
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentListParams
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentListResponse
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentListResponse.Environment
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentRetrieveParams
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentRetrieveResponse
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentSetDefaultParams
- hashCode() - function in dev.case.api.models.compute.v1.environments.EnvironmentSetDefaultResponse
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceCreateParams
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceCreateParams.Body
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceCreateResponse
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceDeleteParams
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceDeleteResponse
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceListParams
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceListResponse
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceListResponse.Instance
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceListResponse.Instance.Status
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceRetrieveParams
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceRetrieveResponse
- hashCode() - function in dev.case.api.models.compute.v1.instances.InstanceRetrieveResponse.Ssh
- hashCode() - function in dev.case.api.models.compute.v1.instancetypes.InstanceTypeListParams
- hashCode() - function in dev.case.api.models.compute.v1.instancetypes.InstanceTypeListResponse
- hashCode() - function in dev.case.api.models.compute.v1.instancetypes.InstanceTypeListResponse.InstanceType
- hashCode() - function in dev.case.api.models.compute.v1.instancetypes.InstanceTypeListResponse.InstanceType.Specs
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretCreateParams
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretCreateParams.Body
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretCreateResponse
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretDeleteGroupParams
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretDeleteGroupResponse
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretListParams
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretListResponse
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretListResponse.Group
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretRetrieveGroupParams
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretRetrieveGroupResponse
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretRetrieveGroupResponse.Group
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretRetrieveGroupResponse.Key
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretUpdateGroupParams
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretUpdateGroupParams.Body
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretUpdateGroupParams.Secrets
- hashCode() - function in dev.case.api.models.compute.v1.secrets.SecretUpdateGroupResponse
- hashCode() - function in dev.case.api.models.database.v1.V1GetUsageParams
- hashCode() - function in dev.case.api.models.database.v1.V1GetUsageResponse
- hashCode() - function in dev.case.api.models.database.v1.V1GetUsageResponse.Period
- hashCode() - function in dev.case.api.models.database.v1.V1GetUsageResponse.Pricing
- hashCode() - function in dev.case.api.models.database.v1.V1GetUsageResponse.Project
- hashCode() - function in dev.case.api.models.database.v1.V1GetUsageResponse.Project.Costs
- hashCode() - function in dev.case.api.models.database.v1.V1GetUsageResponse.Totals
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateBranchParams
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateBranchParams.Body
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateBranchResponse
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateParams
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateParams.Body
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateParams.Region
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateResponse
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateResponse.DefaultBranch
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectCreateResponse.Status
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectDeleteParams
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectDeleteResponse
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectGetConnectionParams
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectGetConnectionResponse
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListBranchesParams
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListBranchesResponse
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListBranchesResponse.Branch
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListParams
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListResponse
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListResponse.Project
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListResponse.Project.LinkedDeployment
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListResponse.Project.LinkedDeployment.Type
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectListResponse.Project.Status
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectRetrieveParams
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectRetrieveResponse
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectRetrieveResponse.Branch
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectRetrieveResponse.Database
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectRetrieveResponse.LinkedDeployment
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectRetrieveResponse.LinkedDeployment.Type
- hashCode() - function in dev.case.api.models.database.v1.projects.ProjectRetrieveResponse.Status
- hashCode() - function in dev.case.api.models.format.v1.V1CreateDocumentParams
- hashCode() - function in dev.case.api.models.format.v1.V1CreateDocumentParams.Body
- hashCode() - function in dev.case.api.models.format.v1.V1CreateDocumentParams.InputFormat
- hashCode() - function in dev.case.api.models.format.v1.V1CreateDocumentParams.Options
- hashCode() - function in dev.case.api.models.format.v1.V1CreateDocumentParams.Options.Component
- hashCode() - function in dev.case.api.models.format.v1.V1CreateDocumentParams.OutputFormat
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateCreateParams
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateCreateParams.Body
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateCreateParams.Type
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateCreateResponse
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateListParams
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateListResponse
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateListResponse.Template
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateRetrieveParams
- hashCode() - function in dev.case.api.models.format.v1.templates.TemplateRetrieveResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1FindParams
- hashCode() - function in dev.case.api.models.legal.v1.V1FindParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1FindResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1FindResponse.Candidate
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlParams
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse.Citations
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse.Citations.Case
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse.Citations.Regulation
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse.Citations.Statute
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsParams
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsResponse.Citation
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsResponse.Citation.Components
- hashCode() - function in dev.case.api.models.legal.v1.V1GetCitationsResponse.Citation.Span
- hashCode() - function in dev.case.api.models.legal.v1.V1GetFullTextParams
- hashCode() - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1GetFullTextResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsParams
- hashCode() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Jurisdiction
- hashCode() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Jurisdiction.Level
- hashCode() - function in dev.case.api.models.legal.v1.V1PatentSearchParams
- hashCode() - function in dev.case.api.models.legal.v1.V1PatentSearchParams.ApplicationType
- hashCode() - function in dev.case.api.models.legal.v1.V1PatentSearchParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1PatentSearchParams.SortBy
- hashCode() - function in dev.case.api.models.legal.v1.V1PatentSearchParams.SortOrder
- hashCode() - function in dev.case.api.models.legal.v1.V1PatentSearchResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1PatentSearchResponse.Result
- hashCode() - function in dev.case.api.models.legal.v1.V1ResearchParams
- hashCode() - function in dev.case.api.models.legal.v1.V1ResearchParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1ResearchResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1ResearchResponse.Candidate
- hashCode() - function in dev.case.api.models.legal.v1.V1SimilarParams
- hashCode() - function in dev.case.api.models.legal.v1.V1SimilarParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1SimilarResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1SimilarResponse.SimilarSource
- hashCode() - function in dev.case.api.models.legal.v1.V1TrademarkSearchParams
- hashCode() - function in dev.case.api.models.legal.v1.V1TrademarkSearchParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.GoodsAndService
- hashCode() - function in dev.case.api.models.legal.v1.V1TrademarkSearchResponse.Owner
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyParams
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyParams.Body
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Citation
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.Candidate
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.Case
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.Span
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.Status
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.VerificationSource
- hashCode() - function in dev.case.api.models.legal.v1.V1VerifyResponse.Summary
- hashCode() - function in dev.case.api.models.llm.LlmGetConfigParams
- hashCode() - function in dev.case.api.models.llm.LlmGetConfigResponse
- hashCode() - function in dev.case.api.models.llm.LlmGetConfigResponse.Model
- hashCode() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams
- hashCode() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.Body
- hashCode() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.EncodingFormat
- hashCode() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingParams.Input
- hashCode() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingResponse
- hashCode() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingResponse.Data
- hashCode() - function in dev.case.api.models.llm.v1.V1CreateEmbeddingResponse.Usage
- hashCode() - function in dev.case.api.models.llm.v1.V1ListModelsParams
- hashCode() - function in dev.case.api.models.llm.v1.V1ListModelsResponse
- hashCode() - function in dev.case.api.models.llm.v1.V1ListModelsResponse.Data
- hashCode() - function in dev.case.api.models.llm.v1.V1ListModelsResponse.Data.Pricing
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Body
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Message
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionParams.Message.Role
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Choice.Message
- hashCode() - function in dev.case.api.models.llm.v1.chat.ChatCreateCompletionResponse.Usage
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateParams
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateParams.Body
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateParams.Message
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateParams.Message.Role
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateParams.Metadata
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateResponse
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateResponse.Result
- hashCode() - function in dev.case.api.models.memory.v1.V1CreateResponse.Result.Event
- hashCode() - function in dev.case.api.models.memory.v1.V1DeleteAllParams
- hashCode() - function in dev.case.api.models.memory.v1.V1DeleteAllResponse
- hashCode() - function in dev.case.api.models.memory.v1.V1DeleteParams
- hashCode() - function in dev.case.api.models.memory.v1.V1DeleteResponse
- hashCode() - function in dev.case.api.models.memory.v1.V1ListParams
- hashCode() - function in dev.case.api.models.memory.v1.V1ListResponse
- hashCode() - function in dev.case.api.models.memory.v1.V1ListResponse.Result
- hashCode() - function in dev.case.api.models.memory.v1.V1RetrieveParams
- hashCode() - function in dev.case.api.models.memory.v1.V1RetrieveResponse
- hashCode() - function in dev.case.api.models.memory.v1.V1SearchParams
- hashCode() - function in dev.case.api.models.memory.v1.V1SearchParams.Body
- hashCode() - function in dev.case.api.models.memory.v1.V1SearchResponse
- hashCode() - function in dev.case.api.models.memory.v1.V1SearchResponse.Result
- hashCode() - function in dev.case.api.models.memory.v1.V1SearchResponse.Result.Tags
- hashCode() - function in dev.case.api.models.ocr.v1.V1DownloadParams
- hashCode() - function in dev.case.api.models.ocr.v1.V1DownloadParams.Type
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Body
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Engine
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Embed
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Forms
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessParams.Features.Tables.Format
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessResponse
- hashCode() - function in dev.case.api.models.ocr.v1.V1ProcessResponse.Status
- hashCode() - function in dev.case.api.models.ocr.v1.V1RetrieveParams
- hashCode() - function in dev.case.api.models.ocr.v1.V1RetrieveResponse
- hashCode() - function in dev.case.api.models.ocr.v1.V1RetrieveResponse.Status
- hashCode() - function in dev.case.api.models.privilege.v1.V1DetectParams
- hashCode() - function in dev.case.api.models.privilege.v1.V1DetectParams.Body
- hashCode() - function in dev.case.api.models.privilege.v1.V1DetectParams.Category
- hashCode() - function in dev.case.api.models.privilege.v1.V1DetectParams.Jurisdiction
- hashCode() - function in dev.case.api.models.privilege.v1.V1DetectResponse
- hashCode() - function in dev.case.api.models.privilege.v1.V1DetectResponse.Category
- hashCode() - function in dev.case.api.models.privilege.v1.V1DetectResponse.Recommendation
- hashCode() - function in dev.case.api.models.search.v1.V1AnswerParams
- hashCode() - function in dev.case.api.models.search.v1.V1AnswerParams.Body
- hashCode() - function in dev.case.api.models.search.v1.V1AnswerParams.SearchType
- hashCode() - function in dev.case.api.models.search.v1.V1AnswerResponse
- hashCode() - function in dev.case.api.models.search.v1.V1AnswerResponse.Citation
- hashCode() - function in dev.case.api.models.search.v1.V1ContentsParams
- hashCode() - function in dev.case.api.models.search.v1.V1ContentsParams.Body
- hashCode() - function in dev.case.api.models.search.v1.V1ContentsResponse
- hashCode() - function in dev.case.api.models.search.v1.V1ContentsResponse.Result
- hashCode() - function in dev.case.api.models.search.v1.V1ResearchParams
- hashCode() - function in dev.case.api.models.search.v1.V1ResearchParams.Body
- hashCode() - function in dev.case.api.models.search.v1.V1ResearchParams.Model
- hashCode() - function in dev.case.api.models.search.v1.V1ResearchResponse
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchParams
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Model
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Results
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Results.Section
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Results.Section.Source
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Results.Source
- hashCode() - function in dev.case.api.models.search.v1.V1RetrieveResearchResponse.Status
- hashCode() - function in dev.case.api.models.search.v1.V1SearchParams
- hashCode() - function in dev.case.api.models.search.v1.V1SearchParams.Body
- hashCode() - function in dev.case.api.models.search.v1.V1SearchParams.Type
- hashCode() - function in dev.case.api.models.search.v1.V1SearchResponse
- hashCode() - function in dev.case.api.models.search.v1.V1SearchResponse.Result
- hashCode() - function in dev.case.api.models.search.v1.V1SimilarParams
- hashCode() - function in dev.case.api.models.search.v1.V1SimilarParams.Body
- hashCode() - function in dev.case.api.models.search.v1.V1SimilarResponse
- hashCode() - function in dev.case.api.models.search.v1.V1SimilarResponse.Result
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Body
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Document
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Field
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Field.Options
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Field.Type
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Field.Value
- hashCode() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.OutputFormat
- hashCode() - function in dev.case.api.models.superdoc.v1.V1ConvertParams
- hashCode() - function in dev.case.api.models.superdoc.v1.V1ConvertParams.Body
- hashCode() - function in dev.case.api.models.superdoc.v1.V1ConvertParams.From
- hashCode() - function in dev.case.api.models.superdoc.v1.V1ConvertParams.To
- hashCode() - function in dev.case.api.models.system.SystemListServicesParams
- hashCode() - function in dev.case.api.models.system.SystemListServicesResponse
- hashCode() - function in dev.case.api.models.system.SystemListServicesResponse.Service
- hashCode() - function in dev.case.api.models.translate.v1.V1DetectParams
- hashCode() - function in dev.case.api.models.translate.v1.V1DetectParams.Body
- hashCode() - function in dev.case.api.models.translate.v1.V1DetectParams.Q
- hashCode() - function in dev.case.api.models.translate.v1.V1DetectResponse
- hashCode() - function in dev.case.api.models.translate.v1.V1DetectResponse.Data
- hashCode() - function in dev.case.api.models.translate.v1.V1DetectResponse.Data.UnnamedSchemaWithArrayParent0
- hashCode() - function in dev.case.api.models.translate.v1.V1ListLanguagesParams
- hashCode() - function in dev.case.api.models.translate.v1.V1ListLanguagesParams.Model
- hashCode() - function in dev.case.api.models.translate.v1.V1ListLanguagesResponse
- hashCode() - function in dev.case.api.models.translate.v1.V1ListLanguagesResponse.Data
- hashCode() - function in dev.case.api.models.translate.v1.V1ListLanguagesResponse.Data.Language
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateParams
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateParams.Body
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateParams.Format
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateParams.Model
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateParams.Q
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateResponse
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateResponse.Data
- hashCode() - function in dev.case.api.models.translate.v1.V1TranslateResponse.Data.Translation
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadParams
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadParams.Body
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadParams.Body.VaultConfirmUploadFailure
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadParams.Body.VaultConfirmUploadFailure.Success
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadParams.Body.VaultConfirmUploadSuccess
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadParams.Body.VaultConfirmUploadSuccess.Success
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadResponse
- hashCode() - function in dev.case.api.models.vault.VaultConfirmUploadResponse.Status
- hashCode() - function in dev.case.api.models.vault.VaultCreateParams
- hashCode() - function in dev.case.api.models.vault.VaultCreateParams.Body
- hashCode() - function in dev.case.api.models.vault.VaultCreateResponse
- hashCode() - function in dev.case.api.models.vault.VaultDeleteParams
- hashCode() - function in dev.case.api.models.vault.VaultDeleteResponse
- hashCode() - function in dev.case.api.models.vault.VaultDeleteResponse.DeletedVault
- hashCode() - function in dev.case.api.models.vault.VaultIngestParams
- hashCode() - function in dev.case.api.models.vault.VaultIngestResponse
- hashCode() - function in dev.case.api.models.vault.VaultIngestResponse.Status
- hashCode() - function in dev.case.api.models.vault.VaultListParams
- hashCode() - function in dev.case.api.models.vault.VaultListResponse
- hashCode() - function in dev.case.api.models.vault.VaultListResponse.Vault
- hashCode() - function in dev.case.api.models.vault.VaultRetrieveParams
- hashCode() - function in dev.case.api.models.vault.VaultRetrieveResponse
- hashCode() - function in dev.case.api.models.vault.VaultRetrieveResponse.ChunkStrategy
- hashCode() - function in dev.case.api.models.vault.VaultSearchParams
- hashCode() - function in dev.case.api.models.vault.VaultSearchParams.Body
- hashCode() - function in dev.case.api.models.vault.VaultSearchParams.Filters
- hashCode() - function in dev.case.api.models.vault.VaultSearchParams.Filters.ObjectId
- hashCode() - function in dev.case.api.models.vault.VaultSearchParams.Method
- hashCode() - function in dev.case.api.models.vault.VaultSearchResponse
- hashCode() - function in dev.case.api.models.vault.VaultSearchResponse.Chunk
- hashCode() - function in dev.case.api.models.vault.VaultSearchResponse.Source
- hashCode() - function in dev.case.api.models.vault.VaultUpdateParams
- hashCode() - function in dev.case.api.models.vault.VaultUpdateParams.Body
- hashCode() - function in dev.case.api.models.vault.VaultUpdateResponse
- hashCode() - function in dev.case.api.models.vault.VaultUploadParams
- hashCode() - function in dev.case.api.models.vault.VaultUploadParams.Body
- hashCode() - function in dev.case.api.models.vault.VaultUploadResponse
- hashCode() - function in dev.case.api.models.vault.VaultUploadResponse.Instructions
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionCreateParams
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionCreateParams.Body
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionDeleteParams
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionListParams
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionTestParams
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionTestParams.Body
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionTestParams.Payload
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionUpdateParams
- hashCode() - function in dev.case.api.models.vault.events.subscriptions.SubscriptionUpdateParams.Body
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragGetStatsParams
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragGetStatsResponse
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragGetStatsResponse.Status
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragInitParams
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragInitResponse
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragProcessObjectParams
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragProcessObjectResponse
- hashCode() - function in dev.case.api.models.vault.graphrag.GraphragProcessObjectResponse.Stats
- hashCode() - function in dev.case.api.models.vault.groups.GroupCreateParams
- hashCode() - function in dev.case.api.models.vault.groups.GroupDeleteParams
- hashCode() - function in dev.case.api.models.vault.groups.GroupListParams
- hashCode() - function in dev.case.api.models.vault.groups.GroupUpdateParams
- hashCode() - function in dev.case.api.models.vault.multipart.MultipartAbortParams
- hashCode() - function in dev.case.api.models.vault.multipart.MultipartAbortParams.Body
- hashCode() - function in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams
- hashCode() - function in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams.Body
- hashCode() - function in dev.case.api.models.vault.multipart.MultipartGetPartUrlsParams.Part
- hashCode() - function in dev.case.api.models.vault.multipart.MultipartGetPartUrlsResponse
- hashCode() - function in dev.case.api.models.vault.multipart.MultipartGetPartUrlsResponse.Url
- hashCode() - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlParams.Body
- hashCode() - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlParams.Operation
- hashCode() - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse
- hashCode() - function in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlResponse.Metadata
- hashCode() - function in dev.case.api.models.vault.objects.ObjectDeleteParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectDeleteParams.Force
- hashCode() - function in dev.case.api.models.vault.objects.ObjectDeleteResponse
- hashCode() - function in dev.case.api.models.vault.objects.ObjectDeleteResponse.DeletedObject
- hashCode() - function in dev.case.api.models.vault.objects.ObjectDownloadParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetOcrWordsParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetOcrWordsResponse
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetOcrWordsResponse.Page
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetOcrWordsResponse.Page.Word
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobResponse
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetSummarizeJobResponse.Status
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetTextParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetTextResponse
- hashCode() - function in dev.case.api.models.vault.objects.ObjectGetTextResponse.Metadata
- hashCode() - function in dev.case.api.models.vault.objects.ObjectListParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectListResponse
- hashCode() - function in dev.case.api.models.vault.objects.ObjectListResponse.Object
- hashCode() - function in dev.case.api.models.vault.objects.ObjectRetrieveParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectRetrieveResponse
- hashCode() - function in dev.case.api.models.vault.objects.ObjectUpdateParams
- hashCode() - function in dev.case.api.models.vault.objects.ObjectUpdateParams.Body
- hashCode() - function in dev.case.api.models.vault.objects.ObjectUpdateResponse
- hashCode() - function in dev.case.api.models.voice.streaming.StreamingGetUrlParams
- hashCode() - function in dev.case.api.models.voice.streaming.StreamingGetUrlResponse
- hashCode() - function in dev.case.api.models.voice.streaming.StreamingGetUrlResponse.AudioFormat
- hashCode() - function in dev.case.api.models.voice.streaming.StreamingGetUrlResponse.Pricing
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Body
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.BoostParam
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionCreateParams.Format
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionCreateResponse
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionCreateResponse.Status
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionDeleteParams
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionRetrieveParams
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionRetrieveResponse
- hashCode() - function in dev.case.api.models.voice.transcription.TranscriptionRetrieveResponse.Status
- hashCode() - function in dev.case.api.models.voice.v1.V1ListVoicesParams
- hashCode() - function in dev.case.api.models.voice.v1.V1ListVoicesParams.Sort
- hashCode() - function in dev.case.api.models.voice.v1.V1ListVoicesParams.SortDirection
- hashCode() - function in dev.case.api.models.voice.v1.V1ListVoicesParams.VoiceType
- hashCode() - function in dev.case.api.models.voice.v1.V1ListVoicesResponse
- hashCode() - function in dev.case.api.models.voice.v1.V1ListVoicesResponse.Voice
- hashCode() - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams
- hashCode() - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.Body
- hashCode() - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.ModelId
- hashCode() - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.OutputFormat
- hashCode() - function in dev.case.api.models.voice.v1.speak.SpeakCreateParams.VoiceSettings
- HEAD - enum entry in dev.case.api.core.http.HttpMethod
- HEAD - enum entry in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlParams.Operation.Known
- HEAD - enum entry in dev.case.api.models.vault.objects.ObjectCreatePresignedUrlParams.Operation.Value
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
- headers(java.util.Map) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
- headers(java.util.Map) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
- headers() - function in dev.case.api.core.ClientOptions
- Headers to send with the request.
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.core.ClientOptions.Builder
- headers(java.util.Map) - function in dev.case.api.core.ClientOptions.Builder
- Headers - class in dev.case.api.core.http
- headers() - function in dev.case.api.core.http.HttpRequest
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.core.http.HttpRequest.Builder
- headers(java.util.Map) - function in dev.case.api.core.http.HttpRequest.Builder
- headers() - function in dev.case.api.core.http.HttpResponse
- headers() - function in dev.case.api.core.http.HttpResponseFor
- headers() - function in dev.case.api.errors.BadRequestException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.BadRequestException.Builder
- headers() - function in dev.case.api.errors.CasedevServiceException
- headers() - function in dev.case.api.errors.InternalServerException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.InternalServerException.Builder
- headers() - function in dev.case.api.errors.NotFoundException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.NotFoundException.Builder
- headers() - function in dev.case.api.errors.PermissionDeniedException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.PermissionDeniedException.Builder
- headers() - function in dev.case.api.errors.RateLimitException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.RateLimitException.Builder
- headers() - function in dev.case.api.errors.UnauthorizedException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.UnauthorizedException.Builder
- headers() - function in dev.case.api.errors.UnexpectedStatusCodeException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.UnexpectedStatusCodeException.Builder
- headers() - function in dev.case.api.errors.UnprocessableEntityException
- headers(dev.case.api.core.http.Headers) - function in dev.case.api.errors.UnprocessableEntityException.Builder
- headers(dev.case.api.core.JsonValue) - function in dev.case.api.models.vault.VaultUploadResponse.Instructions.Builder
- Headers.Builder - class in dev.case.api.core.http.Headers
- height() - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Field.Options
- Image height in pixels
- height(dev.case.api.core.JsonField) - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Field.Options.Builder
- Sets Builder.height to an arbitrary JSON value.
- height(java.lang.Double) - function in dev.case.api.models.superdoc.v1.V1AnnotateParams.Field.Options.Builder
- Image height in pixels
- HEURISTIC - enum entry in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.VerificationSource.Known
- HEURISTIC - enum entry in dev.case.api.models.legal.v1.V1VerifyResponse.Citation.VerificationSource.Value
- HIGH - enum entry in dev.case.api.models.voice.transcription.TranscriptionCreateParams.BoostParam.Known
- HIGH - enum entry in dev.case.api.models.voice.transcription.TranscriptionCreateParams.BoostParam.Value
- highlightQuery() - function in dev.case.api.models.legal.v1.V1GetFullTextParams
- Optional query to extract relevant highlights (e.g., "What is the holding?
- highlightQuery() - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Body
- Optional query to extract relevant highlights (e.g., "What is the holding?
- highlightQuery(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Body.Builder
- Sets Builder.highlightQuery to an arbitrary JSON value.
- highlightQuery(java.lang.String) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Body.Builder
- Optional query to extract relevant highlights (e.g., "What is the holding?
- highlightQuery(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Builder
- Sets Builder.highlightQuery to an arbitrary JSON value.
- highlightQuery(java.lang.String) - function in dev.case.api.models.legal.v1.V1GetFullTextParams.Builder
- Optional query to extract relevant highlights (e.g., "What is the holding?
- highlights() - function in dev.case.api.models.legal.v1.V1GetFullTextResponse
- Highlighted relevant passages
- highlights(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1GetFullTextResponse.Builder
- Sets Builder.highlights to an arbitrary JSON value.
- highlights(java.util.List) - function in dev.case.api.models.legal.v1.V1GetFullTextResponse.Builder
- Highlighted relevant passages
- highlights() - function in dev.case.api.models.legal.v1.V1ResearchResponse.Candidate
- Highlighted relevant passages
- highlights(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Candidate.Builder
- Sets Builder.highlights to an arbitrary JSON value.
- highlights(java.util.List) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Candidate.Builder
- Highlighted relevant passages
- highlights() - function in dev.case.api.models.search.v1.V1ContentsParams
- Whether to include content highlights
- highlights() - function in dev.case.api.models.search.v1.V1ContentsParams.Body
- Whether to include content highlights
- highlights(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1ContentsParams.Body.Builder
- Sets Builder.highlights to an arbitrary JSON value.
- highlights(java.lang.Boolean) - function in dev.case.api.models.search.v1.V1ContentsParams.Body.Builder
- Whether to include content highlights
- highlights(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1ContentsParams.Builder
- Sets Builder.highlights to an arbitrary JSON value.
- highlights(java.lang.Boolean) - function in dev.case.api.models.search.v1.V1ContentsParams.Builder
- Whether to include content highlights
- highlights() - function in dev.case.api.models.search.v1.V1ContentsResponse.Result
- Content highlights if requested
- highlights(dev.case.api.core.JsonField) - function in dev.case.api.models.search.v1.V1ContentsResponse.Result.Builder
- Sets Builder.highlights to an arbitrary JSON value.
- highlights(java.util.List) - function in dev.case.api.models.search.v1.V1ContentsResponse.Result.Builder
- Content highlights if requested
- hint() - function in dev.case.api.models.legal.v1.V1FindResponse
- Usage guidance
- hint(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1FindResponse.Builder
- Sets Builder.hint to an arbitrary JSON value.
- hint(java.lang.String) - function in dev.case.api.models.legal.v1.V1FindResponse.Builder
- Usage guidance
- hint() - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse
- Usage guidance
- hint(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse.Builder
- Sets Builder.hint to an arbitrary JSON value.
- hint(java.lang.String) - function in dev.case.api.models.legal.v1.V1GetCitationsFromUrlResponse.Builder
- Usage guidance
- hint() - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse
- Usage guidance
- hint(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Builder
- Sets Builder.hint to an arbitrary JSON value.
- hint(java.lang.String) - function in dev.case.api.models.legal.v1.V1ListJurisdictionsResponse.Builder
- Usage guidance
- hint() - function in dev.case.api.models.legal.v1.V1ResearchResponse
- Usage guidance
- hint(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Builder
- Sets Builder.hint to an arbitrary JSON value.
- hint(java.lang.String) - function in dev.case.api.models.legal.v1.V1ResearchResponse.Builder
- Usage guidance
- hint() - function in dev.case.api.models.legal.v1.V1SimilarResponse
- Usage guidance
- hint(dev.case.api.core.JsonField) - function in dev.case.api.models.legal.v1.V1SimilarResponse.Builder
- Sets Builder.hint to an arbitrary JSON value.
- hint(java.lang.String) - function in dev.case.api.models.legal.v1.V1SimilarResponse.Builder
- Usage guidance
- host() - function in dev.case.api.models.compute.v1.instances.InstanceRetrieveResponse.Ssh
- host(dev.case.api.core.JsonField) - function in dev.case.api.models.compute.v1.instances.InstanceRetrieveResponse.Ssh.Builder
- Sets Builder.host to an arbitrary JSON value.
- host(java.lang.String) - function in dev.case.api.models.compute.v1.instances.InstanceRetrieveResponse.Ssh.Builder
- hostnameVerifier(java.util.Optional) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
- Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null). - hostnameVerifier(javax.net.ssl.HostnameVerifier) - function in dev.case.api.client.okhttp.CasedevOkHttpClient.Builder
- The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
- hostnameVerifier(java.util.Optional) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
- Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null). - hostnameVerifier(javax.net.ssl.HostnameVerifier) - function in dev.case.api.client.okhttp.CasedevOkHttpClientAsync.Builder
- The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
- hostnameVerifier(javax.net.ssl.HostnameVerifier) - function in dev.case.api.client.okhttp.OkHttpClient.Builder
- href() - function in dev.case.api.models.system.SystemListServicesResponse.Service
- href(dev.case.api.core.JsonField) - function in dev.case.api.models.system.SystemListServicesResponse.Service.Builder
- Sets Builder.href to an arbitrary JSON value.
- href(java.lang.String) - function in dev.case.api.models.system.SystemListServicesResponse.Service.Builder
- HTML - enum entry in dev.case.api.models.superdoc.v1.V1ConvertParams.From.Known
- HTML - enum entry in dev.case.api.models.superdoc.v1.V1ConvertParams.From.Value
- HTML - enum entry in dev.case.api.models.translate.v1.V1TranslateParams.Format.Known
- HTML - enum entry in dev.case.api.models.translate.v1.V1TranslateParams.Format.Value
- HTML_PREVIEW - enum entry in dev.case.api.models.format.v1.V1CreateDocumentParams.OutputFormat.Known
- HTML_PREVIEW - enum entry in dev.case.api.models.format.v1.V1CreateDocumentParams.OutputFormat.Value
- httpClient() - function in dev.case.api.core.ClientOptions
- The HTTP client to use in the SDK.
- httpClient(dev.case.api.core.http.HttpClient) - function in dev.case.api.core.ClientOptions.Builder
- The HTTP client to use in the SDK.
- HttpClient - class in dev.case.api.core.http
- httpClient(dev.case.api.core.http.HttpClient) - function in dev.case.api.core.http.RetryingHttpClient.Builder
- HttpMethod - class in dev.case.api.core.http
- HttpRequest - class in dev.case.api.core.http
- HttpRequest.Builder - class in dev.case.api.core.http.HttpRequest
- HttpRequestBody - class in dev.case.api.core.http
- HttpResponse - class in dev.case.api.core.http
- HttpResponse.Handler - class in dev.case.api.core.http.HttpResponse
- HttpResponseFor - class in dev.case.api.core.http
- HYBRID - enum entry in dev.case.api.models.vault.VaultSearchParams.Method.Known
- HYBRID - enum entry in dev.case.api.models.vault.VaultSearchParams.Method.Value